@@ -131,14 +131,14 @@ INLINE void arm7_cpu_write32(arm_state *cpustate, UINT32 addr, UINT32 data)
 {
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
     addr &= ~3;
 	if ( cpustate->endian == ENDIANNESS_BIG )
-		memory_write_dword_32be(cpustate->program, addr, data);
+		cpustate->program->write_dword(addr, data);
 	else
-	    memory_write_dword_32le(cpustate->program, addr, data);
+	    cpustate->program->write_dword(addr, data);
 }
 
 
@@ -146,27 +146,27 @@ INLINE void arm7_cpu_write16(arm_state *cpustate, UINT32 addr, UINT16 data)
 {
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
     addr &= ~1;
 	if ( cpustate->endian == ENDIANNESS_BIG )
-		memory_write_word_32be(cpustate->program, addr, data);
+		cpustate->program->write_word(addr, data);
 	else
-		memory_write_word_32le(cpustate->program, addr, data);
+		cpustate->program->write_word(addr, data);
 }
 
 INLINE void arm7_cpu_write8(arm_state *cpustate, UINT32 addr, UINT8 data)
 {
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
 	if ( cpustate->endian == ENDIANNESS_BIG )
-		memory_write_byte_32be(cpustate->program, addr, data);
+		cpustate->program->write_byte(addr, data);
 	else
-		memory_write_byte_32le(cpustate->program, addr, data);
+		cpustate->program->write_byte(addr, data);
 }
 
 INLINE UINT32 arm7_cpu_read32(arm_state *cpustate, offs_t addr)
@@ -175,23 +175,23 @@ INLINE UINT32 arm7_cpu_read32(arm_state *cpustate, offs_t addr)
 
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
     if (addr & 3)
     {
 		if ( cpustate->endian == ENDIANNESS_BIG )
-			result = memory_read_dword_32be(cpustate->program, addr & ~3);
+			result = cpustate->program->read_dword(addr & ~3);
 		else
-			result = memory_read_dword_32le(cpustate->program, addr & ~3);
+			result = cpustate->program->read_dword(addr & ~3);
         result = (result >> (8 * (addr & 3))) | (result << (32 - (8 * (addr & 3))));
     }
     else
     {
 		if ( cpustate->endian == ENDIANNESS_BIG )
-			result = memory_read_dword_32be(cpustate->program, addr);
+			result = cpustate->program->read_dword(addr);
 		else
-			result = memory_read_dword_32le(cpustate->program, addr);
+			result = cpustate->program->read_dword(addr);
     }
 
     return result;
@@ -203,13 +203,13 @@ INLINE UINT16 arm7_cpu_read16(arm_state *cpustate, offs_t addr)
 
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
 	if ( cpustate->endian == ENDIANNESS_BIG )
-		result = memory_read_word_32be(cpustate->program, addr & ~1);
+		result = cpustate->program->read_word(addr & ~1);
 	else
-		result = memory_read_word_32le(cpustate->program, addr & ~1);
+		result = cpustate->program->read_word(addr & ~1);
 
     if (addr & 1)
     {
@@ -223,14 +223,14 @@ INLINE UINT8 arm7_cpu_read8(arm_state *cpustate, offs_t addr)
 {
     if( COPRO_CTRL & COPRO_CTRL_MMU_EN )
     {
-        addr = arm7_tlb_translate( cpustate, addr );
+        addr = arm7_tlb_translate( cpustate, addr, ARM7_TLB_ABORT_D );
     }
 
     // Handle through normal 8 bit handler (for 32 bit cpu)
 	if ( cpustate->endian == ENDIANNESS_BIG )
-		return memory_read_byte_32be(cpustate->program, addr);
+		return cpustate->program->read_byte(addr);
 	else
-		return memory_read_byte_32le(cpustate->program, addr);
+		return cpustate->program->read_byte(addr);
 }
 
 /***************
@@ -460,6 +460,7 @@ static UINT32 decodeShift(arm_state *cpustate, UINT32 insn, UINT32 *pCarry)
 static int loadInc(arm_state *cpustate, UINT32 pat, UINT32 rbv, UINT32 s)
 {
     int i, result;
+    UINT32 data;
 
     result = 0;
     rbv &= ~3;
@@ -467,13 +468,20 @@ static int loadInc(arm_state *cpustate, UINT32 pat, UINT32 rbv, UINT32 s)
     {
         if ((pat >> i) & 1)
         {
+            data = READ32(rbv += 4);
+            if (cpustate->pendingAbtD != 0) break;
             if (i == 15) {
                 if (s) /* Pull full contents from stack */
-                    SET_REGISTER(cpustate, 15, READ32(rbv += 4));
+                    SET_REGISTER(cpustate, 15, data);
                 else /* Pull only address, preserve mode & status flags */
-                    SET_REGISTER(cpustate, 15, READ32(rbv += 4));
+                	if (MODE32)
+                    	SET_REGISTER(cpustate, 15, data);
+                    else
+                    {
+                    	SET_REGISTER(cpustate, 15, (GET_REGISTER(cpustate, 15) & ~0x03FFFFFC) | (data & 0x03FFFFFC));
+                    }
             } else
-                SET_REGISTER(cpustate, i, READ32(rbv += 4));
+                SET_REGISTER(cpustate, i, data);
 
             result++;
         }
@@ -484,6 +492,7 @@ static int loadInc(arm_state *cpustate, UINT32 pat, UINT32 rbv, UINT32 s)
 static int loadDec(arm_state *cpustate, UINT32 pat, UINT32 rbv, UINT32 s)
 {
     int i, result;
+    UINT32 data;
 
     result = 0;
     rbv &= ~3;
@@ -491,14 +500,21 @@ static int loadDec(arm_state *cpustate, UINT32 pat, UINT32 rbv, UINT32 s)
     {
         if ((pat >> i) & 1)
         {
+            data = READ32(rbv -= 4);
+            if (cpustate->pendingAbtD != 0) break;
             if (i == 15) {
                 if (s) /* Pull full contents from stack */
-                    SET_REGISTER(cpustate, 15, READ32(rbv -= 4));
+                    SET_REGISTER(cpustate, 15, data);
                 else /* Pull only address, preserve mode & status flags */
-                    SET_REGISTER(cpustate, 15, READ32(rbv -= 4));
+                	if (MODE32)
+                    	SET_REGISTER(cpustate, 15, data);
+                    else
+                    {
+                    	SET_REGISTER(cpustate, 15, (GET_REGISTER(cpustate, 15) & ~0x03FFFFFC) | (data & 0x03FFFFFC));
+                    }
             }
             else
-                SET_REGISTER(cpustate, i, READ32(rbv -= 4));
+                SET_REGISTER(cpustate, i, data);
             result++;
         }
     }
@@ -550,7 +566,7 @@ static int storeDec(arm_state *cpustate, UINT32 pat, UINT32 rbv)
  ***************************************************************************/
 
 // CPU INIT
-static void arm7_core_init(running_device *device, const char *cpuname)
+static void arm7_core_init(device_t *device, const char *cpuname)
 {
     arm_state *cpustate = get_safe_token(device);
 
@@ -575,10 +591,11 @@ static void arm7_core_reset(legacy_cpu_device *device)
     cpustate->device = device;
     cpustate->program = device->space(AS_PROGRAM);
 	cpustate->endian = ENDIANNESS_LITTLE;
+	cpustate->direct = &cpustate->program->direct();
 
     /* start up in SVC mode with interrupts disabled. */
+    ARM7REG(eCPSR) = I_MASK | F_MASK | 0x10;
     SwitchMode(cpustate, eARM7_MODE_SVC);
-    SET_CPSR(GET_CPSR | I_MASK | F_MASK | 0x10);
     R15 = 0;
 }
 
@@ -604,58 +621,85 @@ static void arm7_check_irq_state(arm_state *cpustate)
 
     // Data Abort
     if (cpustate->pendingAbtD) {
+    	if (MODE26) fatalerror( "pendingAbtD (todo)");
         SwitchMode(cpustate, eARM7_MODE_ABT);             /* Set ABT mode so PC is saved to correct R14 bank */
-        SET_REGISTER(cpustate, 14, pc);                   /* save PC to R14 */
+        SET_REGISTER(cpustate, 14, pc - 8 + 8);                   /* save PC to R14 */
         SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
         SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
         SET_CPSR(GET_CPSR & ~T_MASK);
         R15 = 0x10;                             /* IRQ Vector address */
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         cpustate->pendingAbtD = 0;
         return;
     }
 
     // FIQ
     if (cpustate->pendingFiq && (cpsr & F_MASK) == 0) {
+    	if (MODE26) fatalerror( "pendingFiq (todo)");
         SwitchMode(cpustate, eARM7_MODE_FIQ);             /* Set FIQ mode so PC is saved to correct R14 bank */
-        SET_REGISTER(cpustate, 14, pc);                   /* save PC to R14 */
+        SET_REGISTER(cpustate, 14, pc - 4 + 4);                   /* save PC to R14 */
         SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
         SET_CPSR(GET_CPSR | I_MASK | F_MASK);   /* Mask both IRQ & FIQ */
         SET_CPSR(GET_CPSR & ~T_MASK);
         R15 = 0x1c;                             /* IRQ Vector address */
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         return;
     }
 
     // IRQ
     if (cpustate->pendingIrq && (cpsr & I_MASK) == 0) {
         SwitchMode(cpustate, eARM7_MODE_IRQ);             /* Set IRQ mode so PC is saved to correct R14 bank */
-        SET_REGISTER(cpustate, 14, pc);                   /* save PC to R14 */
-        SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
-        SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
-        SET_CPSR(GET_CPSR & ~T_MASK);
-        R15 = 0x18;                             /* IRQ Vector address */
+    	SET_REGISTER(cpustate, 14, pc - 4 + 4);                   /* save PC to R14 */
+        if (MODE32)
+        {
+        	SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
+        	SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
+        	SET_CPSR(GET_CPSR & ~T_MASK);
+        	R15 = 0x18;                             /* IRQ Vector address */
+        }
+        else
+        {
+        	UINT32 temp;
+        	R15 = (pc & 0xF4000000) /* N Z C V F */ | 0x18 | 0x00000002 /* IRQ */ | 0x08000000 /* I */;
+        	temp = (GET_CPSR & 0x0FFFFF3F) /* N Z C V I F */ | (R15 & 0xF0000000) /* N Z C V */ | ((R15 & 0x0C000000) >> (26 - 6)) /* I F */;
+        	SET_CPSR(temp);            /* Mask IRQ */
+        }
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         return;
     }
 
     // Prefetch Abort
     if (cpustate->pendingAbtP) {
+    	if (MODE26) fatalerror( "pendingAbtP (todo)");
         SwitchMode(cpustate, eARM7_MODE_ABT);             /* Set ABT mode so PC is saved to correct R14 bank */
-        SET_REGISTER(cpustate, 14, pc);                   /* save PC to R14 */
+        SET_REGISTER(cpustate, 14, pc - 4 + 4);                   /* save PC to R14 */
         SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
         SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
         SET_CPSR(GET_CPSR & ~T_MASK);
         R15 = 0x0c;                             /* IRQ Vector address */
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         cpustate->pendingAbtP = 0;
         return;
     }
 
     // Undefined instruction
     if (cpustate->pendingUnd) {
+    	if (MODE26) fatalerror( "pendingUnd (todo)");
         SwitchMode(cpustate, eARM7_MODE_UND);             /* Set UND mode so PC is saved to correct R14 bank */
-        SET_REGISTER(cpustate, 14, pc);                   /* save PC to R14 */
+        // compensate for prefetch (should this also be done for normal IRQ?)
+        if (T_IS_SET(GET_CPSR))
+        {
+                SET_REGISTER(cpustate, 14, pc - 4 + 2);         /* save PC to R14 */
+        }
+        else
+        {
+                SET_REGISTER(cpustate, 14, pc - 4 + 4 - 4);           /* save PC to R14 */
+        }
         SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
         SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
         SET_CPSR(GET_CPSR & ~T_MASK);
         R15 = 0x04;                             /* IRQ Vector address */
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         cpustate->pendingUnd = 0;
         return;
     }
@@ -666,16 +710,28 @@ static void arm7_check_irq_state(arm_state *cpustate)
         // compensate for prefetch (should this also be done for normal IRQ?)
         if (T_IS_SET(GET_CPSR))
         {
-                SET_REGISTER(cpustate, 14, pc-2);         /* save PC to R14 */
+                SET_REGISTER(cpustate, 14, pc - 4 + 2);         /* save PC to R14 */
         }
         else
         {
-                SET_REGISTER(cpustate, 14, pc);           /* save PC to R14 */
+                SET_REGISTER(cpustate, 14, pc - 4 + 4);           /* save PC to R14 */
         }
-        SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
-        SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
-        SET_CPSR(GET_CPSR & ~T_MASK);           /* Go to ARM mode */
-        R15 = 0x08;                             /* Jump to the SWI vector */
+        if (MODE32)
+        {
+        	SET_REGISTER(cpustate, SPSR, cpsr);               /* Save current CPSR */
+        	SET_CPSR(GET_CPSR | I_MASK);            /* Mask IRQ */
+        	SET_CPSR(GET_CPSR & ~T_MASK);           /* Go to ARM mode */
+        	R15 = 0x08;                             /* Jump to the SWI vector */
+        }
+        else
+        {
+        	UINT32 temp;
+        	R15 = (pc & 0xF4000000) /* N Z C V F */ | 0x08 | 0x00000003 /* SVC */ | 0x08000000 /* I */;
+        	temp = (GET_CPSR & 0x0FFFFF3F) /* N Z C V I F */ | (R15 & 0xF0000000) /* N Z C V */ | ((R15 & 0x0C000000) >> (26 - 6)) /* I F */;
+        	SET_CPSR(temp);            /* Mask IRQ */
+        }
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
+        if ((COPRO_CTRL & COPRO_CTRL_MMU_EN) && (COPRO_CTRL & COPRO_CTRL_INTVEC_ADJUST)) R15 |= 0xFFFF0000;
         cpustate->pendingSwi = 0;
         return;
     }
@@ -743,7 +799,7 @@ static void HandleCoProcRT(arm_state *cpustate, UINT32 insn)
     // Store (MCR) data from ARM7 to Co-Proc register
     else
     {
-        if (arm7_coproc_rt_r_callback)
+        if (arm7_coproc_rt_w_callback)
             arm7_coproc_rt_w_callback(cpustate->device, insn, GET_REGISTER(cpustate, (insn >> 12) & 0xf), 0);
         else
             LOG(("%08x: Co-Processor Register Transfer executed, but no RT Write callback defined!\n", R15));
@@ -826,17 +882,23 @@ INLINE void HandleBranch(arm_state *cpustate, UINT32 insn)
     /* Sign-extend the 24-bit offset in our calculations */
     if (off & 0x2000000u)
     {
-        R15 -= ((~(off | 0xfc000000u)) + 1) - 8;
+    	if (MODE32)
+        	R15 -= ((~(off | 0xfc000000u)) + 1) - 8;
+        else
+        	R15 = ((R15 - (((~(off | 0xfc000000u)) + 1) - 8)) & 0x03FFFFFC) | (R15 & ~0x03FFFFFC);
     }
     else
     {
-        R15 += off + 8;
+    	if (MODE32)
+	        R15 += off + 8;
+        else
+        	R15 = ((R15 + (off + 8)) & 0x03FFFFFC) | (R15 & ~0x03FFFFFC);
     }
 }
 
 static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
 {
-    UINT32 rn, rnv, off, rd;
+    UINT32 rn, rnv, off, rd, rnv_old = 0;
 
     /* Fetch the offset */
     if (insn & INSN_I)
@@ -858,15 +920,22 @@ static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
         /* Pre-indexed addressing */
         if (insn & INSN_SDT_U)
         {
-            rnv = (GET_REGISTER(cpustate, rn) + off);
+        	if ((MODE32) || (rn != eR15))
+            	rnv = (GET_REGISTER(cpustate, rn) + off);
+            else
+            	rnv = (GET_PC + off);
         }
         else
         {
-            rnv = (GET_REGISTER(cpustate, rn) - off);
+        	if ((MODE32) || (rn != eR15))
+	            rnv = (GET_REGISTER(cpustate, rn) - off);
+			else
+	            rnv = (GET_PC - off);
         }
 
         if (insn & INSN_SDT_W)
         {
+            rnv_old = GET_REGISTER(cpustate, rn);
             SET_REGISTER(cpustate, rn, rnv);
 
     // check writeback???
@@ -881,7 +950,10 @@ static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
         /* Post-indexed addressing */
         if (rn == eR15)
         {
-            rnv = R15 + 8;
+        	if (MODE32)
+	            rnv = R15 + 8;
+	        else
+	            rnv = GET_PC + 8;
         }
         else
         {
@@ -896,20 +968,30 @@ static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
         /* Load */
         if (insn & INSN_SDT_B)
         {
-            SET_REGISTER(cpustate, rd, (UINT32)READ8(rnv));
+            UINT32 data = READ8(rnv);
+            if (cpustate->pendingAbtD == 0)
+            {
+                SET_REGISTER(cpustate, rd, data);
+            }
         }
         else
         {
-            if (rd == eR15)
+            UINT32 data = READ32(rnv);
+            if (cpustate->pendingAbtD == 0)
             {
-                R15 = READ32(rnv);
-                R15 -= 4;
-                // LDR, PC takes 2S + 2N + 1I (5 total cycles)
-                ARM7_ICOUNT -= 2;
-            }
-            else
-            {
-                SET_REGISTER(cpustate, rd, READ32(rnv));
+                if (rd == eR15)
+                {
+                	if (MODE32)
+	            		R15 = data - 4;
+			        else
+			        	R15 = (R15 & ~0x03FFFFFC) /* N Z C V I F M1 M0 */ | ((data - 4) & 0x03FFFFFC);
+        	    // LDR, PC takes 2S + 2N + 1I (5 total cycles)
+                    ARM7_ICOUNT -= 2;
+                }
+                else
+                {
+                    SET_REGISTER(cpustate, rd, data);
+                }
             }
         }
     }
@@ -939,6 +1021,16 @@ static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
         ARM7_ICOUNT += 1;
     }
 
+	if (cpustate->pendingAbtD != 0)
+	{
+		if ((insn & INSN_SDT_P) && (insn & INSN_SDT_W))
+		{
+			SET_REGISTER(cpustate, rn, rnv_old);
+		}
+	}
+	else
+	{
+
     /* Do post-indexing writeback */
     if (!(insn & INSN_SDT_P)/* && (insn & INSN_SDT_W)*/)
     {
@@ -974,13 +1066,15 @@ static void HandleMemSingle(arm_state *cpustate, UINT32 insn)
         }
     }
 
+	}
+
 //  ARM7_CHECKIRQ
 
 } /* HandleMemSingle */
 
 static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
 {
-    UINT32 rn, rnv, off, rd;
+    UINT32 rn, rnv, off, rd, rnv_old = 0;
 
     // Immediate or Register Offset?
     if (insn & 0x400000) {               // Bit 22 - 1 = immediate, 0 = register
@@ -1009,6 +1103,7 @@ static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
 
         if (insn & INSN_SDT_W)
         {
+            rnv_old = GET_REGISTER(cpustate, rn);
             SET_REGISTER(cpustate, rn, rnv);
 
         // check writeback???
@@ -1058,6 +1153,9 @@ static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
                 newval = (UINT32)(signbyte << 8)|databyte;
             }
 
+			if (cpustate->pendingAbtD == 0)
+			{
+
             // PC?
             if (rd == eR15)
             {
@@ -1071,19 +1169,38 @@ static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
                 SET_REGISTER(cpustate, rd, newval);
                 R15 += 4;
             }
+
+            }
+            else
+            {
+                R15 += 4;
+            }
+
         }
         // Unsigned Half Word
         else
         {
+			UINT32 newval = READ16(rnv);
+
+			if (cpustate->pendingAbtD == 0)
+			{
+
             if (rd == eR15)
             {
-                R15 = READ16(rnv) + 8;
+                R15 = newval + 8;
             }
             else
             {
-                SET_REGISTER(cpustate, rd, READ16(rnv));
+                SET_REGISTER(cpustate, rd, newval);
                 R15 += 4;
             }
+
+            }
+            else
+            {
+                R15 += 4;
+            }
+
         }
 
 
@@ -1107,14 +1224,27 @@ static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
 	{
 	        // WRITE16(rnv, rd == eR15 ? R15 + 8 : GET_REGISTER(cpustate, rd));
 	        WRITE16(rnv, rd == eR15 ? R15 + 8 + 4 : GET_REGISTER(cpustate, rd)); // manual says STR RD=PC, +12 of address
+
+// if R15 is not increased then e.g. "STRH R10, [R15,#$10]" will be executed over and over again
+#if 0
 	        if (rn != eR15)
+#endif
 	            R15 += 4;
+
 	        // STRH takes 2 cycles, so we add + 1
 	        ARM7_ICOUNT += 1;
 	}
     }
 
-
+	if (cpustate->pendingAbtD != 0)
+	{
+		if ((insn & INSN_SDT_P) && (insn & INSN_SDT_W))
+		{
+			SET_REGISTER(cpustate, rn, rnv_old);
+		}
+	}
+	else
+	{
 
     // SJE: No idea if this writeback code works or makes sense here..
 
@@ -1152,6 +1282,9 @@ static void HandleHalfWordDT(arm_state *cpustate, UINT32 insn)
             }
         }
     }
+
+    }
+
 }
 
 static void HandleSwap(arm_state *cpustate, UINT32 insn)
@@ -1263,11 +1396,16 @@ static void HandlePSRTransfer(arm_state *cpustate, UINT32 insn)
             }
         }
 
+#if 0
         // force valid mode
         newval |= 0x10;
+#endif
 
         // Update the Register
-        SET_REGISTER(cpustate, reg, newval);
+        if (reg == eCPSR)
+        	SET_CPSR(newval);
+        else
+        	SET_REGISTER(cpustate, reg, newval);
 
         // Switch to new mode if changed
         if ((newval & MODE_FLAG) != oldmode)
@@ -1329,7 +1467,10 @@ static void HandleALU(arm_state *cpustate, UINT32 insn)
 #if ARM7_DEBUG_CORE
             LOG(("%08x:  Pipelined R15 (Shift %d)\n", R15, (insn & INSN_I ? 8 : insn & 0x10u ? 12 : 12)));
 #endif
-            rn = R15 + 8;
+			if (MODE32)
+            	rn = R15 + 8;
+            else
+            	rn = GET_PC + 8;
         }
         else
         {
@@ -1405,19 +1546,45 @@ static void HandleALU(arm_state *cpustate, UINT32 insn)
         // If Rd = R15, but S Flag not set, Result is placed in R15, but CPSR is not affected (page 44)
         if (rdn == eR15 && !(insn & INSN_S))
         {
-            R15 = rd;
+			if (MODE32)
+			{
+	            R15 = rd;
+	        }
+	        else
+	        {
+	            R15 = (R15 & ~0x03FFFFFC) | (rd & 0x03FFFFFC);
+	        }
         }
         else
         {
             // Rd = 15 and S Flag IS set, Result is placed in R15, and current mode SPSR moved to CPSR
             if (rdn == eR15) {
 
-                // Update CPSR from SPSR
-                SET_CPSR(GET_REGISTER(cpustate, SPSR));
-                SwitchMode(cpustate, GET_MODE);
+				if (MODE32)
+				{
+				// When Rd is R15 and the S flag is set the result of the operation is placed in R15 and the SPSR corresponding to
+				// the current mode is moved to the CPSR. This allows state changes which automatically restore both PC and
+				// CPSR. --> This form of instruction should not be used in User mode. <--
+
+				if (GET_MODE != eARM7_MODE_USER)
+				{
+	                // Update CPSR from SPSR
+    	            SET_CPSR(GET_REGISTER(cpustate, SPSR));
+        	        SwitchMode(cpustate, GET_MODE);
+            	}
 
                 R15 = rd;
 
+                }
+                else
+                {
+	            	UINT32 temp;
+					R15 = rd; //(R15 & 0x03FFFFFC) | (rd & 0xFC000003);
+					temp = (GET_CPSR & 0x0FFFFF20) | (rd & 0xF0000000) /* N Z C V */ | ((rd & 0x0C000000) >> (26 - 6)) /* I F */ | (rd & 0x00000003) /* M1 M0 */;
+					SET_CPSR( temp);
+					SwitchMode( cpustate, temp & 3);
+                }
+
                 /* IRQ masks may have changed in this instruction */
 //              ARM7_CHECKIRQ;
             }
@@ -1434,7 +1601,16 @@ static void HandleALU(arm_state *cpustate, UINT32 insn)
 #if ARM7_DEBUG_CORE
                 LOG(("%08x: TST class on R15 s bit set\n", R15));
 #endif
-            R15 = rd;
+			if (MODE32)
+            	R15 = rd;
+            else
+            {
+            	UINT32 temp;
+				R15 = (R15 & 0x03FFFFFC) | (rd & ~0x03FFFFFC);
+				temp = (GET_CPSR & 0x0FFFFF20) | (rd & 0xF0000000) /* N Z C V */ | ((rd & 0x0C000000) >> (26 - 6)) /* I F */ | (rd & 0x00000003) /* M1 M0 */;
+				SET_CPSR( temp);
+				SwitchMode( cpustate, temp & 3);
+			}
 
             /* IRQ masks may have changed in this instruction */
 //          ARM7_CHECKIRQ;
@@ -1566,9 +1742,6 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
         LOG(("%08x: Unaligned Mem Transfer @ %08x\n", R15, rbp));
 #endif
 
-    // We will specify the cycle count for each case, so remove the -3 that occurs at the end
-    ARM7_ICOUNT += 3;
-
     if (insn & INSN_BDT_L)
     {
         /* Loading */
@@ -1594,7 +1767,7 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             else
                 result = loadInc(cpustate, insn & 0xffff, rbp, insn & INSN_BDT_S);
 
-            if (insn & INSN_BDT_W)
+            if ((insn & INSN_BDT_W) && (cpustate->pendingAbtD == 0))
             {
 #if ARM7_DEBUG_CORE
                     if (rb == 15)
@@ -1604,16 +1777,28 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             }
 
             // R15 included? (NOTE: CPSR restore must occur LAST otherwise wrong registers restored!)
-            if (insn & 0x8000) {
+            if ((insn & 0x8000) && (cpustate->pendingAbtD == 0)) {
                 R15 -= 4;     // SJE: I forget why i did this?
                 // S - Flag Set? Signals transfer of current mode SPSR->CPSR
-                if (insn & INSN_BDT_S) {
-                    SET_CPSR(GET_REGISTER(cpustate, SPSR));
-                    SwitchMode(cpustate, GET_MODE);
+                if (insn & INSN_BDT_S)
+				{
+                	if (MODE32)
+                	{
+                    	SET_CPSR(GET_REGISTER(cpustate, SPSR));
+                    	SwitchMode(cpustate, GET_MODE);
+                    }
+                    else
+                    {
+                    	UINT32 temp;
+//                      LOG(("LDM + S | R15 %08X CPSR %08X\n", R15, GET_CPSR));
+						temp = (GET_CPSR & 0x0FFFFF20) | (R15 & 0xF0000000) /* N Z C V */ | ((R15 & 0x0C000000) >> (26 - 6)) /* I F */ | (R15 & 0x00000003) /* M1 M0 */;
+						SET_CPSR( temp);
+						SwitchMode(cpustate, temp & 3);
+                    }
                 }
+               // LDM PC - takes 1 extra cycle
+    	        ARM7_ICOUNT -= 1;
             }
-            // LDM PC - takes 1 extra cycle
-            ARM7_ICOUNT -= 1;
         }
         else
         {
@@ -1637,7 +1822,7 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             else
                 result = loadDec(cpustate, insn & 0xffff, rbp, insn & INSN_BDT_S);
 
-            if (insn & INSN_BDT_W)
+            if ((insn & INSN_BDT_W) && (cpustate->pendingAbtD == 0))
             {
                 if (rb == 0xf)
                     LOG(("%08x:  Illegal LDRM writeback to r15\n", R15));
@@ -1645,12 +1830,24 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             }
 
             // R15 included? (NOTE: CPSR restore must occur LAST otherwise wrong registers restored!)
-            if (insn & 0x8000) {
+            if ((insn & 0x8000) && (cpustate->pendingAbtD == 0)) {
                 R15 -= 4;     // SJE: I forget why i did this?
                 // S - Flag Set? Signals transfer of current mode SPSR->CPSR
-                if (insn & INSN_BDT_S) {
-                    SET_CPSR(GET_REGISTER(cpustate, SPSR));
-                    SwitchMode(cpustate, GET_MODE);
+                if (insn & INSN_BDT_S)
+				{
+                	if (MODE32)
+                	{
+	                    SET_CPSR(GET_REGISTER(cpustate, SPSR));
+    	                SwitchMode(cpustate, GET_MODE);
+                    }
+                    else
+                    {
+                    	UINT32 temp;
+//                      LOG(("LDM + S | R15 %08X CPSR %08X\n", R15, GET_CPSR));
+						temp = (GET_CPSR & 0x0FFFFF20) /* N Z C V I F M4 M3 M2 M1 M0 */ | (R15 & 0xF0000000) /* N Z C V */ | ((R15 & 0x0C000000) >> (26 - 6)) /* I F */ | (R15 & 0x00000003) /* M1 M0 */;
+						SET_CPSR( temp);
+						SwitchMode(cpustate, temp & 3);
+                    }
                 }
                 // LDM PC - takes 1 extra cycle
                 ARM7_ICOUNT -= 1;
@@ -1679,8 +1876,8 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
                 rbp = rbp + (- 4);
             }
 
-            // S Flag Set, but R15 not in list = User Bank Transfer
-            if (insn & INSN_BDT_S && (insn & 0x8000) == 0)
+            // S Flag Set = User Bank Transfer
+            if (insn & INSN_BDT_S)
             {
                 // todo: needs to be tested..
 
@@ -1695,7 +1892,7 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             else
                 result = storeInc(cpustate, insn & 0xffff, rbp);
 
-            if (insn & INSN_BDT_W)
+            if ((insn & INSN_BDT_W) && (cpustate->pendingAbtD == 0))
             {
                 SET_REGISTER(cpustate, rb, GET_REGISTER(cpustate, rb) + result * 4);
             }
@@ -1708,8 +1905,8 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
                 rbp = rbp - (-4);
             }
 
-            // S Flag Set, but R15 not in list = User Bank Transfer
-            if (insn & INSN_BDT_S && (insn & 0x8000) == 0)
+            // S Flag Set = User Bank Transfer
+            if (insn & INSN_BDT_S)
             {
                 // set to user mode - then do the transfer, and set back
                 int curmode = GET_MODE;
@@ -1722,7 +1919,7 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
             else
                 result = storeDec(cpustate, insn & 0xffff, rbp);
 
-            if (insn & INSN_BDT_W)
+            if ((insn & INSN_BDT_W) && (cpustate->pendingAbtD == 0))
             {
                 SET_REGISTER(cpustate, rb, GET_REGISTER(cpustate, rb) - result * 4);
             }
@@ -1733,4 +1930,8 @@ static void HandleMemBlock(arm_state *cpustate, UINT32 insn)
         // STM takes (n+1)S+2N+1I cycles (n = # of register transfers)
         ARM7_ICOUNT -= (result + 1) + 2 + 1;
     }
+
+    // We will specify the cycle count for each case, so remove the -3 that occurs at the end
+    ARM7_ICOUNT += 3;
+
 } /* HandleMemBlock */
