@@ -33,6 +33,7 @@
 #ifndef __ARM7CORE_H__
 #define __ARM7CORE_H__
 
+#define ARM7_MMU_ENABLE_HACK 0
 
 /****************************************************************************************************
  *  INTERRUPT LINES/EXCEPTIONS
@@ -136,10 +137,22 @@ enum
 #define COPRO_CTRL_INTVEC_F                 1
 #define COPRO_CTRL_MASK                     0x0000338f
 
+#define COPRO_DOMAIN_ACCESS_CONTROL     	cpustate->domainAccessControl
+
+#define COPRO_FAULT_STATUS      	cpustate->faultStatus
+
+#define COPRO_FAULT_ADDRESS     	cpustate->faultAddress
+
+#define COPRO_FCSE_PID      	cpustate->fcsePID
+
 /* Coprocessor Registers */
 #define ARM7COPRO_REGS \
     UINT32 control; \
-    UINT32 tlbBase;
+    UINT32 tlbBase; \
+    UINT32 faultStatus; \
+    UINT32 faultAddress; \
+    UINT32 fcsePID; \
+    UINT32 domainAccessControl;
 
 enum
 {
@@ -163,7 +176,8 @@ enum
 	endianness_t endian;				\
     device_irq_callback irq_callback;		\
     legacy_cpu_device *device;		\
-    const address_space *program;
+    address_space *program;			\
+    direct_read_data *direct;
 
 
 /* CPU state struct */
@@ -175,6 +189,9 @@ typedef struct
 	UINT8 archRev;			// ARM architecture revision (3, 4, and 5 are valid)
 	UINT8 archFlags;		// architecture flags
 
+#if ARM7_MMU_ENABLE_HACK
+	UINT32 mmu_enable_addr;	// workaround for "MMU is enabled when PA != VA" problem
+#endif
 } arm_state;
 
 /****************************************************************************************************
@@ -472,7 +489,7 @@ enum
 #define R15                     ARM7REG(eR15)
 #define SPSR                    17                     // SPSR is always the 18th register in our 0 based array sRegisterTable[][18]
 #define GET_CPSR                ARM7REG(eCPSR)
-#define SET_CPSR(v)             (GET_CPSR = (v))
+#define SET_CPSR(v)             set_cpsr(cpustate,v)
 #define MODE_FLAG               0xF                    // Mode bits are 4:0 of CPSR, but we ignore bit 4.
 #define GET_MODE                (GET_CPSR & MODE_FLAG)
 #define SIGN_BIT                ((UINT32)(1 << 31))
@@ -481,6 +498,17 @@ enum
 #define THUMB_SIGN_BIT               ((UINT32)(1 << 31))
 #define THUMB_SIGN_BITS_DIFFER(a, b) (((a)^(b)) >> 31)
 
+#define MODE32					(GET_CPSR & 0x10)
+#define MODE26					(!(GET_CPSR & 0x10))
+#define GET_PC                  (MODE32 ? R15 : R15 & 0x03FFFFFC)
+
+enum
+{
+	ARM7_TLB_NO_ABORT,
+	ARM7_TLB_ABORT_D,
+	ARM7_TLB_ABORT_P
+};
+
 /* At one point I thought these needed to be cpu implementation specific, but they don't.. */
 #define GET_REGISTER(state, reg)       GetRegister(state, reg)
 #define SET_REGISTER(state, reg, val)  SetRegister(state, reg, val)
