@@ -62,11 +62,12 @@ struct _konami_state
 	UINT8	nmi_pending;
 	int		icount;
 	legacy_cpu_device *device;
-	const address_space *program;
+	address_space *program;
+	direct_read_data *direct;
 	konami_set_lines_func setlines_callback;
 };
 
-INLINE konami_state *get_safe_token(running_device *device)
+INLINE konami_state *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
 	assert(device->type() == KONAMI);
@@ -118,10 +119,10 @@ INLINE konami_state *get_safe_token(running_device *device)
 #define KONAMI_SYNC		16	/* set when SYNC is waiting for an interrupt */
 #define KONAMI_LDS		32	/* set when LDS occured at least once */
 
-#define RM(cs,Addr)				memory_read_byte_8be((cs)->program, Addr)
-#define WM(cs,Addr,Value)		memory_write_byte_8be((cs)->program, Addr,Value)
-#define ROP(cs,Addr)			memory_decrypted_read_byte((cs)->program, Addr)
-#define ROP_ARG(cs,Addr)		memory_raw_read_byte((cs)->program, Addr)
+#define RM(cs,Addr)				(cs)->program->read_byte(Addr)
+#define WM(cs,Addr,Value)		(cs)->program->write_byte(Addr,Value)
+#define ROP(cs,Addr)			(cs)->direct->read_decrypted_byte(Addr)
+#define ROP_ARG(cs,Addr)		(cs)->direct->read_raw_byte(Addr)
 
 #define SIGNED(a)	(UINT16)(INT16)(INT8)(a)
 
@@ -404,6 +405,7 @@ static CPU_INIT( konami )
 	cpustate->irq_callback = irqcallback;
 	cpustate->device = device;
 	cpustate->program = device->space(AS_PROGRAM);
+	cpustate->direct = &cpustate->program->direct();
 
 	state_save_register_device_item(device, 0, PC);
 	state_save_register_device_item(device, 0, U);
@@ -500,7 +502,7 @@ static CPU_EXECUTE( konami )
 }
 
 
-void konami_configure_set_lines(running_device *device, konami_set_lines_func func)
+void konami_configure_set_lines(device_t *device, konami_set_lines_func func)
 {
 	konami_state *cpustate = get_safe_token(device);
 	cpustate->setlines_callback = func;
