@@ -74,11 +74,6 @@
 #include "debugger.h"
 #include "m6809.h"
 
-/* Enable big switch statement for the main opcodes */
-#ifndef BIG_SWITCH
-#define BIG_SWITCH  1
-#endif
-
 #define VERBOSE 0
 
 #define LOG(x)	do { if (VERBOSE) logerror x; } while (0)
@@ -105,13 +100,14 @@ struct _m68_state_t
 	PAIR	ea;			/* effective address */
 
 	/* Memory spaces */
-    const address_space *program;
+    address_space *program;
+    direct_read_data *direct;
 
 	UINT8	int_state;	/* SYNC and CWAI flags */
 	UINT8	nmi_state;
 };
 
-INLINE m68_state_t *get_safe_token(running_device *device)
+INLINE m68_state_t *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
 	assert(device->type() == M6809 ||
@@ -172,26 +168,26 @@ INLINE void fetch_effective_address( m68_state_t *m68_state );
 /****************************************************************************/
 /* Read a byte from given memory location                                   */
 /****************************************************************************/
-#define RM(Addr) ((unsigned)memory_read_byte_8be(m68_state->program, Addr))
+#define RM(Addr) ((unsigned)m68_state->program->read_byte(Addr))
 
 /****************************************************************************/
 /* Write a byte to given memory location                                    */
 /****************************************************************************/
-#define WM(Addr,Value) (memory_write_byte_8be(m68_state->program, Addr,Value))
+#define WM(Addr,Value) (m68_state->program->write_byte(Addr,Value))
 
 /****************************************************************************/
 /* Z80_RDOP() is identical to Z80_RDMEM() except it is used for reading     */
 /* opcodes. In case of system with memory mapped I/O, this function can be  */
 /* used to greatly speed up emulation                                       */
 /****************************************************************************/
-#define ROP(Addr) ((unsigned)memory_decrypted_read_byte(m68_state->program, Addr))
+#define ROP(Addr) ((unsigned)m68_state->direct->read_decrypted_byte(Addr))
 
 /****************************************************************************/
 /* Z80_RDOP_ARG() is identical to Z80_RDOP() except it is used for reading  */
 /* opcode arguments. This difference can be used to support systems that    */
 /* use different encoding mechanisms for opcodes and opcode arguments       */
 /****************************************************************************/
-#define ROP_ARG(Addr) ((unsigned)memory_raw_read_byte(m68_state->program, Addr))
+#define ROP_ARG(Addr) ((unsigned)m68_state->direct->read_raw_byte(Addr))
 
 /* macros to access memory */
 #define IMMBYTE(b)	b = ROP_ARG(PCD); PC++
@@ -383,6 +379,7 @@ static CPU_INIT( m6809 )
 	m68_state->device = device;
 
 	m68_state->program = device->space(AS_PROGRAM);
+	m68_state->direct = &m68_state->program->direct();
 
 	/* setup regtable */
 
@@ -506,270 +503,8 @@ static CPU_EXECUTE( m6809 )	/* NS 970908 */
 
 			m68_state->ireg = ROP(PCD);
 			PC++;
-#if BIG_SWITCH
-            switch( m68_state->ireg )
-			{
-			case 0x00: neg_di(m68_state);    break;
-			case 0x01: neg_di(m68_state);    break;	/* undocumented */
-			case 0x02: IIError(m68_state);   break;
-			case 0x03: com_di(m68_state);    break;
-			case 0x04: lsr_di(m68_state);    break;
-			case 0x05: IIError(m68_state);   break;
-			case 0x06: ror_di(m68_state);    break;
-			case 0x07: asr_di(m68_state);    break;
-			case 0x08: asl_di(m68_state);    break;
-			case 0x09: rol_di(m68_state);    break;
-			case 0x0a: dec_di(m68_state);    break;
-			case 0x0b: IIError(m68_state);   break;
-			case 0x0c: inc_di(m68_state);    break;
-			case 0x0d: tst_di(m68_state);    break;
-			case 0x0e: jmp_di(m68_state);    break;
-			case 0x0f: clr_di(m68_state);    break;
-			case 0x10: pref10(m68_state);					 break;
-			case 0x11: pref11(m68_state);					 break;
-			case 0x12: nop(m68_state);	    break;
-			case 0x13: sync(m68_state);	    break;
-			case 0x14: IIError(m68_state);   break;
-			case 0x15: IIError(m68_state);   break;
-			case 0x16: lbra(m68_state);	    break;
-			case 0x17: lbsr(m68_state);	    break;
-			case 0x18: IIError(m68_state);   break;
-			case 0x19: daa(m68_state);	    break;
-			case 0x1a: orcc(m68_state);	    break;
-			case 0x1b: IIError(m68_state);   break;
-			case 0x1c: andcc(m68_state);     break;
-			case 0x1d: sex(m68_state);	    break;
-			case 0x1e: exg(m68_state);	    break;
-			case 0x1f: tfr(m68_state);	    break;
-			case 0x20: bra(m68_state);	    break;
-			case 0x21: brn(m68_state);	    break;
-			case 0x22: bhi(m68_state);	    break;
-			case 0x23: bls(m68_state);	    break;
-			case 0x24: bcc(m68_state);	    break;
-			case 0x25: bcs(m68_state);	    break;
-			case 0x26: bne(m68_state);	    break;
-			case 0x27: beq(m68_state);	    break;
-			case 0x28: bvc(m68_state);	    break;
-			case 0x29: bvs(m68_state);	    break;
-			case 0x2a: bpl(m68_state);	    break;
-			case 0x2b: bmi(m68_state);	    break;
-			case 0x2c: bge(m68_state);	    break;
-			case 0x2d: blt(m68_state);	    break;
-			case 0x2e: bgt(m68_state);	    break;
-			case 0x2f: ble(m68_state);	    break;
-			case 0x30: leax(m68_state);	    break;
-			case 0x31: leay(m68_state);	    break;
-			case 0x32: leas(m68_state);	    break;
-			case 0x33: leau(m68_state);	    break;
-			case 0x34: pshs(m68_state);	    break;
-			case 0x35: puls(m68_state);	    break;
-			case 0x36: pshu(m68_state);	    break;
-			case 0x37: pulu(m68_state);	    break;
-			case 0x38: IIError(m68_state);   break;
-			case 0x39: rts(m68_state);	    break;
-			case 0x3a: abx(m68_state);	    break;
-			case 0x3b: rti(m68_state);	    break;
-			case 0x3c: cwai(m68_state);	    break;
-			case 0x3d: mul(m68_state);	    break;
-			case 0x3e: IIError(m68_state);   break;
-			case 0x3f: swi(m68_state);	    break;
-			case 0x40: nega(m68_state);	    break;
-			case 0x41: IIError(m68_state);   break;
-			case 0x42: IIError(m68_state);   break;
-			case 0x43: coma(m68_state);	    break;
-			case 0x44: lsra(m68_state);	    break;
-			case 0x45: IIError(m68_state);   break;
-			case 0x46: rora(m68_state);	    break;
-			case 0x47: asra(m68_state);	    break;
-			case 0x48: asla(m68_state);	    break;
-			case 0x49: rola(m68_state);	    break;
-			case 0x4a: deca(m68_state);	    break;
-			case 0x4b: IIError(m68_state);   break;
-			case 0x4c: inca(m68_state);	    break;
-			case 0x4d: tsta(m68_state);	    break;
-			case 0x4e: IIError(m68_state);   break;
-			case 0x4f: clra(m68_state);	    break;
-			case 0x50: negb(m68_state);	    break;
-			case 0x51: IIError(m68_state);   break;
-			case 0x52: IIError(m68_state);   break;
-			case 0x53: comb(m68_state);	    break;
-			case 0x54: lsrb(m68_state);	    break;
-			case 0x55: IIError(m68_state);   break;
-			case 0x56: rorb(m68_state);	    break;
-			case 0x57: asrb(m68_state);	    break;
-			case 0x58: aslb(m68_state);	    break;
-			case 0x59: rolb(m68_state);	    break;
-			case 0x5a: decb(m68_state);	    break;
-			case 0x5b: IIError(m68_state);   break;
-			case 0x5c: incb(m68_state);	    break;
-			case 0x5d: tstb(m68_state);	    break;
-			case 0x5e: IIError(m68_state);   break;
-			case 0x5f: clrb(m68_state);	    break;
-			case 0x60: neg_ix(m68_state);    break;
-			case 0x61: IIError(m68_state);   break;
-			case 0x62: IIError(m68_state);   break;
-			case 0x63: com_ix(m68_state);    break;
-			case 0x64: lsr_ix(m68_state);    break;
-			case 0x65: IIError(m68_state);   break;
-			case 0x66: ror_ix(m68_state);    break;
-			case 0x67: asr_ix(m68_state);    break;
-			case 0x68: asl_ix(m68_state);    break;
-			case 0x69: rol_ix(m68_state);    break;
-			case 0x6a: dec_ix(m68_state);    break;
-			case 0x6b: IIError(m68_state);   break;
-			case 0x6c: inc_ix(m68_state);    break;
-			case 0x6d: tst_ix(m68_state);    break;
-			case 0x6e: jmp_ix(m68_state);    break;
-			case 0x6f: clr_ix(m68_state);    break;
-			case 0x70: neg_ex(m68_state);    break;
-			case 0x71: IIError(m68_state);   break;
-			case 0x72: IIError(m68_state);   break;
-			case 0x73: com_ex(m68_state);    break;
-			case 0x74: lsr_ex(m68_state);    break;
-			case 0x75: IIError(m68_state);   break;
-			case 0x76: ror_ex(m68_state);    break;
-			case 0x77: asr_ex(m68_state);    break;
-			case 0x78: asl_ex(m68_state);    break;
-			case 0x79: rol_ex(m68_state);    break;
-			case 0x7a: dec_ex(m68_state);    break;
-			case 0x7b: IIError(m68_state);   break;
-			case 0x7c: inc_ex(m68_state);    break;
-			case 0x7d: tst_ex(m68_state);    break;
-			case 0x7e: jmp_ex(m68_state);    break;
-			case 0x7f: clr_ex(m68_state);    break;
-			case 0x80: suba_im(m68_state);   break;
-			case 0x81: cmpa_im(m68_state);   break;
-			case 0x82: sbca_im(m68_state);   break;
-			case 0x83: subd_im(m68_state);   break;
-			case 0x84: anda_im(m68_state);   break;
-			case 0x85: bita_im(m68_state);   break;
-			case 0x86: lda_im(m68_state);    break;
-			case 0x87: sta_im(m68_state);    break;
-			case 0x88: eora_im(m68_state);   break;
-			case 0x89: adca_im(m68_state);   break;
-			case 0x8a: ora_im(m68_state);    break;
-			case 0x8b: adda_im(m68_state);   break;
-			case 0x8c: cmpx_im(m68_state);   break;
-			case 0x8d: bsr(m68_state);	    break;
-			case 0x8e: ldx_im(m68_state);    break;
-			case 0x8f: stx_im(m68_state);    break;
-			case 0x90: suba_di(m68_state);   break;
-			case 0x91: cmpa_di(m68_state);   break;
-			case 0x92: sbca_di(m68_state);   break;
-			case 0x93: subd_di(m68_state);   break;
-			case 0x94: anda_di(m68_state);   break;
-			case 0x95: bita_di(m68_state);   break;
-			case 0x96: lda_di(m68_state);    break;
-			case 0x97: sta_di(m68_state);    break;
-			case 0x98: eora_di(m68_state);   break;
-			case 0x99: adca_di(m68_state);   break;
-			case 0x9a: ora_di(m68_state);    break;
-			case 0x9b: adda_di(m68_state);   break;
-			case 0x9c: cmpx_di(m68_state);   break;
-			case 0x9d: jsr_di(m68_state);    break;
-			case 0x9e: ldx_di(m68_state);    break;
-			case 0x9f: stx_di(m68_state);    break;
-			case 0xa0: suba_ix(m68_state);   break;
-			case 0xa1: cmpa_ix(m68_state);   break;
-			case 0xa2: sbca_ix(m68_state);   break;
-			case 0xa3: subd_ix(m68_state);   break;
-			case 0xa4: anda_ix(m68_state);   break;
-			case 0xa5: bita_ix(m68_state);   break;
-			case 0xa6: lda_ix(m68_state);    break;
-			case 0xa7: sta_ix(m68_state);    break;
-			case 0xa8: eora_ix(m68_state);   break;
-			case 0xa9: adca_ix(m68_state);   break;
-			case 0xaa: ora_ix(m68_state);    break;
-			case 0xab: adda_ix(m68_state);   break;
-			case 0xac: cmpx_ix(m68_state);   break;
-			case 0xad: jsr_ix(m68_state);    break;
-			case 0xae: ldx_ix(m68_state);    break;
-			case 0xaf: stx_ix(m68_state);    break;
-			case 0xb0: suba_ex(m68_state);   break;
-			case 0xb1: cmpa_ex(m68_state);   break;
-			case 0xb2: sbca_ex(m68_state);   break;
-			case 0xb3: subd_ex(m68_state);   break;
-			case 0xb4: anda_ex(m68_state);   break;
-			case 0xb5: bita_ex(m68_state);   break;
-			case 0xb6: lda_ex(m68_state);    break;
-			case 0xb7: sta_ex(m68_state);    break;
-			case 0xb8: eora_ex(m68_state);   break;
-			case 0xb9: adca_ex(m68_state);   break;
-			case 0xba: ora_ex(m68_state);    break;
-			case 0xbb: adda_ex(m68_state);   break;
-			case 0xbc: cmpx_ex(m68_state);   break;
-			case 0xbd: jsr_ex(m68_state);    break;
-			case 0xbe: ldx_ex(m68_state);    break;
-			case 0xbf: stx_ex(m68_state);    break;
-			case 0xc0: subb_im(m68_state);   break;
-			case 0xc1: cmpb_im(m68_state);   break;
-			case 0xc2: sbcb_im(m68_state);   break;
-			case 0xc3: addd_im(m68_state);   break;
-			case 0xc4: andb_im(m68_state);   break;
-			case 0xc5: bitb_im(m68_state);   break;
-			case 0xc6: ldb_im(m68_state);    break;
-			case 0xc7: stb_im(m68_state);    break;
-			case 0xc8: eorb_im(m68_state);   break;
-			case 0xc9: adcb_im(m68_state);   break;
-			case 0xca: orb_im(m68_state);    break;
-			case 0xcb: addb_im(m68_state);   break;
-			case 0xcc: ldd_im(m68_state);    break;
-			case 0xcd: std_im(m68_state);    break;
-			case 0xce: ldu_im(m68_state);    break;
-			case 0xcf: stu_im(m68_state);    break;
-			case 0xd0: subb_di(m68_state);   break;
-			case 0xd1: cmpb_di(m68_state);   break;
-			case 0xd2: sbcb_di(m68_state);   break;
-			case 0xd3: addd_di(m68_state);   break;
-			case 0xd4: andb_di(m68_state);   break;
-			case 0xd5: bitb_di(m68_state);   break;
-			case 0xd6: ldb_di(m68_state);    break;
-			case 0xd7: stb_di(m68_state);    break;
-			case 0xd8: eorb_di(m68_state);   break;
-			case 0xd9: adcb_di(m68_state);   break;
-			case 0xda: orb_di(m68_state);    break;
-			case 0xdb: addb_di(m68_state);   break;
-			case 0xdc: ldd_di(m68_state);    break;
-			case 0xdd: std_di(m68_state);    break;
-			case 0xde: ldu_di(m68_state);    break;
-			case 0xdf: stu_di(m68_state);    break;
-			case 0xe0: subb_ix(m68_state);   break;
-			case 0xe1: cmpb_ix(m68_state);   break;
-			case 0xe2: sbcb_ix(m68_state);   break;
-			case 0xe3: addd_ix(m68_state);   break;
-			case 0xe4: andb_ix(m68_state);   break;
-			case 0xe5: bitb_ix(m68_state);   break;
-			case 0xe6: ldb_ix(m68_state);    break;
-			case 0xe7: stb_ix(m68_state);    break;
-			case 0xe8: eorb_ix(m68_state);   break;
-			case 0xe9: adcb_ix(m68_state);   break;
-			case 0xea: orb_ix(m68_state);    break;
-			case 0xeb: addb_ix(m68_state);   break;
-			case 0xec: ldd_ix(m68_state);    break;
-			case 0xed: std_ix(m68_state);    break;
-			case 0xee: ldu_ix(m68_state);    break;
-			case 0xef: stu_ix(m68_state);    break;
-			case 0xf0: subb_ex(m68_state);   break;
-			case 0xf1: cmpb_ex(m68_state);   break;
-			case 0xf2: sbcb_ex(m68_state);   break;
-			case 0xf3: addd_ex(m68_state);   break;
-			case 0xf4: andb_ex(m68_state);   break;
-			case 0xf5: bitb_ex(m68_state);   break;
-			case 0xf6: ldb_ex(m68_state);    break;
-			case 0xf7: stb_ex(m68_state);    break;
-			case 0xf8: eorb_ex(m68_state);   break;
-			case 0xf9: adcb_ex(m68_state);   break;
-			case 0xfa: orb_ex(m68_state);    break;
-			case 0xfb: addb_ex(m68_state);   break;
-			case 0xfc: ldd_ex(m68_state);    break;
-			case 0xfd: std_ex(m68_state);    break;
-			case 0xfe: ldu_ex(m68_state);    break;
-			case 0xff: stu_ex(m68_state);    break;
-			}
-#else
-            		(*m6809_main[m68_state->ireg])(m68_state);
-#endif    /* BIG_SWITCH */
-        		m68_state->icount -= cycles1[m68_state->ireg];
+        	(*m6809_main[m68_state->ireg])(m68_state);
+			m68_state->icount -= cycles1[m68_state->ireg];
 
 		} while( m68_state->icount > 0 );
 
