@@ -83,11 +83,12 @@ struct _saturn_state
 	int		monitor_in;
 	device_irq_callback irq_callback;
 	legacy_cpu_device *device;
-	const address_space *program;
+	address_space *program;
+	direct_read_data *direct;
 	int icount;
 };
 
-INLINE saturn_state *get_safe_token(running_device *device)
+INLINE saturn_state *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
 	assert(device->type() == SATURN);
@@ -115,6 +116,7 @@ static CPU_INIT( saturn )
 	cpustate->irq_callback = irqcallback;
 	cpustate->device = device;
 	cpustate->program = device->space(AS_PROGRAM);
+	cpustate->direct = &cpustate->program->direct();
 
 	state_save_register_device_item_array(device, 0,cpustate->reg[R0]);
 	state_save_register_device_item_array(device, 0,cpustate->reg[R1]);
