@@ -12,7 +12,6 @@
 #include "emu.h"
 #include "emuopts.h"
 #include "debugcmd.h"
-#include "debugcmt.h"
 #include "debugcon.h"
 #include "debugcpu.h"
 #include "express.h"
@@ -93,12 +92,12 @@ static cheat_system cheat;
 
 static void debug_command_exit(running_machine &machine);
 
-static UINT64 execute_min(void *globalref, void *ref, UINT32 params, const UINT64 *param);
-static UINT64 execute_max(void *globalref, void *ref, UINT32 params, const UINT64 *param);
-static UINT64 execute_if(void *globalref, void *ref, UINT32 params, const UINT64 *param);
+static UINT64 execute_min(symbol_table &table, void *ref, int params, const UINT64 *param);
+static UINT64 execute_max(symbol_table &table, void *ref, int params, const UINT64 *param);
+static UINT64 execute_if(symbol_table &table, void *ref, int params, const UINT64 *param);
 
-static UINT64 global_get(void *globalref, void *ref);
-static void global_set(void *globalref, void *ref, UINT64 value);
+static UINT64 global_get(symbol_table &table, void *ref);
+static void global_set(symbol_table &table, void *ref, UINT64 value);
 
 static void execute_help(running_machine *machine, int ref, int params, const char **param);
 static void execute_print(running_machine *machine, int ref, int params, const char **param);
@@ -161,9 +160,9 @@ static void execute_hardreset(running_machine *machine, int ref, int params, con
     given address is valid for cheating
 -------------------------------------------------*/
 
-INLINE int cheat_address_is_valid(const address_space *space, offs_t address)
+INLINE int cheat_address_is_valid(address_space *space, offs_t address)
 {
-	return debug_cpu_translate(space, TRANSLATE_READ, &address) && (memory_get_write_ptr(space, address) != NULL);
+	return debug_cpu_translate(space, TRANSLATE_READ, &address) && (space->get_write_ptr(address) != NULL);
 }
 
 
@@ -210,7 +209,7 @@ INLINE UINT64 cheat_byte_swap(const cheat_system *cheatsys, UINT64 value)
     and swapping if necessary
 -------------------------------------------------*/
 
-INLINE UINT64 cheat_read_extended(const cheat_system *cheatsys, const address_space *space, offs_t address)
+INLINE UINT64 cheat_read_extended(const cheat_system *cheatsys, address_space *space, offs_t address)
 {
 	return cheat_sign_extend(cheatsys, cheat_byte_swap(cheatsys, debug_read_memory(space, address, cheatsys->width, TRUE)));
 }
@@ -233,9 +232,9 @@ void debug_command_init(running_machine *machine)
 	int itemnum;
 
 	/* add a few simple global functions */
-	symtable_add_function(symtable, "min", NULL, 2, 2, execute_min);
-	symtable_add_function(symtable, "max", NULL, 2, 2, execute_max);
-	symtable_add_function(symtable, "if", NULL, 3, 3, execute_if);
+	symtable->add("min", NULL, 2, 2, execute_min);
+	symtable->add("max", NULL, 2, 2, execute_max);
+	symtable->add("if", NULL, 3, 3, execute_if);
 
 	/* add all single-entry save state globals */
 	for (itemnum = 0; itemnum < MAX_GLOBALS; itemnum++)
@@ -255,7 +254,7 @@ void debug_command_init(running_machine *machine)
 			sprintf(symname, ".%s", strrchr(name, '/') + 1);
 			global_array[itemnum].base = base;
 			global_array[itemnum].size = valsize;
-			symtable_add_register(symtable, symname, &global_array, global_get, global_set);
+			symtable->add(symname, &global_array, global_get, global_set);
 		}
 	}
 
@@ -365,9 +364,6 @@ void debug_command_init(running_machine *machine)
 	debug_console_register_command(machine, "softreset",	CMDFLAG_NONE, 0, 0, 1, execute_softreset);
 	debug_console_register_command(machine, "hardreset",	CMDFLAG_NONE, 0, 0, 1, execute_hardreset);
 
-	/* ask all the devices if they would like to register functions or symbols */
-	machine->m_devicelist.debug_setup_all();
-
 	machine->add_notifier(MACHINE_NOTIFY_EXIT, debug_command_exit);
 
 	/* set up the initial debugscript if specified */
@@ -401,7 +397,7 @@ static void debug_command_exit(running_machine &machine)
     execute_min - return the minimum of two values
 -------------------------------------------------*/
 
-static UINT64 execute_min(void *globalref, void *ref, UINT32 params, const UINT64 *param)
+static UINT64 execute_min(symbol_table &table, void *ref, int params, const UINT64 *param)
 {
 	return (param[0] < param[1]) ? param[0] : param[1];
 }
@@ -411,7 +407,7 @@ static UINT64 execute_min(void *globalref, void *ref, UINT32 params, const UINT6
     execute_max - return the maximum of two values
 -------------------------------------------------*/
 
-static UINT64 execute_max(void *globalref, void *ref, UINT32 params, const UINT64 *param)
+static UINT64 execute_max(symbol_table &table, void *ref, int params, const UINT64 *param)
 {
 	return (param[0] > param[1]) ? param[0] : param[1];
 }
@@ -421,7 +417,7 @@ static UINT64 execute_max(void *globalref, void *ref, UINT32 params, const UINT6
     execute_if - if (a) return b; else return c;
 -------------------------------------------------*/
 
-static UINT64 execute_if(void *globalref, void *ref, UINT32 params, const UINT64 *param)
+static UINT64 execute_if(symbol_table &table, void *ref, int params, const UINT64 *param)
 {
 	return param[0] ? param[1] : param[2];
 }
@@ -436,7 +432,7 @@ static UINT64 execute_if(void *globalref, void *ref, UINT32 params, const UINT64
     global_get - symbol table getter for globals
 -------------------------------------------------*/
 
-static UINT64 global_get(void *globalref, void *ref)
+static UINT64 global_get(symbol_table &table, void *ref)
 {
 	global_entry *global = (global_entry *)ref;
 	switch (global->size)
@@ -454,7 +450,7 @@ static UINT64 global_get(void *globalref, void *ref)
     global_set - symbol table setter for globals
 -------------------------------------------------*/
 
-static void global_set(void *globalref, void *ref, UINT64 value)
+static void global_set(symbol_table &table, void *ref, UINT64 value)
 {
 	global_entry *global = (global_entry *)ref;
 	switch (global->size)
@@ -479,22 +475,24 @@ static void global_set(void *globalref, void *ref, UINT64 value)
 
 int debug_command_parameter_number(running_machine *machine, const char *param, UINT64 *result)
 {
-	EXPRERR err;
-
 	/* NULL parameter does nothing and returns no error */
 	if (param == NULL)
 		return TRUE;
 
 	/* evaluate the expression; success if no error */
-	err = expression_evaluate(param, debug_cpu_get_visible_symtable(machine), &debug_expression_callbacks, machine, result);
-	if (err == EXPRERR_NONE)
+	try
+	{
+		parsed_expression expression(debug_cpu_get_visible_symtable(machine), param, result);
 		return TRUE;
-
-	/* print an error pointing to the character that caused it */
-	debug_console_printf(machine, "Error in expression: %s\n", param);
-	debug_console_printf(machine, "                     %*s^", EXPRERR_ERROR_OFFSET(err), "");
-	debug_console_printf(machine, "%s\n", exprerr_to_string(err));
-	return FALSE;
+	}
+	catch (expression_error &error)
+	{
+		/* print an error pointing to the character that caused it */
+		debug_console_printf(machine, "Error in expression: %s\n", param);
+		debug_console_printf(machine, "                     %*s^", error.offset(), "");
+		debug_console_printf(machine, "%s\n", error.code_string());
+		return FALSE;
+	}
 }
 
 
@@ -506,7 +504,6 @@ int debug_command_parameter_number(running_machine *machine, const char *param,
 int debug_command_parameter_cpu(running_machine *machine, const char *param, device_t **result)
 {
 	UINT64 cpunum;
-	EXPRERR err;
 
 	/* if no parameter, use the visible CPU */
 	if (param == NULL)
@@ -526,8 +523,11 @@ int debug_command_parameter_cpu(running_machine *machine, const char *param, dev
 		return TRUE;
 
 	/* then evaluate as an expression; on an error assume it was a tag */
-	err = expression_evaluate(param, debug_cpu_get_visible_symtable(machine), &debug_expression_callbacks, machine, &cpunum);
-	if (err != EXPRERR_NONE)
+	try
+	{
+		parsed_expression expression(debug_cpu_get_visible_symtable(machine), param, &cpunum);
+	}
+	catch (expression_error &)
 	{
 		debug_console_printf(machine, "Unable to find CPU '%s'\n", param);
 		return FALSE;
@@ -554,7 +554,7 @@ int debug_command_parameter_cpu(running_machine *machine, const char *param, dev
     address space
 -------------------------------------------------*/
 
-int debug_command_parameter_cpu_space(running_machine *machine, const char *param, int spacenum, const address_space **result)
+int debug_command_parameter_cpu_space(running_machine *machine, const char *param, int spacenum, address_space **result)
 {
 	device_t *cpu;
 
@@ -578,27 +578,26 @@ int debug_command_parameter_cpu_space(running_machine *machine, const char *para
     an expression parameter
 -------------------------------------------------*/
 
-static int debug_command_parameter_expression(running_machine *machine, const char *param, parsed_expression **result)
+static int debug_command_parameter_expression(running_machine *machine, const char *param, parsed_expression &result)
 {
-	EXPRERR err;
-
 	/* NULL parameter does nothing and returns no error */
 	if (param == NULL)
-	{
-		*result = NULL;
 		return TRUE;
-	}
 
 	/* parse the expression; success if no error */
-	err = expression_parse(param, debug_cpu_get_visible_symtable(machine), &debug_expression_callbacks, machine, result);
-	if (err == EXPRERR_NONE)
+	try
+	{
+		result.parse(param);
 		return TRUE;
-
-	/* output an error */
-	debug_console_printf(machine, "Error in expression: %s\n", param);
-	debug_console_printf(machine, "                     %*s^", EXPRERR_ERROR_OFFSET(err), "");
-	debug_console_printf(machine, "%s\n", exprerr_to_string(err));
-	return FALSE;
+	}
+	catch (expression_error &err)
+	{
+		/* output an error */
+		debug_console_printf(machine, "Error in expression: %s\n", param);
+		debug_console_printf(machine, "                     %*s^", err.offset(), "");
+		debug_console_printf(machine, "%s\n", err.code_string());
+		return FALSE;
+	}
 }
 
 
@@ -998,14 +997,14 @@ static void execute_ignore(running_machine *machine, int ref, int params, const
 			/* build up a comma-separated list */
 			if (!exec->device().debug()->observing())
 			{
-				if (buffer.len() == 0)
+				if (!buffer)
 					buffer.printf("Currently ignoring device '%s'", exec->device().tag());
 				else
 					buffer.catprintf(", '%s'", exec->device().tag());
 			}
 
 		/* special message for none */
-		if (buffer.len() == 0)
+		if (!buffer)
 			buffer.printf("Not currently ignoring any devices");
 		debug_console_printf(machine, "%s\n", buffer.cstr());
 	}
@@ -1060,14 +1059,14 @@ static void execute_observe(running_machine *machine, int ref, int params, const
 			/* build up a comma-separated list */
 			if (exec->device().debug()->observing())
 			{
-				if (buffer.len() == 0)
+				if (!buffer)
 					buffer.printf("Currently observing CPU '%s'", exec->device().tag());
 				else
 					buffer.catprintf(", '%s'", exec->device().tag());
 			}
 
 		/* special message for none */
-		if (buffer.len() == 0)
+		if (!buffer)
 			buffer.printf("Not currently observing any devices");
 		debug_console_printf(machine, "%s\n", buffer.cstr());
 	}
@@ -1117,8 +1116,8 @@ static void execute_comment(running_machine *machine, int ref, int params, const
 	}
 
 	/* Now try adding the comment */
-	debug_comment_add(cpu, address, param[1], 0x00ff0000, debug_comment_get_opcode_crc32(cpu, address));
-	cpu->machine->m_debug_view->update_all(DVT_DISASSEMBLY);
+	cpu->debug()->comment_add(address, param[1], 0x00ff0000);
+	cpu->machine->debug_view().update_all(DVT_DISASSEMBLY);
 }
 
 
@@ -1141,8 +1140,8 @@ static void execute_comment_del(running_machine *machine, int ref, int params, c
 
 	/* If it's a number, it must be an address */
 	/* The bankoff and cbn will be pulled from what's currently active */
-	debug_comment_remove(cpu, address, debug_comment_get_opcode_crc32(cpu, address));
-	cpu->machine->m_debug_view->update_all(DVT_DISASSEMBLY);
+	cpu->debug()->comment_remove(address);
+	cpu->machine->debug_view().update_all(DVT_DISASSEMBLY);
 }
 
 
@@ -1164,30 +1163,30 @@ static void execute_comment_save(running_machine *machine, int ref, int params,
 
 static void execute_bpset(running_machine *machine, int ref, int params, const char *param[])
 {
-	parsed_expression *condition = NULL;
 	device_t *cpu;
 	const char *action = NULL;
 	UINT64 address;
 	int bpnum;
 
+	/* CPU is implicit */
+	if (!debug_command_parameter_cpu(machine, NULL, &cpu))
+		return;
+
 	/* param 1 is the address */
 	if (!debug_command_parameter_number(machine, param[0], &address))
 		return;
 
 	/* param 2 is the condition */
-	if (!debug_command_parameter_expression(machine, param[1], &condition))
+	parsed_expression condition(&cpu->debug()->symtable());
+	if (!debug_command_parameter_expression(machine, param[1], condition))
 		return;
 
 	/* param 3 is the action */
 	if (!debug_command_parameter_command(machine, action = param[2]))
 		return;
 
-	/* CPU is implicit */
-	if (!debug_command_parameter_cpu(machine, NULL, &cpu))
-		return;
-
 	/* set the breakpoint */
-	bpnum = cpu->debug()->breakpoint_set(address, condition, action);
+	bpnum = cpu->debug()->breakpoint_set(address, (condition.is_empty()) ? NULL : condition.original_string(), action);
 	debug_console_printf(machine, "Breakpoint %X set\n", bpnum);
 }
 
@@ -1304,13 +1303,16 @@ static void execute_bplist(running_machine *machine, int ref, int params, const
 
 static void execute_wpset(running_machine *machine, int ref, int params, const char *param[])
 {
-	parsed_expression *condition = NULL;
-	const address_space *space;
+	address_space *space;
 	const char *action = NULL;
 	UINT64 address, length;
 	int type = 0;
 	int wpnum;
 
+	/* CPU is implicit */
+	if (!debug_command_parameter_cpu_space(machine, NULL, ref, &space))
+		return;
+
 	/* param 1 is the address */
 	if (!debug_command_parameter_number(machine, param[0], &address))
 		return;
@@ -1333,19 +1335,16 @@ static void execute_wpset(running_machine *machine, int ref, int params, const c
 	}
 
 	/* param 4 is the condition */
-	if (!debug_command_parameter_expression(machine, param[3], &condition))
+	parsed_expression condition(&space->cpu->debug()->symtable());
+	if (!debug_command_parameter_expression(machine, param[3], condition))
 		return;
 
 	/* param 5 is the action */
 	if (!debug_command_parameter_command(machine, action = param[4]))
 		return;
 
-	/* CPU is implicit */
-	if (!debug_command_parameter_cpu_space(machine, NULL, ref, &space))
-		return;
-
 	/* set the watchpoint */
-	wpnum = space->cpu->debug()->watchpoint_set(*space, type, address, length, condition, action);
+	wpnum = space->cpu->debug()->watchpoint_set(*space, type, address, length, (condition.is_empty()) ? NULL : condition.original_string(), action);
 	debug_console_printf(machine, "Watchpoint %X set\n", wpnum);
 }
 
@@ -1438,14 +1437,14 @@ static void execute_wplist(running_machine *machine, int ref, int params, const
 			{
 				static const char *const types[] = { "unkn ", "read ", "write", "r/w  " };
 
-				debug_console_printf(machine, "Device '%s' %s space watchpoints:\n", device->tag(), device->debug()->watchpoint_first(spacenum)->space().name);
+				debug_console_printf(machine, "Device '%s' %s space watchpoints:\n", device->tag(), device->debug()->watchpoint_first(spacenum)->space().name());
 
 				/* loop over the watchpoints */
 				for (device_debug::watchpoint *wp = device->debug()->watchpoint_first(spacenum); wp != NULL; wp = wp->next())
 				{
 					buffer.printf("%c%4X @ %s-%s %s", wp->enabled() ? ' ' : 'D', wp->index(),
-							core_i64_hex_format(memory_byte_to_address(&wp->space(), wp->address()), wp->space().addrchars),
-							core_i64_hex_format(memory_byte_to_address_end(&wp->space(), wp->address() + wp->length()) - 1, wp->space().addrchars),
+							core_i64_hex_format(wp->space().byte_to_address(wp->address()), wp->space().addrchars()),
+							core_i64_hex_format(wp->space().byte_to_address_end(wp->address() + wp->length()) - 1, wp->space().addrchars()),
 							types[wp->type() & 3]);
 					if (wp->condition() != NULL)
 						buffer.catprintf(" if %s", wp->condition());
@@ -1511,7 +1510,7 @@ static void execute_hotspot(running_machine *machine, int ref, int params, const
 static void execute_save(running_machine *machine, int ref, int params, const char *param[])
 {
 	UINT64 offset, endoffset, length;
-	const address_space *space;
+	address_space *space;
 	FILE *f;
 	UINT64 i;
 
@@ -1524,8 +1523,8 @@ static void execute_save(running_machine *machine, int ref, int params, const ch
 		return;
 
 	/* determine the addresses to write */
-	endoffset = memory_address_to_byte(space, offset + length - 1) & space->bytemask;
-	offset = memory_address_to_byte(space, offset) & space->bytemask;
+	endoffset = space->address_to_byte(offset + length - 1) & space->bytemask();
+	offset = space->address_to_byte(offset) & space->bytemask();
 
 	/* open the file */
 	f = fopen(param[0], "wb");
@@ -1555,7 +1554,7 @@ static void execute_save(running_machine *machine, int ref, int params, const ch
 static void execute_dump(running_machine *machine, int ref, int params, const char *param[])
 {
 	UINT64 offset, endoffset, length, width = 0, ascii = 1;
-	const address_space *space;
+	address_space *space;
 	FILE *f = NULL;
 	UINT64 i, j;
 
@@ -1573,16 +1572,16 @@ static void execute_dump(running_machine *machine, int ref, int params, const ch
 
 	/* further validation */
 	if (width == 0)
-		width = space->dbits / 8;
-	if (width < memory_address_to_byte(space, 1))
-		width = memory_address_to_byte(space, 1);
+		width = space->data_width() / 8;
+	if (width < space->address_to_byte(1))
+		width = space->address_to_byte(1);
 	if (width != 1 && width != 2 && width != 4 && width != 8)
 	{
 		debug_console_printf(machine, "Invalid width! (must be 1,2,4 or 8)\n");
 		return;
 	}
-	endoffset = memory_address_to_byte(space, offset + length - 1) & space->bytemask;
-	offset = memory_address_to_byte(space, offset) & space->bytemask;
+	endoffset = space->address_to_byte(offset + length - 1) & space->bytemask();
+	offset = space->address_to_byte(offset) & space->bytemask();
 
 	/* open the file */
 	f = fopen(param[0], "w");
@@ -1599,7 +1598,7 @@ static void execute_dump(running_machine *machine, int ref, int params, const ch
 		int outdex = 0;
 
 		/* print the address */
-		outdex += sprintf(&output[outdex], "%s: ", core_i64_hex_format((UINT32)memory_byte_to_address(space, i), space->logaddrchars));
+		outdex += sprintf(&output[outdex], "%s: ", core_i64_hex_format((UINT32)space->byte_to_address(i), space->logaddrchars()));
 
 		/* print the bytes */
 		for (j = 0; j < 16; j += width)
@@ -1653,7 +1652,7 @@ static void execute_dump(running_machine *machine, int ref, int params, const ch
 static void execute_cheatinit(running_machine *machine, int ref, int params, const char *param[])
 {
 	UINT64 offset, length = 0, real_length = 0;
-	const address_space *space;
+	address_space *space;
 	UINT32 active_cheat = 0;
 	UINT64 curaddr;
 	UINT8 i, region_count = 0;
@@ -1711,19 +1710,19 @@ static void execute_cheatinit(running_machine *machine, int ref, int params, con
 	if (params <= 1)
 	{
 		offset = 0;
-		length = space->bytemask + 1;
-		for (entry = space->map->entrylist; entry != NULL; entry = entry->next)
+		length = space->bytemask() + 1;
+		for (entry = space->map()->m_entrylist.first(); entry != NULL; entry = entry->next())
 		{
-			cheat_region[region_count].offset = memory_address_to_byte(space, entry->addrstart) & space->bytemask;
-			cheat_region[region_count].endoffset = memory_address_to_byte(space, entry->addrend) & space->bytemask;
-			cheat_region[region_count].share = entry->share;
-			cheat_region[region_count].disabled = (entry->write.type == AMH_RAM) ? FALSE : TRUE;
+			cheat_region[region_count].offset = space->address_to_byte(entry->m_addrstart) & space->bytemask();
+			cheat_region[region_count].endoffset = space->address_to_byte(entry->m_addrend) & space->bytemask();
+			cheat_region[region_count].share = entry->m_share;
+			cheat_region[region_count].disabled = (entry->m_write.m_type == AMH_RAM) ? FALSE : TRUE;
 
 			/* disable double share regions */
-			if (entry->share != NULL)
+			if (entry->m_share != NULL)
 				for (i = 0; i < region_count; i++)
 					if (cheat_region[i].share != NULL)
-						if (strcmp(cheat_region[i].share, entry->share)==0)
+						if (strcmp(cheat_region[i].share, entry->m_share) == 0)
 							cheat_region[region_count].disabled = TRUE;
 
 			region_count++;
@@ -1738,8 +1737,8 @@ static void execute_cheatinit(running_machine *machine, int ref, int params, con
 			return;
 
 		/* force region to the specified range */
-		cheat_region[region_count].offset = memory_address_to_byte(space, offset) & space->bytemask;;
-		cheat_region[region_count].endoffset = memory_address_to_byte(space, offset + length - 1) & space->bytemask;;
+		cheat_region[region_count].offset = space->address_to_byte(offset) & space->bytemask();
+		cheat_region[region_count].endoffset = space->address_to_byte(offset + length - 1) & space->bytemask();
 		cheat_region[region_count].share = NULL;
 		cheat_region[region_count].disabled = FALSE;
 		region_count++;
@@ -1815,7 +1814,7 @@ static void execute_cheatinit(running_machine *machine, int ref, int params, con
 
 static void execute_cheatnext(running_machine *machine, int ref, int params, const char *param[])
 {
-	const address_space *space;
+	address_space *space;
 	UINT64 cheatindex;
 	UINT32 active_cheat = 0;
 	UINT8 condition;
@@ -1835,7 +1834,8 @@ static void execute_cheatnext(running_machine *machine, int ref, int params, con
 		CHEAT_DECREASEOF,
 		CHEAT_INCREASEOF,
 		CHEAT_SMALLEROF,
-		CHEAT_GREATEROF
+		CHEAT_GREATEROF,
+		CHEAT_CHANGEDBY
 	};
 
 	if (cheat.cpu == 0)
@@ -1870,6 +1870,8 @@ static void execute_cheatnext(running_machine *machine, int ref, int params, con
 		condition = CHEAT_SMALLEROF;
 	else if (!strcmp(param[0], "greaterof") || !strcmp(param[0], "gt") || !strcmp(param[0], ">"))
 		condition = CHEAT_GREATEROF;
+	else if (!strcmp(param[0], "changedby") || !strcmp(param[0], "ch") || !strcmp(param[0], "~"))
+		condition = CHEAT_CHANGEDBY;
 	else
 	{
 		debug_console_printf(machine, "Invalid condition type\n");
@@ -1956,6 +1958,12 @@ static void execute_cheatnext(running_machine *machine, int ref, int params, con
 					else
 						disable_byte = ((UINT64)cheat_value <= (UINT64)comp_value);
 					break;
+				case CHEAT_CHANGEDBY:
+					if (cheat_value > comp_byte)
+						disable_byte = (cheat_value != comp_byte + comp_value);
+					else
+						disable_byte = (cheat_value != comp_byte - comp_value);
+					break;
 			}
 
 			if (disable_byte)
@@ -1984,7 +1992,7 @@ static void execute_cheatnext(running_machine *machine, int ref, int params, con
 static void execute_cheatlist(running_machine *machine, int ref, int params, const char *param[])
 {
 	char spaceletter, sizeletter;
-	const address_space *space;
+	address_space *space;
 	device_t *cpu;
 	UINT32 active_cheat = 0;
 	UINT64 cheatindex;
@@ -2000,7 +2008,7 @@ static void execute_cheatlist(running_machine *machine, int ref, int params, con
 	if (params > 0)
 		f = fopen(param[0], "w");
 
-	switch (space->spacenum)
+	switch (space->spacenum())
 	{
 		default:
 		case ADDRESS_SPACE_PROGRAM:	spaceletter = 'p';	break;
@@ -2023,19 +2031,19 @@ static void execute_cheatlist(running_machine *machine, int ref, int params, con
 		if (cheat.cheatmap[cheatindex].state == 1)
 		{
 			UINT64 value = cheat_byte_swap(&cheat, cheat_read_extended(&cheat, space, cheat.cheatmap[cheatindex].offset)) & sizemask;
-			offs_t address = memory_byte_to_address(space, cheat.cheatmap[cheatindex].offset);
+			offs_t address = space->byte_to_address(cheat.cheatmap[cheatindex].offset);
 
 			if (params > 0)
 			{
 				active_cheat++;
-				fprintf(f, "  <cheat desc=\"Possibility %d : %s (%s)\">\n", active_cheat, core_i64_hex_format(address, space->logaddrchars), core_i64_hex_format(value, cheat.width * 2));
+				fprintf(f, "  <cheat desc=\"Possibility %d : %s (%s)\">\n", active_cheat, core_i64_hex_format(address, space->logaddrchars()), core_i64_hex_format(value, cheat.width * 2));
 				fprintf(f, "    <script state=\"run\">\n");
-				fprintf(f, "      <action>%s.p%c%c@%s=%s</action>\n", cpu->tag(), spaceletter, sizeletter, core_i64_hex_format(address, space->logaddrchars), core_i64_hex_format(cheat_byte_swap(&cheat, cheat.cheatmap[cheatindex].first_value) & sizemask, cheat.width * 2));
+				fprintf(f, "      <action>%s.p%c%c@%s=%s</action>\n", cpu->tag(), spaceletter, sizeletter, core_i64_hex_format(address, space->logaddrchars()), core_i64_hex_format(cheat_byte_swap(&cheat, cheat.cheatmap[cheatindex].first_value) & sizemask, cheat.width * 2));
 				fprintf(f, "    </script>\n");
 				fprintf(f, "  </cheat>\n\n");
 			}
 			else
-				debug_console_printf(machine, "Address=%s Start=%s Current=%s\n", core_i64_hex_format(address, space->logaddrchars), core_i64_hex_format(cheat_byte_swap(&cheat, cheat.cheatmap[cheatindex].first_value) & sizemask, cheat.width * 2), core_i64_hex_format(value, cheat.width * 2));
+				debug_console_printf(machine, "Address=%s Start=%s Current=%s\n", core_i64_hex_format(address, space->logaddrchars()), core_i64_hex_format(cheat_byte_swap(&cheat, cheat.cheatmap[cheatindex].first_value) & sizemask, cheat.width * 2), core_i64_hex_format(value, cheat.width * 2));
 		}
 	}
 	if (params > 0)
@@ -2079,7 +2087,7 @@ static void execute_cheatundo(running_machine *machine, int ref, int params, con
 static void execute_find(running_machine *machine, int ref, int params, const char *param[])
 {
 	UINT64 offset, endoffset, length;
-	const address_space *space;
+	address_space *space;
 	UINT64 data_to_find[256];
 	UINT8 data_size[256];
 	int cur_data_size;
@@ -2096,9 +2104,9 @@ static void execute_find(running_machine *machine, int ref, int params, const ch
 		return;
 
 	/* further validation */
-	endoffset = memory_address_to_byte(space, offset + length - 1) & space->bytemask;
-	offset = memory_address_to_byte(space, offset) & space->bytemask;
-	cur_data_size = memory_address_to_byte(space, 1);
+	endoffset = space->address_to_byte(offset + length - 1) & space->bytemask();
+	offset = space->address_to_byte(offset) & space->bytemask();
+	cur_data_size = space->address_to_byte(1);
 	if (cur_data_size == 0)
 		cur_data_size = 1;
 
@@ -2161,7 +2169,7 @@ static void execute_find(running_machine *machine, int ref, int params, const ch
 		if (match)
 		{
 			found++;
-			debug_console_printf(machine, "Found at %s\n", core_i64_hex_format((UINT32)memory_byte_to_address(space, i), space->addrchars));
+			debug_console_printf(machine, "Found at %s\n", core_i64_hex_format((UINT32)space->byte_to_address(i), space->addrchars()));
 		}
 	}
 
@@ -2179,7 +2187,7 @@ static void execute_dasm(running_machine *machine, int ref, int params, const ch
 {
 	UINT64 offset, length, bytes = 1;
 	int minbytes, maxbytes, byteswidth;
-	const address_space *space;
+	address_space *space;
 	FILE *f = NULL;
 	int i, j;
 
@@ -2215,15 +2223,15 @@ static void execute_dasm(running_machine *machine, int ref, int params, const ch
 	/* now write the data out */
 	for (i = 0; i < length; )
 	{
-		int pcbyte = memory_address_to_byte(space, offset + i) & space->bytemask;
-		char output[200+DEBUG_COMMENT_MAX_LINE_LENGTH], disasm[200];
+		int pcbyte = space->address_to_byte(offset + i) & space->bytemask();
+		char output[512], disasm[200];
 		const char *comment;
 		offs_t tempaddr;
 		int outdex = 0;
 		int numbytes = 0;
 
 		/* print the address */
-		outdex += sprintf(&output[outdex], "%s: ", core_i64_hex_format((UINT32)memory_byte_to_address(space, pcbyte), space->logaddrchars));
+		outdex += sprintf(&output[outdex], "%s: ", core_i64_hex_format((UINT32)space->byte_to_address(pcbyte), space->logaddrchars()));
 
 		/* make sure we can translate the address */
 		tempaddr = pcbyte;
@@ -2246,7 +2254,7 @@ static void execute_dasm(running_machine *machine, int ref, int params, const ch
 		if (bytes)
 		{
 			int startdex = outdex;
-			numbytes = memory_address_to_byte(space, numbytes);
+			numbytes = space->address_to_byte(numbytes);
 			for (j = 0; j < numbytes; j += minbytes)
 				outdex += sprintf(&output[outdex], "%s ", core_i64_hex_format(debug_read_opcode(space, pcbyte + j, minbytes, FALSE), minbytes * 2));
 			if (outdex - startdex < byteswidth)
@@ -2258,7 +2266,7 @@ static void execute_dasm(running_machine *machine, int ref, int params, const ch
 		sprintf(&output[outdex], "%s", disasm);
 
 		/* attempt to add the comment */
-		comment = debug_comment_get_text(space->cpu, tempaddr, debug_comment_get_opcode_crc32(space->cpu, tempaddr));
+		comment = space->cpu->debug()->comment_text(tempaddr);
 		if (comment != NULL)
 		{
 			/* somewhat arbitrary guess as to how long most disassembly lines will be [column 60] */
@@ -2373,7 +2381,7 @@ static void execute_traceflush(running_machine *machine, int ref, int params, co
 static void execute_history(running_machine *machine, int ref, int params, const char *param[])
 {
 	/* validate parameters */
-	const address_space *space;
+	address_space *space;
 	if (!debug_command_parameter_cpu_space(machine, (params > 0) ? param[0] : NULL, ADDRESS_SPACE_PROGRAM, &space))
 		return;
 
@@ -2394,7 +2402,7 @@ static void execute_history(running_machine *machine, int ref, int params, const
 		offs_t pc = debug->history_pc(-index);
 
 		/* fetch the bytes up to the maximum */
-		offs_t pcbyte = memory_address_to_byte(space, pc) & space->bytemask;
+		offs_t pcbyte = space->address_to_byte(pc) & space->bytemask();
 		UINT8 opbuf[64], argbuf[64];
 		for (int numbytes = 0; numbytes < maxbytes; numbytes++)
 		{
@@ -2405,7 +2413,7 @@ static void execute_history(running_machine *machine, int ref, int params, const
 		char buffer[200];
 		debug->disassemble(buffer, pc, opbuf, argbuf);
 
-		debug_console_printf(machine, "%s: %s\n", core_i64_hex_format(pc, space->logaddrchars), buffer);
+		debug_console_printf(machine, "%s: %s\n", core_i64_hex_format(pc, space->logaddrchars()), buffer);
 	}
 }
 
@@ -2419,7 +2427,7 @@ static void execute_snap(running_machine *machine, int ref, int params, const ch
 	/* if no params, use the default behavior */
 	if (params == 0)
 	{
-		video_save_active_screen_snapshots(machine);
+		machine->video().save_active_screen_snapshots();
 		debug_console_printf(machine, "Saved snapshot\n");
 	}
 
@@ -2431,9 +2439,9 @@ static void execute_snap(running_machine *machine, int ref, int params, const ch
 		const char *filename = param[0];
 		int scrnum = (params > 1) ? atoi(param[1]) : 0;
 
-		device_t *screen = machine->m_devicelist.find(SCREEN, scrnum);
+		screen_device *screen = downcast<screen_device *>(machine->m_devicelist.find(SCREEN, scrnum));
 
-		if ((screen == NULL) || !render_is_live_screen(screen))
+		if ((screen == NULL) || !machine->render().is_live(*screen))
 		{
 			debug_console_printf(machine, "Invalid screen number '%d'\n", scrnum);
 			return;
@@ -2450,7 +2458,7 @@ static void execute_snap(running_machine *machine, int ref, int params, const ch
 			return;
 		}
 
-		screen_save_snapshot(screen->machine, screen, fp);
+		screen->machine->video().save_snapshot(screen, *fp);
 		mame_fclose(fp);
 		debug_console_printf(machine, "Saved screen #%d snapshot as '%s'\n", scrnum, filename);
 	}
@@ -2473,7 +2481,7 @@ static void execute_source(running_machine *machine, int ref, int params, const
 
 static void execute_map(running_machine *machine, int ref, int params, const char *param[])
 {
-	const address_space *space;
+	address_space *space;
 	offs_t taddress;
 	UINT64 address;
 	int intention;
@@ -2490,14 +2498,14 @@ static void execute_map(running_machine *machine, int ref, int params, const cha
 	for (intention = TRANSLATE_READ_DEBUG; intention <= TRANSLATE_FETCH_DEBUG; intention++)
 	{
 		static const char *const intnames[] = { "Read", "Write", "Fetch" };
-		taddress = memory_address_to_byte(space, address) & space->bytemask;
+		taddress = space->address_to_byte(address) & space->bytemask();
 		if (debug_cpu_translate(space, intention, &taddress))
 		{
-			const char *mapname = memory_get_handler_string(space, intention == TRANSLATE_WRITE_DEBUG, taddress);
-			debug_console_printf(machine, "%7s: %s logical == %s physical -> %s\n", intnames[intention & 3], core_i64_hex_format(address, space->logaddrchars), core_i64_hex_format(memory_byte_to_address(space, taddress), space->addrchars), mapname);
+			const char *mapname = const_cast<address_space *>(space)->get_handler_string((intention == TRANSLATE_WRITE_DEBUG) ? ROW_WRITE : ROW_READ, taddress);
+			debug_console_printf(machine, "%7s: %s logical == %s physical -> %s\n", intnames[intention & 3], core_i64_hex_format(address, space->logaddrchars()), core_i64_hex_format(space->byte_to_address(taddress), space->addrchars()), mapname);
 		}
 		else
-			debug_console_printf(machine, "%7s: %s logical is unmapped\n", intnames[intention & 3], core_i64_hex_format(address, space->logaddrchars));
+			debug_console_printf(machine, "%7s: %s logical is unmapped\n", intnames[intention & 3], core_i64_hex_format(address, space->logaddrchars()));
 	}
 }
 
@@ -2542,13 +2550,13 @@ static void execute_symlist(running_machine *machine, int ref, int params, const
 	symbol_table *symtable;
 	int symnum, count = 0;
 
-	/* validate parameters */
-	if (!debug_command_parameter_cpu(machine, param[0], &cpu))
-		return;
 
-	if (cpu != NULL)
+	if (param[0] != NULL)
 	{
-		symtable = cpu->debug()->symtable();
+		/* validate parameters */
+		if (!debug_command_parameter_cpu(machine, param[0], &cpu))
+			return;
+		symtable = &cpu->debug()->symtable();
 		debug_console_printf(machine, "CPU '%s' symbols:\n", cpu->tag());
 	}
 	else
@@ -2558,19 +2566,12 @@ static void execute_symlist(running_machine *machine, int ref, int params, const
 	}
 
 	/* gather names for all symbols */
-	for (symnum = 0; symnum < 100000; symnum++)
+	for (symbol_entry *entry = symtable->first(); entry != NULL; entry = entry->next())
 	{
-		const symbol_entry *entry;
-		const char *name = symtable_find_indexed(symtable, symnum, &entry);
-
-		/* if we didn't get anything, we're done */
-		if (name == NULL)
-			break;
-
 		/* only display "register" type symbols */
-		if (entry->type == SMT_REGISTER)
+		if (!entry->is_function())
 		{
-			namelist[count++] = name;
+			namelist[count++] = entry->name();
 			if (count >= ARRAY_LENGTH(namelist))
 				break;
 		}
@@ -2583,13 +2584,13 @@ static void execute_symlist(running_machine *machine, int ref, int params, const
 	/* iterate over symbols and print out relevant ones */
 	for (symnum = 0; symnum < count; symnum++)
 	{
-		const symbol_entry *entry = symtable_find(symtable, namelist[symnum]);
-		UINT64 value = (*entry->info.reg.getter)(symtable_get_globalref(entry->table), entry->ref);
+		const symbol_entry *entry = symtable->find(namelist[symnum]);
 		assert(entry != NULL);
+		UINT64 value = entry->value();
 
 		/* only display "register" type symbols */
 		debug_console_printf(machine, "%s = %s", namelist[symnum], core_i64_hex_format(value, 0));
-		if (entry->info.reg.setter == NULL)
+		if (!entry->is_lval())
 			debug_console_printf(machine, "  (read-only)");
 		debug_console_printf(machine, "\n");
 	}
