@@ -345,7 +345,6 @@ bool legacy_image_device_base::load_software(char *swlist, char *swname, rom_ent
 
 bool legacy_image_device_base::load_internal(const char *path, bool is_create, int create_format, option_resolution *create_args)
 {
-    image_error_t err;
     UINT32 open_plan[4];
     int i;
 	bool softload = FALSE;
@@ -360,8 +359,8 @@ bool legacy_image_device_base::load_internal(const char *path, bool is_create, i
     m_is_loading = TRUE;
 
     /* record the filename */
-    err = set_image_filename(path);
-    if (err)
+    m_err = set_image_filename(path);
+    if (m_err)
         goto done;
 
 	/* Check if there's a software list defined for this device and use that if we're not creating an image */
@@ -375,8 +374,8 @@ bool legacy_image_device_base::load_internal(const char *path, bool is_create, i
 		for (i = 0; !m_file && open_plan[i]; i++)
 		{
 			/* open the file */
-			err = load_image_by_path(open_plan[i], path);
-			if (err && (err != IMAGE_ERROR_FILENOTFOUND))
+			m_err = load_image_by_path(open_plan[i], path);
+			if (m_err && (m_err != IMAGE_ERROR_FILENOTFOUND))
 				goto done;
 		}
 	}
@@ -393,7 +392,7 @@ bool legacy_image_device_base::load_internal(const char *path, bool is_create, i
 	/* did we fail to find the file? */
 	if (!is_loaded() && !softload)
 	{
-		err = IMAGE_ERROR_FILENOTFOUND;
+		m_err = IMAGE_ERROR_FILENOTFOUND;
 		goto done;
 	}
 
@@ -402,14 +401,14 @@ bool legacy_image_device_base::load_internal(const char *path, bool is_create, i
 	m_create_args = create_args;
 
 	if (m_init_phase==FALSE) {
-		err = (image_error_t)finish_load();
-		if (err)
+		m_err = (image_error_t)finish_load();
+		if (m_err)
 			goto done;
 	}
     /* success! */
 
 done:
-    if (m_err) {
+    if (m_err!=0) {
 		if (!m_init_phase)
 		{
 			if (machine->phase() == MACHINE_PHASE_RUNNING)
@@ -434,7 +433,7 @@ done:
 			}
 		}
 	}
-	return err ? IMAGE_INIT_FAIL : IMAGE_INIT_PASS;
+	return m_err ? IMAGE_INIT_FAIL : IMAGE_INIT_PASS;
 }
 
 
@@ -529,6 +528,7 @@ void legacy_image_device_base::clear()
     m_year.reset();
     m_playable.reset();
     m_extrainfo.reset();
+	m_basename.reset();
     m_basename_noext.reset();
 	m_filetype.reset();
 
