@@ -14,6 +14,7 @@
  * DSD_555_CC            - NE555 Constant Current VCO
  * DSD_555_VCO1          - Op-Amp linear ramp based 555 VCO
  * DSD_566               - NE566 Simulation
+ * DSD_LS624             - 74LS624/629 Simulation
  *
  ************************************************************************
  *
@@ -55,7 +56,6 @@ struct dsd_555_mstbl_context
 	int		trig_is_logic;
 	int		trig_discharges_cap;
 	int		output_type;
-	int		output_is_ac;
 	double	ac_shift;				/* DC shift needed to make waveform ac */
 	int		flip_flop;				/* 555 flip/flop output state */
 	int		has_rc_nodes;
@@ -125,22 +125,13 @@ struct dsd_566_context
 
 struct dsd_ls624_context
 {
-	int			state;
-	double		remain;			/* remaining time from last step */
-	int			out_type;
-	double		k1;				/* precalculated cap part of formula */
-	double		k2;				/* precalculated ring part of formula */
-	double		dt_vmod_at_0;
-};
-
-struct dsd_ls629_context
-{
-	double	v_bias;
-	double	v_cap;
-	double	v_peak;
-	double	v_threshold;
-	double	k_vmod_to_i;
+	double	exponent;
+	double	t_used;
+	double	v_cap_freq_in;
+	double	v_freq_scale;
+	double	v_rng_scale;
 	int		flip_flop;
+	int		has_freq_in_cap;
 	int		out_type;
 };
 
@@ -174,10 +165,10 @@ struct dsd_ls629_context
 #define DSD_555_ASTBL_T_RC_CHARGE		((DSD_555_ASTBL__R1 + ((info->options & DISC_555_ASTABLE_HAS_FAST_CHARGE_DIODE) ? 0 : DSD_555_ASTBL__R2)) * DSD_555_ASTBL__C)
 #define DSD_555_ASTBL_T_RC_DISCHARGE	(DSD_555_ASTBL__R2 * DSD_555_ASTBL__C)
 
-static DISCRETE_STEP(dsd_555_astbl)
+DISCRETE_STEP(dsd_555_astbl)
 {
-	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
-	struct dsd_555_astbl_context *context = (struct dsd_555_astbl_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_astbl)
+	DISCRETE_DECLARE_INFO(discrete_555_desc)
 
 	int		count_f = 0;
 	int		count_r = 0;
@@ -400,10 +391,11 @@ static DISCRETE_STEP(dsd_555_astbl)
 	context->flip_flop = flip_flop;
 }
 
-static DISCRETE_RESET(dsd_555_astbl)
+DISCRETE_RESET(dsd_555_astbl)
 {
-	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
-	struct dsd_555_astbl_context *context = (struct dsd_555_astbl_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_astbl)
+	DISCRETE_DECLARE_INFO(discrete_555_desc)
+
 	node_description *v_charge_node;
 
 	context->use_ctrlv   = (node->input_is_node >> 4) & 1;
@@ -484,20 +476,21 @@ static DISCRETE_RESET(dsd_555_astbl)
 /* bit mask of the above RC inputs */
 #define DSD_555_MSTBL_RC_MASK	0x0c
 
-static DISCRETE_STEP(dsd_555_mstbl)
+DISCRETE_STEP(dsd_555_mstbl)
 {
-	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
-	struct dsd_555_mstbl_context *context = (struct dsd_555_mstbl_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_mstbl)
+	DISCRETE_DECLARE_INFO(discrete_555_desc)
 
 	double v_cap;			/* Current voltage on capacitor, before dt */
-	double v_cap_next = 0;	/* Voltage on capacitor, after dt */
-	double x_time  = 0;		/* time since change happened */
+	double x_time = 0;		/* time since change happened */
 	double dt, exponent;
+	double out = 0;
 	int trigger = 0;
 	int trigger_type;
-	int update_exponent = 0;
+	int update_exponent = context->has_rc_nodes;
+	int flip_flop;
 
-	if(DSD_555_MSTBL__RESET)
+	if(UNEXPECTED(DSD_555_MSTBL__RESET))
 	{
 		/* We are in RESET */
 		node->output[0]     = 0;
@@ -506,108 +499,121 @@ static DISCRETE_STEP(dsd_555_mstbl)
 		return;
 	}
 
-	trigger_type = info->options;
 	dt = node->info->sample_time;
+	flip_flop = context->flip_flop;
+	trigger_type = info->options;
+	v_cap = context->cap_voltage;
 
 	switch (trigger_type & DSD_555_TRIGGER_TYPE_MASK)
 	{
 		case DISC_555_TRIGGER_IS_LOGIC:
-			trigger = (int)!DSD_555_MSTBL__TRIGGER;
+			trigger = ((int)DSD_555_MSTBL__TRIGGER) ? 0 : 1;
+			if (UNEXPECTED(trigger))
+				x_time = 1.0 - DSD_555_MSTBL__TRIGGER;
 			break;
 		case DISC_555_TRIGGER_IS_VOLTAGE:
 			trigger = (int)(DSD_555_MSTBL__TRIGGER < context->trigger);
 			break;
 		case DISC_555_TRIGGER_IS_COUNT:
 			trigger = (int)DSD_555_MSTBL__TRIGGER;
-			if (trigger && !context->flip_flop)
-			{
+			if (UNEXPECTED(trigger))
 				x_time = DSD_555_MSTBL__TRIGGER - trigger;
-				if (x_time != 0)
-				{
-					/* adjust sample to after trigger */
-					x_time = (1.0 - x_time);
-					update_exponent = 1;
-					dt = x_time * node->info->sample_time;
-				}
-			}
 			break;
 	}
 
+	if (UNEXPECTED(trigger && !flip_flop && x_time != 0))
+	{
+		/* adjust sample to after trigger */
+		update_exponent = 1;
+		dt *= x_time;
+	}
+	x_time = 0;
+
 	if ((trigger_type & DISC_555_TRIGGER_DISCHARGES_CAP) && trigger)
 		context->cap_voltage = 0;
 
 	/* Wait for trigger */
-	if (!context->flip_flop && trigger)
-		context->flip_flop = 1;
-
-	if (context->flip_flop)
+	if (UNEXPECTED(!flip_flop && trigger))
 	{
-		v_cap = context->cap_voltage;
+		flip_flop = 1;
+		context->flip_flop = 1;
+	}
 
+	if (flip_flop)
+	{
 		/* Sometimes a switching network is used to setup the capacitance.
          * These may select 'no' capacitor, causing oscillation to stop.
          */
-		if (DSD_555_MSTBL__C == 0)
+		if (UNEXPECTED(DSD_555_MSTBL__C == 0))
 		{
-			context->flip_flop = 0;
-			/* The voltage goes high because the cap circuit is open. */
-			v_cap_next = info->v_pos;
-			v_cap      = info->v_pos;
+			/* The trigger voltage goes high because the cap circuit is open.
+             * and the cap discharges */
+			v_cap = info->v_pos;	/* needed for cap output type */
 			context->cap_voltage = 0;
+
+			if (!trigger)
+			{
+				flip_flop = 0;
+				context->flip_flop = 0;
+			}
 		}
 		else
 		{
 			/* Charging */
-			update_exponent |= context->has_rc_nodes;
-			if (update_exponent)
+			double v_diff = context->v_charge - v_cap;
+
+			if (UNEXPECTED(update_exponent))
 				exponent = RC_CHARGE_EXP_DT(DSD_555_MSTBL__R * DSD_555_MSTBL__C, dt);
 			else
 				exponent = context->exp_charge;
-			v_cap_next = v_cap + ((info->v_pos - v_cap) * exponent);
+			v_cap += v_diff * exponent;
 
 			/* Has it charged past upper limit? */
 			/* If trigger is still enabled, then we keep charging,
              * regardless of threshold. */
-			if ((v_cap_next >= context->threshold) && !trigger)
+			if (UNEXPECTED((v_cap >= context->threshold) && !trigger))
 			{
-				dt = DSD_555_MSTBL__R * DSD_555_MSTBL__C  * log(1.0 / (1.0 - ((v_cap_next - context->threshold) / (context->v_charge - v_cap))));
-				x_time = dt / node->info->sample_time;
-				v_cap_next = 0;
-				v_cap      = context->threshold;
+				dt = DSD_555_MSTBL__R * DSD_555_MSTBL__C  * log(1.0 / (1.0 - ((v_cap - context->threshold) / v_diff)));
+				x_time = 1.0 - dt / node->info->sample_time;
+				v_cap  = 0;
+				flip_flop = 0;
 				context->flip_flop = 0;
 			}
+			context->cap_voltage = v_cap;
 		}
-
-		context->cap_voltage = v_cap_next;
 	}
 
-	switch (info->options & DISC_555_OUT_MASK)
+	switch (context->output_type)
 	{
 		case DISC_555_OUT_SQW:
-			node->output[0] = context->flip_flop * context->v_out_high;
-			/* Fake it to AC if needed */
-			if (context->output_is_ac)
-				node->output[0] -= context->v_out_high / 2.0;
+			out = flip_flop * context->v_out_high - context->ac_shift;
 			break;
 		case DISC_555_OUT_CAP:
-			node->output[0] = v_cap_next;
-			/* Fake it to AC if needed */
-			if (context->output_is_ac)
-				node->output[0] -= context->threshold * 3.0 /4.0;
+			if (x_time > 0)
+				out = v_cap * x_time;
+			else
+				out = v_cap;
+
+			out -= context->ac_shift;
 			break;
 		case DISC_555_OUT_ENERGY:
-			if (x_time == 0) x_time = 1.0;
-			node->output[0] = context->v_out_high * (context->flip_flop ? x_time : (1.0 - x_time));
-				if (context->output_is_ac)
-					node->output[0] -= context->v_out_high / 2.0;
+			if (x_time > 0)
+				out = context->v_out_high * x_time;
+			else if (flip_flop)
+				out = context->v_out_high;
+			else
+				out = 0;
+
+			out -= context->ac_shift;
 			break;
 	}
+	node->output[0] = out;
 }
 
-static DISCRETE_RESET(dsd_555_mstbl)
+DISCRETE_RESET(dsd_555_mstbl)
 {
-	const  discrete_555_desc     *info    = (const  discrete_555_desc *)node->custom;
-	struct dsd_555_mstbl_context *context = (struct dsd_555_mstbl_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_mstbl)
+	DISCRETE_DECLARE_INFO(discrete_555_desc)
 
 	context->output_type = info->options & DISC_555_OUT_MASK;
 	if ((context->output_type == DISC_555_OUT_COUNT_F) || (context->output_type == DISC_555_OUT_COUNT_R))
@@ -624,9 +630,16 @@ static DISCRETE_RESET(dsd_555_mstbl)
 	context->threshold = info->v_pos * 2.0 / 3.0;
 	context->trigger   = info->v_pos / 3.0;
 
-	context->output_is_ac = info->options & DISC_555_OUT_AC;
-	/* Calculate DC shift needed to make squarewave waveform AC */
-	context->ac_shift     = context->output_is_ac ? -context->v_out_high / 2.0 : 0;
+	/* Calculate DC shift needed to make waveform AC */
+	if (info->options & DISC_555_OUT_AC)
+	{
+		if (context->output_type == DISC_555_OUT_CAP)
+			context->ac_shift = context->threshold * 3.0 /4.0;
+		else
+			context->ac_shift = context->v_out_high / 2.0;
+	}
+	else
+		context->ac_shift = 0;
 
 	context->trig_is_logic       = (info->options & DISC_555_TRIGGER_IS_VOLTAGE) ? 0: 1;
 	context->trig_discharges_cap = (info->options & DISC_555_TRIGGER_DISCHARGES_CAP) ? 1: 0;
@@ -680,10 +693,10 @@ static DISCRETE_RESET(dsd_555_mstbl)
 #define DSD_555_CC_T_RC_DISCHARGE		(r_discharge * DSD_555_CC__C)
 
 
-static DISCRETE_STEP(dsd_555_cc)
+DISCRETE_STEP(dsd_555_cc)
 {
-	const  discrete_555_cc_desc *info    = (const  discrete_555_cc_desc *)node->custom;
-	struct dsd_555_cc_context   *context = (struct dsd_555_cc_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_cc)
+	DISCRETE_DECLARE_INFO(discrete_555_cc_desc)
 
 	int		count_f  = 0;
 	int		count_r  = 0;
@@ -1001,10 +1014,10 @@ static DISCRETE_STEP(dsd_555_cc)
 	context->flip_flop = flip_flop;
 }
 
-static DISCRETE_RESET(dsd_555_cc)
+DISCRETE_RESET(dsd_555_cc)
 {
-	const  discrete_555_cc_desc *info    = (const  discrete_555_cc_desc *)node->custom;
-	struct dsd_555_cc_context   *context = (struct dsd_555_cc_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_cc)
+	DISCRETE_DECLARE_INFO(discrete_555_cc_desc)
 
 	double	r_temp, r_discharge = 0, r_charge = 0;
 
@@ -1231,10 +1244,10 @@ static DISCRETE_RESET(dsd_555_cc)
 #define DSD_555_VCO1__VIN1	DISCRETE_INPUT(1)
 #define DSD_555_VCO1__VIN2	DISCRETE_INPUT(2)
 
-static DISCRETE_STEP(dsd_555_vco1)
+DISCRETE_STEP(dsd_555_vco1)
 {
-	const  discrete_555_vco1_desc *info    = (const  discrete_555_vco1_desc *)node->custom;
-	struct dsd_555_vco1_context   *context = (struct dsd_555_vco1_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_vco1)
+	DISCRETE_DECLARE_INFO(discrete_555_vco1_desc)
 
 	int		count_f = 0;
 	int		count_r = 0;
@@ -1384,10 +1397,10 @@ static DISCRETE_STEP(dsd_555_vco1)
 	}
 }
 
-static DISCRETE_RESET(dsd_555_vco1)
+DISCRETE_RESET(dsd_555_vco1)
 {
-	const  discrete_555_vco1_desc *info    = (const  discrete_555_vco1_desc *)node->custom;
-	struct dsd_555_vco1_context   *context = (struct dsd_555_vco1_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_555_vco1)
+	DISCRETE_DECLARE_INFO(discrete_555_vco1_desc)
 
 	double v_ratio_r3, v_ratio_r4_1, r_in_1;
 
@@ -1522,9 +1535,9 @@ static const struct
 	{4.495, /*4.895,*/ 5.343, /*5.703,*/ 5.997, 6.507, 7.016, 7.518}		/* osc_stop */
 };
 
-static DISCRETE_STEP(dsd_566)
+DISCRETE_STEP(dsd_566)
 {
-	struct dsd_566_context   *context = (struct dsd_566_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_566)
 
 	double	i = 0;			/* Charging current created by vIn */
 	double	i_rise;			/* non-linear rise charge current */
@@ -1644,9 +1657,9 @@ static DISCRETE_STEP(dsd_566)
 	}
 }
 
-static DISCRETE_RESET(dsd_566)
+DISCRETE_RESET(dsd_566)
 {
-	struct dsd_566_context   *context = (struct dsd_566_context *)node->context;
+	DISCRETE_DECLARE_CONTEXT(dsd_566)
 
 	int		v_int;
 	double	v_float;
@@ -1695,129 +1708,21 @@ static DISCRETE_RESET(dsd_566)
  *
  * DSD_LS624 - Usage of node_description values
  *
- * input[0]    - Modulation Voltage
- * input[1]    - Range Voltage
- * input[2]    - C value
- * input[3]    - Output type
- *
- * Dec 2007, Couriersud
- ************************************************************************/
-#define DSD_LS624__VMOD		DISCRETE_INPUT(0)
-#define DSD_LS624__VRNG		DISCRETE_INPUT(1)
-#define DSD_LS624__C		DISCRETE_INPUT(2)
-#define DSD_LS624__OUTTYPE	DISCRETE_INPUT(3)
-
-/*
- * The datasheet mentions a 600 ohm discharge. It also gives
- * equivalent circuits for VI and VR.
- */
-
-#define LS624_F1(x)			(0.19 + 20.0/90.0*(x))
-#define LS624_T(_C, _R, _F)		((-600.0 * (_C) * log(1.0-LS624_F1(_R)*0.12/LS624_F1(_F))) * 16.0 )
-
-/* The following formula was derived from figures 2 and 3 in LS624 datasheet. Coefficients
- * where calculated using least square approximation.
- * This approach gives a bit better results compared to the first approach.
- */
-/* Original formula before optimization of static values
- #define LS624_F(_C, _VI, _VR)  pow(10, -0.912029404 * log10(_C) + 0.243264328 * (_VI) \
-                  - 0.091695877 * (_VR) -0.014110946 * (_VI) * (_VR) - 3.207072925)
-*/
-
-/* pow(10, x) = exp(ln(10)*x) */
-#define pow10(x) exp(2.30258509299404568401*(x))
-
-#define LS624_F(_VI)	pow10(context->k1 + 0.243264328 * (_VI) + context->k2 * (_VI))
-
-static DISCRETE_STEP(dsd_ls624)
-{
-	struct dsd_ls624_context *context = (struct dsd_ls624_context *)node->context;
-
-	double	dt;	/* change in time */
-	double	sample_t;
-	double	t;
-	double  en = 0.0f;
-	int		cntf = 0, cntr = 0;
-
-	sample_t = node->info->sample_time;	/* Change in time */
-	//dt  = LS624_T(DSD_LS624__C, DSD_LS624__VRNG, DSD_LS624__VMOD) / 2.0;
-	if (EXPECTED(DSD_LS624__VMOD > 0.001))
-		dt = 0.5 / LS624_F(DSD_LS624__VMOD);
-	else
-		/* close enough to 0, so we can speed things up by no longer call pow() */
-		dt = context->dt_vmod_at_0;
-	t   = context->remain;
-	en += (double) context->state * t;
-	while (EXPECTED(t + dt <= sample_t))
-	{
-		en += (double) context->state * dt;
-		context->state = (1 - context->state);
-		if (context->state)
-			cntr++;
-		else
-			cntf++;
-		t += dt;
-	}
-	en += (sample_t - t) * (double) context->state;
-	context->remain = t - sample_t;
-
-	switch (context->out_type)
-	{
-		case DISC_LS624_OUT_ENERGY:
-			node->output[0] = en / sample_t;
-			break;
-		case DISC_LS624_OUT_LOGIC:
-			/* filter out randomness */
-			if (UNEXPECTED(cntf + cntr > 1))
-				node->output[0] = 1;
-			else
-				node->output[0] = context->state;
-			break;
-		case DISC_LS624_OUT_COUNT_F:
-			node->output[0] = cntf;
-			break;
-		case DISC_LS624_OUT_COUNT_R:
-			node->output[0] = cntr;
-			break;
-	}
-}
-
-static DISCRETE_RESET(dsd_ls624)
-{
-	struct dsd_ls624_context *context = (struct dsd_ls624_context *)node->context;
-
-	context->remain   = 0;
-	context->state    = 0;
-	context->out_type = DSD_LS624__OUTTYPE;
-
-	/* precalculate some parts of the formula for speed */
-	context->k1 = -0.912029404 * log10(DSD_LS624__C) -0.091695877 * (DSD_LS624__VRNG) - 3.207072925;
-	context->k2 = -0.014110946 * (DSD_LS624__VRNG);
-
-	context->dt_vmod_at_0 = 0.5 / LS624_F(0);
-
-	/* Step the output */
-	DISCRETE_STEP_CALL(dsd_ls624);
-}
-
-
-/************************************************************************
- *
- * DSD_LS629 - Usage of node_description values
- *
  * Dec 2007, Couriersud based on data sheet
  * Oct 2009, complete re-write based on IC testing
  ************************************************************************/
-#define DSD_LS629__ENABLE		DISCRETE_INPUT(0)
-#define DSD_LS629__VMOD			DISCRETE_INPUT(1)
-#define DSD_LS629__VRNG			DISCRETE_INPUT(2)
-#define DSD_LS629__C			DISCRETE_INPUT(3)
-#define DSD_LS629__R_FREQ_IN	DISCRETE_INPUT(4)
-#define DSD_LS629__OUTTYPE		DISCRETE_INPUT(5)
+#define DSD_LS624__ENABLE		DISCRETE_INPUT(0)
+#define DSD_LS624__VMOD			DISCRETE_INPUT(1)
+#define DSD_LS624__VRNG			DISCRETE_INPUT(2)
+#define DSD_LS624__C			DISCRETE_INPUT(3)
+#define DSD_LS624__R_FREQ_IN	DISCRETE_INPUT(4)
+#define DSD_LS624__C_FREQ_IN	DISCRETE_INPUT(5)
+#define DSD_LS624__R_RNG_IN		DISCRETE_INPUT(6)
+#define DSD_LS624__OUTTYPE		DISCRETE_INPUT(7)
 
 #define LS624_R_EXT			600.0		/* as specified in data sheet */
 #define LS624_OUT_HIGH		4.5			/* measured */
-#define LS624_FREQ_R_IN		RES_K(95)	/* measured */
+#define LS624_IN_R		RES_K(90)	/* measured & 70K + 20k per data sheet */
 
 /*
  * The 74LS624 series are constant current based VCOs.  The Freq Control voltage
@@ -1835,112 +1740,111 @@ static DISCRETE_RESET(dsd_ls624)
  * The Range voltage adjusts the threshold voltage.  The higher the Range voltage,
  * the lower the threshold voltage, the longer the cap can charge, the lower the frequency.
  *
+ * In a perfect world it would work like this:
  * The current is based on the mysterious Rext mentioned in the data sheet.
- * I = (VfreqControl / 5) / Rext
+ * I = (VfreqControl  * 20k/90k) / Rext
  * where Rext = 600 ohms or external Rext on a 74LS628
- * The Freq Control has an input impedance of approximately 100k, so any input resistance
+ * The Freq Control has an input impedance of approximately 90k, so any input resistance
  * connected to the Freq Control pin works as a voltage divider.
- * I = (VfreqControl / 5 * 100000 / (RfreqControl + 100000)) / Rext
+ * I = (VfreqControl * 20k/(90k + RfreqControlIn)) / Rext
  * That gives us a change in voltage on the cap of
  * dV = I / sampleRate / C_inFarads
+ *
+ * Unfortunately the chip does not behave linearly do to internal interactions,
+ * so I have just worked out the formula (using zunzun.com) of FreqControl and
+ * range to frequency out for a fixed cap value of 0.1uf.  Other cap values can just
+ * scale from that.  From the freq, we calculate the time of 1/2 cycle using 1/Freq/2.
+ * Then just use that to toggle a waveform.
  */
 
-/* The range to bias and threshold routines were created from testing a real chip.
- * This data was entered into the function finder routine at www.zunzun.com
- * to create the following 2 routines
- */
 
-double range_to_bias(double range)
+DISCRETE_STEP(dsd_ls624)
 {
-	/* Quadratic2D_model */
-	double bias;
+	DISCRETE_DECLARE_CONTEXT(dsd_ls624)
 
-	// coefficients
-	const double a =  2.3107142857142846E+00;
-	const double b = -1.0714285714278806E-03;
-	const double c = -1.7857142857144002E-03;
-
-	bias  = a;
-	bias += b * range;
-	bias += c * pow(range, 2.0);
-	return bias;
-}
-
-double range_to_threshold(double range)
-{
-	/* Polyfunctional2D_model */
-	double threshold;
-
-	// coefficients
-	const double a = -1.6124587587173614E-01;
-	const double b = -1.3501987413150401E-01;
-	const double offset = 2.2550390868489893E+00;
-
-	threshold  = a * range;
-	threshold += b * exp(-1.0 * range);
-	threshold += offset;
-	return threshold;
-}
-
-
-static DISCRETE_STEP(dsd_ls629)
-{
-	struct dsd_ls629_context *context = (struct dsd_ls629_context *)node->context;
-
-	double	i;			/* Charging current created by Freq Control */
-	double	dt;				/* change in time */
 	double	x_time = 0;
-	double	v_cap;			/* Current voltage on capacitor, before dt */
+	double	freq, t1;
+	double	v_freq_2, v_freq_3, v_freq_4;
+	double	t_used = context->t_used;
+	double	dt = node->info->sample_time;;
+	double	v_freq = DSD_LS624__VMOD;
+	double	v_rng = DSD_LS624__VRNG;
 	int		count_f = 0, count_r = 0;
 
-	if (UNEXPECTED(DSD_LS629__ENABLE == 0))
+	/* coefficients */
+	const double k1 = 1.9904769024796283E+03;
+	const double k2 = 1.2070059213983407E+03;
+	const double k3 = 1.3266985579561108E+03;
+	const double k4 = -1.5500979825922698E+02;
+	const double k5 = 2.8184536266938172E+00;
+	const double k6 = -2.3503421582744556E+02;
+	const double k7 = -3.3836786704527788E+02;
+	const double k8 = -1.3569136703258670E+02;
+	const double k9 = 2.9914575453819188E+00;
+	const double k10 = 1.6855569086173170E+00;
+
+	if (UNEXPECTED(DSD_LS624__ENABLE == 0))
 		return;
 
-	dt    = node->info->sample_time;	/* Change in time */
-	v_cap = context->v_cap;				/* Set to voltage before change */
+	/* scale due to input resistance */
+	v_freq *= context->v_freq_scale;
+	v_rng *= context->v_rng_scale;
 
+	/* apply cap if needed */
+	if (context->has_freq_in_cap)
+	{
+		context->v_cap_freq_in += (v_freq - context->v_cap_freq_in) * context->exponent;
+		v_freq = context->v_cap_freq_in;
+	}
 
-	/* Calculate charging current */
-	i = DSD_LS629__VMOD * context->k_vmod_to_i;
+	/* Polyfunctional3D_model created by zunzun.com using sum of squared absolute error */
+	v_freq_2 = v_freq * v_freq;
+	v_freq_3 = v_freq_2 * v_freq;
+	v_freq_4 = v_freq_3 * v_freq;
+	freq = k1;
+	freq += k2 * v_freq;
+	freq += k3 * v_freq_2;
+	freq += k4 * v_freq_3;
+	freq += k5 * v_freq_4;
+	freq += k6 * v_rng;
+	freq += k7 * v_rng * v_freq;
+	freq += k8 * v_rng * v_freq_2;
+	freq += k9 * v_rng * v_freq_3;
+	freq += k10 * v_rng * v_freq_4;
 
-	/* Keep looping until all toggling in this time sample is used up. */
+	freq *= CAP_U(0.1) / DSD_LS624__C;
+
+	t1 = 0.5 / freq ;
+	t_used += node->info->sample_time;
 	do
 	{
-		/* Always Discharging */
-		v_cap -= i * dt / DSD_LS629__C;
-		dt     = 0;
-
-		/* has it discharged past lower limit? */
-		if (UNEXPECTED(v_cap < context->v_threshold))
+		dt = 0;
+		if (t_used > t1)
 		{
 			/* calculate the overshoot time */
-			dt = DSD_LS629__C * (context->v_threshold - v_cap) / i;
-			v_cap = context->v_peak;
+			t_used -= t1;
 			context->flip_flop ^= 1;
 			if (context->flip_flop)
 				count_r++;
 			else
 				count_f++;
-			x_time = dt;
+			/* fix up any frequency increase change errors */
+			while(t_used > node->info->sample_time)
+				t_used -= node->info->sample_time;
+			x_time = t_used;
+			dt = t_used;
 		}
-	} while(dt);
+	}while(dt);
 
-	context->v_cap = v_cap;
+	context->t_used = t_used;
 
 	/* Convert last switch time to a ratio */
 	x_time = x_time / node->info->sample_time;
 
 	switch (context->out_type)
 	{
-		case DISC_LS624_OUT_SQUARE:
-			node->output[0] = context->flip_flop ? LS624_OUT_HIGH : 0;
-			break;
-		case DISC_LS624_OUT_ENERGY:
-			if (x_time == 0) x_time = 1.0;
-			node->output[0]  = LS624_OUT_HIGH * (context->flip_flop ? x_time : (1.0 - x_time));
-			break;
-		case DISC_LS624_OUT_LOGIC:
-				node->output[0] = context->flip_flop;
+		case DISC_LS624_OUT_LOGIC_X:
+				node->output[0] = context->flip_flop  + x_time;
 			break;
 		case DISC_LS624_OUT_COUNT_F_X:
 			node->output[0] = count_f ? count_f + x_time : count_f;
@@ -1954,26 +1858,37 @@ static DISCRETE_STEP(dsd_ls629)
 		case DISC_LS624_OUT_COUNT_R:
 			node->output[0] = count_r;
 			break;
+		case DISC_LS624_OUT_ENERGY:
+			if (x_time == 0) x_time = 1.0;
+			node->output[0] = LS624_OUT_HIGH * (context->flip_flop ? x_time : (1.0 - x_time));
+			break;
+		case DISC_LS624_OUT_LOGIC:
+				node->output[0] = context->flip_flop;
+			break;
+		case DISC_LS624_OUT_SQUARE:
+			node->output[0] = context->flip_flop ? LS624_OUT_HIGH : 0;
+			break;
 	}
 }
 
-#define LS624_LOSS_FACTOR	0.92
-
-static DISCRETE_RESET(dsd_ls629)
+DISCRETE_RESET(dsd_ls624)
 {
-	struct dsd_ls629_context *context = (struct dsd_ls629_context *)node->context;
+	struct dsd_ls624_context *context = (struct dsd_ls624_context *)node->context;
 
-	context->out_type = (int)DSD_LS629__OUTTYPE;
+	context->out_type = (int)DSD_LS624__OUTTYPE;
 
-	context->v_bias = range_to_bias(DSD_LS629__VRNG);
-	context->v_cap = context->v_bias;
-	context->v_threshold = range_to_threshold(DSD_LS629__VRNG);
-	/* The voltage at the current charge pin after a state change */
-	context->v_peak = context->v_bias * 2 - context->v_threshold;
 	context->flip_flop = 0;
-	/* precalulate the voltage to current formula */
-	context->k_vmod_to_i  = 1.0 / 5 * LS624_FREQ_R_IN / (DSD_LS629__R_FREQ_IN + LS624_FREQ_R_IN) / LS624_R_EXT;
-	context->k_vmod_to_i *= LS624_LOSS_FACTOR;
+	context->t_used = 0;
+	context->v_freq_scale = LS624_IN_R / (DSD_LS624__R_FREQ_IN + LS624_IN_R);
+	context->v_rng_scale = LS624_IN_R / (DSD_LS624__R_RNG_IN + LS624_IN_R);
+	if (DSD_LS624__C_FREQ_IN > 0)
+	{
+		context->has_freq_in_cap = 1;
+		context->exponent = RC_CHARGE_EXP(RES_2_PARALLEL(DSD_LS624__R_FREQ_IN, LS624_IN_R) * DSD_LS624__C_FREQ_IN);
+		context->v_cap_freq_in = 0;
+	}
+	else
+		context->has_freq_in_cap = 0;
 
 	node->output[0] = 0;
 }
