@@ -68,7 +68,7 @@ struct _k054539_channel {
 typedef struct _k054539_state k054539_state;
 struct _k054539_state {
 	const k054539_interface *intf;
-	running_device *device;
+	device_t *device;
 	double voltab[256];
 	double pantab[0xf];
 
@@ -91,22 +91,22 @@ struct _k054539_state {
 	k054539_channel channels[8];
 };
 
-INLINE k054539_state *get_safe_token(running_device *device)
+INLINE k054539_state *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
-	assert(device->type() == SOUND_K054539);
+	assert(device->type() == K054539);
 	return (k054539_state *)downcast<legacy_device_base *>(device)->token();
 }
 
 //*
 
-void k054539_init_flags(running_device *device, int flags)
+void k054539_init_flags(device_t *device, int flags)
 {
 	k054539_state *info = get_safe_token(device);
 	info->k054539_flags = flags;
 }
 
-void k054539_set_gain(running_device *device, int channel, double gain)
+void k054539_set_gain(device_t *device, int channel, double gain)
 {
 	k054539_state *info = get_safe_token(device);
 	if (gain >= 0) info->k054539_gain[channel] = gain;
@@ -443,7 +443,7 @@ static TIMER_CALLBACK( k054539_irq )
 		info->intf->irq(info->device);
 }
 
-static void k054539_init_chip(running_device *device, k054539_state *info)
+static void k054539_init_chip(device_t *device, k054539_state *info)
 {
 	int i;
 
@@ -457,7 +457,7 @@ static void k054539_init_chip(running_device *device, k054539_state *info)
 	info->cur_ptr = 0;
 	memset(info->ram, 0, 0x4000*2+device->clock()/50*2);
 
-	const region_info *region = (info->intf->rgnoverride != NULL) ? device->machine->region(info->intf->rgnoverride) : device->region();
+	const memory_region *region = (info->intf->rgnoverride != NULL) ? device->machine->region(info->intf->rgnoverride) : device->region();
 	info->rom = *region;
 	info->rom_size = region->bytes();
 	info->rom_mask = 0xffffffffU;
