@@ -18,7 +18,7 @@ WRITE8_DEVICE_HANDLER( rf5c68_mem_w );
 typedef struct _rf5c68_interface rf5c68_interface;
 struct _rf5c68_interface
 {
-	void (*sample_end_callback)(running_device* device, int channel);
+	void (*sample_end_callback)(device_t* device, int channel);
 };
 
 DECLARE_LEGACY_SOUND_DEVICE(RF5C68, rf5c68);
