@@ -1,11 +1,45 @@
 /*
     vlm5030.c
 
-    VLM5030 emulator
+    Sanyo VLM5030 emulator
 
     Written by Tatsuyuki Satoh
     Based on TMS5220 simulator (tms5220.c)
 
+                 +-------,_,-------+
+        GND   -- |  1           40 | <-    RST
+  (gnd) TST1  -> |  2           39 | ??    TST4
+        OSC2  ck |  3     _     38 | ??    TST3
+        OSC1  ck |  4    (_)    37 | ??    TST2
+        D0    -> |  5           36 | ->    DAO
+        D1    -> |  6           35 | --    VREF (+5v thru 5.6k resistor)
+        D2    -> |  7           34 | ->    MTE
+        D3    -> |  8      V    33 | ->    /ME
+        D4    -> |  9      L    32 | <-    VCU
+        D5    -> | 10      M    31 | <-    START
+        D6    -> | 11      5    30 | ->    BSY
+        D7    -> | 12      0    29 | --    Vdd (+5v)
+        A0    <- | 13      3    28 | ->    A15
+        A1    <- | 14      0    27 | ->    A14
+        A2    <- | 15           26 | ->    A13
+        A3    <- | 16     _     25 | ->    A12
+        A4    <- | 17    (_)    24 | ->    A11
+        A5    <- | 18           23 | ->    A10
+        A6    <- | 19           22 | ->    A9
+        A7    <- | 20           21 | ->    A8
+                 +-----------------+
+
+TST1 is probably a test mode enable pin, must be grounded for normal operation.
+TST2-4 are some sort of test pins but can be left floating?
+VREF is probably the 0v ref for the output dac
+DAO is the output dac
+/ME is connected to the voice data rom /OE enable
+START strobes in a byte of data over the data bus from host cpu
+OSC1/2 are to both ends of a 3.579545MHz xtal with a 100pf cap from each end to gnd
+VCU makes the data bus select the upper 8 bits of the word register internally instead of the lower 8 bits. it is only useful if you need more than 256 phrases in rom? (recheck this)
+MTE is an output for roms which need to be clocked to latch address before use, or for a latch sitting in front of the voice rom address lines? (recheck this)
+RST not only resets the chip on its rising edge but grabs a byte of mode state data from the data bus on its falling edge? (recheck this)
+
   note:
     memory read cycle(==sampling rate) = 122.9u(440clock)
     interpolator (LC8109 = 2.5ms)      = 20 * samples(125us)
@@ -13,7 +47,7 @@
     9bit DAC is composed of 5bit Physical and 3bitPWM.
 
   todo:
-    Noise Generator circuit without 'mame_rand()' function.
+    Noise Generator circuit without 'machine->rand()' function.
 
 ----------- command format (Analytical result) ----------
 
@@ -89,7 +123,7 @@ chirp 12-..: vokume   0   : silent
 typedef struct _vlm5030_state vlm5030_state;
 struct _vlm5030_state
 {
-	running_device *device;
+	device_t *device;
 	const vlm5030_interface *intf;
 
 	sound_stream * channel;
@@ -219,10 +253,10 @@ static const INT16 K5_table[] = {
        0,   -8127,  -16384,  -24511,   32638,   24511,   16254,    8127
 };
 
-INLINE vlm5030_state *get_safe_token(running_device *device)
+INLINE vlm5030_state *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
-	assert(device->type() == SOUND_VLM5030);
+	assert(device->type() == VLM5030);
 	return (vlm5030_state *)downcast<legacy_device_base *>(device)->token();
 }
 
@@ -377,7 +411,7 @@ static STREAM_UPDATE( vlm5030_update_callback )
 			}
 			else if (chip->old_pitch <= 1)
 			{	/* generate unvoiced samples here */
-				current_val = (mame_rand(chip->device->machine)&1) ? chip->current_energy : -chip->current_energy;
+				current_val = (chip->device->machine->rand()&1) ? chip->current_energy : -chip->current_energy;
 			}
 			else
 			{
@@ -530,14 +564,14 @@ static DEVICE_RESET( vlm5030 )
 
 
 /* set speech rom address */
-void vlm5030_set_rom(running_device *device, void *speech_rom)
+void vlm5030_set_rom(device_t *device, void *speech_rom)
 {
 	vlm5030_state *chip = get_safe_token(device);
 	chip->rom = (UINT8 *)speech_rom;
 }
 
 /* get BSY pin level */
-int vlm5030_bsy(running_device *device)
+int vlm5030_bsy(device_t *device)
 {
 	vlm5030_state *chip = get_safe_token(device);
 	vlm5030_update(chip);
@@ -552,7 +586,7 @@ WRITE8_DEVICE_HANDLER( vlm5030_data_w )
 }
 
 /* set RST pin level : reset / set table address A8-A15 */
-void vlm5030_rst (running_device *device, int pin )
+void vlm5030_rst (device_t *device, int pin )
 {
 	vlm5030_state *chip = get_safe_token(device);
 	if( chip->pin_RST )
@@ -577,7 +611,7 @@ void vlm5030_rst (running_device *device, int pin )
 }
 
 /* set VCU pin level : ?? unknown */
-void vlm5030_vcu(running_device *device, int pin)
+void vlm5030_vcu(device_t *device, int pin)
 {
 	vlm5030_state *chip = get_safe_token(device);
 	/* direct mode / indirect mode */
@@ -586,7 +620,7 @@ void vlm5030_vcu(running_device *device, int pin)
 }
 
 /* set ST pin level  : set table address A0-A7 / start speech */
-void vlm5030_st(running_device *device, int pin )
+void vlm5030_st(device_t *device, int pin )
 {
 	vlm5030_state *chip = get_safe_token(device);
 	int table;
