@@ -824,7 +824,7 @@ void tilemap_draw_primask(bitmap_t *dest, const rectangle *cliprect, tilemap_t *
 	if (!tmap->enable)
 		return;
 
-profiler_mark_start(PROFILER_TILEMAP_DRAW);
+g_profiler.start(PROFILER_TILEMAP_DRAW);
 	/* configure the blit parameters based on the input parameters */
 	configure_blit_parameters(&blit, tmap, dest, cliprect, flags, priority, priority_mask);
 
@@ -927,7 +927,7 @@ profiler_mark_start(PROFILER_TILEMAP_DRAW);
 			}
 		}
 	}
-profiler_mark_end();
+g_profiler.stop();
 }
 
 
@@ -962,7 +962,7 @@ void tilemap_draw_roz_primask(bitmap_t *dest, const rectangle *cliprect, tilemap
 		return;
 	}
 
-profiler_mark_start(PROFILER_TILEMAP_DRAW_ROZ);
+g_profiler.start(PROFILER_TILEMAP_DRAW_ROZ);
 	/* configure the blit parameters */
 	configure_blit_parameters(&blit, tmap, dest, cliprect, flags, priority, priority_mask);
 
@@ -971,7 +971,7 @@ profiler_mark_start(PROFILER_TILEMAP_DRAW_ROZ);
 
 	/* then do the roz copy */
 	tilemap_draw_roz_core(tmap, &blit, startx, starty, incxx, incxy, incyx, incyy, wraparound);
-profiler_mark_end();
+g_profiler.stop();
 }
 
 
@@ -1274,7 +1274,7 @@ static void pixmap_update(tilemap_t *tmap, const rectangle *cliprect)
 	if (tmap->all_tiles_clean)
 		return;
 
-profiler_mark_start(PROFILER_TILEMAP_DRAW);
+g_profiler.start(PROFILER_TILEMAP_DRAW);
 
 	/* compute which columns and rows to update */
 	if (cliprect != NULL)
@@ -1314,7 +1314,7 @@ profiler_mark_start(PROFILER_TILEMAP_DRAW);
 	if (mincol == 0 && minrow == 0 && maxcol == tmap->cols - 1 && maxcol == tmap->rows - 1)
 		tmap->all_tiles_clean = TRUE;
 
-profiler_mark_end();
+g_profiler.stop();
 }
 
 
@@ -1329,7 +1329,7 @@ static void tile_update(tilemap_t *tmap, tilemap_logical_index logindex, UINT32
 	tilemap_memory_index memindex;
 	UINT32 flags;
 
-profiler_mark_start(PROFILER_TILEMAP_UPDATE);
+g_profiler.start(PROFILER_TILEMAP_UPDATE);
 
 	/* call the get info callback for the associated memory index */
 	memindex = tmap->logical_to_memory[logindex];
@@ -1353,7 +1353,7 @@ profiler_mark_start(PROFILER_TILEMAP_UPDATE);
 		tmap->gfx_dirtyseq[tmap->tileinfo.gfxnum] = tmap->machine->gfx[tmap->tileinfo.gfxnum]->dirtyseq;
 	}
 
-profiler_mark_end();
+g_profiler.stop();
 }
 
 
