@@ -15,6 +15,6 @@
 #define __VALIDITY_H__
 
 bool mame_validitychecks(const game_driver *driver);
-bool validate_tag(const game_driver *driver, const char *object, const char *tag);
+bool validate_tag(const game_driver &driver, const char *object, const char *tag);
 
 #endif
