@@ -100,17 +100,17 @@ static const rgb_t TMS9928A_palette[16] =
 /*
 ** Forward declarations of internal functions.
 */
-static void draw_mode0 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_mode1 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_mode2 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_mode12 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_mode3 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_mode23 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_modebogus (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
-static void draw_sprites (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode0 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode1 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode2 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode12 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode3 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode23 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_modebogus (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_sprites (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect);
 static void change_register (running_machine *machine, int reg, UINT8 data);
 
-static void (*const ModeHandlers[])(running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) = {
+static void (*const ModeHandlers[])(device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) = {
         draw_mode0, draw_mode1, draw_mode2,  draw_mode12,
         draw_mode3, draw_modebogus, draw_mode23,
         draw_modebogus
@@ -135,7 +135,7 @@ static void (*const ModeHandlers[])(running_device *screen, bitmap_t *bitmap, co
 
 typedef struct {
     /* TMS9928A internal settings */
-    UINT8 ReadAhead,Regs[8],StatusReg,FirstByte,latch,INT;
+    UINT8 ReadAhead,Regs[8],StatusReg,latch,INT;
     INT32 Addr;
     int colour,pattern,nametbl,spriteattribute,spritepattern;
     int colourmask,patternmask;
@@ -173,7 +173,6 @@ void TMS9928A_reset () {
     tms.spritepattern = tms.spriteattribute = 0;
     tms.colourmask = tms.patternmask = 0;
     tms.Addr = tms.ReadAhead = tms.INT = 0;
-    tms.FirstByte = 0;
 	tms.latch = 0;
 }
 
@@ -222,7 +221,6 @@ static void TMS9928A_start (running_machine *machine, const TMS9928a_interface *
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[7]);
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.StatusReg);
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.ReadAhead);
-	state_save_register_item(machine, "tms9928a", NULL, 0, tms.FirstByte);
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.latch);
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Addr);
 	state_save_register_item(machine, "tms9928a", NULL, 0, tms.INT);
@@ -282,25 +280,26 @@ READ8_HANDLER (TMS9928A_register_r) {
 WRITE8_HANDLER (TMS9928A_register_w) {
 	int reg;
 
-    if (tms.latch) {
-        if (data & 0x80) {
-            /* register write */
+	if (tms.latch) {
+		/* set high part of read/write address */
+		tms.Addr = ((UINT16)data << 8 | (tms.Addr & 0xff)) & (tms.vramsize - 1);
+
+		if (data & 0x80) {
+			/* register write */
 			reg = data & 7;
-			/*if (tms.FirstByte != tms.Regs[reg])*/ /* Removed to fix ColecoVision MESS Driver*/
-	            change_register (space->machine, reg, tms.FirstByte);
-        } else {
-            /* set read/write address */
-            tms.Addr = ((UINT16)data << 8 | tms.FirstByte) & (tms.vramsize - 1);
-            if ( !(data & 0x40) ) {
+			change_register (space->machine, reg, tms.Addr & 0xff);
+		} else {
+			if ( !(data & 0x40) ) {
 				/* read ahead */
 				TMS9928A_vram_r	(space,0);
-            }
-        }
-        tms.latch = 0;
-    } else {
-        tms.FirstByte = data;
+			}
+		}
+		tms.latch = 0;
+	} else {
+		/* set low part of read/write address */
+		tms.Addr = ((tms.Addr & 0xff00) | data) & (tms.vramsize - 1);
 		tms.latch = 1;
-    }
+	}
 }
 
 static void change_register (running_machine *machine, int reg, UINT8 val) {
@@ -435,7 +434,7 @@ int TMS9928A_interrupt(running_machine *machine) {
     int b;
 
     /* when skipping frames, calculate sprite collision */
-    if (video_skip_this_frame() ) {
+    if (machine->video().skip_this_frame()) {
 		if (TMS_SPRITES_ENABLED) {
 			draw_sprites (machine->primary_screen, NULL, NULL);
 		}
@@ -451,7 +450,7 @@ int TMS9928A_interrupt(running_machine *machine) {
     return b;
 }
 
-static void draw_mode1 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode1 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode;
     UINT8 fg,bg,*patternptr;
     rectangle rt;
@@ -486,7 +485,7 @@ static void draw_mode1 (running_device *screen, bitmap_t *bitmap, const rectangl
     }
 }
 
-static void draw_mode12 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode12 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode;
     UINT8 fg,bg,*patternptr;
     const pen_t *pens;
@@ -521,7 +520,7 @@ static void draw_mode12 (running_device *screen, bitmap_t *bitmap, const rectang
     }
 }
 
-static void draw_mode0 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode0 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode,colour;
     UINT8 fg,bg,*patternptr;
     const pen_t *pens;
@@ -547,7 +546,7 @@ static void draw_mode0 (running_device *screen, bitmap_t *bitmap, const rectangl
     }
 }
 
-static void draw_mode2 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode2 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int colour,name,x,y,yy,pattern,xx,charcode;
     UINT8 fg,bg;
     const pen_t *pens;
@@ -577,7 +576,7 @@ static void draw_mode2 (running_device *screen, bitmap_t *bitmap, const rectangl
     }
 }
 
-static void draw_mode3 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode3 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int x,y,yy,yyy,name,charcode;
     UINT8 fg,bg,*patternptr;
     const pen_t *pens;
@@ -607,7 +606,7 @@ static void draw_mode3 (running_device *screen, bitmap_t *bitmap, const rectangl
     }
 }
 
-static void draw_mode23 (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_mode23 (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     int x,y,yy,yyy,name,charcode;
     UINT8 fg,bg,*patternptr;
     const pen_t *pens;
@@ -638,7 +637,7 @@ static void draw_mode23 (running_device *screen, bitmap_t *bitmap, const rectang
     }
 }
 
-static void draw_modebogus (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_modebogus (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     UINT8 fg,bg;
     int x,y,n,xx;
     const pen_t *pens;
@@ -667,7 +666,7 @@ static void draw_modebogus (running_device *screen, bitmap_t *bitmap, const rect
 **
 ** This code should be optimized. One day.
 */
-static void draw_sprites (running_device *screen, bitmap_t *bitmap, const rectangle *cliprect) {
+static void draw_sprites (device_t *screen, bitmap_t *bitmap, const rectangle *cliprect) {
     UINT8 *attributeptr,*patternptr,c;
     int p,x,y,size,i,j,large,yy,xx,limit[192],
         illegalsprite,illegalspriteline;
@@ -817,20 +816,20 @@ VIDEO_START( tms9928a )
 }
 
 
-MACHINE_DRIVER_START( tms9928a )
+MACHINE_CONFIG_FRAGMENT( tms9928a )
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(LEFT_BORDER+32*8+RIGHT_BORDER, TOP_BORDER_60HZ+24*8+BOTTOM_BORDER_60HZ)
-	MDRV_SCREEN_VISIBLE_AREA(LEFT_BORDER-12, LEFT_BORDER+32*8+12-1, TOP_BORDER_60HZ-9, TOP_BORDER_60HZ+24*8+9-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(LEFT_BORDER+32*8+RIGHT_BORDER, TOP_BORDER_60HZ+24*8+BOTTOM_BORDER_60HZ)
+	MCFG_SCREEN_VISIBLE_AREA(LEFT_BORDER-12, LEFT_BORDER+32*8+12-1, TOP_BORDER_60HZ-9, TOP_BORDER_60HZ+24*8+9-1)
 
-	MDRV_PALETTE_LENGTH(TMS9928A_PALETTE_SIZE)
-	MDRV_PALETTE_INIT(tms9928a)
+	MCFG_PALETTE_LENGTH(TMS9928A_PALETTE_SIZE)
+	MCFG_PALETTE_INIT(tms9928a)
 
-	MDRV_VIDEO_START(tms9928a)
-	MDRV_VIDEO_UPDATE(tms9928a)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(tms9928a)
+	MCFG_VIDEO_UPDATE(tms9928a)
+MACHINE_CONFIG_END
 
