@@ -284,9 +284,9 @@ struct _dsio_denver_state
 typedef struct _dcs_state dcs_state;
 struct _dcs_state
 {
-	cpu_device *cpu;
-	const address_space *program;
-	const address_space *data;
+	adsp21xx_device *cpu;
+	address_space *program;
+	address_space *data;
 	UINT8		rev;
 	offs_t		polling_offset;
 	UINT32		polling_count;
@@ -323,8 +323,8 @@ struct _dcs_state
 	UINT16		progflags;
 	void		(*output_full_cb)(running_machine *, int);
 	void		(*input_empty_cb)(running_machine *, int);
-	UINT16		(*fifo_data_r)(running_device *device);
-	UINT16		(*fifo_status_r)(running_device *device);
+	UINT16		(*fifo_data_r)(device_t *device);
+	UINT16		(*fifo_status_r)(device_t *device);
 
 	/* timers */
 	UINT8		timer_enable;
@@ -409,12 +409,12 @@ static WRITE16_HANDLER( output_latch_w );
 static READ16_HANDLER( output_control_r );
 static WRITE16_HANDLER( output_control_w );
 
-static void timer_enable_callback(cpu_device &device, int enable);
+static void timer_enable_callback(adsp21xx_device &device, int enable);
 static TIMER_DEVICE_CALLBACK( internal_timer_callback );
 static TIMER_DEVICE_CALLBACK( dcs_irq );
 static TIMER_DEVICE_CALLBACK( sport0_irq );
 static void recompute_sample_rate(running_machine *machine);
-static void sound_tx_callback(cpu_device &device, int port, INT32 data);
+static void sound_tx_callback(adsp21xx_device &device, int port, INT32 data);
 
 static READ16_HANDLER( dcs_polling_r );
 static WRITE16_HANDLER( dcs_polling_w );
@@ -608,39 +608,37 @@ static const adsp21xx_config adsp_config =
  *************************************/
 
 /* Basic DCS system with ADSP-2105 and 2k of SRAM (T-unit, V-unit, Killer Instinct) */
-MACHINE_DRIVER_START( dcs_audio_2k )
-	MDRV_CPU_ADD("dcs", ADSP2105, XTAL_10MHz)
-	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(dcs_2k_program_map)
-	MDRV_CPU_DATA_MAP(dcs_2k_data_map)
+MACHINE_CONFIG_FRAGMENT( dcs_audio_2k )
+	MCFG_CPU_ADD("dcs", ADSP2105, XTAL_10MHz)
+	MCFG_ADSP21XX_CONFIG(adsp_config)
+	MCFG_CPU_PROGRAM_MAP(dcs_2k_program_map)
+	MCFG_CPU_DATA_MAP(dcs_2k_data_map)
 
-	MDRV_TIMER_ADD("dcs_reg_timer", dcs_irq)
-	MDRV_TIMER_ADD("dcs_int_timer", internal_timer_callback)
+	MCFG_TIMER_ADD("dcs_reg_timer", dcs_irq)
+	MCFG_TIMER_ADD("dcs_int_timer", internal_timer_callback)
 
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("dac", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
 /* Basic DCS system with ADSP-2105 and 2k of SRAM, using a UART for communications (X-unit) */
-MACHINE_DRIVER_START( dcs_audio_2k_uart )
-	MDRV_IMPORT_FROM(dcs_audio_2k)
+MACHINE_CONFIG_DERIVED( dcs_audio_2k_uart, dcs_audio_2k )
 
-	MDRV_CPU_MODIFY("dcs")
-	MDRV_CPU_DATA_MAP(dcs_2k_uart_data_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("dcs")
+	MCFG_CPU_DATA_MAP(dcs_2k_uart_data_map)
+MACHINE_CONFIG_END
 
 
 /* Basic DCS system with ADSP-2105 and 8k of SRAM (Wolf-unit) */
-MACHINE_DRIVER_START( dcs_audio_8k )
-	MDRV_IMPORT_FROM(dcs_audio_2k)
+MACHINE_CONFIG_DERIVED( dcs_audio_8k, dcs_audio_2k )
 
-	MDRV_CPU_MODIFY("dcs")
-	MDRV_CPU_PROGRAM_MAP(dcs_8k_program_map)
-	MDRV_CPU_DATA_MAP(dcs_8k_data_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("dcs")
+	MCFG_CPU_PROGRAM_MAP(dcs_8k_program_map)
+	MCFG_CPU_DATA_MAP(dcs_8k_data_map)
+MACHINE_CONFIG_END
 
 
 
@@ -650,34 +648,33 @@ MACHINE_DRIVER_END
  *
  *************************************/
 
-MACHINE_DRIVER_START( dcs2_audio_2115 )
-	MDRV_CPU_ADD("dcs2", ADSP2115, XTAL_16MHz)
-	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(dcs2_2115_program_map)
-	MDRV_CPU_DATA_MAP(dcs2_2115_data_map)
+MACHINE_CONFIG_FRAGMENT( dcs2_audio_2115 )
+	MCFG_CPU_ADD("dcs2", ADSP2115, XTAL_16MHz)
+	MCFG_ADSP21XX_CONFIG(adsp_config)
+	MCFG_CPU_PROGRAM_MAP(dcs2_2115_program_map)
+	MCFG_CPU_DATA_MAP(dcs2_2115_data_map)
 
-	MDRV_TIMER_ADD("dcs_reg_timer", dcs_irq)
-	MDRV_TIMER_ADD("dcs_sport_timer", sport0_irq)
-	MDRV_TIMER_ADD("dcs_int_timer", internal_timer_callback)
-	MDRV_TIMER_ADD("dcs_hle_timer", transfer_watchdog_callback)
+	MCFG_TIMER_ADD("dcs_reg_timer", dcs_irq)
+	MCFG_TIMER_ADD("dcs_sport_timer", sport0_irq)
+	MCFG_TIMER_ADD("dcs_int_timer", internal_timer_callback)
+	MCFG_TIMER_ADD("dcs_hle_timer", transfer_watchdog_callback)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("dac1", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("dac1", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac2", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
-MACHINE_DRIVER_START( dcs2_audio_2104 )
-	MDRV_IMPORT_FROM(dcs2_audio_2115)
-	MDRV_CPU_REPLACE("dcs2", ADSP2104, XTAL_16MHz)
-	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(dcs2_2104_program_map)
-	MDRV_CPU_DATA_MAP(dcs2_2104_data_map)
-MACHINE_DRIVER_END
+MACHINE_CONFIG_DERIVED( dcs2_audio_2104, dcs2_audio_2115 )
+	MCFG_CPU_REPLACE("dcs2", ADSP2104, XTAL_16MHz)
+	MCFG_ADSP21XX_CONFIG(adsp_config)
+	MCFG_CPU_PROGRAM_MAP(dcs2_2104_program_map)
+	MCFG_CPU_DATA_MAP(dcs2_2104_data_map)
+MACHINE_CONFIG_END
 
 
 
@@ -687,21 +684,21 @@ MACHINE_DRIVER_END
  *
  *************************************/
 
-MACHINE_DRIVER_START( dcs2_audio_dsio )
-	MDRV_CPU_ADD("dsio", ADSP2181, XTAL_32MHz)
-	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(dsio_program_map)
-	MDRV_CPU_DATA_MAP(dsio_data_map)
-	MDRV_CPU_IO_MAP(dsio_io_map)
+MACHINE_CONFIG_FRAGMENT( dcs2_audio_dsio )
+	MCFG_CPU_ADD("dsio", ADSP2181, XTAL_32MHz)
+	MCFG_ADSP21XX_CONFIG(adsp_config)
+	MCFG_CPU_PROGRAM_MAP(dsio_program_map)
+	MCFG_CPU_DATA_MAP(dsio_data_map)
+	MCFG_CPU_IO_MAP(dsio_io_map)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("dac1", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("dac1", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac2", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
 
@@ -711,33 +708,33 @@ MACHINE_DRIVER_END
  *
  *************************************/
 
-MACHINE_DRIVER_START( dcs2_audio_denver )
-	MDRV_CPU_ADD("denver", ADSP2181, XTAL_33_333MHz)
-	MDRV_CPU_CONFIG(adsp_config)
-	MDRV_CPU_PROGRAM_MAP(denver_program_map)
-	MDRV_CPU_DATA_MAP(denver_data_map)
-	MDRV_CPU_IO_MAP(denver_io_map)
+MACHINE_CONFIG_FRAGMENT( dcs2_audio_denver )
+	MCFG_CPU_ADD("denver", ADSP2181, XTAL_33_333MHz)
+	MCFG_ADSP21XX_CONFIG(adsp_config)
+	MCFG_CPU_PROGRAM_MAP(denver_program_map)
+	MCFG_CPU_DATA_MAP(denver_data_map)
+	MCFG_CPU_IO_MAP(denver_io_map)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("dac1", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("dac1", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac2", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ADD("dac2", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac3", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("dac3", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac4", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ADD("dac4", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac5", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("dac5", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("dac6", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac6", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
 
@@ -766,7 +763,7 @@ static void dcs_boot(void)
 			/* convert from 16-bit data to 8-bit data and boot */
 			for (i = 0; i < 0x1000; i++)
 				buffer[i] = base[i];
-			adsp2105_load_boot_data(buffer, dcs_internal_program_ram);
+			dcs.cpu->load_boot_data(buffer, dcs_internal_program_ram);
 			break;
 
 		/* rev 2: use the ROM page in the SDRC to boot from */
@@ -787,7 +784,7 @@ static void dcs_boot(void)
 			/* convert from 16-bit data to 8-bit data and boot */
 			for (i = 0; i < 0x1000; i++)
 				buffer[i] = base[i];
-			adsp2115_load_boot_data(buffer, dcs_internal_program_ram);
+			dcs.cpu->load_boot_data(buffer, dcs_internal_program_ram);
 			break;
 
 		/* rev 3/4: HALT the ADSP-2181 until program is downloaded via IDMA */
@@ -941,16 +938,16 @@ void dcs_init(running_machine *machine)
 	dcs_sram = NULL;
 
 	/* find the DCS CPU and the sound ROMs */
-	dcs.cpu = machine->device<cpu_device>("dcs");
-	dcs.program = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_PROGRAM);
-	dcs.data = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_DATA);
+	dcs.cpu = machine->device<adsp21xx_device>("dcs");
+	dcs.program = dcs.cpu->space(AS_PROGRAM);
+	dcs.data = dcs.cpu->space(AS_DATA);
 	dcs.rev = 1;
 	dcs.channels = 1;
 	dcs.dmadac[0] = machine->device<dmadac_sound_device>("dac");
 
 	/* configure boot and sound ROMs */
-	dcs.bootrom = (UINT16 *)memory_region(machine, "dcs");
-	dcs.bootrom_words = memory_region_length(machine, "dcs") / 2;
+	dcs.bootrom = (UINT16 *)machine->region("dcs")->base();
+	dcs.bootrom_words = machine->region("dcs")->bytes() / 2;
 	dcs.sounddata = dcs.bootrom;
 	dcs.sounddata_words = dcs.bootrom_words;
 	dcs.sounddata_banks = dcs.sounddata_words / 0x1000;
@@ -978,30 +975,30 @@ void dcs2_init(running_machine *machine, int dram_in_mb, offs_t polling_offset)
 	memset(&dcs, 0, sizeof(dcs));
 
 	/* find the DCS CPU and the sound ROMs */
-	dcs.cpu = machine->device<cpu_device>("dcs2");
+	dcs.cpu = machine->device<adsp21xx_device>("dcs2");
 	dcs.rev = 2;
 	soundbank_words = 0x1000;
 	if (dcs.cpu == NULL)
 	{
-		dcs.cpu = machine->device<cpu_device>("dsio");
+		dcs.cpu = machine->device<adsp21xx_device>("dsio");
 		dcs.rev = 3;
 		soundbank_words = 0x400;
 	}
 	if (dcs.cpu == NULL)
 	{
-		dcs.cpu = machine->device<cpu_device>("denver");
+		dcs.cpu = machine->device<adsp21xx_device>("denver");
 		dcs.rev = 4;
 		soundbank_words = 0x800;
 	}
-	dcs.program = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_PROGRAM);
-	dcs.data = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_DATA);
+	dcs.program = dcs.cpu->space(AS_PROGRAM);
+	dcs.data = dcs.cpu->space(AS_DATA);
 	dcs.channels = 2;
 	dcs.dmadac[0] = machine->device<dmadac_sound_device>("dac1");
 	dcs.dmadac[1] = machine->device<dmadac_sound_device>("dac2");
 
 	/* always boot from the base of "dcs" */
-	dcs.bootrom = (UINT16 *)memory_region(machine, "dcs");
-	dcs.bootrom_words = memory_region_length(machine, "dcs") / 2;
+	dcs.bootrom = (UINT16 *)machine->region("dcs")->base();
+	dcs.bootrom_words = machine->region("dcs")->bytes() / 2;
 
 	/* supports both RAM and ROM variants */
 	if (dram_in_mb != 0)
@@ -1032,7 +1029,7 @@ void dcs2_init(running_machine *machine, int dram_in_mb, offs_t polling_offset)
 	/* install the speedup handler */
 	dcs.polling_offset = polling_offset;
 	if (polling_offset)
-		dcs_polling_base = memory_install_readwrite16_handler(cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_DATA), polling_offset, polling_offset, 0, 0, dcs_polling_r, dcs_polling_w);
+		dcs_polling_base = memory_install_readwrite16_handler(dcs.cpu->space(AS_DATA), polling_offset, polling_offset, 0, 0, dcs_polling_r, dcs_polling_w);
 
 	/* allocate a watchdog timer for HLE transfers */
 	transfer.hle_enabled = (ENABLE_HLE_TRANSFERS && dram_in_mb != 0);
@@ -1171,7 +1168,7 @@ static void sdrc_remap_memory(running_machine *machine)
 
 	/* reinstall the polling hotspot */
 	if (dcs.polling_offset)
-		dcs_polling_base = memory_install_readwrite16_handler(cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_DATA), dcs.polling_offset, dcs.polling_offset, 0, 0, dcs_polling_r, dcs_polling_w);
+		dcs_polling_base = memory_install_readwrite16_handler(dcs.cpu->space(AS_DATA), dcs.polling_offset, dcs.polling_offset, 0, 0, dcs_polling_r, dcs_polling_w);
 }
 
 
@@ -1443,7 +1440,7 @@ WRITE32_HANDLER( dsio_idma_addr_w )
 {
 	if (LOG_DCS_TRANSFERS)
 		logerror("%08X:IDMA_addr = %04X\n", cpu_get_pc(space->cpu), data);
-	adsp2181_idma_addr_w(dcs.cpu, data);
+	downcast<adsp2181_device *>(dcs.cpu)->idma_addr_w(data);
 	if (data == 0)
 		dsio.start_on_next_write = 2;
 }
@@ -1455,14 +1452,14 @@ WRITE32_HANDLER( dsio_idma_data_w )
 	if (ACCESSING_BITS_0_15)
 	{
 		if (LOG_DCS_TRANSFERS)
-			logerror("%08X:IDMA_data_w(%04X) = %04X\n", pc, adsp2181_idma_addr_r(dcs.cpu), data & 0xffff);
-		adsp2181_idma_data_w(dcs.cpu, data & 0xffff);
+			logerror("%08X:IDMA_data_w(%04X) = %04X\n", pc, downcast<adsp2181_device *>(dcs.cpu)->idma_addr_r(), data & 0xffff);
+		downcast<adsp2181_device *>(dcs.cpu)->idma_data_w(data & 0xffff);
 	}
 	if (ACCESSING_BITS_16_31)
 	{
 		if (LOG_DCS_TRANSFERS)
-			logerror("%08X:IDMA_data_w(%04X) = %04X\n", pc, adsp2181_idma_addr_r(dcs.cpu), data >> 16);
-		adsp2181_idma_data_w(dcs.cpu, data >> 16);
+			logerror("%08X:IDMA_data_w(%04X) = %04X\n", pc, downcast<adsp2181_device *>(dcs.cpu)->idma_addr_r(), data >> 16);
+		downcast<adsp2181_device *>(dcs.cpu)->idma_data_w(data >> 16);
 	}
 	if (dsio.start_on_next_write && --dsio.start_on_next_write == 0)
 	{
@@ -1475,9 +1472,9 @@ WRITE32_HANDLER( dsio_idma_data_w )
 READ32_HANDLER( dsio_idma_data_r )
 {
 	UINT32 result;
-	result = adsp2181_idma_data_r(dcs.cpu);
+	result = downcast<adsp2181_device *>(dcs.cpu)->idma_data_r();
 	if (LOG_DCS_TRANSFERS)
-		logerror("%08X:IDMA_data_r(%04X) = %04X\n", cpu_get_pc(space->cpu), adsp2181_idma_addr_r(dcs.cpu), result);
+		logerror("%08X:IDMA_data_r(%04X) = %04X\n", cpu_get_pc(space->cpu), downcast<adsp2181_device *>(dcs.cpu)->idma_addr_r(), result);
 	return result;
 }
 
@@ -1494,7 +1491,7 @@ void dcs_set_io_callbacks(void (*output_full_cb)(running_machine *, int), void (
 }
 
 
-void dcs_set_fifo_callbacks(UINT16 (*fifo_data_r)(running_device *device), UINT16 (*fifo_status_r)(running_device *device))
+void dcs_set_fifo_callbacks(UINT16 (*fifo_data_r)(device_t *device), UINT16 (*fifo_status_r)(device_t *device))
 {
 	dcs.fifo_data_r = fifo_data_r;
 	dcs.fifo_status_r = fifo_status_r;
@@ -1778,11 +1775,11 @@ static void reset_timer(running_machine *machine)
 	{
 		/* Road Burners: @ 28: JMP $0032  18032F, same code at $32 */
 
-		if (memory_read_dword(dcs.program, 0x18*4) == 0x0c0030 &&		/* ENA SEC_REG */
-			memory_read_dword(dcs.program, 0x19*4) == 0x804828 &&		/* SI = DM($0482) */
-			memory_read_dword(dcs.program, 0x1a*4) == 0x904828 &&		/* DM($0482) = SI */
-			memory_read_dword(dcs.program, 0x1b*4) == 0x0C0020 &&		/* DIS SEC_REG */
-			memory_read_dword(dcs.program, 0x1c*4) == 0x0A001F)			/* RTI */
+		if (dcs.program->read_dword(0x18*4) == 0x0c0030 &&		/* ENA SEC_REG */
+			dcs.program->read_dword(0x19*4) == 0x804828 &&		/* SI = DM($0482) */
+			dcs.program->read_dword(0x1a*4) == 0x904828 &&		/* DM($0482) = SI */
+			dcs.program->read_dword(0x1b*4) == 0x0C0020 &&		/* DIS SEC_REG */
+			dcs.program->read_dword(0x1c*4) == 0x0A001F)			/* RTI */
 		{
 			dcs.timer_ignore = TRUE;
 		}
@@ -1794,7 +1791,7 @@ static void reset_timer(running_machine *machine)
 }
 
 
-static void timer_enable_callback(cpu_device &device, int enable)
+static void timer_enable_callback(adsp21xx_device &device, int enable)
 {
 	dcs.timer_enable = enable;
 	dcs.timer_ignore = 0;
@@ -1848,7 +1845,7 @@ static READ16_HANDLER( adsp_control_r )
 			break;
 
 		case IDMA_CONTROL_REG:
-			result = adsp2181_idma_addr_r(dcs.cpu);
+			result = downcast<adsp2181_device *>(dcs.cpu)->idma_addr_r();
 			break;
 
 		case TIMER_COUNT_REG:
@@ -1929,7 +1926,7 @@ static WRITE16_HANDLER( adsp_control_w )
 			break;
 
 		case IDMA_CONTROL_REG:
-			adsp2181_idma_addr_w(dcs.cpu, data);
+			downcast<adsp2181_device *>(dcs.cpu)->idma_addr_w(data);
 			break;
 	}
 }
@@ -1952,7 +1949,7 @@ static TIMER_DEVICE_CALLBACK( dcs_irq )
 
 		for (i = 0; i < count; i++)
 		{
-			buffer[i] = memory_read_word(dcs.data, reg * 2);
+			buffer[i] = dcs.data->read_word(reg * 2);
 			reg += dcs.incs;
 		}
 
@@ -2010,7 +2007,7 @@ static void recompute_sample_rate(running_machine *machine)
 }
 
 
-static void sound_tx_callback(cpu_device &device, int port, INT32 data)
+static void sound_tx_callback(adsp21xx_device &device, int port, INT32 data)
 {
 	/* check if it's for SPORT1 */
 	if (port != 1)
@@ -2252,10 +2249,10 @@ static int preprocess_stage_1(running_machine *machine, UINT16 data)
 					if (transfer.writes_left & 1)
 						transfer.temp = data;
 					else
-						memory_write_dword(dcs.program, transfer.start++ * 4, (transfer.temp << 8) | (data & 0xff));
+						dcs.program->write_dword(transfer.start++ * 4, (transfer.temp << 8) | (data & 0xff));
 				}
 				else
-					memory_write_word(dcs.data, transfer.start++ * 2, data);
+					dcs.data->write_word(transfer.start++ * 2, data);
 
 				/* if we're done, start a timer to send the response words */
 				if (transfer.state == 0)
@@ -2270,7 +2267,7 @@ static int preprocess_stage_1(running_machine *machine, UINT16 data)
 
 static TIMER_CALLBACK( s2_ack_callback )
 {
-	const address_space *space = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_PROGRAM);
+	address_space *space = cpu_get_address_space(dcs.cpu, ADDRESS_SPACE_PROGRAM);
 
 	/* if the output is full, stall for a usec */
 	if (IS_OUTPUT_FULL())
