@@ -42,14 +42,24 @@ typedef struct tone
 	INT16	form[16];
 } TONE;
 
-static TONE tone_channels[CHANNELS];
-static INT32 tone_clock_expire;
-static INT32 tone_clock;
-static sound_stream * tone_stream;
+typedef struct _snk6502_sound_state snk6502_sound_state;
+struct _snk6502_sound_state
+{
+	TONE tone_channels[CHANNELS];
+	INT32 tone_clock_expire;
+	INT32 tone_clock;
+	sound_stream * tone_stream;
 
-static int Sound0StopOnRollover;
-static UINT8 LastPort1;
+	device_t *samples;
+	UINT8 *ROM;
+	int Sound0StopOnRollover;
+	UINT8 LastPort1;
 
+	int hd38880_cmd;
+	UINT32 hd38880_addr;
+	int hd38880_data_bytes;
+	double hd38880_speed;
+};
 
 static const char *const sasuke_sample_names[] =
 {
@@ -372,13 +382,21 @@ DISCRETE_SOUND_START( fantasy )
 	DISCRETE_OUTPUT(NODE_23, 32760.0/12)
 DISCRETE_SOUND_END
 
-
-INLINE void validate_tone_channel(running_machine *machine, int channel)
+INLINE snk6502_sound_state *get_safe_token( device_t *device )
 {
+	assert(device != NULL);
+	assert(device->type() == SNK6502);
+
+	return (snk6502_sound_state *)downcast<legacy_device_base *>(device)->token();
+}
+
+INLINE void validate_tone_channel(snk6502_sound_state *state, int channel)
+{
+	TONE *tone_channels = state->tone_channels;
+
 	if (!tone_channels[channel].mute)
 	{
-		UINT8 *ROM = memory_region(machine, "snk6502");
-		UINT8 romdata = ROM[tone_channels[channel].base + tone_channels[channel].offset];
+		UINT8 romdata = state->ROM[tone_channels[channel].base + tone_channels[channel].offset];
 
 		if (romdata != 0xff)
 			tone_channels[channel].sample_step = tone_channels[channel].sample_rate / (256 - romdata);
@@ -390,10 +408,12 @@ INLINE void validate_tone_channel(running_machine *machine, int channel)
 static STREAM_UPDATE( snk6502_tone_update )
 {
 	stream_sample_t *buffer = outputs[0];
+	snk6502_sound_state *state = get_safe_token(device);
+	TONE *tone_channels = state->tone_channels;
 	int i;
 
 	for (i = 0; i < CHANNELS; i++)
-		validate_tone_channel(device->machine, i);
+		validate_tone_channel(state, i);
 
 	while (samples-- > 0)
 	{
@@ -420,29 +440,30 @@ static STREAM_UPDATE( snk6502_tone_update )
 
 		*buffer++ = data;
 
-		tone_clock += FRAC_ONE;
-		if (tone_clock >= tone_clock_expire)
+		state->tone_clock += FRAC_ONE;
+		if (state->tone_clock >= state->tone_clock_expire)
 		{
 			for (i = 0; i < CHANNELS; i++)
 			{
 				tone_channels[i].offset++;
 				tone_channels[i].offset &= tone_channels[i].mask;
 
-				validate_tone_channel(device->machine, i);
+				validate_tone_channel(state, i);
 			}
 
-			if (tone_channels[0].offset == 0 && Sound0StopOnRollover)
+			if (tone_channels[0].offset == 0 && state->Sound0StopOnRollover)
 				tone_channels[0].mute = 1;
 
-			tone_clock -= tone_clock_expire;
+			state->tone_clock -= state->tone_clock_expire;
 		}
 
 	}
 }
 
 
-static void sasuke_build_waveform(int mask)
+static void sasuke_build_waveform(snk6502_sound_state *state, int mask)
 {
+	TONE *tone_channels = state->tone_channels;
 	int bit0, bit1, bit2, bit3;
 	int base;
 	int i;
@@ -483,8 +504,9 @@ static void sasuke_build_waveform(int mask)
 		tone_channels[0].form[i] *= 65535 / 16;
 }
 
-static void satansat_build_waveform(int mask)
+static void satansat_build_waveform(snk6502_sound_state *state, int mask)
 {
+	TONE *tone_channels = state->tone_channels;
 	int bit0, bit1, bit2, bit3;
 	int base;
 	int i;
@@ -521,8 +543,9 @@ static void satansat_build_waveform(int mask)
 		tone_channels[1].form[i] *= 65535 / 16;
 }
 
-static void build_waveform(int channel, int mask)
+static void build_waveform(snk6502_sound_state *state, int channel, int mask)
 {
+	TONE *tone_channels = state->tone_channels;
 	int bit0, bit1, bit2, bit3;
 	int base;
 	int i;
@@ -596,8 +619,12 @@ static void build_waveform(int channel, int mask)
 		tone_channels[channel].form[i] *= 65535 / 160;
 }
 
-void snk6502_set_music_freq(int freq)
+void snk6502_set_music_freq(running_machine *machine, int freq)
 {
+	device_t *device = machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	TONE *tone_channels = state->tone_channels;
+
 	int i;
 
 	for (i = 0; i < CHANNELS; i++)
@@ -610,31 +637,42 @@ void snk6502_set_music_freq(int freq)
 		tone_channels[i].sample_cur = 0;
 		tone_channels[i].sample_rate = (double)(freq * 8) / SAMPLE_RATE * FRAC_ONE;
 
-		build_waveform(i, 1);
+		build_waveform(state, i, 1);
 	}
 }
 
-void snk6502_set_music_clock(double clock_time)
+void snk6502_set_music_clock(running_machine *machine, double clock_time)
 {
-	tone_clock_expire = clock_time * SAMPLE_RATE * FRAC_ONE;
-	tone_clock = 0;
+	device_t *device = machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+
+	state->tone_clock_expire = clock_time * SAMPLE_RATE * FRAC_ONE;
+	state->tone_clock = 0;
 }
 
 static DEVICE_START( snk6502_sound )
 {
+	snk6502_sound_state *state = get_safe_token(device);
+
+	state->samples = device->machine->device("samples");
+	state->ROM = device->machine->region("snk6502")->base();
+
 	// adjusted
-	snk6502_set_music_freq(43000);
+	snk6502_set_music_freq(device->machine, 43000);
 
 	// 38.99 Hz update (according to schematic)
-	snk6502_set_music_clock(M_LN2 * (RES_K(18) * 2 + RES_K(1)) * CAP_U(1));
+	snk6502_set_music_clock(device->machine, M_LN2 * (RES_K(18) * 2 + RES_K(1)) * CAP_U(1));
 
-	tone_stream = stream_create(device, 0, 1, SAMPLE_RATE, NULL, snk6502_tone_update);
+	state->tone_stream = stream_create(device, 0, 1, SAMPLE_RATE, NULL, snk6502_tone_update);
 }
 
 DEVICE_GET_INFO( snk6502_sound )
 {
 	switch (state)
 	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(snk6502_sound_state);			break;
+
 		/* --- the following bits of info are returned as pointers to data or functions --- */
 		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(snk6502_sound);	break;
 
@@ -644,15 +682,23 @@ DEVICE_GET_INFO( snk6502_sound )
 	}
 }
 
-int snk6502_music0_playing(void)
+int snk6502_music0_playing(running_machine *machine)
 {
+	device_t *device = machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	TONE *tone_channels = state->tone_channels;
+
 	return tone_channels[0].mute;
 }
 
 
 WRITE8_HANDLER( sasuke_sound_w )
 {
-	running_device *samples = space->machine->device("samples");
+	device_t *device = space->machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	device_t *samples = state->samples;
+	TONE *tone_channels = state->tone_channels;
+
 	switch (offset)
 	{
 	case 0:
@@ -669,25 +715,25 @@ WRITE8_HANDLER( sasuke_sound_w )
             7   reset counter
         */
 
-		if ((~data & 0x01) && (LastPort1 & 0x01))
+		if ((~data & 0x01) && (state->LastPort1 & 0x01))
 			sample_start(samples, 0, 0, 0);
-		if ((~data & 0x02) && (LastPort1 & 0x02))
+		if ((~data & 0x02) && (state->LastPort1 & 0x02))
 			sample_start(samples, 1, 1, 0);
-		if ((~data & 0x04) && (LastPort1 & 0x04))
+		if ((~data & 0x04) && (state->LastPort1 & 0x04))
 			sample_start(samples, 2, 2, 0);
-		if ((~data & 0x08) && (LastPort1 & 0x08))
+		if ((~data & 0x08) && (state->LastPort1 & 0x08))
 			sample_start(samples, 3, 3, 0);
 
-		if ((data & 0x80) && (~LastPort1 & 0x80))
+		if ((data & 0x80) && (~state->LastPort1 & 0x80))
 		{
 			tone_channels[0].offset = 0;
 			tone_channels[0].mute = 0;
 		}
 
-		if ((~data & 0x80) && (LastPort1 & 0x80))
+		if ((~data & 0x80) && (state->LastPort1 & 0x80))
 			tone_channels[0].mute = 1;
 
-		LastPort1 = data;
+		state->LastPort1 = data;
 		break;
 
 	case 1:
@@ -708,17 +754,21 @@ WRITE8_HANDLER( sasuke_sound_w )
 		tone_channels[0].base = 0x0000 + ((data & 0x70) << 4);
 		tone_channels[0].mask = 0xff;
 
-		Sound0StopOnRollover = 1;
+		state->Sound0StopOnRollover = 1;
 
 		/* bit 1-3 sound0 waveform control */
-		sasuke_build_waveform((data & 0x0e) >> 1);
+		sasuke_build_waveform(state, (data & 0x0e) >> 1);
 		break;
 	}
 }
 
 WRITE8_HANDLER( satansat_sound_w )
 {
-	running_device *samples = space->machine->device("samples");
+	device_t *device = space->machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	device_t *samples = state->samples;
+	TONE *tone_channels = state->tone_channels;
+
 	switch (offset)
 	{
 	case 0:
@@ -732,7 +782,7 @@ WRITE8_HANDLER( satansat_sound_w )
 		/* bit 1 = to 76477 */
 
 		/* bit 2 = analog sound trigger */
-		if (data & 0x04 && !(LastPort1 & 0x04))
+		if (data & 0x04 && !(state->LastPort1 & 0x04))
 			sample_start(samples, 0, 1, 0);
 
 		if (data & 0x08)
@@ -742,12 +792,12 @@ WRITE8_HANDLER( satansat_sound_w )
 		}
 
 		/* bit 4-6 sound0 waveform control */
-		sasuke_build_waveform((data & 0x70) >> 4);
+		sasuke_build_waveform(state, (data & 0x70) >> 4);
 
 		/* bit 7 sound1 waveform control */
-		satansat_build_waveform((data & 0x80) >> 7);
+		satansat_build_waveform(state, (data & 0x80) >> 7);
 
-		LastPort1 = data;
+		state->LastPort1 = data;
 		break;
 	case 1:
 		/*
@@ -761,7 +811,7 @@ WRITE8_HANDLER( satansat_sound_w )
 		tone_channels[1].base = 0x0800 + ((data & 0x60) << 4);
 		tone_channels[1].mask = 0x1ff;
 
-		Sound0StopOnRollover = 1;
+		state->Sound0StopOnRollover = 1;
 
 		if (data & 0x01)
 			tone_channels[0].mute = 0;
@@ -781,7 +831,11 @@ WRITE8_HANDLER( satansat_sound_w )
 
 WRITE8_HANDLER( vanguard_sound_w )
 {
-	running_device *samples = space->machine->device("samples");
+	device_t *device = space->machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	device_t *samples = state->samples;
+	TONE *tone_channels = state->tone_channels;
+
 	switch (offset)
 	{
 	case 0:
@@ -802,17 +856,17 @@ WRITE8_HANDLER( vanguard_sound_w )
 		tone_channels[0].base = ((data & 0x07) << 8);
 		tone_channels[0].mask = 0xff;
 
-		Sound0StopOnRollover = 1;
+		state->Sound0StopOnRollover = 1;
 
 		/* play noise samples requested by sound command byte */
 		/* SHOT A */
-		if (data & 0x20 && !(LastPort1 & 0x20))
+		if (data & 0x20 && !(state->LastPort1 & 0x20))
 			sample_start(samples, 1, 0, 0);
-		else if (!(data & 0x20) && LastPort1 & 0x20)
+		else if (!(data & 0x20) && state->LastPort1 & 0x20)
 			sample_stop(samples, 1);
 
 		/* BOMB */
-		if (data & 0x80 && !(LastPort1 & 0x80))
+		if (data & 0x80 && !(state->LastPort1 & 0x80))
 			sample_start(samples, 2, 1, 0);
 
 		if (data & 0x08)
@@ -829,7 +883,7 @@ WRITE8_HANDLER( vanguard_sound_w )
 		/* SHOT B */
 		sn76477_enable_w(space->machine->device("sn76477.2"), (data & 0x40) ? 0 : 1);
 
-		LastPort1 = data;
+		state->LastPort1 = data;
 		break;
 	case 1:
 		/*
@@ -871,13 +925,17 @@ WRITE8_HANDLER( vanguard_sound_w )
             7   AS 8    (sound1 waveform)
         */
 
-		build_waveform(0, (data & 0x3) | ((data & 4) << 1) | ((data & 8) >> 1));
-		build_waveform(1, data >> 4);
+		build_waveform(state, 0, (data & 0x3) | ((data & 4) << 1) | ((data & 8) >> 1));
+		build_waveform(state, 1, data >> 4);
 	}
 }
 
 WRITE8_HANDLER( fantasy_sound_w )
 {
+	device_t *device = space->machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	TONE *tone_channels = state->tone_channels;
+
 	switch (offset)
 	{
 	case 0:
@@ -898,7 +956,7 @@ WRITE8_HANDLER( fantasy_sound_w )
 		tone_channels[0].base = 0x0000 + ((data & 0x07) << 8);
 		tone_channels[0].mask = 0xff;
 
-		Sound0StopOnRollover = 0;
+		state->Sound0StopOnRollover = 0;
 
 		if (data & 0x08)
 			tone_channels[0].mute = 0;
@@ -919,7 +977,7 @@ WRITE8_HANDLER( fantasy_sound_w )
 		/* BOMB */
 		discrete_sound_w(space->machine->device("discrete"), FANTASY_BOMB_EN, data & 0x80);
 
-		LastPort1 = data;
+		state->LastPort1 = data;
 		break;
 	case 1:
 		/*
@@ -961,8 +1019,8 @@ WRITE8_HANDLER( fantasy_sound_w )
             7   AS 8    (sound1 waveform)
         */
 
-		build_waveform(0, (data & 0x9) | ((data & 2) << 1) | ((data & 4) >> 1));
-		build_waveform(1, data >> 4);
+		build_waveform(state, 0, (data & 0x9) | ((data & 2) << 1) | ((data & 4) >> 1));
+		build_waveform(state, 1, data >> 4);
 		break;
 	case 3:
 		/*
@@ -1012,11 +1070,6 @@ WRITE8_HANDLER( fantasy_sound_w )
 #define HD38880_CMV	0x20
 #define HD68880_SYBS	0x0f
 
-static int	hd38880_cmd;
-static UINT32	hd38880_addr;
-static int	hd38880_data_bytes;
-static double	hd38880_speed;
-
 
 static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16 *table, int start)
 {
@@ -1032,12 +1085,15 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
         7
     */
 
+	device_t *device = machine->device("snk6502");
+	snk6502_sound_state *state = get_safe_token(device);
+	device_t *samples = state->samples;
+
 	if ((data & HD38880_CTP) && (data & HD38880_CMV))
 	{
-		running_device *samples = machine->device("samples");
 		data &= HD68880_SYBS;
 
-		switch (hd38880_cmd)
+		switch (state->hd38880_cmd)
 		{
 		case 0:
 			switch (data)
@@ -1045,15 +1101,14 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 			case HD38880_START:
 				logerror("speech: START\n");
 
-				if (hd38880_data_bytes == 5 && !sample_playing(samples, 0))
+				if (state->hd38880_data_bytes == 5 && !sample_playing(samples, 0))
 				{
 					int i;
 
 					for (i = 0; i < 16; i++)
 					{
-						if (table[i] && table[i] == hd38880_addr)
+						if (table[i] && table[i] == state->hd38880_addr)
 						{
-							running_device *samples = machine->device("samples");
 							sample_start(samples, 0, start + i, 0);
 							break;
 						}
@@ -1071,7 +1126,7 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 				break;
 
 			case HD38880_SYSPD:
-				hd38880_cmd = data;
+				state->hd38880_cmd = data;
 				break;
 
 			case HD38880_CONDT:
@@ -1079,9 +1134,9 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 				break;
 
 			case HD38880_ADSET:
-				hd38880_cmd = data;
-				hd38880_addr = 0;
-				hd38880_data_bytes = 0;
+				state->hd38880_cmd = data;
+				state->hd38880_addr = 0;
+				state->hd38880_data_bytes = 0;
 				break;
 
 			case HD38880_READ:
@@ -1089,11 +1144,11 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 				break;
 
 			case HD38880_INT1:
-				hd38880_cmd = data;
+				state->hd38880_cmd = data;
 				break;
 
 			case HD38880_INT2:
-				hd38880_cmd = data;
+				state->hd38880_cmd = data;
 				break;
 
 			case 0:
@@ -1118,7 +1173,7 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 			if ((data & 2) && (data & 8))
 				logerror("speech:   use external pitch control\n");
 
-			hd38880_cmd = 0;
+			state->hd38880_cmd = 0;
 			break;
 
 		case HD38880_INT2:
@@ -1129,21 +1184,21 @@ static void snk6502_speech_w(running_machine *machine, UINT8 data, const UINT16
 			logerror("speech:   %sable repeat\n", data & 2 ? "en" : "dis");
 			logerror("speech:   %d operations\n", ((data & 8) == 0) || (data & 1) ? 10 : 8);
 
-			hd38880_cmd = 0;
+			state->hd38880_cmd = 0;
 			break;
 
 		case HD38880_SYSPD:
-			hd38880_speed = ((double)(data + 1)) / 10.0;
-			logerror("speech: SYSPD: %1.1f\n", hd38880_speed);
-			hd38880_cmd = 0;
+			state->hd38880_speed = ((double)(data + 1)) / 10.0;
+			logerror("speech: SYSPD: %1.1f\n", state->hd38880_speed);
+			state->hd38880_cmd = 0;
 			break;
 
 		case HD38880_ADSET:
-			hd38880_addr |= (data << (hd38880_data_bytes++ * 4));
-			if (hd38880_data_bytes == 5)
+			state->hd38880_addr |= (data << (state->hd38880_data_bytes++ * 4));
+			if (state->hd38880_data_bytes == 5)
 			{
-				logerror("speech: ADSET: 0x%05x\n", hd38880_addr);
-				hd38880_cmd = 0;
+				logerror("speech: ADSET: 0x%05x\n", state->hd38880_addr);
+				state->hd38880_cmd = 0;
 			}
 			break;
 		}
