@@ -27,12 +27,11 @@
 #include "machine/pxa255.h"
 #include "sound/dmadac.h"
 
-class _39in1_state
+class _39in1_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, _39in1_state(machine)); }
-
-	_39in1_state(running_machine &machine) { }
+	_39in1_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	UINT32 seed;
 	UINT32 magic;
@@ -78,7 +77,7 @@ static WRITE32_HANDLER( pxa255_intc_w );
 static READ32_HANDLER( pxa255_gpio_r );
 static WRITE32_HANDLER( pxa255_gpio_w );
 
-static void pxa255_lcd_load_dma_descriptor(const address_space* space, UINT32 address, int channel);
+static void pxa255_lcd_load_dma_descriptor(address_space* space, UINT32 address, int channel);
 static void pxa255_lcd_irq_check(running_machine* machine);
 static void pxa255_lcd_dma_kickoff(running_machine* machine, int channel);
 static void pxa255_lcd_check_load_next_branch(running_machine* machine, int channel);
@@ -111,7 +110,7 @@ INLINE void ATTR_PRINTF(3,4) verboselog( running_machine* machine, int n_level,
 
 static READ32_HANDLER( pxa255_i2s_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_I2S_Regs *i2s_regs = &state->i2s_regs;
 
 	switch(PXA255_I2S_BASE_ADDR | (offset << 2))
@@ -146,7 +145,7 @@ static READ32_HANDLER( pxa255_i2s_r )
 
 static WRITE32_HANDLER( pxa255_i2s_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_I2S_Regs *i2s_regs = &state->i2s_regs;
 
 #if 0
@@ -225,7 +224,7 @@ static WRITE32_HANDLER( pxa255_i2s_w )
 
 static void pxa255_dma_irq_check(running_machine* machine)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_DMA_Regs *dma_regs = &state->dma_regs;
 	int channel = 0;
 	int set_intr = 0;
@@ -248,7 +247,7 @@ static void pxa255_dma_irq_check(running_machine* machine)
 
 static void pxa255_dma_load_descriptor_and_start(running_machine* machine, int channel)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_DMA_Regs *dma_regs = &state->dma_regs;
 	attotime period;
 
@@ -261,10 +260,11 @@ static void pxa255_dma_load_descriptor_and_start(running_machine* machine, int c
 
 	// Load the next descriptor
 
-	dma_regs->dsadr[channel] = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), dma_regs->ddadr[channel] + 0x4);
-	dma_regs->dtadr[channel] = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), dma_regs->ddadr[channel] + 0x8);
-	dma_regs->dcmd[channel]  = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), dma_regs->ddadr[channel] + 0xc);
-	dma_regs->ddadr[channel] = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), dma_regs->ddadr[channel]);
+	address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
+	dma_regs->dsadr[channel] = space->read_dword(dma_regs->ddadr[channel] + 0x4);
+	dma_regs->dtadr[channel] = space->read_dword(dma_regs->ddadr[channel] + 0x8);
+	dma_regs->dcmd[channel]  = space->read_dword(dma_regs->ddadr[channel] + 0xc);
+	dma_regs->ddadr[channel] = space->read_dword(dma_regs->ddadr[channel]);
 
 	// Start our end-of-transfer timer
 	switch(channel)
@@ -290,7 +290,7 @@ static void pxa255_dma_load_descriptor_and_start(running_machine* machine, int c
 
 static TIMER_CALLBACK( pxa255_dma_dma_end )
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_DMA_Regs *dma_regs = &state->dma_regs;
 	UINT32 sadr = dma_regs->dsadr[param];
 	UINT32 tadr = dma_regs->dtadr[param];
@@ -300,12 +300,13 @@ static TIMER_CALLBACK( pxa255_dma_dma_end )
 	UINT16 temp16;
 	UINT32 temp32;
 
+	address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
 	switch(param)
 	{
 		case 3:
 			for(index = 0; index < count; index += 4)
 			{
-				state->words[index >> 2] = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), sadr);
+				state->words[index >> 2] = space->read_dword(sadr);
 				state->samples[(index >> 1) + 0] = (INT16)(state->words[index >> 2] >> 16);
 				state->samples[(index >> 1) + 1] = (INT16)(state->words[index >> 2] & 0xffff);
 				sadr += 4;
@@ -318,18 +319,18 @@ static TIMER_CALLBACK( pxa255_dma_dma_end )
 				switch(dma_regs->dcmd[param] & PXA255_DCMD_SIZE)
 				{
 					case PXA255_DCMD_SIZE_8:
-						temp8 = memory_read_byte_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), sadr);
-						memory_write_byte_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), tadr, temp8);
+						temp8 = space->read_byte(sadr);
+						space->write_byte(tadr, temp8);
 						index++;
 						break;
 					case PXA255_DCMD_SIZE_16:
-						temp16 = memory_read_word_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), sadr);
-						memory_write_word_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), tadr, temp16);
+						temp16 = space->read_word(sadr);
+						space->write_word(tadr, temp16);
 						index += 2;
 						break;
 					case PXA255_DCMD_SIZE_32:
-						temp32 = memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), sadr);
-						memory_write_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), tadr, temp32);
+						temp32 = space->read_dword(sadr);
+						space->write_dword(tadr, temp32);
 						index += 4;
 						break;
 					default:
@@ -400,7 +401,7 @@ static TIMER_CALLBACK( pxa255_dma_dma_end )
 
 static READ32_HANDLER( pxa255_dma_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_DMA_Regs *dma_regs = &state->dma_regs;
 
 	switch(PXA255_DMA_BASE_ADDR | (offset << 2))
@@ -459,7 +460,7 @@ static READ32_HANDLER( pxa255_dma_r )
 
 static WRITE32_HANDLER( pxa255_dma_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_DMA_Regs *dma_regs = &state->dma_regs;
 
 	switch(PXA255_DMA_BASE_ADDR | (offset << 2))
@@ -551,7 +552,7 @@ static WRITE32_HANDLER( pxa255_dma_w )
 
 static void pxa255_ostimer_irq_check(running_machine* machine)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_OSTMR_Regs *ostimer_regs = &state->ostimer_regs;
 
 	pxa255_set_irq_line(machine, PXA255_INT_OSTIMER0, (ostimer_regs->oier & PXA255_OIER_E0) ? ((ostimer_regs->ossr & PXA255_OSSR_M0) ? 1 : 0) : 0);
@@ -562,7 +563,7 @@ static void pxa255_ostimer_irq_check(running_machine* machine)
 
 static TIMER_CALLBACK( pxa255_ostimer_match )
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_OSTMR_Regs *ostimer_regs = &state->ostimer_regs;
 
 	if (0) verboselog(machine, 3, "pxa255_ostimer_match channel %d\n", param);
@@ -573,7 +574,7 @@ static TIMER_CALLBACK( pxa255_ostimer_match )
 
 static READ32_HANDLER( pxa255_ostimer_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_OSTMR_Regs *ostimer_regs = &state->ostimer_regs;
 
 	switch(PXA255_OSTMR_BASE_ADDR | (offset << 2))
@@ -613,7 +614,7 @@ static READ32_HANDLER( pxa255_ostimer_r )
 
 static WRITE32_HANDLER( pxa255_ostimer_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_OSTMR_Regs *ostimer_regs = &state->ostimer_regs;
 
 	switch(PXA255_OSTMR_BASE_ADDR | (offset << 2))
@@ -705,7 +706,7 @@ static WRITE32_HANDLER( pxa255_ostimer_w )
 
 static void pxa255_update_interrupts(running_machine* machine)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_INTC_Regs *intc_regs = &state->intc_regs;
 
 	intc_regs->icfp = (intc_regs->icpr & intc_regs->icmr) & intc_regs->iclr;
@@ -716,7 +717,7 @@ static void pxa255_update_interrupts(running_machine* machine)
 
 static void pxa255_set_irq_line(running_machine* machine, UINT32 line, int irq_state)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_INTC_Regs *intc_regs = &state->intc_regs;
 
 	intc_regs->icpr &= ~line;
@@ -727,7 +728,7 @@ static void pxa255_set_irq_line(running_machine* machine, UINT32 line, int irq_s
 
 static READ32_HANDLER( pxa255_intc_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_INTC_Regs *intc_regs = &state->intc_regs;
 
 	switch(PXA255_INTC_BASE_ADDR | (offset << 2))
@@ -759,7 +760,7 @@ static READ32_HANDLER( pxa255_intc_r )
 
 static WRITE32_HANDLER( pxa255_intc_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_INTC_Regs *intc_regs = &state->intc_regs;
 
 	switch(PXA255_INTC_BASE_ADDR | (offset << 2))
@@ -801,7 +802,7 @@ static WRITE32_HANDLER( pxa255_intc_w )
 
 static READ32_HANDLER( pxa255_gpio_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_GPIO_Regs *gpio_regs = &state->gpio_regs;
 
 	switch(PXA255_GPIO_BASE_ADDR | (offset << 2))
@@ -828,23 +829,23 @@ static READ32_HANDLER( pxa255_gpio_r )
 			verboselog( space->machine, 3, "pxa255_gpio_r: GPIO Pin Direction Register 2: %08x & %08x\n", gpio_regs->gpdr2, mem_mask );
 			return gpio_regs->gpdr2;
 		case PXA255_GPSR0:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 0: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 0: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GPSR1:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 1: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 1: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GPSR2:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 2: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Set Register 2: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GPCR0:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 0: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 0: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GPCR1:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 1: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 1: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GPCR2:
-			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 2: %08x & %08x\n", mame_rand(space->machine), mem_mask );
-			return mame_rand(space->machine);
+			verboselog( space->machine, 3, "pxa255_gpio_r: (Invalid Read) GPIO Pin Output Clear Register 2: %08x & %08x\n", space->machine->rand(), mem_mask );
+			return space->machine->rand();
 		case PXA255_GRER0:
 			verboselog( space->machine, 3, "pxa255_gpio_r: GPIO Rising Edge Detect Enable Register 0: %08x & %08x\n", gpio_regs->grer0, mem_mask );
 			return gpio_regs->grer0;
@@ -899,7 +900,7 @@ static READ32_HANDLER( pxa255_gpio_r )
 
 static WRITE32_HANDLER( pxa255_gpio_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_GPIO_Regs *gpio_regs = &state->gpio_regs;
 
 	switch(PXA255_GPIO_BASE_ADDR | (offset << 2))
@@ -1047,15 +1048,15 @@ static WRITE32_HANDLER( pxa255_gpio_w )
 
 */
 
-static void pxa255_lcd_load_dma_descriptor(const address_space* space, UINT32 address, int channel)
+static void pxa255_lcd_load_dma_descriptor(address_space* space, UINT32 address, int channel)
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
-	lcd_regs->dma[channel].fdadr = memory_read_dword_32le(space, address);
-	lcd_regs->dma[channel].fsadr = memory_read_dword_32le(space, address + 0x04);
-	lcd_regs->dma[channel].fidr  = memory_read_dword_32le(space, address + 0x08);
-	lcd_regs->dma[channel].ldcmd = memory_read_dword_32le(space, address + 0x0c);
+	lcd_regs->dma[channel].fdadr = space->read_dword(address);
+	lcd_regs->dma[channel].fsadr = space->read_dword(address + 0x04);
+	lcd_regs->dma[channel].fidr  = space->read_dword(address + 0x08);
+	lcd_regs->dma[channel].ldcmd = space->read_dword(address + 0x0c);
 	verboselog( space->machine, 4, "pxa255_lcd_load_dma_descriptor, address = %08x, channel = %d\n", address, channel);
 	verboselog( space->machine, 4, "    DMA Frame Descriptor: %08x\n", lcd_regs->dma[channel].fdadr );
 	verboselog( space->machine, 4, "    DMA Frame Source Address: %08x\n", lcd_regs->dma[channel].fsadr );
@@ -1065,7 +1066,7 @@ static void pxa255_lcd_load_dma_descriptor(const address_space* space, UINT32 ad
 
 static void pxa255_lcd_irq_check(running_machine* machine)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	if(((lcd_regs->lcsr & PXA255_LCSR_BS)  != 0 && (lcd_regs->lccr0 & PXA255_LCCR0_BM)  == 0) ||
@@ -1082,7 +1083,7 @@ static void pxa255_lcd_irq_check(running_machine* machine)
 
 static void pxa255_lcd_dma_kickoff(running_machine* machine, int channel)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	if(lcd_regs->dma[channel].fdadr != 0)
@@ -1100,22 +1101,24 @@ static void pxa255_lcd_dma_kickoff(running_machine* machine, int channel)
 
 		if(lcd_regs->dma[channel].ldcmd & PXA255_LDCMD_PAL)
 		{
+			address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
 			int length = lcd_regs->dma[channel].ldcmd & 0x000fffff;
 			int index = 0;
 			for(index = 0; index < length; index += 2)
 			{
-				UINT16 color = memory_read_word_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), (lcd_regs->dma[channel].fsadr &~ 1) + index);
+				UINT16 color = space->read_word((lcd_regs->dma[channel].fsadr &~ 1) + index);
 				state->pxa255_lcd_palette[index >> 1] = (((((color >> 11) & 0x1f) << 3) | (color >> 13)) << 16) | (((((color >> 5) & 0x3f) << 2) | ((color >> 9) & 0x3)) << 8) | (((color & 0x1f) << 3) | ((color >> 2) & 0x7));
 				palette_set_color_rgb(machine, index >> 1, (((color >> 11) & 0x1f) << 3) | (color >> 13), (((color >> 5) & 0x3f) << 2) | ((color >> 9) & 0x3), ((color & 0x1f) << 3) | ((color >> 2) & 0x7));
 			}
 		}
 		else
 		{
+			address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
 			int length = lcd_regs->dma[channel].ldcmd & 0x000fffff;
 			int index = 0;
 			for(index = 0; index < length; index++)
 			{
-				state->pxa255_lcd_framebuffer[index] = memory_read_byte_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), lcd_regs->dma[channel].fsadr + index);
+				state->pxa255_lcd_framebuffer[index] = space->read_byte(lcd_regs->dma[channel].fsadr + index);
 			}
 		}
 	}
@@ -1123,17 +1126,18 @@ static void pxa255_lcd_dma_kickoff(running_machine* machine, int channel)
 
 static void pxa255_lcd_check_load_next_branch(running_machine* machine, int channel)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	if(lcd_regs->fbr[channel] & 1)
 	{
 		verboselog( machine, 4, "pxa255_lcd_check_load_next_branch: Taking branch\n" );
 		lcd_regs->fbr[channel] &= ~1;
-		//lcd_regs->fbr[channel] = (memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), lcd_regs->fbr[channel] & 0xfffffff0) & 0xfffffff0) | (lcd_regs->fbr[channel] & 0x00000003);
+		address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
+		//lcd_regs->fbr[channel] = (space->read_dword(lcd_regs->fbr[channel] & 0xfffffff0) & 0xfffffff0) | (lcd_regs->fbr[channel] & 0x00000003);
 		//printf( "%08x\n", lcd_regs->fbr[channel] );
-		pxa255_lcd_load_dma_descriptor(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), lcd_regs->fbr[channel] & 0xfffffff0, 0);
-		lcd_regs->fbr[channel] = (memory_read_dword_32le(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), lcd_regs->fbr[channel] & 0xfffffff0) & 0xfffffff0) | (lcd_regs->fbr[channel] & 0x00000003);
+		pxa255_lcd_load_dma_descriptor(space, lcd_regs->fbr[channel] & 0xfffffff0, 0);
+		lcd_regs->fbr[channel] = (space->read_dword(lcd_regs->fbr[channel] & 0xfffffff0) & 0xfffffff0) | (lcd_regs->fbr[channel] & 0x00000003);
 		pxa255_lcd_dma_kickoff(machine, 0);
 		if(lcd_regs->fbr[channel] & 2)
 		{
@@ -1152,7 +1156,7 @@ static void pxa255_lcd_check_load_next_branch(running_machine* machine, int chan
 
 static TIMER_CALLBACK( pxa255_lcd_dma_eof )
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	if (0) verboselog( machine, 3, "End of frame callback\n" );
@@ -1167,7 +1171,7 @@ static TIMER_CALLBACK( pxa255_lcd_dma_eof )
 
 static READ32_HANDLER( pxa255_lcd_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	switch(PXA255_LCD_BASE_ADDR | (offset << 2))
@@ -1235,7 +1239,7 @@ static READ32_HANDLER( pxa255_lcd_r )
 
 static WRITE32_HANDLER( pxa255_lcd_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 	PXA255_LCD_Regs *lcd_regs = &state->lcd_regs;
 
 	switch(PXA255_LCD_BASE_ADDR | (offset << 2))
@@ -1358,7 +1362,7 @@ static READ32_HANDLER( unknown_r )
 
 static READ32_HANDLER( cpld_r )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 
 	//if (cpu_get_pc(space->cpu) != 0xe3af4) printf("CPLD read @ %x (PC %x state %d)\n", offset, cpu_get_pc(space->cpu), state);
 
@@ -1415,7 +1419,7 @@ static READ32_HANDLER( cpld_r )
 
 static WRITE32_HANDLER( cpld_w )
 {
-	_39in1_state *state = (_39in1_state *)space->machine->driver_data;
+	_39in1_state *state = space->machine->driver_data<_39in1_state>();
 
 	if (mem_mask == 0xffff)
 	{
@@ -1429,7 +1433,7 @@ static WRITE32_HANDLER( cpld_w )
 	if (cpu_get_pc(space->cpu) == 0x2874)
 	{
 		state->state = 2;
-		state->magic = memory_read_byte_32le(space, 0x2d4ff0);
+		state->magic = space->read_byte(0x2d4ff0);
 	}
 	else if (offset == 0xa)
 	{
@@ -1449,13 +1453,14 @@ static READ32_HANDLER( prot_cheater_r )
 
 static DRIVER_INIT( 39in1 )
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 
 	state->dmadac[0] = machine->device<dmadac_sound_device>("dac1");
 	state->dmadac[1] = machine->device<dmadac_sound_device>("dac2");
 	state->eeprom = machine->device<eeprom_device>("eeprom");
 
-	memory_install_read32_handler (cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xa0151648, 0xa015164b, 0, 0, prot_cheater_r);
+	address_space *space = machine->device<pxa255_device>("maincpu")->space(AS_PROGRAM);
+	memory_install_read32_handler (space, 0xa0151648, 0xa015164b, 0, 0, prot_cheater_r);
 }
 
 static ADDRESS_MAP_START( 39in1_map, ADDRESS_SPACE_PROGRAM, 32 )
@@ -1509,7 +1514,7 @@ INPUT_PORTS_END
 
 static VIDEO_UPDATE( 39in1 )
 {
-	_39in1_state *state = (_39in1_state *)screen->machine->driver_data;
+	_39in1_state *state = screen->machine->driver_data<_39in1_state>();
 	int x = 0;
 	int y = 0;
 
@@ -1527,7 +1532,7 @@ static VIDEO_UPDATE( 39in1 )
 /* To be moved to DEVICE_START( pxa255 ) upon completion */
 static void pxa255_start(running_machine* machine)
 {
-	_39in1_state *state = (_39in1_state *)machine->driver_data;
+	_39in1_state *state = machine->driver_data<_39in1_state>();
 	int index = 0;
 
 	//pxa255_t* pxa255 = pxa255_get_safe_token( device );
@@ -1560,7 +1565,7 @@ static void pxa255_start(running_machine* machine)
 
 static MACHINE_START(39in1)
 {
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	UINT8 *ROM = machine->region("maincpu")->base();
 	int i;
 
 	for (i = 0; i < 0x80000; i += 2)
@@ -1577,36 +1582,34 @@ static MACHINE_START(39in1)
 	pxa255_start(machine);
 }
 
-static MACHINE_DRIVER_START( 39in1 )
+static MACHINE_CONFIG_START( 39in1, _39in1_state )
 
-	MDRV_DRIVER_DATA( _39in1_state )
+	MCFG_CPU_ADD("maincpu", PXA255, 200000000)
+	MCFG_CPU_PROGRAM_MAP(39in1_map)
+	MCFG_CPU_VBLANK_INT("screen", pxa255_vblank_start)
 
-	MDRV_CPU_ADD("maincpu", PXA255, 200000000)
-	MDRV_CPU_PROGRAM_MAP(39in1_map)
-	MDRV_CPU_VBLANK_INT("screen", pxa255_vblank_start)
+	MCFG_PALETTE_LENGTH(32768)
 
-	MDRV_PALETTE_LENGTH(32768)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(1024, 1024)
+	MCFG_SCREEN_VISIBLE_AREA(0, 295, 0, 479)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(1024, 1024)
-	MDRV_SCREEN_VISIBLE_AREA(0, 295, 0, 479)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_MACHINE_START(39in1)
+	MCFG_EEPROM_93C66B_ADD("eeprom")
 
-	MDRV_MACHINE_START(39in1)
-	MDRV_EEPROM_93C66B_ADD("eeprom")
+	MCFG_VIDEO_UPDATE(39in1)
 
-	MDRV_VIDEO_UPDATE(39in1)
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
-
-	MDRV_SOUND_ADD("dac1", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-	MDRV_SOUND_ADD("dac2", DMADAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac1", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ADD("dac2", DMADAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 ROM_START( 39in1 )
 	// main program, encrypted
