@@ -137,7 +137,7 @@ INPUT_PORTS_END
 
 static WRITE8_HANDLER( sound_bank_w )
 {
-	ajax_state *state = (ajax_state *)space->machine->driver_data;
+	ajax_state *state = space->machine->driver_data<ajax_state>();
 	int bank_A, bank_B;
 
 	/* banks # for the 007232 (chip 1) */
@@ -151,7 +151,7 @@ static WRITE8_HANDLER( sound_bank_w )
 	k007232_set_bank(state->k007232_2, bank_A, bank_B);
 }
 
-static void volume_callback0(running_device *device, int v)
+static void volume_callback0(device_t *device, int v)
 {
 	k007232_set_volume(device, 0, (v >> 4) * 0x11, 0);
 	k007232_set_volume(device, 1, 0, (v & 0x0f) * 0x11);
@@ -163,7 +163,7 @@ static WRITE8_DEVICE_HANDLER( k007232_extvol_w )
 	k007232_set_volume(device, 0, (data & 0x0f) * 0x11/2, (data & 0x0f) * 0x11/2);
 }
 
-static void volume_callback1(running_device *device, int v)
+static void volume_callback1(device_t *device, int v)
 {
 	/* channel B volume/pan */
 	k007232_set_volume(device, 1, (v & 0x0f) * 0x11/2, (v >> 4) * 0x11/2);
@@ -205,64 +205,61 @@ static const k051316_interface ajax_k051316_intf =
 	ajax_zoom_callback
 };
 
-static MACHINE_DRIVER_START( ajax )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(ajax_state)
+static MACHINE_CONFIG_START( ajax, ajax_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", KONAMI, 3000000)	/* 12/4 MHz*/
-	MDRV_CPU_PROGRAM_MAP(ajax_main_map)
-	MDRV_CPU_VBLANK_INT("screen", ajax_interrupt)	/* IRQs triggered by the 051960 */
+	MCFG_CPU_ADD("maincpu", KONAMI, 3000000)	/* 12/4 MHz*/
+	MCFG_CPU_PROGRAM_MAP(ajax_main_map)
+	MCFG_CPU_VBLANK_INT("screen", ajax_interrupt)	/* IRQs triggered by the 051960 */
 
-	MDRV_CPU_ADD("sub", M6809, 3000000)	/* ? */
-	MDRV_CPU_PROGRAM_MAP(ajax_sub_map)
+	MCFG_CPU_ADD("sub", M6809, 3000000)	/* ? */
+	MCFG_CPU_PROGRAM_MAP(ajax_sub_map)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3579545)	/* 3.58 MHz */
-	MDRV_CPU_PROGRAM_MAP(ajax_sound_map)
+	MCFG_CPU_ADD("audiocpu", Z80, 3579545)	/* 3.58 MHz */
+	MCFG_CPU_PROGRAM_MAP(ajax_sound_map)
 
-	MDRV_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(HZ(600))
 
-	MDRV_MACHINE_RESET(ajax)
-	MDRV_MACHINE_START(ajax)
+	MCFG_MACHINE_RESET(ajax)
+	MCFG_MACHINE_START(ajax)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(ajax)
-	MDRV_VIDEO_UPDATE(ajax)
+	MCFG_VIDEO_START(ajax)
+	MCFG_VIDEO_UPDATE(ajax)
 
-	MDRV_K052109_ADD("k052109", ajax_k052109_intf)
-	MDRV_K051960_ADD("k051960", ajax_k051960_intf)
-	MDRV_K051316_ADD("k051316", ajax_k051316_intf)
+	MCFG_K052109_ADD("k052109", ajax_k052109_intf)
+	MCFG_K051960_ADD("k051960", ajax_k051960_intf)
+	MCFG_K051316_ADD("k051316", ajax_k051316_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 3579545)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("ymsnd", YM2151, 3579545)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("k007232_1", K007232, 3579545)
-	MDRV_SOUND_CONFIG(k007232_interface_1)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.20)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 0.20)
-	MDRV_SOUND_ROUTE(1, "lspeaker", 0.20)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 0.20)
+	MCFG_SOUND_ADD("k007232_1", K007232, 3579545)
+	MCFG_SOUND_CONFIG(k007232_interface_1)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.20)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 0.20)
+	MCFG_SOUND_ROUTE(1, "lspeaker", 0.20)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 0.20)
 
-	MDRV_SOUND_ADD("k007232_2", K007232, 3579545)
-	MDRV_SOUND_CONFIG(k007232_interface_2)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.50)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("k007232_2", K007232, 3579545)
+	MCFG_SOUND_CONFIG(k007232_interface_2)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.50)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 0.50)
+MACHINE_CONFIG_END
 
 
 /*
