@@ -51,16 +51,18 @@
 #include "cpu/m68000/m68000.h"
 #include "includes/amiga.h"
 #include "machine/6526cia.h"
+#include "machine/nvram.h"
 
 
 
-/*************************************
- *
- *  Globals
- *
- *************************************/
+class arcadia_state : public amiga_state
+{
+public:
+	arcadia_state(running_machine &machine, const driver_device_config_base &config)
+		: amiga_state(machine, config) { }
 
-static UINT8 coin_counter[2];
+	UINT8 coin_counter[2];
+};
 
 
 
@@ -135,6 +137,8 @@ static WRITE8_DEVICE_HANDLER( arcadia_cia_0_portb_w )
 	/* writing a 0 in the low bit clears one of the coins */
 	if ((data & 1) == 0)
 	{
+		UINT8 *coin_counter = device->machine->driver_data<arcadia_state>()->coin_counter;
+
 		if (coin_counter[0] > 0)
 			coin_counter[0]--;
 		else if (coin_counter[1] > 0)
@@ -152,23 +156,29 @@ static WRITE8_DEVICE_HANDLER( arcadia_cia_0_portb_w )
 
 static CUSTOM_INPUT( coin_counter_r )
 {
+	int coin = (FPTR)param;
+	UINT8 *coin_counter = field->port->machine->driver_data<arcadia_state>()->coin_counter;
+
 	/* return coin counter values */
-	return *(UINT8 *)param & 3;
+	return coin_counter[coin] & 3;
 }
 
 
 static INPUT_CHANGED( coin_changed_callback )
 {
-	UINT8 *counter = (UINT8 *)param;
+	int coin = (FPTR)param;
+	UINT8 *coin_counter = field->port->machine->driver_data<arcadia_state>()->coin_counter;
 
 	/* check for a 0 -> 1 transition */
-	if (!oldval && newval && *counter < 3)
-		*counter += 1;
+	if (!oldval && newval && coin_counter[coin] < 3)
+		coin_counter[coin] += 1;
 }
 
 
 static void arcadia_reset_coins(running_machine *machine)
 {
+	UINT8 *coin_counter = machine->driver_data<arcadia_state>()->coin_counter;
+
 	/* reset coin counters */
 	coin_counter[0] = coin_counter[1] = 0;
 }
@@ -183,15 +193,15 @@ static void arcadia_reset_coins(running_machine *machine)
 
 static ADDRESS_MAP_START( amiga_map, ADDRESS_SPACE_PROGRAM, 16 )
 	ADDRESS_MAP_UNMAP_HIGH
-	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE(&amiga_chip_ram) AM_SIZE(&amiga_chip_ram_size)
+	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK("bank1") AM_BASE_SIZE_MEMBER(arcadia_state, chip_ram, chip_ram_size)
 	AM_RANGE(0xbfd000, 0xbfefff) AM_READWRITE(amiga_cia_r, amiga_cia_w)
-	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE(&amiga_custom_regs)
+	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE_MEMBER(arcadia_state, custom_regs)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_READWRITE(amiga_autoconfig_r, amiga_autoconfig_w)
 	AM_RANGE(0xf80000, 0xffffff) AM_ROM AM_REGION("user1", 0)		/* Kickstart BIOS */
 
 	AM_RANGE(0x800000, 0x97ffff) AM_ROMBANK("bank2") AM_REGION("user3", 0)
 	AM_RANGE(0x980000, 0x9fbfff) AM_ROM AM_REGION("user2", 0)
-	AM_RANGE(0x9fc000, 0x9ffffd) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x9fc000, 0x9ffffd) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x9ffffe, 0x9fffff) AM_WRITE(arcadia_multibios_change_game)
 	AM_RANGE(0xf00000, 0xf7ffff) AM_ROM AM_REGION("user2", 0)
 ADDRESS_MAP_END
@@ -217,8 +227,8 @@ static INPUT_PORTS_START( arcadia )
 	PORT_SERVICE_NO_TOGGLE( 0x02, IP_ACTIVE_LOW )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x30, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, &coin_counter[0])
-	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, &coin_counter[1])
+	PORT_BIT( 0x30, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, 0)
+	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, 1)
 
 	PORT_START("JOY0DAT")
 	PORT_BIT( 0x0303, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(amiga_joystick_convert, "P1JOY")
@@ -248,8 +258,8 @@ static INPUT_PORTS_START( arcadia )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
 
 	PORT_START("COINS")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_changed_callback, &coin_counter[0])
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(coin_changed_callback, &coin_counter[1])
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_changed_callback, 0)
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(coin_changed_callback, 1)
 INPUT_PORTS_END
 
 
@@ -286,43 +296,43 @@ static const mos6526_interface cia_1_intf =
 	DEVCB_NULL
 };
 
-static MACHINE_DRIVER_START( arcadia )
+static MACHINE_CONFIG_START( arcadia, arcadia_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, AMIGA_68000_NTSC_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(amiga_map)
+	MCFG_CPU_ADD("maincpu", M68000, AMIGA_68000_NTSC_CLOCK)
+	MCFG_CPU_PROGRAM_MAP(amiga_map)
 
-	MDRV_MACHINE_RESET(amiga)
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_MACHINE_RESET(amiga)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(59.997)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512*2, 262)
-	MDRV_SCREEN_VISIBLE_AREA((129-8)*2, (449+8-1)*2, 44-8, 244+8-1)
-	MDRV_PALETTE_LENGTH(4096)
-	MDRV_PALETTE_INIT(amiga)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(59.997)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512*2, 262)
+	MCFG_SCREEN_VISIBLE_AREA((129-8)*2, (449+8-1)*2, 44-8, 244+8-1)
+	MCFG_PALETTE_LENGTH(4096)
+	MCFG_PALETTE_INIT(amiga)
 
-	MDRV_VIDEO_START(amiga)
-	MDRV_VIDEO_UPDATE(amiga)
+	MCFG_VIDEO_START(amiga)
+	MCFG_VIDEO_UPDATE(amiga)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("amiga", AMIGA, 3579545)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.50)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 0.50)
-	MDRV_SOUND_ROUTE(2, "rspeaker", 0.50)
-	MDRV_SOUND_ROUTE(3, "lspeaker", 0.50)
+	MCFG_SOUND_ADD("amiga", AMIGA, 3579545)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.50)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 0.50)
+	MCFG_SOUND_ROUTE(2, "rspeaker", 0.50)
+	MCFG_SOUND_ROUTE(3, "lspeaker", 0.50)
 
 	/* cia */
-	MDRV_MOS8520_ADD("cia_0", AMIGA_68000_NTSC_CLOCK / 10, cia_0_intf)
-	MDRV_MOS8520_ADD("cia_1", AMIGA_68000_NTSC_CLOCK / 10, cia_1_intf)
-MACHINE_DRIVER_END
+	MCFG_MOS8520_ADD("cia_0", AMIGA_68000_NTSC_CLOCK / 10, cia_0_intf)
+	MCFG_MOS8520_ADD("cia_1", AMIGA_68000_NTSC_CLOCK / 10, cia_1_intf)
+MACHINE_CONFIG_END
 
 
 
@@ -717,7 +727,7 @@ ROM_END
 
 INLINE void generic_decode(running_machine *machine, const char *tag, int bit7, int bit6, int bit5, int bit4, int bit3, int bit2, int bit1, int bit0)
 {
-	UINT16 *rom = (UINT16 *)memory_region(machine, tag);
+	UINT16 *rom = (UINT16 *)machine->region(tag)->base();
 	int i;
 
 	/* only the low byte of ROMs are encrypted in these games */
@@ -726,8 +736,8 @@ INLINE void generic_decode(running_machine *machine, const char *tag, int bit7,
 
 	#if 0
 	{
-		UINT8 *ROM = memory_region(machine, tag);
-		int size = memory_region_length(machine, tag);
+		UINT8 *ROM = machine->region(tag)->base();
+		int size = machine->region(tag)->bytes();
 
 		FILE *fp;
 		char filename[256];
@@ -752,6 +762,7 @@ INLINE void generic_decode(running_machine *machine, const char *tag, int bit7,
 
 static void arcadia_init(running_machine *machine)
 {
+	arcadia_state *state = machine->driver_data<arcadia_state>();
 	static const amiga_machine_interface arcadia_intf =
 	{
 		ANGUS_CHIP_RAM_MASK,
@@ -767,11 +778,11 @@ static void arcadia_init(running_machine *machine)
 	amiga_machine_config(machine, &arcadia_intf);
 
 	/* set up memory */
-	memory_configure_bank(machine, "bank1", 0, 1, amiga_chip_ram, 0);
-	memory_configure_bank(machine, "bank1", 1, 1, memory_region(machine, "user1"), 0);
+	memory_configure_bank(machine, "bank1", 0, 1, state->chip_ram, 0);
+	memory_configure_bank(machine, "bank1", 1, 1, machine->region("user1")->base(), 0);
 
 	/* OnePlay bios is encrypted, TenPlay is not */
-	biosrom = (UINT16 *)memory_region(machine, "user2");
+	biosrom = (UINT16 *)machine->region("user2")->base();
 	if (biosrom[0] != 0x4afc)
 		generic_decode(machine, "user2", 6, 1, 0, 2, 3, 4, 5, 7);
 }
