@@ -53,7 +53,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
     to find its purpose (any more infos are welcome)
 
 
-1b) 'legiono'
+1b) 'legiono' (bootleg set?)
 
   - The ROM test (code at 0x000466) checks range 0x000102-0x03ffff
     but NEVER reports an error if the checksum isn't correct due
@@ -176,7 +176,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 
 static WRITE16_HANDLER( io_w )
 {
-	armedf_state *state = (armedf_state *)space->machine->driver_data;
+	armedf_state *state = space->machine->driver_data<armedf_state>();
 
 	COMBINE_DATA(&state->vreg);
 	/* bits 0 and 1 of armedf_vreg are coin counters */
@@ -186,7 +186,7 @@ static WRITE16_HANDLER( io_w )
 
 static WRITE16_HANDLER( terraf_io_w )
 {
-	armedf_state *state = (armedf_state *)space->machine->driver_data;
+	armedf_state *state = space->machine->driver_data<armedf_state>();
 
 	COMBINE_DATA(&state->vreg);
 	/* bits 0 and 1 of armedf_vreg are coin counters */
@@ -209,7 +209,7 @@ static WRITE16_HANDLER( terraf_io_w )
 
 static WRITE16_HANDLER( kodure_io_w )
 {
-	armedf_state *state = (armedf_state *)space->machine->driver_data;
+	armedf_state *state = space->machine->driver_data<armedf_state>();
 
 	COMBINE_DATA(&state->vreg);
 	/* bits 0 and 1 of armedf_vreg are coin counters */
@@ -236,7 +236,7 @@ static WRITE16_HANDLER( sound_command_w )
 #ifdef UNUSED_FUNCTION
 static WRITE16_HANDLER( legion_command_c )
 {
-	armedf_state *state = (armedf_state *)space->machine->driver_data;
+	armedf_state *state = space->machine->driver_data<armedf_state>();
 
 	COMBINE_DATA(&state->legion_cmd[offset]);
 	//logerror("Legion CMD %04x=%04x", offset, data);
@@ -762,7 +762,7 @@ GFXDECODE_END
 
 static MACHINE_START( armedf )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 
 	state_save_register_global(machine, state->mcu_mode);
 	state_save_register_global(machine, state->old_mcu_mode);
@@ -777,7 +777,7 @@ static MACHINE_START( armedf )
 
 static MACHINE_RESET( armedf )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 
 	state->mcu_mode = 0;
 	state->old_mcu_mode = 0;
@@ -791,339 +791,318 @@ static MACHINE_RESET( armedf )
 }
 
 
-static MACHINE_DRIVER_START( terraf )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( terraf, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(terraf_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(terraf_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(57)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( terrafb )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( terrafb, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(terrafb_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(terrafb_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_CPU_ADD("extra", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(terrafb_extraz80_map)
-	MDRV_CPU_IO_MAP(terrafb_extraz80_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("extra", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(terrafb_extraz80_map)
+	MCFG_CPU_IO_MAP(terrafb_extraz80_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(57)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( kodure )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( kodure, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(kodure_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(kodure_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000) /* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000) /* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( armedf )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( armedf, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(armedf_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(armedf_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(57)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-12)*8-1, 1*8, 31*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( cclimbr2 )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( cclimbr2, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(cclimbr2_map)
-	MDRV_CPU_VBLANK_INT("screen", irq2_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(cclimbr2_map)
+	MCFG_CPU_VBLANK_INT("screen", irq2_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)		/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(cclimbr2_soundmap)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)		/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(cclimbr2_soundmap)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( legion )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( legion, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(legion_map)
-	MDRV_CPU_VBLANK_INT("screen", irq2_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(legion_map)
+	MCFG_CPU_VBLANK_INT("screen", irq2_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(cclimbr2_soundmap)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(cclimbr2_soundmap)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( legiono )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(armedf_state)
+static MACHINE_CONFIG_START( legiono, armedf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
-	MDRV_CPU_PROGRAM_MAP(legiono_map)
-	MDRV_CPU_VBLANK_INT("screen", irq2_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000) /* 8 MHz?? */
+	MCFG_CPU_PROGRAM_MAP(legiono_map)
+	MCFG_CPU_VBLANK_INT("screen", irq2_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
-	MDRV_CPU_PROGRAM_MAP(cclimbr2_soundmap)
-	MDRV_CPU_IO_MAP(sound_portmap)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)	/* 3.072 MHz???? */
+	MCFG_CPU_PROGRAM_MAP(cclimbr2_soundmap)
+	MCFG_CPU_IO_MAP(sound_portmap)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,128)
 
-	MDRV_MACHINE_START(armedf)
-	MDRV_MACHINE_RESET(armedf)
+	MCFG_MACHINE_START(armedf)
+	MCFG_MACHINE_RESET(armedf)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
-	MDRV_GFXDECODE(armedf)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_GFXDECODE(armedf)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_EOF(armedf)
-	MDRV_VIDEO_START(armedf)
-	MDRV_VIDEO_UPDATE(armedf)
+	MCFG_VIDEO_EOF(armedf)
+	MCFG_VIDEO_START(armedf)
+	MCFG_VIDEO_UPDATE(armedf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
 
 /*************************************
@@ -1141,6 +1120,7 @@ ROM_START( legion )
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* Z80 code (sound) */
 	ROM_LOAD( "legion.1h", 0x00000, 0x04000, CRC(2ca4f7f0) SHA1(7cf997af9dd74ced9d28c047069ccfb67d72e257) ) // lg9
+	ROM_LOAD( "legion.1i", 0x04000, 0x08000, CRC(79f4a827) SHA1(25e4c1b5b8466627244b7226310e67e4261333b6) ) // lg10
 
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "lg8.bin", 0x00000, 0x08000, CRC(e0596570) SHA1(68ddc950efc55a16e6abc699e3bad18ea19d579f) )
@@ -1158,9 +1138,6 @@ ROM_START( legion )
 
 	ROM_REGION( 0x4000, "gfx5", 0 )	/* data for mcu/blitter */
 	ROM_LOAD ( "lg7.bin", 0x0000, 0x4000, CRC(533e2b58) SHA1(a13ea4a530038760ffa87713903c59a932452717) )
-
-	ROM_REGION( 0x8000, "user1", 0 )	/* ? */
-	ROM_LOAD( "legion.1i",        0x0000, 0x8000, CRC(79f4a827) SHA1(25e4c1b5b8466627244b7226310e67e4261333b6) ) // lg10
 ROM_END
 
 ROM_START( legiono )
@@ -1172,6 +1149,7 @@ ROM_START( legiono )
 
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* Z80 code (sound) */
 	ROM_LOAD( "legion.1h", 0x00000, 0x04000, CRC(2ca4f7f0) SHA1(7cf997af9dd74ced9d28c047069ccfb67d72e257) )
+	ROM_LOAD( "legion.1i", 0x04000, 0x08000, CRC(79f4a827) SHA1(25e4c1b5b8466627244b7226310e67e4261333b6) )
 
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "legion.1g", 0x00000, 0x08000, CRC(c50b0125) SHA1(83b5e9707152d97777fb65fa8820ba34ec2fac8d) )
@@ -1187,10 +1165,6 @@ ROM_START( legiono )
 	ROM_LOAD( "legion.1k", 0x000000, 0x010000, CRC(ff5a0db9) SHA1(9308deb363d3b7686cc69485ec14201dd68f9a97) )
 	ROM_LOAD( "legion.1j", 0x010000, 0x010000, CRC(bae220c8) SHA1(392ae0fb0351dcad7b0e8e0ed4a1dc6e07f493df) )
 
-	/* should lg7.bin be loaded here too? The ROM wasn't included in this set */
-
-	ROM_REGION( 0x8000, "user1", 0 )	/* ? */
-	ROM_LOAD( "legion.1i",        0x0000, 0x8000, CRC(79f4a827) SHA1(25e4c1b5b8466627244b7226310e67e4261333b6) )
 ROM_END
 
 ROM_START( terraf )
@@ -1527,36 +1501,36 @@ ROM_END
 
 static DRIVER_INIT( terraf )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 	state->scroll_type = 0;
 }
 
 static DRIVER_INIT( terrafu )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 	state->scroll_type = 5;
 }
 
 static DRIVER_INIT( armedf )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 	state->scroll_type = 1;
 }
 
 
 static DRIVER_INIT( kodure )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 	state->scroll_type = 2;
 }
 
 static DRIVER_INIT( legion )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 #if LEGION_HACK
 	/* This is a hack to allow you to use the extra features
          of 3 of the "Unused" Dip Switches (see notes above). */
-	UINT16 *RAM = (UINT16 *)memory_region(machine, "maincpu");
+	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
 	RAM[0x0001d6 / 2] = 0x0001;
 	/* To avoid checksum error */
 	RAM[0x000488 / 2] = 0x4e71;
@@ -1567,11 +1541,11 @@ static DRIVER_INIT( legion )
 
 static DRIVER_INIT( legiono )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 #if LEGION_HACK
 	/* This is a hack to allow you to use the extra features
          of 3 of the "Unused" Dip Switches (see notes above). */
-	UINT16 *RAM = (UINT16 *)memory_region(machine, "maincpu");
+	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
 	RAM[0x0001d6/2] = 0x0001;
 	/* No need to patch the checksum routine (see notes) ! */
 #endif
@@ -1581,7 +1555,7 @@ static DRIVER_INIT( legiono )
 
 static DRIVER_INIT( cclimbr2 )
 {
-	armedf_state *state = (armedf_state *)machine->driver_data;
+	armedf_state *state = machine->driver_data<armedf_state>();
 	state->scroll_type = 4;
 }
 
@@ -1594,7 +1568,7 @@ static DRIVER_INIT( cclimbr2 )
 
 /*     YEAR, NAME,    PARENT,   MACHINE,  INPUT,    INIT,     MONITOR, COMPANY,         FULLNAME,                          FLAGS */
 GAME( 1987, legion,   0,        legion,   legion,   legion,   ROT270, "Nichibutsu",     "Chouji Meikyuu Legion (ver 2.03)", GAME_SUPPORTS_SAVE | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION )
-GAME( 1987, legiono,  legion,   legiono,  legion,   legiono,  ROT270, "Nichibutsu",     "Chouji Meikyuu Legion (ver 1.05)", GAME_SUPPORTS_SAVE | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION )
+GAME( 1987, legiono,  legion,   legiono,  legion,   legiono,  ROT270, "Nichibutsu",     "Chouji Meikyuu Legion (ver 1.05)", GAME_SUPPORTS_SAVE ) /* bootleg? */
 GAME( 1987, terraf,   0,        terraf,   terraf,   terraf,   ROT0,   "Nichibutsu",     "Terra Force (set 1)", GAME_SUPPORTS_SAVE | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION )
 GAME( 1987, terrafb,  terraf,   terrafb,  terraf,   terrafu,  ROT0,   "bootleg",        "Terra Force (bootleg with additional Z80)", GAME_SUPPORTS_SAVE | GAME_NOT_WORKING )
 GAME( 1987, terrafa,  terraf,   terraf,   terraf,   terrafu,  ROT0,   "Nichibutsu",     "Terra Force (set 2)", GAME_SUPPORTS_SAVE | GAME_IMPERFECT_GRAPHICS | GAME_UNEMULATED_PROTECTION )
