@@ -41,12 +41,11 @@ enum
 };
 
 
-class astinvad_state
+class astinvad_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, astinvad_state(machine)); }
-
-	astinvad_state(running_machine &machine) { }
+	astinvad_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	UINT8 *    colorram;
 	UINT8 *    videoram;
@@ -59,10 +58,10 @@ public:
 	UINT8      flip_yoffs;
 	UINT8      color_latch;
 
-	running_device *maincpu;
-	running_device *ppi8255_0;
-	running_device *ppi8255_1;
-	running_device *samples;
+	device_t *maincpu;
+	device_t *ppi8255_0;
+	device_t *ppi8255_1;
+	device_t *samples;
 };
 
 
@@ -105,7 +104,7 @@ static const ppi8255_interface ppi8255_intf[2] =
 
 static VIDEO_START( spaceint )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 	state->colorram = auto_alloc_array(machine, UINT8, state->videoram_size);
 
 	state_save_register_global(machine, state->color_latch);
@@ -115,14 +114,14 @@ static VIDEO_START( spaceint )
 
 static WRITE8_HANDLER( color_latch_w )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 	state->color_latch = data & 0x0f;
 }
 
 
 static WRITE8_HANDLER( spaceint_videoram_w )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 	state->videoram[offset] = data;
 	state->colorram[offset] = state->color_latch;
 }
@@ -137,7 +136,7 @@ static WRITE8_HANDLER( spaceint_videoram_w )
 
 static void plot_byte( running_machine *machine, bitmap_t *bitmap, UINT8 y, UINT8 x, UINT8 data, UINT8 color )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 	pen_t fore_pen = MAKE_RGB(pal1bit(color >> 0), pal1bit(color >> 2), pal1bit(color >> 1));
 	UINT8 flip_xor = state->screen_flip & 7;
 
@@ -154,8 +153,8 @@ static void plot_byte( running_machine *machine, bitmap_t *bitmap, UINT8 y, UINT
 
 static VIDEO_UPDATE( astinvad )
 {
-	astinvad_state *state = (astinvad_state *)screen->machine->driver_data;
-	const UINT8 *color_prom = memory_region(screen->machine, "proms");
+	astinvad_state *state = screen->machine->driver_data<astinvad_state>();
+	const UINT8 *color_prom = screen->machine->region("proms")->base();
 	UINT8 yoffs = state->flip_yoffs & state->screen_flip;
 	int x, y;
 
@@ -174,8 +173,8 @@ static VIDEO_UPDATE( astinvad )
 
 static VIDEO_UPDATE( spaceint )
 {
-	astinvad_state *state = (astinvad_state *)screen->machine->driver_data;
-	const UINT8 *color_prom = memory_region(screen->machine, "proms");
+	astinvad_state *state = screen->machine->driver_data<astinvad_state>();
+	const UINT8 *color_prom = screen->machine->region("proms")->base();
 	int offs;
 
 	for (offs = 0; offs < state->videoram_size; offs++)
@@ -206,14 +205,14 @@ static VIDEO_UPDATE( spaceint )
 
 static TIMER_CALLBACK( kamikaze_int_off )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 	cpu_set_input_line(state->maincpu, 0, CLEAR_LINE);
 }
 
 
 static TIMER_CALLBACK( kamizake_int_gen )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 	/* interrupts are asserted on every state change of the 128V line */
 	cpu_set_input_line(state->maincpu, 0, ASSERT_LINE);
 	param ^= 128;
@@ -226,7 +225,7 @@ static TIMER_CALLBACK( kamizake_int_gen )
 
 static MACHINE_START( kamikaze )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->ppi8255_0 = machine->device("ppi8255_0");
@@ -243,7 +242,7 @@ static MACHINE_START( kamikaze )
 
 static MACHINE_RESET( kamikaze )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	state->screen_flip = 0;
 	state->screen_red = 0;
@@ -254,7 +253,7 @@ static MACHINE_RESET( kamikaze )
 
 static MACHINE_START( spaceint )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->samples = machine->device("samples");
@@ -265,7 +264,7 @@ static MACHINE_START( spaceint )
 
 static MACHINE_RESET( spaceint )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	state->screen_flip = 0;
 	state->sound_state[0] = 0;
@@ -276,7 +275,7 @@ static MACHINE_RESET( spaceint )
 
 static INPUT_CHANGED( spaceint_coin_inserted )
 {
-	astinvad_state *state = (astinvad_state *)field->port->machine->driver_data;
+	astinvad_state *state = field->port->machine->driver_data<astinvad_state>();
 	/* coin insertion causes an NMI */
 	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
 }
@@ -291,7 +290,7 @@ static INPUT_CHANGED( spaceint_coin_inserted )
 
 static READ8_HANDLER( kamikaze_ppi_r )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 	UINT8 result = 0xff;
 
 	/* the address lines are used for /CS; yes, they can overlap! */
@@ -305,7 +304,7 @@ static READ8_HANDLER( kamikaze_ppi_r )
 
 static WRITE8_HANDLER( kamikaze_ppi_w )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 
 	/* the address lines are used for /CS; yes, they can overlap! */
 	if (!(offset & 4))
@@ -324,7 +323,7 @@ static WRITE8_HANDLER( kamikaze_ppi_w )
 
 static WRITE8_DEVICE_HANDLER( astinvad_sound1_w )
 {
-	astinvad_state *state = (astinvad_state *)device->machine->driver_data;
+	astinvad_state *state = device->machine->driver_data<astinvad_state>();
 	int bits_gone_hi = data & ~state->sound_state[0];
 	state->sound_state[0] = data;
 
@@ -341,7 +340,7 @@ static WRITE8_DEVICE_HANDLER( astinvad_sound1_w )
 
 static WRITE8_DEVICE_HANDLER( astinvad_sound2_w )
 {
-	astinvad_state *state = (astinvad_state *)device->machine->driver_data;
+	astinvad_state *state = device->machine->driver_data<astinvad_state>();
 	int bits_gone_hi = data & ~state->sound_state[1];
 	state->sound_state[1] = data;
 
@@ -357,7 +356,7 @@ static WRITE8_DEVICE_HANDLER( astinvad_sound2_w )
 
 static WRITE8_HANDLER( spaceint_sound1_w )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 	int bits_gone_hi = data & ~state->sound_state[0];
 	state->sound_state[0] = data;
 
@@ -376,7 +375,7 @@ static WRITE8_HANDLER( spaceint_sound1_w )
 
 static WRITE8_HANDLER( spaceint_sound2_w )
 {
-	astinvad_state *state = (astinvad_state *)space->machine->driver_data;
+	astinvad_state *state = space->machine->driver_data<astinvad_state>();
 	int bits_gone_hi = data & ~state->sound_state[1];
 	state->sound_state[1] = data;
 
@@ -585,78 +584,71 @@ static const samples_interface astinvad_samples_interface =
  *
  *************************************/
 
-static MACHINE_DRIVER_START( kamikaze )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(astinvad_state)
+static MACHINE_CONFIG_START( kamikaze, astinvad_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MASTER_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(kamikaze_map)
-	MDRV_CPU_IO_MAP(kamikaze_portmap)
+	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK)
+	MCFG_CPU_PROGRAM_MAP(kamikaze_map)
+	MCFG_CPU_IO_MAP(kamikaze_portmap)
 
-	MDRV_MACHINE_START(kamikaze)
-	MDRV_MACHINE_RESET(kamikaze)
+	MCFG_MACHINE_START(kamikaze)
+	MCFG_MACHINE_RESET(kamikaze)
 
-	MDRV_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
-	MDRV_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
+	MCFG_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
+	MCFG_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
 
 	/* video hardware */
-	MDRV_VIDEO_UPDATE(astinvad)
+	MCFG_VIDEO_UPDATE(astinvad)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_RAW_PARAMS(VIDEO_CLOCK, 320, 0, 256, 256, 32, 256)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_RAW_PARAMS(VIDEO_CLOCK, 320, 0, 256, 256, 32, 256)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(astinvad_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(astinvad_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( spcking2 )
+static MACHINE_CONFIG_DERIVED( spcking2, kamikaze )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(kamikaze)
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_RAW_PARAMS(VIDEO_CLOCK, 320, 0, 256, 256, 16, 240)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_RAW_PARAMS(VIDEO_CLOCK, 320, 0, 256, 256, 16, 240)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( spaceint )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(astinvad_state)
+static MACHINE_CONFIG_START( spaceint, astinvad_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MASTER_CLOCK)        /* a guess */
-	MDRV_CPU_PROGRAM_MAP(spaceint_map)
-	MDRV_CPU_IO_MAP(spaceint_portmap)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK)        /* a guess */
+	MCFG_CPU_PROGRAM_MAP(spaceint_map)
+	MCFG_CPU_IO_MAP(spaceint_portmap)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_MACHINE_START(spaceint)
-	MDRV_MACHINE_RESET(spaceint)
+	MCFG_MACHINE_START(spaceint)
+	MCFG_MACHINE_RESET(spaceint)
 
 	/* video hardware */
-	MDRV_VIDEO_START(spaceint)
-	MDRV_VIDEO_UPDATE(spaceint)
+	MCFG_VIDEO_START(spaceint)
+	MCFG_VIDEO_UPDATE(spaceint)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
-	MDRV_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_REFRESH_RATE(60)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(astinvad_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(astinvad_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
 
@@ -752,7 +744,7 @@ ROM_END
 
 static DRIVER_INIT( kamikaze )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	/* the flip screen logic adds 32 to the Y after flipping */
 	state->flip_yoffs = 32;
@@ -761,7 +753,7 @@ static DRIVER_INIT( kamikaze )
 
 static DRIVER_INIT( spcking2 )
 {
-	astinvad_state *state = (astinvad_state *)machine->driver_data;
+	astinvad_state *state = machine->driver_data<astinvad_state>();
 
 	/* don't have the schematics, but the blanking must center the screen here */
 	state->flip_yoffs = 0;
