@@ -115,6 +115,7 @@
 #include "cpu/z80/z80daisy.h"
 #include "includes/astrocde.h"
 #include "machine/z80ctc.h"
+#include "machine/nvram.h"
 #include "sound/samples.h"
 #include "sound/astrocde.h"
 #include "sound/ay8910.h"
@@ -207,7 +208,7 @@ static WRITE8_HANDLER( seawolf2_lamps_w )
 
 static WRITE8_HANDLER( seawolf2_sound_1_w )  // Port 40
 {
-	running_device *samples = space->machine->device("samples");
+	device_t *samples = space->machine->device("samples");
 	UINT8 rising_bits = data & ~port_1_last;
 	port_1_last = data;
 
@@ -222,7 +223,7 @@ static WRITE8_HANDLER( seawolf2_sound_1_w )  // Port 40
 
 static WRITE8_HANDLER( seawolf2_sound_2_w )  // Port 41
 {
-	running_device *samples = space->machine->device("samples");
+	device_t *samples = space->machine->device("samples");
 	UINT8 rising_bits = data & ~port_2_last;
 	port_2_last = data;
 
@@ -429,14 +430,14 @@ static WRITE8_HANDLER( profpac_banksw_w )
 
 	/* set the main banking */
 	memory_install_read_bank(space, 0x4000, 0xbfff, 0, 0, "bank1");
-	memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "user1") + 0x8000 * bank);
+	memory_set_bankptr(space->machine, "bank1", space->machine->region("user1")->base() + 0x8000 * bank);
 
 	/* bank 0 reads video RAM in the 4000-7FFF range */
 	if (bank == 0)
 		memory_install_read8_handler(space, 0x4000, 0x7fff, 0, 0, profpac_videoram_r);
 
 	/* if we have a 640k EPROM board, map that on top of the 4000-7FFF range if specified */
-	if ((data & 0x80) && memory_region(space->machine, "user2") != NULL)
+	if ((data & 0x80) && space->machine->region("user2")->base() != NULL)
 	{
 		/* Note: There is a jumper which could change the base offset to 0xa8 instead */
 		bank = data - 0x80;
@@ -445,7 +446,7 @@ static WRITE8_HANDLER( profpac_banksw_w )
 		if (bank < 0x28)
 		{
 			memory_install_read_bank(space, 0x4000, 0x7fff, 0, 0, "bank2");
-			memory_set_bankptr(space->machine, "bank2", memory_region(space->machine, "user2") + 0x4000 * bank);
+			memory_set_bankptr(space->machine, "bank2", space->machine->region("user2")->base() + 0x4000 * bank);
 		}
 		else
 			memory_unmap_read(space, 0x4000, 0x7fff, 0, 0);
@@ -455,7 +456,7 @@ static WRITE8_HANDLER( profpac_banksw_w )
 
 static STATE_POSTLOAD( profbank_banksw_restore )
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	profpac_banksw_w(space, 0, profpac_bank);
 }
@@ -583,7 +584,7 @@ static WRITE8_HANDLER( tenpindx_lights_w )
 static ADDRESS_MAP_START( seawolf2_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_GENERIC(videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
 	AM_RANGE(0xc000, 0xc3ff) AM_RAM
 ADDRESS_MAP_END
 
@@ -591,14 +592,14 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( ebases_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_GENERIC(videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( spacezap_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_GENERIC(videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
 	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
 	AM_RANGE(0xd040, 0xd7ff) AM_RAM
 ADDRESS_MAP_END
@@ -607,7 +608,7 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( wow_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_GENERIC(videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
 	AM_RANGE(0x8000, 0xcfff) AM_ROM
 	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
 	AM_RANGE(0xd040, 0xdfff) AM_RAM
@@ -617,10 +618,10 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( robby_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_GENERIC(videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
 	AM_RANGE(0x8000, 0xdfff) AM_ROM
 	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -632,7 +633,7 @@ static ADDRESS_MAP_START( profpac_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xdfff) AM_ROM
 	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -643,7 +644,7 @@ static ADDRESS_MAP_START( demndrgn_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(profpac_videoram_r, profpac_videoram_w)
 	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xdfff) AM_ROM
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -1270,64 +1271,63 @@ static const z80_daisy_config tenpin_daisy_chain[] =
  *
  *************************************/
 
-static MACHINE_DRIVER_START( astrocade_base )
+static MACHINE_CONFIG_START( astrocade_base, astrocde_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, ASTROCADE_CLOCK/4)
+	MCFG_CPU_ADD("maincpu", Z80, ASTROCADE_CLOCK/4)
 	/* each game has its own map */
 
-	MDRV_MACHINE_START(astrocde)
+	MCFG_MACHINE_START(astrocde)
 
 	/* video hardware */
-	MDRV_PALETTE_LENGTH(512)
+	MCFG_PALETTE_LENGTH(512)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_RAW_PARAMS(ASTROCADE_CLOCK, 455, 0, 352, 262, 0, 240)
-	MDRV_SCREEN_DEFAULT_POSITION(1.1, 0.0, 1.18, -0.018)	/* clip out borders */
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_RAW_PARAMS(ASTROCADE_CLOCK, 455, 0, 352, 262, 0, 240)
+	MCFG_SCREEN_DEFAULT_POSITION(1.1, 0.0, 1.18, -0.018)	/* clip out borders */
 
-	MDRV_PALETTE_INIT(astrocde)
-	MDRV_VIDEO_START(astrocde)
-	MDRV_VIDEO_UPDATE(astrocde)
-MACHINE_DRIVER_END
+	MCFG_PALETTE_INIT(astrocde)
+	MCFG_VIDEO_START(astrocde)
+	MCFG_VIDEO_UPDATE(astrocde)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( astrocade_16color_base )
-	MDRV_IMPORT_FROM(astrocade_base)
+static MACHINE_CONFIG_DERIVED( astrocade_16color_base, astrocade_base )
 
 	/* basic machine hardware */
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	/* video hardware */
-	MDRV_PALETTE_LENGTH(4096)
+	MCFG_PALETTE_LENGTH(4096)
 
-	MDRV_PALETTE_INIT(profpac)
-	MDRV_VIDEO_START(profpac)
-	MDRV_VIDEO_UPDATE(profpac)
-MACHINE_DRIVER_END
+	MCFG_PALETTE_INIT(profpac)
+	MCFG_VIDEO_START(profpac)
+	MCFG_VIDEO_UPDATE(profpac)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( astrocade_mono_sound )
+static MACHINE_CONFIG_FRAGMENT( astrocade_mono_sound )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( astrocade_stereo_sound )
+static MACHINE_CONFIG_FRAGMENT( astrocade_stereo_sound )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
 
-	MDRV_SOUND_ADD("astrocade2",  ASTROCADE, ASTROCADE_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("astrocade2",  ASTROCADE, ASTROCADE_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
 
@@ -1337,160 +1337,151 @@ MACHINE_DRIVER_END
  *
  *************************************/
 
-static MACHINE_DRIVER_START( seawolf2 )
-	MDRV_IMPORT_FROM(astrocade_base)
+static MACHINE_CONFIG_DERIVED( seawolf2, astrocade_base )
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(seawolf2_map)
-	MDRV_CPU_IO_MAP(port_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(seawolf2_map)
+	MCFG_CPU_IO_MAP(port_map)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(seawolf2_samples_interface)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(1, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(2, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(3, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(4, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(5, "rspeaker", 0.25)
-	MDRV_SOUND_ROUTE(6, "rspeaker", 0.25)
-	MDRV_SOUND_ROUTE(7, "rspeaker", 0.25)
-	MDRV_SOUND_ROUTE(8, "rspeaker", 0.25)
-	MDRV_SOUND_ROUTE(9, "rspeaker", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(seawolf2_samples_interface)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(1, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(2, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(3, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(4, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(5, "rspeaker", 0.25)
+	MCFG_SOUND_ROUTE(6, "rspeaker", 0.25)
+	MCFG_SOUND_ROUTE(7, "rspeaker", 0.25)
+	MCFG_SOUND_ROUTE(8, "rspeaker", 0.25)
+	MCFG_SOUND_ROUTE(9, "rspeaker", 0.25)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( ebases )
-	MDRV_IMPORT_FROM(astrocade_base)
-	MDRV_IMPORT_FROM(astrocade_mono_sound)
+static MACHINE_CONFIG_DERIVED( ebases, astrocade_base )
+	MCFG_FRAGMENT_ADD(astrocade_mono_sound)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(ebases_map)
-	MDRV_CPU_IO_MAP(port_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(ebases_map)
+	MCFG_CPU_IO_MAP(port_map)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( spacezap )
-	MDRV_IMPORT_FROM(astrocade_base)
-	MDRV_IMPORT_FROM(astrocade_mono_sound)
+static MACHINE_CONFIG_DERIVED( spacezap, astrocade_base )
+	MCFG_FRAGMENT_ADD(astrocade_mono_sound)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(spacezap_map)
-	MDRV_CPU_IO_MAP(port_map_mono_pattern)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(spacezap_map)
+	MCFG_CPU_IO_MAP(port_map_mono_pattern)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( wow )
-	MDRV_IMPORT_FROM(astrocade_base)
-	MDRV_IMPORT_FROM(astrocade_stereo_sound)
+static MACHINE_CONFIG_DERIVED( wow, astrocade_base )
+	MCFG_FRAGMENT_ADD(astrocade_stereo_sound)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(wow_map)
-	MDRV_CPU_IO_MAP(port_map_stereo_pattern)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(wow_map)
+	MCFG_CPU_IO_MAP(port_map_stereo_pattern)
 
 	/* video hardware */
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_DEFAULT_POSITION(1.0, 0.0, 1.0, 0.0)	/* adjusted to match screenshots */
-//  MDRV_SCREEN_DEFAULT_POSITION(1.066, -0.004, 1.048, -0.026)  /* adjusted to match flyer */
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_DEFAULT_POSITION(1.0, 0.0, 1.0, 0.0)	/* adjusted to match screenshots */
+//  MCFG_SCREEN_DEFAULT_POSITION(1.066, -0.004, 1.048, -0.026)  /* adjusted to match flyer */
 
 	/* sound hardware */
-	MDRV_SPEAKER_ADD("center", 0.0, 0.0, 1.0)
+	MCFG_SPEAKER_ADD("center", 0.0, 0.0, 1.0)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(wow_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "center", 0.85)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(wow_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "center", 0.85)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( gorf )
-	MDRV_IMPORT_FROM(astrocade_base)
+static MACHINE_CONFIG_DERIVED( gorf, astrocade_base )
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(wow_map)
-	MDRV_CPU_IO_MAP(port_map_stereo_pattern)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(wow_map)
+	MCFG_CPU_IO_MAP(port_map_stereo_pattern)
 
 	/* video hardware */
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_DEFAULT_POSITION(1.0, 0.0, 1.0, 0.0)	/* adjusted to match flyer */
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_DEFAULT_POSITION(1.0, 0.0, 1.0, 0.0)	/* adjusted to match flyer */
 
 	/* sound hardware */
-	MDRV_SPEAKER_ADD("upper", 0.0, 0.0, 1.0)
-	MDRV_SPEAKER_ADD("lower", 0.0, -0.5, 1.0)
+	MCFG_SPEAKER_ADD("upper", 0.0, 0.0, 1.0)
+	MCFG_SPEAKER_ADD("lower", 0.0, -0.5, 1.0)
 
-	MDRV_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "upper", 1.0)
+	MCFG_SOUND_ADD("astrocade1",  ASTROCADE, ASTROCADE_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "upper", 1.0)
 
-	MDRV_SOUND_ADD("astrocade2",  ASTROCADE, ASTROCADE_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lower", 1.0)
+	MCFG_SOUND_ADD("astrocade2",  ASTROCADE, ASTROCADE_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lower", 1.0)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(gorf_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "upper", 0.85)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(gorf_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "upper", 0.85)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( robby )
-	MDRV_IMPORT_FROM(astrocade_base)
-	MDRV_IMPORT_FROM(astrocade_stereo_sound)
+static MACHINE_CONFIG_DERIVED( robby, astrocade_base )
+	MCFG_FRAGMENT_ADD(astrocade_stereo_sound)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(robby_map)
-	MDRV_CPU_IO_MAP(port_map_stereo_pattern)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(robby_map)
+	MCFG_CPU_IO_MAP(port_map_stereo_pattern)
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
-MACHINE_DRIVER_END
+	MCFG_NVRAM_ADD_0FILL("nvram")
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( profpac )
-	MDRV_IMPORT_FROM(astrocade_16color_base)
-	MDRV_IMPORT_FROM(astrocade_stereo_sound)
+static MACHINE_CONFIG_DERIVED( profpac, astrocade_16color_base )
+	MCFG_FRAGMENT_ADD(astrocade_stereo_sound)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(profpac_map)
-	MDRV_CPU_IO_MAP(port_map_16col_pattern)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(profpac_map)
+	MCFG_CPU_IO_MAP(port_map_16col_pattern)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( demndrgn )
-	MDRV_IMPORT_FROM(astrocade_16color_base)
+static MACHINE_CONFIG_DERIVED( demndrgn, astrocade_16color_base )
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(demndrgn_map)
-	MDRV_CPU_IO_MAP(port_map_16col_pattern_nosound)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(demndrgn_map)
+	MCFG_CPU_IO_MAP(port_map_16col_pattern_nosound)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( tenpindx )
-	MDRV_IMPORT_FROM(astrocade_16color_base)
+static MACHINE_CONFIG_DERIVED( tenpindx, astrocade_16color_base )
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(profpac_map)
-	MDRV_CPU_IO_MAP(port_map_16col_pattern_nosound)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(profpac_map)
+	MCFG_CPU_IO_MAP(port_map_16col_pattern_nosound)
 
-	MDRV_CPU_ADD("sub", Z80, ASTROCADE_CLOCK/4)	/* real clock unknown */
-	MDRV_CPU_CONFIG(tenpin_daisy_chain)
-	MDRV_CPU_PROGRAM_MAP(tenpin_sub_map)
-	MDRV_CPU_IO_MAP(tenpin_sub_io_map)
+	MCFG_CPU_ADD("sub", Z80, ASTROCADE_CLOCK/4)	/* real clock unknown */
+	MCFG_CPU_CONFIG(tenpin_daisy_chain)
+	MCFG_CPU_PROGRAM_MAP(tenpin_sub_map)
+	MCFG_CPU_IO_MAP(tenpin_sub_io_map)
 
-	MDRV_Z80CTC_ADD("ctc", ASTROCADE_CLOCK/4 /* same as "sub" */, ctc_intf)
+	MCFG_Z80CTC_ADD("ctc", ASTROCADE_CLOCK/4 /* same as "sub" */, ctc_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("aysnd", AY8912, ASTROCADE_CLOCK/4)	/* real clock unknown */
-	MDRV_SOUND_CONFIG(ay8912_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("aysnd", AY8912, ASTROCADE_CLOCK/4)	/* real clock unknown */
+	MCFG_SOUND_CONFIG(ay8912_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
+MACHINE_CONFIG_END
 
 
 
@@ -1766,7 +1757,7 @@ static DRIVER_INIT( robby )
 
 static DRIVER_INIT( profpac )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	astrocade_video_config = AC_SOUND_PRESENT;
 	memory_install_read8_handler(iospace, 0x14, 0x14, 0x0fff, 0xff00, profpac_io_1_r);
@@ -1780,7 +1771,7 @@ static DRIVER_INIT( profpac )
 
 static DRIVER_INIT( demndrgn )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	astrocade_video_config = 0x00;
 	memory_install_read8_handler(iospace, 0x14, 0x14, 0x1fff, 0xff00, demndrgn_io_r);
@@ -1796,7 +1787,7 @@ static DRIVER_INIT( demndrgn )
 
 static DRIVER_INIT( tenpindx )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	astrocade_video_config = 0x00;
 	memory_install_read_port(iospace, 0x60, 0x60, 0x0000, 0xff00, "P60");
