@@ -178,15 +178,15 @@ Measurements -
 
 static void update_interrupts(running_machine *machine)
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
-	cputag_set_input_line(machine, "maincpu", 1, state->atarigen.video_int_state ? ASSERT_LINE : CLEAR_LINE);
-	cputag_set_input_line(machine, "maincpu", 2, state->atarigen.sound_int_state ? ASSERT_LINE : CLEAR_LINE);
+	badlands_state *state = machine->driver_data<badlands_state>();
+	cputag_set_input_line(machine, "maincpu", 1, state->video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(machine, "maincpu", 2, state->sound_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static void scanline_update(screen_device &screen, int scanline)
 {
-	const address_space *space = cputag_get_address_space(screen.machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(screen.machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 
 	/* sound IRQ is on 32V */
 	if (scanline & 32)
@@ -198,7 +198,7 @@ static void scanline_update(screen_device &screen, int scanline)
 
 static MACHINE_START( badlands )
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
+	badlands_state *state = machine->driver_data<badlands_state>();
 
 	atarigen_init(machine);
 
@@ -208,12 +208,12 @@ static MACHINE_START( badlands )
 
 static MACHINE_RESET( badlands )
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
+	badlands_state *state = machine->driver_data<badlands_state>();
 
 	state->pedal_value[0] = state->pedal_value[1] = 0x80;
 
-	atarigen_eeprom_reset(&state->atarigen);
-	atarigen_interrupt_reset(&state->atarigen, update_interrupts);
+	atarigen_eeprom_reset(state);
+	atarigen_interrupt_reset(state, update_interrupts);
 	atarigen_scanline_timer_reset(*machine->primary_screen, scanline_update, 32);
 
 	atarigen_sound_io_reset(machine->device("audiocpu"));
@@ -230,7 +230,7 @@ static MACHINE_RESET( badlands )
 
 static INTERRUPT_GEN( vblank_int )
 {
-	badlands_state *state = (badlands_state *)device->machine->driver_data;
+	badlands_state *state = device->machine->driver_data<badlands_state>();
 	int pedal_state = input_port_read(device->machine, "PEDALS");
 	int i;
 
@@ -255,23 +255,23 @@ static INTERRUPT_GEN( vblank_int )
 
 static READ16_HANDLER( sound_busy_r )
 {
-	badlands_state *state = (badlands_state *)space->machine->driver_data;
+	badlands_state *state = space->machine->driver_data<badlands_state>();
 	int temp = 0xfeff;
-	if (state->atarigen.cpu_to_sound_ready) temp ^= 0x0100;
+	if (state->cpu_to_sound_ready) temp ^= 0x0100;
 	return temp;
 }
 
 
 static READ16_HANDLER( pedal_0_r )
 {
-	badlands_state *state = (badlands_state *)space->machine->driver_data;
+	badlands_state *state = space->machine->driver_data<badlands_state>();
 	return state->pedal_value[0];
 }
 
 
 static READ16_HANDLER( pedal_1_r )
 {
-	badlands_state *state = (badlands_state *)space->machine->driver_data;
+	badlands_state *state = space->machine->driver_data<badlands_state>();
 	return state->pedal_value[1];
 }
 
@@ -285,7 +285,7 @@ static READ16_HANDLER( pedal_1_r )
 
 static READ8_HANDLER( audio_io_r )
 {
-	badlands_state *state = (badlands_state *)space->machine->driver_data;
+	badlands_state *state = space->machine->driver_data<badlands_state>();
 	int result = 0xff;
 
 	switch (offset & 0x206)
@@ -311,8 +311,8 @@ static READ8_HANDLER( audio_io_r )
             */
 			result = input_port_read(space->machine, "AUDIO");
 			if (!(input_port_read(space->machine, "FE4000") & 0x0080)) result ^= 0x90;
-			if (state->atarigen.cpu_to_sound_ready) result ^= 0x40;
-			if (state->atarigen.sound_to_cpu_ready) result ^= 0x20;
+			if (state->cpu_to_sound_ready) result ^= 0x40;
+			if (state->sound_to_cpu_ready) result ^= 0x20;
 			result ^= 0x10;
 			break;
 
@@ -334,7 +334,7 @@ static READ8_HANDLER( audio_io_r )
 
 static WRITE8_HANDLER( audio_io_w )
 {
-	badlands_state *state = (badlands_state *)space->machine->driver_data;
+	badlands_state *state = space->machine->driver_data<badlands_state>();
 
 	switch (offset & 0x206)
 	{
@@ -384,7 +384,7 @@ static WRITE8_HANDLER( audio_io_w )
 static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0xfc0000, 0xfc1fff) AM_READWRITE(sound_busy_r, atarigen_sound_reset_w)
-	AM_RANGE(0xfd0000, 0xfd1fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_BASE_SIZE_MEMBER(badlands_state, atarigen.eeprom, atarigen.eeprom_size)
+	AM_RANGE(0xfd0000, 0xfd1fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_SHARE("eeprom")
 	AM_RANGE(0xfe0000, 0xfe1fff) AM_WRITE(watchdog_reset16_w)
 	AM_RANGE(0xfe2000, 0xfe3fff) AM_WRITE(atarigen_video_int_ack_w)
 	AM_RANGE(0xfe4000, 0xfe5fff) AM_READ_PORT("FE4000")
@@ -397,7 +397,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfec000, 0xfedfff) AM_WRITE(badlands_pf_bank_w)
 	AM_RANGE(0xfee000, 0xfeffff) AM_WRITE(atarigen_eeprom_enable_w)
 	AM_RANGE(0xffc000, 0xffc3ff) AM_RAM_WRITE(atarigen_expanded_666_paletteram_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0xffe000, 0xffefff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(badlands_state, atarigen.playfield)
+	AM_RANGE(0xffe000, 0xffefff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(badlands_state, playfield)
 	AM_RANGE(0xfff000, 0xfff1ff) AM_RAM_WRITE(atarimo_0_spriteram_expanded_w) AM_BASE(&atarimo_0_spriteram)
 	AM_RANGE(0xfff200, 0xffffff) AM_RAM
 ADDRESS_MAP_END
@@ -503,42 +503,41 @@ GFXDECODE_END
  *
  *************************************/
 
-static MACHINE_DRIVER_START( badlands )
-	MDRV_DRIVER_DATA(badlands_state)
+static MACHINE_CONFIG_START( badlands, badlands_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, ATARI_CLOCK_14MHz/2)
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_VBLANK_INT("screen", vblank_int)
+	MCFG_CPU_ADD("maincpu", M68000, ATARI_CLOCK_14MHz/2)
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_VBLANK_INT("screen", vblank_int)
 
-	MDRV_CPU_ADD("audiocpu", M6502, ATARI_CLOCK_14MHz/8)
-	MDRV_CPU_PROGRAM_MAP(audio_map)
+	MCFG_CPU_ADD("audiocpu", M6502, ATARI_CLOCK_14MHz/8)
+	MCFG_CPU_PROGRAM_MAP(audio_map)
 
-	MDRV_MACHINE_START(badlands)
-	MDRV_MACHINE_RESET(badlands)
-	MDRV_NVRAM_HANDLER(atarigen)
+	MCFG_MACHINE_START(badlands)
+	MCFG_MACHINE_RESET(badlands)
+	MCFG_NVRAM_ADD_1FILL("eeprom")
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
-	MDRV_GFXDECODE(badlands)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+	MCFG_GFXDECODE(badlands)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
-	MDRV_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz/2, 456, 0, 336, 262, 0, 240)
+	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz/2, 456, 0, 336, 262, 0, 240)
 
-	MDRV_VIDEO_START(badlands)
-	MDRV_VIDEO_UPDATE(badlands)
+	MCFG_VIDEO_START(badlands)
+	MCFG_VIDEO_UPDATE(badlands)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, ATARI_CLOCK_14MHz/4)
-	MDRV_SOUND_ROUTE(0, "mono", 0.30)
-	MDRV_SOUND_ROUTE(1, "mono", 0.30)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM2151, ATARI_CLOCK_14MHz/4)
+	MCFG_SOUND_ROUTE(0, "mono", 0.30)
+	MCFG_SOUND_ROUTE(1, "mono", 0.30)
+MACHINE_CONFIG_END
 
 
 
@@ -589,11 +588,11 @@ ROM_END
 
 static DRIVER_INIT( badlands )
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
+	badlands_state *state = machine->driver_data<badlands_state>();
 
 	/* initialize the audio system */
-	state->bank_base = &memory_region(machine, "audiocpu")[0x03000];
-	state->bank_source_data = &memory_region(machine, "audiocpu")[0x10000];
+	state->bank_base = &machine->region("audiocpu")->base()[0x03000];
+	state->bank_source_data = &machine->region("audiocpu")->base()[0x10000];
 }
 
 
@@ -653,14 +652,14 @@ static ADDRESS_MAP_START( bootleg_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfe4006, 0xfe4007) AM_READ(badlandsb_unk_r )
 
 
-	AM_RANGE(0xfd0000, 0xfd1fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_BASE_SIZE_MEMBER(badlands_state, atarigen.eeprom, atarigen.eeprom_size)
+	AM_RANGE(0xfd0000, 0xfd1fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_SHARE("eeprom")
 	//AM_RANGE(0xfe0000, 0xfe1fff) AM_WRITE(watchdog_reset16_w)
 	AM_RANGE(0xfe2000, 0xfe3fff) AM_WRITE(atarigen_video_int_ack_w)
 
 	AM_RANGE(0xfec000, 0xfedfff) AM_WRITE(badlands_pf_bank_w)
 	AM_RANGE(0xfee000, 0xfeffff) AM_WRITE(atarigen_eeprom_enable_w)
 	AM_RANGE(0xffc000, 0xffc3ff) AM_RAM_WRITE(atarigen_expanded_666_paletteram_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0xffe000, 0xffefff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(badlands_state, atarigen.playfield)
+	AM_RANGE(0xffe000, 0xffefff) AM_RAM_WRITE(atarigen_playfield_w) AM_BASE_MEMBER(badlands_state, playfield)
 	AM_RANGE(0xfff000, 0xfff1ff) AM_RAM_WRITE(atarimo_0_spriteram_expanded_w) AM_BASE(&atarimo_0_spriteram)
 	AM_RANGE(0xfff200, 0xffffff) AM_RAM
 ADDRESS_MAP_END
@@ -684,8 +683,8 @@ GFXDECODE_END
 
 static void update_interrupts_bootleg(running_machine *machine)
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
-	cputag_set_input_line(machine, "maincpu", 1, state->atarigen.video_int_state ? ASSERT_LINE : CLEAR_LINE);
+	badlands_state *state = machine->driver_data<badlands_state>();
+	cputag_set_input_line(machine, "maincpu", 1, state->video_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -702,53 +701,52 @@ static void scanline_update_bootleg(screen_device &screen, int scanline)
 
 static MACHINE_RESET( badlandsb )
 {
-	badlands_state *state = (badlands_state *)machine->driver_data;
+	badlands_state *state = machine->driver_data<badlands_state>();
 //  state->pedal_value[0] = state->pedal_value[1] = 0x80;
 
-	atarigen_eeprom_reset(&state->atarigen);
-	atarigen_interrupt_reset(&state->atarigen, update_interrupts_bootleg);
+	atarigen_eeprom_reset(state);
+	atarigen_interrupt_reset(state, update_interrupts_bootleg);
 	atarigen_scanline_timer_reset(*machine->primary_screen, scanline_update_bootleg, 32);
 
 //  atarigen_sound_io_reset(machine->device("audiocpu"));
 //  memcpy(state->bank_base, &state->bank_source_data[0x0000], 0x1000);
 }
 
-static MACHINE_DRIVER_START( badlandsb )
-	MDRV_DRIVER_DATA(badlands_state)
+static MACHINE_CONFIG_START( badlandsb, badlands_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 2800000/2)
-	MDRV_CPU_PROGRAM_MAP(bootleg_map)
-	MDRV_CPU_VBLANK_INT("screen", vblank_int)
+	MCFG_CPU_ADD("maincpu", M68000, 2800000/2)
+	MCFG_CPU_PROGRAM_MAP(bootleg_map)
+	MCFG_CPU_VBLANK_INT("screen", vblank_int)
 
-//  MDRV_CPU_ADD("audiocpu", Z80, 2800000/8)
-//  MDRV_CPU_PROGRAM_MAP(bootleg_soundmap)
+//  MCFG_CPU_ADD("audiocpu", Z80, 2800000/8)
+//  MCFG_CPU_PROGRAM_MAP(bootleg_soundmap)
 
-	MDRV_MACHINE_START(badlands)
-	MDRV_MACHINE_RESET(badlandsb)
-	MDRV_NVRAM_HANDLER(atarigen)
+	MCFG_MACHINE_START(badlands)
+	MCFG_MACHINE_RESET(badlandsb)
+	MCFG_NVRAM_ADD_1FILL("eeprom")
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
-	MDRV_GFXDECODE(badlandsb)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+	MCFG_GFXDECODE(badlandsb)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses an SOS-2 chip to generate video signals */
-	MDRV_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz/2, 456, 0, 336, 262, 0, 240)
+	MCFG_SCREEN_RAW_PARAMS(ATARI_CLOCK_14MHz/2, 456, 0, 336, 262, 0, 240)
 
-	MDRV_VIDEO_START(badlands)
-	MDRV_VIDEO_UPDATE(badlands)
+	MCFG_VIDEO_START(badlands)
+	MCFG_VIDEO_UPDATE(badlands)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 2800000/4)
-	MDRV_SOUND_ROUTE(0, "mono", 0.30)
-	MDRV_SOUND_ROUTE(1, "mono", 0.30)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM2151, 2800000/4)
+	MCFG_SOUND_ROUTE(0, "mono", 0.30)
+	MCFG_SOUND_ROUTE(1, "mono", 0.30)
+MACHINE_CONFIG_END
 
 
 
