@@ -91,6 +91,7 @@ Optional (on expansion card) (Viper)
 #include "machine/meters.h"
 #include "sound/ay8910.h"
 #include "sound/upd7759.h"
+#include "machine/nvram.h"
 #include "bfm_sc1.lh"
 #define VFD_RESET  0x20
 #define VFD_CLOCK1 0x80
@@ -660,7 +661,7 @@ static void decode_sc1(running_machine *machine,const char *rom_region)
 {
 	UINT8 *tmp, *rom;
 
-	rom = memory_region(machine,rom_region);
+	rom = machine->region(rom_region)->base();
 
 	tmp = auto_alloc_array(machine, UINT8, 0x10000);
 
@@ -750,7 +751,7 @@ static MACHINE_RESET( bfm_sc1 )
 
 // init rom bank ////////////////////////////////////////////////////////////////////
 	{
-		UINT8 *rom = memory_region(machine, "maincpu");
+		UINT8 *rom = machine->region("maincpu")->base();
 
 		memory_configure_bank(machine,"bank1", 0, 1, &rom[0x10000], 0);
 		memory_configure_bank(machine,"bank1", 1, 3, &rom[0x02000], 0x02000);
@@ -765,7 +766,7 @@ static MACHINE_RESET( bfm_sc1 )
 
 static ADDRESS_MAP_START( memmap, ADDRESS_SPACE_PROGRAM, 8 )
 
-	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_BASE_SIZE_GENERIC(nvram) //8k RAM
+	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_SHARE("nvram") //8k RAM
 	AM_RANGE(0x2000, 0x21FF) AM_WRITE(reel34_w)				// reel 2+3 latch
 	AM_RANGE(0x2200, 0x23FF) AM_WRITE(reel12_w)				// reel 1+2 latch
 	AM_RANGE(0x2400, 0x25FF) AM_WRITE(vfd_w)				// vfd latch
@@ -808,7 +809,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( memmap_adder2, ADDRESS_SPACE_PROGRAM, 8 )
 
-	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_BASE_SIZE_GENERIC(nvram) //8k RAM
+	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_SHARE("nvram") //8k RAM
 	AM_RANGE(0x2000, 0x21FF) AM_WRITE(reel34_w)	  // reel 2+3 latch
 	AM_RANGE(0x2200, 0x23FF) AM_WRITE(reel12_w)	  // reel 1+2 latch
 	AM_RANGE(0x2400, 0x25FF) AM_WRITE(vfd_w)	  // vfd latch
@@ -857,7 +858,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sc1_nec_uk, ADDRESS_SPACE_PROGRAM, 8 )
 
-	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_BASE_SIZE_GENERIC(nvram) //8k RAM
+	AM_RANGE(0x0000, 0x1FFF) AM_RAM AM_SHARE("nvram") //8k RAM
 	AM_RANGE(0x2000, 0x21FF) AM_WRITE(reel34_w)	  // reel 2+3 latch
 	AM_RANGE(0x2200, 0x23FF) AM_WRITE(reel12_w)	  // reel 1+2 latch
 	AM_RANGE(0x2400, 0x25FF) AM_WRITE(vfd_w)	  // vfd latch
@@ -1240,63 +1241,61 @@ INPUT_PORTS_END
 // machine driver for scorpion1 board ///////////////////////////////////////////////
 /////////////////////////////////////////////////////////////////////////////////////
 
-static MACHINE_DRIVER_START( scorpion1 )
-	MDRV_MACHINE_RESET(bfm_sc1)							// main scorpion1 board initialisation
-	MDRV_CPU_ADD("maincpu", M6809, MASTER_CLOCK/4)			// 6809 CPU at 1 Mhz
-	MDRV_CPU_PROGRAM_MAP(memmap)						// setup read and write memorymap
-	MDRV_CPU_PERIODIC_INT(timer_irq, 1000 )				// generate 1000 IRQ's per second
+static MACHINE_CONFIG_START( scorpion1, driver_device )
+	MCFG_MACHINE_RESET(bfm_sc1)							// main scorpion1 board initialisation
+	MCFG_CPU_ADD("maincpu", M6809, MASTER_CLOCK/4)			// 6809 CPU at 1 Mhz
+	MCFG_CPU_PROGRAM_MAP(memmap)						// setup read and write memorymap
+	MCFG_CPU_PERIODIC_INT(timer_irq, 1000 )				// generate 1000 IRQ's per second
 
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("aysnd",AY8912, MASTER_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("aysnd",AY8912, MASTER_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
-	MDRV_DEFAULT_LAYOUT(layout_awpvid14)
-MACHINE_DRIVER_END
+	MCFG_NVRAM_ADD_0FILL("nvram")
+	MCFG_DEFAULT_LAYOUT(layout_awpvid14)
+MACHINE_CONFIG_END
 
 /////////////////////////////////////////////////////////////////////////////////////
 // machine driver for scorpion1 board + adder2 extension ////////////////////////////
 /////////////////////////////////////////////////////////////////////////////////////
 
-static MACHINE_DRIVER_START( scorpion1_adder2 )
-	MDRV_IMPORT_FROM( scorpion1 )
+static MACHINE_CONFIG_DERIVED( scorpion1_adder2, scorpion1 )
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(memmap_adder2)				// setup read and write memorymap
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(memmap_adder2)				// setup read and write memorymap
 
-	MDRV_DEFAULT_LAYOUT(layout_bfm_sc1)
-	MDRV_SCREEN_ADD("adder", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_REFRESH_RATE(50)
-	MDRV_SCREEN_SIZE( 400, 300)
-	MDRV_SCREEN_VISIBLE_AREA(  0, 400-1, 0, 300-1)
+	MCFG_DEFAULT_LAYOUT(layout_bfm_sc1)
+	MCFG_SCREEN_ADD("adder", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_REFRESH_RATE(50)
+	MCFG_SCREEN_SIZE( 400, 300)
+	MCFG_SCREEN_VISIBLE_AREA(  0, 400-1, 0, 300-1)
 
-	MDRV_VIDEO_START( adder2)
-	MDRV_VIDEO_RESET( adder2)
-	MDRV_VIDEO_UPDATE(adder2)
+	MCFG_VIDEO_START( adder2)
+	MCFG_VIDEO_RESET( adder2)
+	MCFG_VIDEO_UPDATE(adder2)
 
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_PALETTE_INIT(adder2)
-	MDRV_GFXDECODE(adder2)
+	MCFG_PALETTE_INIT(adder2)
+	MCFG_GFXDECODE(adder2)
 
-	MDRV_CPU_ADD("adder2", M6809, ADDER_CLOCK/4 )		// adder2 board 6809 CPU at 2 Mhz
-	MDRV_CPU_PROGRAM_MAP(adder2_memmap)				// setup adder2 board memorymap
-	MDRV_CPU_VBLANK_INT("adder",adder2_vbl)				// board has a VBL IRQ
-MACHINE_DRIVER_END
+	MCFG_CPU_ADD("adder2", M6809, ADDER_CLOCK/4 )		// adder2 board 6809 CPU at 2 Mhz
+	MCFG_CPU_PROGRAM_MAP(adder2_memmap)				// setup adder2 board memorymap
+	MCFG_CPU_VBLANK_INT("adder",adder2_vbl)				// board has a VBL IRQ
+MACHINE_CONFIG_END
 
 /////////////////////////////////////////////////////////////////////////////////////
 // machine driver for scorpion1 board ///////////////////////////////////////////////
 /////////////////////////////////////////////////////////////////////////////////////
 
-static MACHINE_DRIVER_START( scorpion1_nec_uk )
-	MDRV_IMPORT_FROM( scorpion1 )
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(sc1_nec_uk)					// setup read and write memorymap
+static MACHINE_CONFIG_DERIVED( scorpion1_nec_uk, scorpion1 )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(sc1_nec_uk)					// setup read and write memorymap
 
-	MDRV_SOUND_ADD("upd",UPD7759, UPD7759_STANDARD_CLOCK)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("upd",UPD7759, UPD7759_STANDARD_CLOCK)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 // ROM definition ///////////////////////////////////////////////////////////////////
 
@@ -1339,7 +1338,7 @@ static void sc1_common_init(running_machine *machine, int reels, int decrypt)
 {
 	UINT8 *rom, i;
 
-	rom = memory_region(machine, "maincpu");
+	rom = machine->region("maincpu")->base();
 	if ( rom )
 	{
 		memcpy(&rom[0x10000], &rom[0x00000], 0x2000);
