@@ -493,7 +493,7 @@ static VIDEO_UPDATE(bingor)
 #if 0
 static READ16_HANDLER( test_r )
 {
-	return mame_rand(space->machine);
+	return space->machine->rand();
 }
 #endif
 
@@ -514,7 +514,7 @@ ADDRESS_MAP_END
 
 static READ8_HANDLER( test8_r )
 {
-	return mame_rand(space->machine);
+	return space->machine->rand();
 }
 
 static ADDRESS_MAP_START( pic_io_map, ADDRESS_SPACE_IO, 8 )
@@ -602,37 +602,37 @@ static GFXDECODE_START( bingor )
 GFXDECODE_END
 
 
-static MACHINE_DRIVER_START( bingor )
-	MDRV_CPU_ADD("maincpu", I80186, 14000000 ) //?? Mhz
-	MDRV_CPU_PROGRAM_MAP(bingor_map)
-	MDRV_CPU_IO_MAP(bingor_io)
-	MDRV_CPU_VBLANK_INT("screen", vblank_irq)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 30)
-	MDRV_CPU_PERIODIC_INT(unk_irq, 30)
+static MACHINE_CONFIG_START( bingor, driver_device )
+	MCFG_CPU_ADD("maincpu", I80186, 14000000 ) //?? Mhz
+	MCFG_CPU_PROGRAM_MAP(bingor_map)
+	MCFG_CPU_IO_MAP(bingor_io)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse, 30)
+	MCFG_CPU_PERIODIC_INT(unk_irq, 30)
 
-	MDRV_CPU_ADD("pic", PIC16C57, 12000000) //?? Mhz
-	MDRV_CPU_IO_MAP(pic_io_map)
+	MCFG_CPU_ADD("pic", PIC16C57, 12000000) //?? Mhz
+	MCFG_CPU_IO_MAP(pic_io_map)
 
 
-	MDRV_GFXDECODE(bingor)
-	//MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_GFXDECODE(bingor)
+	//MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(400, 300)
-	MDRV_SCREEN_VISIBLE_AREA(0, 400-1, 0, 300-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(400, 300)
+	MCFG_SCREEN_VISIBLE_AREA(0, 400-1, 0, 300-1)
 
-	MDRV_PALETTE_LENGTH(0x100)
+	MCFG_PALETTE_LENGTH(0x100)
 
-	MDRV_VIDEO_START(bingor)
-	MDRV_VIDEO_UPDATE(bingor)
+	MCFG_VIDEO_START(bingor)
+	MCFG_VIDEO_UPDATE(bingor)
 
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("saa", SAA1099, 6000000 )
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("saa", SAA1099, 6000000 )
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 // I doubt we need to load the eeproms
 
