@@ -50,22 +50,22 @@ this seems more like 8-bit hardware, maybe it should be v25, not v35...
 static const UINT8 cb2001_decryption_table[256] = {
 	0xe8,xxxx,xxxx,xxxx,0x80,0xe4,0x12,0x2f, 0x3c,xxxx,xxxx,0x23,xxxx,xxxx,xxxx,0x5f, /* 00 */
 //    ----                ---- **** pppp pppp  pppp           pppp                pppp
-	0x86,xxxx,xxxx,0x27,0x1c,xxxx,xxxx,xxxx, 0x32,xxxx,0xa0,0xd3,0x3a,0x14,0x89,0x1f, /* 10 */
-//    wwww           **** pppp                 pppp      pppp pppp pppp pppp pppp pppp
+	0x86,xxxx,xxxx,0x27,0x1c,xxxx,xxxx,xxxx, 0x32,0x40,0xa0,0xd3,0x3a,0x14,0x89,0x1f, /* 10 */
+//    wwww           **** pppp                 pppp pppp pppp pppp pppp pppp pppp pppp
 	xxxx,0x8e,xxxx,0x0f,xxxx,0x49,0xb5,xxxx, 0x56,xxxx,xxxx,0x75,0x33,0xb6,xxxx,0x39, /* 20 */
 //         !!!!      pppp      pppp pppp       pppp           pppp pppp pppp      ****
 	0x89,xxxx,xxxx,xxxx,xxxx,0x22,0x5b,xxxx, xxxx,xxxx,0x74,xxxx,xxxx,0xa6,xxxx,0x74, /* 30 */
 //    wwww                     **** pppp                 debu           pppp      pppp
 	xxxx,0xea,xxxx,xxxx,0xd0,0xb0,0x5e,xxxx, xxxx,0xa2,xxxx,xxxx,0xa3,xxxx,xxxx,0xb3, /* 40 */
 //         !!!!           **** pppp pppp            pppp           pppp           pppp
-	xxxx,xxxx,0x2c,xxxx,0x9d,xxxx,0x42,0xc0, 0x04,xxxx,0xb7,xxxx,0xeb,0xab,xxxx,xxxx, /* 50 */
-//              pppp      ****      pppp pppp  ****      ****      pppp pppp
+	0x13,xxxx,0x2c,xxxx,0x9d,xxxx,0x42,0xc0, 0x04,xxxx,0xb7,xxxx,0xeb,0xab,xxxx,xxxx, /* 50 */
+//    ????      pppp      ****      pppp pppp  ****      ****      pppp pppp
 	xxxx,xxxx,xxxx,xxxx,0x0a,xxxx,xxxx,xxxx, 0xa1,0xa5,xxxx,xxxx,xxxx,0xbb,0xba,xxxx, /* 60 */
 //                        pppp                 pppp pppp                pppp pppp
 	0xc3,0x53,0x02,0x58,xxxx,xxxx,0x24,xxxx, 0x72,xxxx,0xf3,xxxx,xxxx,0x43,xxxx,0x34, /* 70 */
 //    pppp pppp pppp pppp           pppp       pppp      pppp           pppp      ****
-	0x26,xxxx,0x81,xxxx,xxxx,0x3d,0xfb,0xf6, xxxx,xxxx,0x59,xxxx,0x73,xxxx,0x2a,xxxx, /* 80 */
-//    pppp      wwww           pppp **** pppp            pppp      pppp      pppp
+	0x26,xxxx,0xd1,xxxx,xxxx,0x3d,0xfb,0xf6, xxxx,xxxx,0x59,xxxx,0x73,xxxx,0x2a,xxxx, /* 80 */
+//    pppp      rrrr           pppp **** pppp            pppp      pppp      pppp
 	xxxx,0x3d,0xe9,xxxx,xxxx,0xbe,0xf9,xxxx, xxxx,xxxx,0x57,xxxx,0xb9,xxxx,0xbf,xxxx, /* 90 */
 //         wwww pppp           pppp ****                 pppp      pppp      pppp
 	0xc1,xxxx,0xe6,0x06,0xaa,0x9c,0xad,0xb8, 0x4e,xxxx,0x8d,0x50,0x51,0xa4,xxxx,0x1a, /* A0 */
@@ -74,8 +74,8 @@ static const UINT8 cb2001_decryption_table[256] = {
 //    pppp      pppp           pppp                 pppp pppp      pppp **** pppp pppp
 	0xcb,0xec,0xee,xxxx,xxxx,0xe2,0x87,xxxx, xxxx,xxxx,0x76,0x61,0x48,xxxx,0x2e,xxxx, /* C0 */
 //    pppp pppp pppp           pppp pppp                 pppp **** ****      pppp
-	xxxx,0xf2,0x46,xxxx,0x60,xxxx,0x4f,0x47, 0x88,xxxx,xxxx,0x04,xxxx,0xfa,0xc7,0x8b, /* D0 */
-//         ???? pppp      ****      pppp pppp  pppp           wwww      **** !!!! pppp
+	xxxx,0xf2,0x46,xxxx,0x60,xxxx,0x4f,0x47, 0x88,xxxx,xxxx,0xff,xxxx,0xfa,0xc7,0x8b, /* D0 */
+//         ???? pppp      ****      pppp pppp  pppp           pppp      **** !!!! pppp
 	0x8a,0xb1,xxxx,0xc6,xxxx,0x5a,xxxx,0xb2, 0x9a,0x52,xxxx,xxxx,xxxx,xxxx,xxxx,xxxx, /* E0 */
 //    pppp gggg      !!!!      ****      pppp  pppp ****
 	xxxx,0xae,0xfe,xxxx,xxxx,xxxx,xxxx,0x2a, xxxx,xxxx,0x04,xxxx,0x81,xxxx,xxxx,xxxx, /* F0 */
@@ -738,8 +738,8 @@ static PALETTE_INIT(cb2001)
 	{
 		int r,g,b;
 
-		UINT8*proms = memory_region(machine, "proms");
-		int length = memory_region_length(machine, "proms");
+		UINT8*proms = machine->region("proms")->base();
+		int length = machine->region("proms")->bytes();
 		UINT16 dat;
 
 		dat = (proms[0x000+i] << 8) | proms[0x200+i];
@@ -791,38 +791,38 @@ static const ay8910_interface cb2001_ay8910_config =
 };
 
 static const nec_config cb2001_config = { cb2001_decryption_table, };
-static MACHINE_DRIVER_START( cb2001 )
-	MDRV_CPU_ADD("maincpu", V30, 20000000) // CPU91A-011-0016JK004; encrypted cpu like nec v25/35 used in some irem game
-	MDRV_CPU_CONFIG(cb2001_config)
-	MDRV_CPU_PROGRAM_MAP(cb2001_map)
-	MDRV_CPU_IO_MAP(cb2001_io)
-	MDRV_CPU_VBLANK_INT("screen", vblank_irq)
+static MACHINE_CONFIG_START( cb2001, driver_device )
+	MCFG_CPU_ADD("maincpu", V35, 20000000) // CPU91A-011-0016JK004; encrypted cpu like nec v25/35 used in some irem game
+	MCFG_CPU_CONFIG(cb2001_config)
+	MCFG_CPU_PROGRAM_MAP(cb2001_map)
+	MCFG_CPU_IO_MAP(cb2001_io)
+	MCFG_CPU_VBLANK_INT("screen", vblank_irq)
 
-	MDRV_PPI8255_ADD( "ppi8255_0", cb2001_ppi8255_intf[0] )
-	MDRV_PPI8255_ADD( "ppi8255_1", cb2001_ppi8255_intf[1] )
+	MCFG_PPI8255_ADD( "ppi8255_0", cb2001_ppi8255_intf[0] )
+	MCFG_PPI8255_ADD( "ppi8255_1", cb2001_ppi8255_intf[1] )
 
-	MDRV_GFXDECODE(cb2001)
+	MCFG_GFXDECODE(cb2001)
 
-	MDRV_PALETTE_INIT( cb2001 )
+	MCFG_PALETTE_INIT( cb2001 )
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(64*8, 64*8)
-	MDRV_SCREEN_VISIBLE_AREA(0, 64*8-1, 0, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(64*8, 64*8)
+	MCFG_SCREEN_VISIBLE_AREA(0, 64*8-1, 0, 32*8-1)
 
-	MDRV_PALETTE_LENGTH(0x100)
+	MCFG_PALETTE_LENGTH(0x100)
 
-	MDRV_VIDEO_START(cb2001)
-	MDRV_VIDEO_UPDATE(cb2001)
+	MCFG_VIDEO_START(cb2001)
+	MCFG_VIDEO_UPDATE(cb2001)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("aysnd", AY8910, 1500000) // wrong
-	MDRV_SOUND_CONFIG(cb2001_ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("aysnd", AY8910, 1500000) // wrong
+	MCFG_SOUND_CONFIG(cb2001_ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
 ROM_START( cb2001 )
