@@ -97,7 +97,7 @@ TODO:
 
 static VIDEO_EOF( champbas )
 {
-	champbas_state *state = (champbas_state *)machine->driver_data;
+	champbas_state *state = machine->driver_data<champbas_state>();
 	state->watchdog_count++;
 
 	if (state->watchdog_count == 0x10)
@@ -113,20 +113,20 @@ static VIDEO_EOF( champbas )
 
 static WRITE8_HANDLER( champbas_watchdog_reset_w )
 {
-	champbas_state *state = (champbas_state *)space->machine->driver_data;
+	champbas_state *state = space->machine->driver_data<champbas_state>();
 	state->watchdog_count = 0;
 }
 
 static CUSTOM_INPUT( champbas_watchdog_bit2 )
 {
-	champbas_state *state = (champbas_state *)field->port->machine->driver_data;
+	champbas_state *state = field->port->machine->driver_data<champbas_state>();
 	return BIT(state->watchdog_count, 2);
 }
 
 
 static WRITE8_HANDLER( irq_enable_w )
 {
-	champbas_state *state = (champbas_state *)space->machine->driver_data;
+	champbas_state *state = space->machine->driver_data<champbas_state>();
 	int bit = data & 1;
 
 	cpu_interrupt_enable(state->maincpu, bit);
@@ -136,7 +136,7 @@ static WRITE8_HANDLER( irq_enable_w )
 
 static TIMER_CALLBACK( exctsccr_fm_callback )
 {
-	champbas_state *state = (champbas_state *)machine->driver_data;
+	champbas_state *state = machine->driver_data<champbas_state>();
 	cpu_set_input_line_and_vector(state->audiocpu, 0, HOLD_LINE, 0xff);
 }
 
@@ -161,7 +161,7 @@ static WRITE8_HANDLER( champbas_mcu_switch_w )
 
 static WRITE8_HANDLER( champbas_mcu_halt_w )
 {
-	champbas_state *state = (champbas_state *)space->machine->driver_data;
+	champbas_state *state = space->machine->driver_data<champbas_state>();
 
 	// MCU not present/not used in champbas
 	if (state->mcu == NULL)
@@ -566,7 +566,7 @@ GFXDECODE_END
 
 static MACHINE_START( champbas )
 {
-	champbas_state *state = (champbas_state *)machine->driver_data;
+	champbas_state *state = machine->driver_data<champbas_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->mcu = machine->device(CPUTAG_MCU);
@@ -578,7 +578,7 @@ static MACHINE_START( champbas )
 
 static MACHINE_START( exctsccr )
 {
-	champbas_state *state = (champbas_state *)machine->driver_data;
+	champbas_state *state = machine->driver_data<champbas_state>();
 	state->audiocpu = machine->device("audiocpu");
 
 	// FIXME
@@ -590,209 +590,197 @@ static MACHINE_START( exctsccr )
 
 static MACHINE_RESET( champbas )
 {
-	champbas_state *state = (champbas_state *)machine->driver_data;
+	champbas_state *state = machine->driver_data<champbas_state>();
 
 	state->palette_bank = 0;
 	state->gfx_bank = 0;	// talbot has only 1 bank
 }
 
 
-static MACHINE_DRIVER_START( talbot )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(champbas_state)
+static MACHINE_CONFIG_START( talbot, champbas_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
-	MDRV_CPU_PROGRAM_MAP(talbot_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_assert)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
+	MCFG_CPU_PROGRAM_MAP(talbot_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_assert)
 
 	/* MCU */
-	MDRV_CPU_ADD(CPUTAG_MCU, ALPHA8201, XTAL_18_432MHz/6/8)
-	MDRV_CPU_PROGRAM_MAP(mcu_map)
+	MCFG_CPU_ADD(CPUTAG_MCU, ALPHA8201, XTAL_18_432MHz/6/8)
+	MCFG_CPU_PROGRAM_MAP(mcu_map)
 
-	MDRV_MACHINE_START(champbas)
-	MDRV_MACHINE_RESET(champbas)
+	MCFG_MACHINE_START(champbas)
+	MCFG_MACHINE_RESET(champbas)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(talbot)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(talbot)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(champbas)
-	MDRV_VIDEO_START(champbas)
-	MDRV_VIDEO_UPDATE(champbas)
-	MDRV_VIDEO_EOF(champbas)
+	MCFG_PALETTE_INIT(champbas)
+	MCFG_VIDEO_START(champbas)
+	MCFG_VIDEO_UPDATE(champbas)
+	MCFG_VIDEO_EOF(champbas)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( champbas )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(champbas_state)
+static MACHINE_CONFIG_START( champbas, champbas_state )
 
 	/* basic machine hardware */
 	/* main cpu */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
-	MDRV_CPU_PROGRAM_MAP(champbas_main_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_assert)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
+	MCFG_CPU_PROGRAM_MAP(champbas_main_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_assert)
 
-	MDRV_CPU_ADD("sub", Z80, XTAL_18_432MHz/6)
-	MDRV_CPU_PROGRAM_MAP(champbas_sub_map)
+	MCFG_CPU_ADD("sub", Z80, XTAL_18_432MHz/6)
+	MCFG_CPU_PROGRAM_MAP(champbas_sub_map)
 
-	MDRV_MACHINE_START(champbas)
-	MDRV_MACHINE_RESET(champbas)
+	MCFG_MACHINE_START(champbas)
+	MCFG_MACHINE_RESET(champbas)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(champbas)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(champbas)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(champbas)
-	MDRV_VIDEO_START(champbas)
-	MDRV_VIDEO_UPDATE(champbas)
-	MDRV_VIDEO_EOF(champbas)
+	MCFG_PALETTE_INIT(champbas)
+	MCFG_VIDEO_START(champbas)
+	MCFG_VIDEO_UPDATE(champbas)
+	MCFG_VIDEO_EOF(champbas)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( champmcu )
+static MACHINE_CONFIG_DERIVED( champmcu, champbas )
+
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(champbas)
 
 	/* MCU */
-	MDRV_CPU_ADD(CPUTAG_MCU, ALPHA8201, XTAL_18_432MHz/6/8)
-	MDRV_CPU_PROGRAM_MAP(mcu_map)
+	MCFG_CPU_ADD(CPUTAG_MCU, ALPHA8201, XTAL_18_432MHz/6/8)
+	MCFG_CPU_PROGRAM_MAP(mcu_map)
 
 	/* to MCU timeout champbbj */
-	MDRV_QUANTUM_TIME(HZ(3000))
-MACHINE_DRIVER_END
+	MCFG_QUANTUM_TIME(HZ(3000))
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( exctsccr )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(champbas_state)
+static MACHINE_CONFIG_START( exctsccr, champbas_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6 )
-	MDRV_CPU_PROGRAM_MAP(exctsccr_main_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_assert)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6 )
+	MCFG_CPU_PROGRAM_MAP(exctsccr_main_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_assert)
 
-	MDRV_CPU_ADD("audiocpu", Z80, XTAL_14_31818MHz/4 )
-	MDRV_CPU_PROGRAM_MAP(exctsccr_sub_map)
-	MDRV_CPU_IO_MAP(exctsccr_sound_io_map)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 4000) /* 4 kHz, updates the dac */
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_14_31818MHz/4 )
+	MCFG_CPU_PROGRAM_MAP(exctsccr_sub_map)
+	MCFG_CPU_IO_MAP(exctsccr_sound_io_map)
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse, 4000) /* 4 kHz, updates the dac */
 
 	/* MCU */
-	MDRV_CPU_ADD(CPUTAG_MCU, ALPHA8301, XTAL_18_432MHz/6/8)		/* Actually 8302 */
-	MDRV_CPU_PROGRAM_MAP(mcu_map)
+	MCFG_CPU_ADD(CPUTAG_MCU, ALPHA8301, XTAL_18_432MHz/6/8)		/* Actually 8302 */
+	MCFG_CPU_PROGRAM_MAP(mcu_map)
 
-	MDRV_MACHINE_START(exctsccr)
-	MDRV_MACHINE_RESET(champbas)
+	MCFG_MACHINE_START(exctsccr)
+	MCFG_MACHINE_RESET(champbas)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60.54)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60.54)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(exctsccr)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(exctsccr)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(exctsccr)
-	MDRV_VIDEO_START(exctsccr)
-	MDRV_VIDEO_UPDATE(exctsccr)
-	MDRV_VIDEO_EOF(champbas)
+	MCFG_PALETTE_INIT(exctsccr)
+	MCFG_VIDEO_START(exctsccr)
+	MCFG_VIDEO_UPDATE(exctsccr)
+	MCFG_VIDEO_EOF(champbas)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
 	/* AY (melody) clock is specified by a VR (0.9 - 3.9 MHz) */
-	MDRV_SOUND_ADD("ay1", AY8910, 1940000) /* VR has a factory mark and this is the value read */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
+	MCFG_SOUND_ADD("ay1", AY8910, 1940000) /* VR has a factory mark and this is the value read */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
 
-	MDRV_SOUND_ADD("ay2", AY8910, XTAL_14_31818MHz/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
+	MCFG_SOUND_ADD("ay2", AY8910, XTAL_14_31818MHz/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
 
-	MDRV_SOUND_ADD("ay3", AY8910, XTAL_14_31818MHz/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
+	MCFG_SOUND_ADD("ay3", AY8910, XTAL_14_31818MHz/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
 
-	MDRV_SOUND_ADD("ay4", AY8910, XTAL_14_31818MHz/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
+	MCFG_SOUND_ADD("ay4", AY8910, XTAL_14_31818MHz/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.08)
 
-	MDRV_SOUND_ADD("dac1", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+	MCFG_SOUND_ADD("dac1", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD("dac2", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac2", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+MACHINE_CONFIG_END
 
 /* Bootleg running on a modified Champion Baseball board */
-static MACHINE_DRIVER_START( exctsccrb )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(champbas_state)
+static MACHINE_CONFIG_START( exctsccrb, champbas_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
-	MDRV_CPU_PROGRAM_MAP(exctsccrb_main_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_assert)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)
+	MCFG_CPU_PROGRAM_MAP(exctsccrb_main_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_assert)
 
-	MDRV_CPU_ADD("sub", Z80, XTAL_18_432MHz/6)
-	MDRV_CPU_PROGRAM_MAP(champbas_sub_map)
+	MCFG_CPU_ADD("sub", Z80, XTAL_18_432MHz/6)
+	MCFG_CPU_PROGRAM_MAP(champbas_sub_map)
 
-	MDRV_MACHINE_START(champbas)
-	MDRV_MACHINE_RESET(champbas)
+	MCFG_MACHINE_START(champbas)
+	MCFG_MACHINE_RESET(champbas)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(exctsccr)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(exctsccr)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(exctsccr)
-	MDRV_VIDEO_START(exctsccr)
-	MDRV_VIDEO_UPDATE(exctsccr)
-	MDRV_VIDEO_EOF(champbas)
+	MCFG_PALETTE_INIT(exctsccr)
+	MCFG_VIDEO_START(exctsccr)
+	MCFG_VIDEO_UPDATE(exctsccr)
+	MCFG_VIDEO_EOF(champbas)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_18_432MHz/12)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.70)
+MACHINE_CONFIG_END
 
 
 
@@ -1185,9 +1173,9 @@ ROM_END
 static DRIVER_INIT(champbas)
 {
 	// chars and sprites are mixed in the same ROMs, so rearrange them for easier decoding
-	UINT8 *rom1 = memory_region(machine, "gfx1");
-	UINT8 *rom2 = memory_region(machine, "gfx2");
-	int len = memory_region_length(machine, "gfx1");
+	UINT8 *rom1 = machine->region("gfx1")->base();
+	UINT8 *rom2 = machine->region("gfx2")->base();
+	int len = machine->region("gfx1")->bytes();
 	int i;
 
 	for (i = 0; i < len/2; ++i)
@@ -1202,8 +1190,8 @@ static DRIVER_INIT(champbas)
 static DRIVER_INIT( exctsccr )
 {
 	// chars and sprites are mixed in the same ROMs, so rearrange them for easier decoding
-	UINT8 *rom1 = memory_region(machine, "gfx1");
-	UINT8 *rom2 = memory_region(machine, "gfx2");
+	UINT8 *rom1 = machine->region("gfx1")->base();
+	UINT8 *rom2 = machine->region("gfx2")->base();
 	int i;
 
 	// planes 0,1
