@@ -1,52 +1,45 @@
+#define ADDRESS_MAP_MODERN
+
 #include "emu.h"
-#include "cpu/cdp1802/cdp1802.h"
+#include "cpu/cosmac/cosmac.h"
 #include "cpu/cop400/cop400.h"
 #include "sound/cdp1869.h"
 #include "sound/ay8910.h"
 #include "machine/cdp1852.h"
+#include "machine/nvram.h"
 #include "includes/cidelsa.h"
 
 /* CDP1802 Interface */
 
-static CDP1802_MODE_READ( cidelsa_mode_r )
+READ_LINE_MEMBER( cidelsa_state::clear_r )
 {
-	cidelsa_state *state = (cidelsa_state *)device->machine->driver_data;
-
-	return state->cdp1802_mode;
+	return m_reset;
 }
 
-static CDP1802_EF_READ( cidelsa_ef_r )
+WRITE_LINE_MEMBER( cidelsa_state::q_w )
 {
-	/*
-        EF1     CDP1869 _PRD
-        EF2     Test
-        EF3     Coin 2
-        EF4     Coin 1
-    */
-
-	return input_port_read(device->machine, "EF");
+	m_cdp1802_q = state;
 }
 
-static WRITE_LINE_DEVICE_HANDLER( cidelsa_q_w )
+static COSMAC_INTERFACE( cidelsa_cdp1802_config )
 {
-	cidelsa_state *driver_state = (cidelsa_state *)device->machine->driver_data;
-
-	driver_state->cdp1802_q = state;
-}
-
-static CDP1802_INTERFACE( cidelsa_cdp1802_config )
-{
-	cidelsa_mode_r,				// MODE
-	cidelsa_ef_r,				// EF
-	NULL,						// SC
-	DEVCB_LINE(cidelsa_q_w),	// Q
-	DEVCB_NULL,					// DMA read
-	DEVCB_NULL					// DMA write
+	DEVCB_LINE_VCC,
+	DEVCB_DRIVER_LINE_MEMBER(cidelsa_state, clear_r),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_DRIVER_LINE_MEMBER(cidelsa_state, q_w),
+	DEVCB_NULL,
+	DEVCB_NULL,
+	NULL,
+	DEVCB_NULL,
+	DEVCB_NULL
 };
 
 /* Sound Interface */
 
-static WRITE8_HANDLER( draco_sound_bankswitch_w )
+WRITE8_MEMBER( cidelsa_state::draco_sound_bankswitch_w )
 {
 	/*
 
@@ -61,13 +54,11 @@ static WRITE8_HANDLER( draco_sound_bankswitch_w )
 
 	int bank = BIT(data, 3);
 
-	memory_set_bank(space->machine, "bank1", bank);
+	memory_set_bank(&m_machine, "bank1", bank);
 }
 
-static WRITE8_DEVICE_HANDLER( draco_sound_g_w )
+WRITE8_MEMBER( cidelsa_state::draco_sound_g_w )
 {
-	cidelsa_state *state = (cidelsa_state *)device->machine->driver_data;
-
 	/*
 
      G1 G0  description
@@ -82,43 +73,37 @@ static WRITE8_DEVICE_HANDLER( draco_sound_g_w )
 	switch (data)
 	{
 	case 0x01:
-		ay8910_data_w(device, 0, state->draco_ay_latch);
+		ay8910_data_w(m_psg, 0, m_draco_ay_latch);
 		break;
 
 	case 0x02:
-		state->draco_ay_latch = ay8910_r(device, 0);
+		m_draco_ay_latch = ay8910_r(m_psg, 0);
 		break;
 
 	case 0x03:
-		ay8910_address_w(device, 0, state->draco_ay_latch);
+		ay8910_address_w(m_psg, 0, m_draco_ay_latch);
 		break;
 	}
 }
 
-static READ8_HANDLER( draco_sound_in_r )
+READ8_MEMBER( cidelsa_state::draco_sound_in_r )
 {
-	cidelsa_state *state = (cidelsa_state *)space->machine->driver_data;
-
-	return ~(state->draco_sound) & 0x07;
+	return ~(m_draco_sound) & 0x07;
 }
 
-static READ8_HANDLER( draco_sound_ay8910_r )
+READ8_MEMBER( cidelsa_state::draco_sound_ay8910_r )
 {
-	cidelsa_state *state = (cidelsa_state *)space->machine->driver_data;
-
-	return state->draco_ay_latch;
+	return m_draco_ay_latch;
 }
 
-static WRITE8_HANDLER( draco_sound_ay8910_w )
+WRITE8_MEMBER( cidelsa_state::draco_sound_ay8910_w )
 {
-	cidelsa_state *state = (cidelsa_state *)space->machine->driver_data;
-
-	state->draco_ay_latch = data;
+	m_draco_ay_latch = data;
 }
 
 /* Read/Write Handlers */
 
-static WRITE8_HANDLER( destryer_out1_w )
+WRITE8_MEMBER( cidelsa_state::destryer_out1_w )
 {
 	/*
       bit   description
@@ -136,7 +121,7 @@ static WRITE8_HANDLER( destryer_out1_w )
 
 /* CDP1852 Interfaces */
 
-static WRITE8_HANDLER( altair_out1_w )
+WRITE8_MEMBER( cidelsa_state::altair_out1_w )
 {
 	/*
       bit   description
@@ -151,12 +136,12 @@ static WRITE8_HANDLER( altair_out1_w )
         7   CONT. M1
     */
 
-	set_led_status(space->machine, 0, data & 0x08); // 1P
-	set_led_status(space->machine, 1, data & 0x10); // 2P
-	set_led_status(space->machine, 2, data & 0x20); // FIRE
+	set_led_status(&m_machine, 0, data & 0x08); // 1P
+	set_led_status(&m_machine, 1, data & 0x10); // 2P
+	set_led_status(&m_machine, 2, data & 0x20); // FIRE
 }
 
-static WRITE8_HANDLER( draco_out1_w )
+WRITE8_MEMBER( cidelsa_state::draco_out1_w )
 {
 	/*
       bit   description
@@ -171,9 +156,7 @@ static WRITE8_HANDLER( draco_out1_w )
         7   SONIDO C -> COP402 IN2
     */
 
-	cidelsa_state *state = (cidelsa_state *)space->machine->driver_data;
-
-    state->draco_sound = (data & 0xe0) >> 5;
+	m_draco_sound = (data & 0xe0) >> 5;
 }
 
 static CDP1852_INTERFACE( cidelsa_cdp1852_in0_intf )
@@ -204,7 +187,7 @@ static CDP1852_INTERFACE( altair_cdp1852_out1_intf )
 {
 	CDP1852_MODE_OUTPUT,
 	DEVCB_NULL,
-	DEVCB_MEMORY_HANDLER(CDP1802_TAG, PROGRAM, altair_out1_w),
+	DEVCB_DRIVER_MEMBER(cidelsa_state, altair_out1_w),
 	DEVCB_NULL
 };
 
@@ -212,7 +195,7 @@ static CDP1852_INTERFACE( draco_cdp1852_out1_intf )
 {
 	CDP1852_MODE_OUTPUT,
 	DEVCB_NULL,
-	DEVCB_MEMORY_HANDLER(CDP1802_TAG, PROGRAM, draco_out1_w),
+	DEVCB_DRIVER_MEMBER(cidelsa_state, draco_out1_w),
 	DEVCB_NULL
 };
 
@@ -229,75 +212,65 @@ static COP400_INTERFACE( draco_cop_intf )
 
 // Destroyer
 
-static ADDRESS_MAP_START( destryer_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( destryer_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0x2000, 0x20ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
-	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_charram_r, cdp1869_charram_w)
-	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_pageram_r, cdp1869_pageram_w)
+	AM_RANGE(0x2000, 0x20ff) AM_RAM AM_SHARE("nvram")
+	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
+	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( destryera_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( destryera_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
-	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_charram_r, cdp1869_charram_w)
-	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_pageram_r, cdp1869_pageram_w)
+	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_SHARE("nvram")
+	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
+	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( destryer_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( destryer_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN0") AM_WRITE(destryer_out1_w)
 	AM_RANGE(0x02, 0x02) AM_READ_PORT("IN1")
-	AM_RANGE(0x03, 0x03) AM_DEVWRITE(CDP1869_TAG, cdp1869_out3_w)
-	AM_RANGE(0x04, 0x04) AM_DEVWRITE(CDP1869_TAG, cdp1869_out4_w)
-	AM_RANGE(0x05, 0x05) AM_DEVWRITE(CDP1869_TAG, cdp1869_out5_w)
-	AM_RANGE(0x06, 0x06) AM_DEVWRITE(CDP1869_TAG, cdp1869_out6_w)
-	AM_RANGE(0x07, 0x07) AM_DEVWRITE(CDP1869_TAG, cdp1869_out7_w)
+	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
 ADDRESS_MAP_END
 
 // Altair
 
-static ADDRESS_MAP_START( altair_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( altair_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x2fff) AM_ROM
-	AM_RANGE(0x3000, 0x30ff) AM_RAM
-	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_charram_r, cdp1869_charram_w)
-	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_pageram_r, cdp1869_pageram_w)
+	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_SHARE("nvram")
+	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
+	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( altair_io_map, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x01, 0x01) AM_DEVREAD("ic23", cdp1852_data_r) AM_DEVWRITE("ic26", cdp1852_data_w)
-	AM_RANGE(0x02, 0x02) AM_DEVREAD("ic24", cdp1852_data_r)
-	AM_RANGE(0x03, 0x03) AM_DEVWRITE(CDP1869_TAG, cdp1869_out3_w)
-	AM_RANGE(0x04, 0x04) AM_DEVREAD("ic25", cdp1852_data_r) AM_DEVWRITE(CDP1869_TAG, cdp1869_out4_w)
-	AM_RANGE(0x05, 0x05) AM_DEVWRITE(CDP1869_TAG, cdp1869_out5_w)
-	AM_RANGE(0x06, 0x06) AM_DEVWRITE(CDP1869_TAG, cdp1869_out6_w)
-	AM_RANGE(0x07, 0x07) AM_DEVWRITE(CDP1869_TAG, cdp1869_out7_w)
+static ADDRESS_MAP_START( altair_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
+	AM_RANGE(0x01, 0x01) AM_DEVREAD_LEGACY("ic23", cdp1852_data_r) AM_DEVWRITE_LEGACY("ic26", cdp1852_data_w)
+	AM_RANGE(0x02, 0x02) AM_DEVREAD_LEGACY("ic24", cdp1852_data_r)
+	AM_RANGE(0x04, 0x04) AM_DEVREAD_LEGACY("ic25", cdp1852_data_r)
+	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
 ADDRESS_MAP_END
 
 // Draco
 
-static ADDRESS_MAP_START( draco_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( draco_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
-	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_charram_r, cdp1869_charram_w)
-	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_pageram_r, cdp1869_pageram_w)
+	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_SHARE("nvram")
+	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
+	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_io_map, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x01, 0x01) AM_DEVREAD("ic29", cdp1852_data_r) AM_DEVWRITE("ic32", cdp1852_data_w)
-	AM_RANGE(0x02, 0x02) AM_DEVREAD("ic30", cdp1852_data_r)
-	AM_RANGE(0x03, 0x03) AM_DEVWRITE(CDP1869_TAG, cdp1869_out3_w)
-	AM_RANGE(0x04, 0x04) AM_DEVREAD("ic31", cdp1852_data_r) AM_DEVWRITE(CDP1869_TAG, cdp1869_out4_w)
-	AM_RANGE(0x05, 0x05) AM_DEVWRITE(CDP1869_TAG, cdp1869_out5_w)
-	AM_RANGE(0x06, 0x06) AM_DEVWRITE(CDP1869_TAG, cdp1869_out6_w)
-	AM_RANGE(0x07, 0x07) AM_DEVWRITE(CDP1869_TAG, cdp1869_out7_w)
+static ADDRESS_MAP_START( draco_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
+	AM_RANGE(0x01, 0x01) AM_DEVREAD_LEGACY("ic29", cdp1852_data_r) AM_DEVWRITE_LEGACY("ic32", cdp1852_data_w)
+	AM_RANGE(0x02, 0x02) AM_DEVREAD_LEGACY("ic30", cdp1852_data_r)
+	AM_RANGE(0x04, 0x04) AM_DEVREAD_LEGACY("ic31", cdp1852_data_r)
+	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( draco_sound_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x000, 0x3ff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( draco_sound_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
 	AM_RANGE(COP400_PORT_D, COP400_PORT_D) AM_WRITE(draco_sound_bankswitch_w)
-	AM_RANGE(COP400_PORT_G, COP400_PORT_G) AM_DEVWRITE(AY8910_TAG, draco_sound_g_w)
+	AM_RANGE(COP400_PORT_G, COP400_PORT_G) AM_WRITE(draco_sound_g_w)
 	AM_RANGE(COP400_PORT_L, COP400_PORT_L) AM_READWRITE(draco_sound_ay8910_r, draco_sound_ay8910_w)
 	AM_RANGE(COP400_PORT_IN, COP400_PORT_IN) AM_READ(draco_sound_in_r)
 	AM_RANGE(COP400_PORT_SIO, COP400_PORT_SIO) AM_NOP
@@ -308,16 +281,14 @@ ADDRESS_MAP_END
 
 static CUSTOM_INPUT( cdp1869_pcb_r )
 {
-	cidelsa_state *state = (cidelsa_state *)field->port->machine->driver_data;
+	cidelsa_state *state = field->port->machine->driver_data<cidelsa_state>();
 
-	return state->cdp1869_pcb;
+	return state->m_cdp1869_pcb;
 }
 
-static CUSTOM_INPUT( cidelsa_prd_r )
+static INPUT_CHANGED( ef_w )
 {
-	cidelsa_state *state = (cidelsa_state *)field->port->machine->driver_data;
-
-	return state->cdp1869_prd;
+	cputag_set_input_line(field->port->machine, CDP1802_TAG, (int)(FPTR)param, newval);
 }
 
 static INPUT_PORTS_START( destryer )
@@ -354,10 +325,10 @@ static INPUT_PORTS_START( destryer )
 	PORT_DIPSETTING(    0x00, "Slot A: 2.5  Slot B: 5" )
 
 	PORT_START("EF")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SPECIAL ) PORT_CUSTOM(cidelsa_prd_r, NULL)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE ) // ST
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 ) // M2
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 ) // M1
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) // inverted CDP1869 PRD, pushed
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF2)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF3)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF4)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( altair )
@@ -404,10 +375,10 @@ static INPUT_PORTS_START( altair )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START("EF")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SPECIAL ) PORT_CUSTOM(cidelsa_prd_r, NULL)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE ) // ST
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 ) // M2
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 ) // M1
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) // inverted CDP1869 PRD, pushed
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF2)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF3)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF4)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( draco )
@@ -456,148 +427,132 @@ static INPUT_PORTS_START( draco )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_LEFT )
 
 	PORT_START("EF")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SPECIAL ) PORT_READ_LINE_DEVICE(CDP1869_TAG, cdp1869_predisplay_r)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE ) // ST
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 ) // M2
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 ) // M1
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) // CDP1869 PRD, pushed
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF2)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF3)
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(ef_w, (void*)COSMAC_INPUT_LINE_EF4)
 INPUT_PORTS_END
 
 /* Machine Start */
 
 static TIMER_CALLBACK( set_cpu_mode )
 {
-	cidelsa_state *state = (cidelsa_state *)machine->driver_data;
+	cidelsa_state *state = machine->driver_data<cidelsa_state>();
 
-	state->cdp1802_mode = CDP1802_MODE_RUN;
+	state->m_reset = 1;
 }
 
 static MACHINE_START( cidelsa )
 {
-	cidelsa_state *state = (cidelsa_state *)machine->driver_data;
-
-	state->cdp1802 = machine->device(CDP1802_TAG);
-
-	/* reset the CPU */
-	state->cdp1802_mode = CDP1802_MODE_RESET;
-	timer_set(machine, ATTOTIME_IN_MSEC(200), NULL, 0, set_cpu_mode);
+	cidelsa_state *state = machine->driver_data<cidelsa_state>();
 
 	/* register for state saving */
-	state_save_register_global(machine, state->cdp1802_mode);
+	state_save_register_global(machine, state->m_reset);
 }
 
 static MACHINE_START( draco )
 {
-	cidelsa_state *state = (cidelsa_state *)machine->driver_data;
+	cidelsa_state *state = machine->driver_data<cidelsa_state>();
 
 	MACHINE_START_CALL( cidelsa );
 
 	/* setup COP402 memory banking */
-	memory_configure_bank(machine, "bank1", 0, 2, memory_region(machine, "audiocpu"), 0x400);
+	memory_configure_bank(machine, "bank1", 0, 2, machine->region(COP402N_TAG)->base(), 0x400);
 	memory_set_bank(machine, "bank1", 0);
 
 	/* register for state saving */
-	state_save_register_global(machine, state->draco_sound);
-	state_save_register_global(machine, state->draco_ay_latch);
+	state_save_register_global(machine, state->m_draco_sound);
+	state_save_register_global(machine, state->m_draco_ay_latch);
 }
 
 /* Machine Reset */
 
-static MACHINE_RESET( cidelsa )
+void cidelsa_state::machine_reset()
 {
-	cputag_set_input_line(machine, CDP1802_TAG, INPUT_LINE_RESET, PULSE_LINE);
+	/* reset the CPU */
+	m_reset = 0;
+	timer_set(&m_machine, ATTOTIME_IN_MSEC(200), NULL, 0, set_cpu_mode);
 }
 
 /* Machine Drivers */
 
-static MACHINE_DRIVER_START( destryer )
-	MDRV_DRIVER_DATA(cidelsa_state)
-
+static MACHINE_CONFIG_START( destryer, cidelsa_state )
 	/* basic system hardware */
-	MDRV_CPU_ADD(CDP1802_TAG, CDP1802, DESTRYER_CHR1)
-	MDRV_CPU_PROGRAM_MAP(destryer_map)
-	MDRV_CPU_IO_MAP(destryer_io_map)
-	MDRV_CPU_CONFIG(cidelsa_cdp1802_config)
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_CPU_ADD(CDP1802_TAG, COSMAC, DESTRYER_CHR1)
+	MCFG_CPU_PROGRAM_MAP(destryer_map)
+	MCFG_CPU_IO_MAP(destryer_io_map)
+	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_MACHINE_START(cidelsa)
-	MDRV_MACHINE_RESET(cidelsa)
+	MCFG_MACHINE_START(cidelsa)
 
 	/* sound and video hardware */
-	MDRV_IMPORT_FROM(destryer_video)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( destryera )
-	MDRV_DRIVER_DATA(cidelsa_state)
+	MCFG_FRAGMENT_ADD(destryer_video)
+MACHINE_CONFIG_END
 
+static MACHINE_CONFIG_START( destryera, cidelsa_state )
 	/* basic system hardware */
-	MDRV_CPU_ADD(CDP1802_TAG, CDP1802, DESTRYER_CHR1)
-	MDRV_CPU_PROGRAM_MAP(destryera_map)
-	MDRV_CPU_IO_MAP(destryer_io_map)
-	MDRV_CPU_CONFIG(cidelsa_cdp1802_config)
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_CPU_ADD(CDP1802_TAG, COSMAC, DESTRYER_CHR1)
+	MCFG_CPU_PROGRAM_MAP(destryera_map)
+	MCFG_CPU_IO_MAP(destryer_io_map)
+	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_MACHINE_START(cidelsa)
-	MDRV_MACHINE_RESET(cidelsa)
+	MCFG_MACHINE_START(cidelsa)
 
 	/* sound and video hardware */
-	MDRV_IMPORT_FROM(destryer_video)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( altair )
-	MDRV_DRIVER_DATA(cidelsa_state)
+	MCFG_FRAGMENT_ADD(destryer_video)
+MACHINE_CONFIG_END
 
+static MACHINE_CONFIG_START( altair, cidelsa_state )
 	/* basic system hardware */
+	MCFG_CPU_ADD(CDP1802_TAG, COSMAC, ALTAIR_CHR1)
+	MCFG_CPU_PROGRAM_MAP(altair_map)
+	MCFG_CPU_IO_MAP(altair_io_map)
+	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_CPU_ADD(CDP1802_TAG, CDP1802, ALTAIR_CHR1)
-	MDRV_CPU_PROGRAM_MAP(altair_map)
-	MDRV_CPU_IO_MAP(altair_io_map)
-	MDRV_CPU_CONFIG(cidelsa_cdp1802_config)
-
-	MDRV_MACHINE_START(cidelsa)
-	MDRV_MACHINE_RESET(cidelsa)
+	MCFG_MACHINE_START(cidelsa)
 
 	/* input/output hardware */
-	MDRV_CDP1852_ADD("ic23", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in0_intf)	/* clock is really tied to CDP1869 CMSEL (pin 37) */
-	MDRV_CDP1852_ADD("ic24", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in1_intf)
-	MDRV_CDP1852_ADD("ic25", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in2_intf)
-	MDRV_CDP1852_ADD("ic26", ALTAIR_CHR1 / 8, altair_cdp1852_out1_intf)		/* clock is CDP1802 TPB */
+	MCFG_CDP1852_ADD("ic23", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in0_intf)	/* clock is really tied to CDP1869 CMSEL (pin 37) */
+	MCFG_CDP1852_ADD("ic24", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in1_intf)
+	MCFG_CDP1852_ADD("ic25", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in2_intf)
+	MCFG_CDP1852_ADD("ic26", ALTAIR_CHR1 / 8, altair_cdp1852_out1_intf)		/* clock is CDP1802 TPB */
 
 	/* sound and video hardware */
-	MDRV_IMPORT_FROM(altair_video)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( draco )
-	MDRV_DRIVER_DATA(cidelsa_state)
+	MCFG_FRAGMENT_ADD(altair_video)
+MACHINE_CONFIG_END
 
+static MACHINE_CONFIG_START( draco, cidelsa_state )
 	/* basic system hardware */
-	MDRV_CPU_ADD(CDP1802_TAG, CDP1802, DRACO_CHR1)
-	MDRV_CPU_PROGRAM_MAP(draco_map)
-	MDRV_CPU_IO_MAP(draco_io_map)
-	MDRV_CPU_CONFIG(cidelsa_cdp1802_config)
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_CPU_ADD(CDP1802_TAG, COSMAC, DRACO_CHR1)
+	MCFG_CPU_PROGRAM_MAP(draco_map)
+	MCFG_CPU_IO_MAP(draco_io_map)
+	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_MACHINE_START(draco)
-	MDRV_MACHINE_RESET(cidelsa)
+	MCFG_MACHINE_START(draco)
 
-	MDRV_CPU_ADD("audiocpu", COP402, DRACO_SND_CHR1) // COP402N
-	MDRV_CPU_PROGRAM_MAP(draco_sound_map)
-	MDRV_CPU_IO_MAP(draco_sound_io_map)
-	MDRV_CPU_CONFIG(draco_cop_intf)
+	MCFG_CPU_ADD(COP402N_TAG, COP402, DRACO_SND_CHR1)
+	MCFG_CPU_PROGRAM_MAP(draco_sound_map)
+	MCFG_CPU_IO_MAP(draco_sound_io_map)
+	MCFG_CPU_CONFIG(draco_cop_intf)
 
 	/* input/output hardware */
-	MDRV_CDP1852_ADD("ic29", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in0_intf)	/* clock is really tied to CDP1876 CMSEL (pin 32) */
-	MDRV_CDP1852_ADD("ic30", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in1_intf)
-	MDRV_CDP1852_ADD("ic31", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in2_intf)
-	MDRV_CDP1852_ADD("ic32", DRACO_CHR1 / 8, draco_cdp1852_out1_intf)		/* clock is CDP1802 TPB */
+	MCFG_CDP1852_ADD("ic29", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in0_intf)	/* clock is really tied to CDP1876 CMSEL (pin 32) */
+	MCFG_CDP1852_ADD("ic30", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in1_intf)
+	MCFG_CDP1852_ADD("ic31", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in2_intf)
+	MCFG_CDP1852_ADD("ic32", DRACO_CHR1 / 8, draco_cdp1852_out1_intf)		/* clock is CDP1802 TPB */
 
 	/* sound and video hardware */
-	MDRV_IMPORT_FROM(draco_video)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(draco_video)
+MACHINE_CONFIG_END
 
 /* ROMs */
 
 ROM_START( destryer )
-	ROM_REGION( 0x10000, CDP1802_TAG, 0 )
+	ROM_REGION( 0x2000, CDP1802_TAG, 0 )
 	ROM_LOAD( "des a 2.ic4", 0x0000, 0x0800, CRC(63749870) SHA1(a8eee4509d7a52dcf33049de221d928da3632174) )
 	ROM_LOAD( "des b 2.ic5", 0x0800, 0x0800, CRC(60604f40) SHA1(32ca95c5b38b0f4992e04d77123d217f143ae084) )
 	ROM_LOAD( "des c 2.ic6", 0x1000, 0x0800, CRC(a7cdeb7b) SHA1(a5a7748967d4ca89fb09632e1f0130ef050dbd68) )
@@ -606,7 +561,7 @@ ROM_END
 
 // this was destroyer2.rom in standalone emu..
 ROM_START( destryera )
-	ROM_REGION( 0x10000, CDP1802_TAG, 0 )
+	ROM_REGION( 0x2000, CDP1802_TAG, 0 )
 	ROM_LOAD( "destryera_1", 0x0000, 0x0800, CRC(421428e9) SHA1(0ac3a1e7f61125a1cd82145fa28cbc4b93505dc9) )
 	ROM_LOAD( "destryera_2", 0x0800, 0x0800, CRC(55dc8145) SHA1(a0066d3f3ac0ae56273485b74af90eeffea5e64e) )
 	ROM_LOAD( "destryera_3", 0x1000, 0x0800, CRC(5557bdf8) SHA1(37a9cbc5d25051d3bed7535c58aac937cd7c64e1) )
@@ -614,7 +569,7 @@ ROM_START( destryera )
 ROM_END
 
 ROM_START( altair )
-	ROM_REGION( 0x10000, CDP1802_TAG, 0 )
+	ROM_REGION( 0x3000, CDP1802_TAG, 0 )
 	ROM_LOAD( "alt a 1.ic7",  0x0000, 0x0800, CRC(37c26c4e) SHA1(30df7efcf5bd12dafc1cb6e894fc18e7b76d3e61) )
 	ROM_LOAD( "alt b 1.ic8",  0x0800, 0x0800, CRC(76b814a4) SHA1(e8ab1d1cbcef974d929ef8edd10008f60052a607) )
 	ROM_LOAD( "alt c 1.ic9",  0x1000, 0x0800, CRC(2569ce44) SHA1(a09597d2f8f50fab9a09ed9a59c50a2bdcba47bb) )
@@ -624,7 +579,7 @@ ROM_START( altair )
 ROM_END
 
 ROM_START( draco )
-	ROM_REGION( 0x10000, CDP1802_TAG, 0 )
+	ROM_REGION( 0x4000, CDP1802_TAG, 0 )
 	ROM_LOAD( "dra a 1.ic10", 0x0000, 0x0800, CRC(ca127984) SHA1(46721cf42b1c891f7c88bc063a2149dd3cefea74) )
 	ROM_LOAD( "dra b 1.ic11", 0x0800, 0x0800, CRC(e4936e28) SHA1(ddbbf769994d32a6bce75312306468a89033f0aa) )
 	ROM_LOAD( "dra c 1.ic12", 0x1000, 0x0800, CRC(94480f5d) SHA1(8f49ce0f086259371e999d097a502482c83c6e9e) )
@@ -634,7 +589,7 @@ ROM_START( draco )
 	ROM_LOAD( "dra g 1.ic16", 0x3000, 0x0800, CRC(f28546c0) SHA1(daedf1d64f94358b15580d697dd77d3c977aa22c) )
 	ROM_LOAD( "dra h 1.ic17", 0x3800, 0x0800, CRC(dce782ea) SHA1(f558096f43fb30337bc4a527169718326c265c2c) )
 
-	ROM_REGION( 0x800, "audiocpu", 0 )
+	ROM_REGION( 0x800, COP402N_TAG, 0 )
 	ROM_LOAD( "dra s 1.ic4",  0x0000, 0x0800, CRC(292a57f8) SHA1(b34a189394746d77c3ee669db24109ee945c3be7) )
 ROM_END
 
