@@ -121,15 +121,15 @@ Notes:
 #include "video/vrender0.h"
 #include "machine/ds1302.h"
 #include "sound/vrender0.h"
+#include "machine/nvram.h"
 
 #define IDLE_LOOP_SPEEDUP
 
-class crystal_state
+class crystal_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, crystal_state(machine)); }
-
-	crystal_state(running_machine &machine) { }
+	crystal_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT32 *  workram;
@@ -152,21 +152,21 @@ public:
 	UINT8     OldPort4;
 	UINT32    *ResetPatch;
 
-	running_device *maincpu;
-	running_device *ds1302;
-	running_device *vr0video;
+	device_t *maincpu;
+	device_t *ds1302;
+	device_t *vr0video;
 };
 
 static void IntReq( running_machine *machine, int num )
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
-	const address_space *space = cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM);
-	UINT32 IntEn = memory_read_dword(space, 0x01800c08);
-	UINT32 IntPend = memory_read_dword(space, 0x01800c0c);
+	crystal_state *state = machine->driver_data<crystal_state>();
+	address_space *space = cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM);
+	UINT32 IntEn = space->read_dword(0x01800c08);
+	UINT32 IntPend = space->read_dword(0x01800c0c);
 	if (IntEn & (1 << num))
 	{
 		IntPend |= (1 << num);
-		memory_write_dword(space, 0x01800c0c, IntPend);
+		space->write_dword(0x01800c0c, IntPend);
 		cpu_set_input_line(state->maincpu, SE3208_INT, ASSERT_LINE);
 	}
 #ifdef IDLE_LOOP_SPEEDUP
@@ -177,10 +177,10 @@ static void IntReq( running_machine *machine, int num )
 
 static READ32_HANDLER( FlipCount_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 #ifdef IDLE_LOOP_SPEEDUP
-	UINT32 IntPend = memory_read_dword(space, 0x01800c0c);
+	UINT32 IntPend = space->read_dword(0x01800c0c);
 	state->FlipCntRead++;
 	if (state->FlipCntRead >= 16 && !IntPend && state->FlipCount != 0)
 		cpu_suspend(state->maincpu, SUSPEND_REASON_SPIN, 1);
@@ -190,7 +190,7 @@ static READ32_HANDLER( FlipCount_r )
 
 static WRITE32_HANDLER( FlipCount_w )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	if (mem_mask & 0x00ff0000)
 	{
@@ -204,7 +204,7 @@ static WRITE32_HANDLER( FlipCount_w )
 
 static READ32_HANDLER( Input_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	if (offset == 0)
 		return input_port_read(space->machine, "P1_P2");
@@ -225,13 +225,13 @@ static READ32_HANDLER( Input_r )
 
 static WRITE32_HANDLER( IntAck_w )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
-	UINT32 IntPend = memory_read_dword(space, 0x01800c0c);
+	crystal_state *state = space->machine->driver_data<crystal_state>();
+	UINT32 IntPend = space->read_dword(0x01800c0c);
 
 	if (mem_mask & 0xff)
 	{
 		IntPend &= ~(1 << (data & 0x1f));
-		memory_write_dword(space, 0x01800c0c, IntPend);
+		space->write_dword(0x01800c0c, IntPend);
 		if (!IntPend)
 			cpu_set_input_line(state->maincpu, SE3208_INT, CLEAR_LINE);
 	}
@@ -241,9 +241,9 @@ static WRITE32_HANDLER( IntAck_w )
 
 static IRQ_CALLBACK( icallback )
 {
-	crystal_state *state = (crystal_state *)device->machine->driver_data;
-	const address_space *space = cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM);
-	UINT32 IntPend = memory_read_dword(space, 0x01800c0c);
+	crystal_state *state = device->machine->driver_data<crystal_state>();
+	address_space *space = cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM);
+	UINT32 IntPend = space->read_dword(0x01800c0c);
 	int i;
 
 	for (i = 0; i < 32; ++i)
@@ -258,18 +258,18 @@ static IRQ_CALLBACK( icallback )
 
 static WRITE32_HANDLER( Banksw_w )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	state->Bank = (data >> 1) & 7;
 	if (state->Bank <= 2)
-		memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "user1") + state->Bank * 0x1000000);
+		memory_set_bankptr(space->machine, "bank1", space->machine->region("user1")->base() + state->Bank * 0x1000000);
 	else
-		memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "user2"));
+		memory_set_bankptr(space->machine, "bank1", space->machine->region("user2")->base());
 }
 
 static TIMER_CALLBACK( Timercb )
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
+	crystal_state *state = machine->driver_data<crystal_state>();
 	int which = (int)(FPTR)ptr;
 	static const int num[] = { 0, 1, 9, 10 };
 
@@ -279,14 +279,14 @@ static TIMER_CALLBACK( Timercb )
 	IntReq(machine, num[which]);
 }
 
-INLINE void Timer_w( const address_space *space, int which, UINT32 data, UINT32 mem_mask )
+INLINE void Timer_w( address_space *space, int which, UINT32 data, UINT32 mem_mask )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	if (((data ^ state->Timerctrl[which]) & 1) && (data & 1))	//Timer activate
 	{
 		int PD = (data >> 8) & 0xff;
-		int TCV = memory_read_dword(space, 0x01801404 + which * 8);
+		int TCV = space->read_dword(0x01801404 + which * 8);
 		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
 
 		if (state->Timerctrl[which] & 2)
@@ -304,7 +304,7 @@ static WRITE32_HANDLER( Timer0_w )
 
 static READ32_HANDLER( Timer0_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->Timerctrl[0];
 }
 
@@ -315,7 +315,7 @@ static WRITE32_HANDLER( Timer1_w )
 
 static READ32_HANDLER( Timer1_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->Timerctrl[1];
 }
 
@@ -326,7 +326,7 @@ static WRITE32_HANDLER( Timer2_w )
 
 static READ32_HANDLER( Timer2_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->Timerctrl[2];
 }
 
@@ -337,19 +337,19 @@ static WRITE32_HANDLER( Timer3_w )
 
 static READ32_HANDLER( Timer3_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->Timerctrl[3];
 }
 
 static READ32_HANDLER( FlashCmd_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	if ((state->FlashCmd & 0xff) == 0xff)
 	{
 		if (state->Bank <= 2)
 		{
-			UINT32 *ptr = (UINT32*)(memory_region(space->machine, "user1") + state->Bank * 0x1000000);
+			UINT32 *ptr = (UINT32*)(space->machine->region("user1")->base() + state->Bank * 0x1000000);
 			return ptr[0];
 		}
 		else
@@ -367,19 +367,19 @@ static READ32_HANDLER( FlashCmd_r )
 
 static WRITE32_HANDLER( FlashCmd_w )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	state->FlashCmd = data;
 }
 
 static READ32_HANDLER( PIO_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->PIO;
 }
 
 static WRITE32_HANDLER( PIO_w )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	UINT32 RST = data & 0x01000000;
 	UINT32 CLK = data & 0x02000000;
 	UINT32 DAT = data & 0x10000000;
@@ -391,51 +391,51 @@ static WRITE32_HANDLER( PIO_w )
 	ds1302_clk_w(state->ds1302, 0, CLK ? 1 : 0);
 
 	if (ds1302_read(state->ds1302, 0))
-		memory_write_dword(space, 0x01802008, memory_read_dword(space, 0x01802008) | 0x10000000);
+		space->write_dword(0x01802008, space->read_dword(0x01802008) | 0x10000000);
 	else
-		memory_write_dword(space, 0x01802008, memory_read_dword(space, 0x01802008) & (~0x10000000));
+		space->write_dword(0x01802008, space->read_dword(0x01802008) & (~0x10000000));
 
 	COMBINE_DATA(&state->PIO);
 }
 
-INLINE void DMA_w( const address_space *space, int which, UINT32 data, UINT32 mem_mask )
+INLINE void DMA_w( address_space *space, int which, UINT32 data, UINT32 mem_mask )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 
 	if (((data ^ state->DMActrl[which]) & (1 << 10)) && (data & (1 << 10)))	//DMAOn
 	{
 		UINT32 CTR = data;
-		UINT32 SRC = memory_read_dword(space, 0x01800804 + which * 0x10);
-		UINT32 DST = memory_read_dword(space, 0x01800808 + which * 0x10);
-		UINT32 CNT = memory_read_dword(space, 0x0180080C + which * 0x10);
+		UINT32 SRC = space->read_dword(0x01800804 + which * 0x10);
+		UINT32 DST = space->read_dword(0x01800808 + which * 0x10);
+		UINT32 CNT = space->read_dword(0x0180080C + which * 0x10);
 		int i;
 
 		if (CTR & 0x2)	//32 bits
 		{
 			for (i = 0; i < CNT; ++i)
 			{
-				UINT32 v = memory_read_dword(space, SRC + i * 4);
-				memory_write_dword(space, DST + i * 4, v);
+				UINT32 v = space->read_dword(SRC + i * 4);
+				space->write_dword(DST + i * 4, v);
 			}
 		}
 		else if (CTR & 0x1)	//16 bits
 		{
 			for (i = 0; i < CNT; ++i)
 			{
-				UINT16 v = memory_read_word(space, SRC + i * 2);
-				memory_write_word(space, DST + i * 2, v);
+				UINT16 v = space->read_word(SRC + i * 2);
+				space->write_word(DST + i * 2, v);
 			}
 		}
 		else	//8 bits
 		{
 			for (i = 0; i < CNT; ++i)
 			{
-				UINT8 v = memory_read_byte(space, SRC + i);
-				memory_write_byte(space, DST + i, v);
+				UINT8 v = space->read_byte(SRC + i);
+				space->write_byte(DST + i, v);
 			}
 		}
 		data &= ~(1 << 10);
-		memory_write_dword(space, 0x0180080C + which * 0x10, 0);
+		space->write_dword(0x0180080C + which * 0x10, 0);
 		IntReq(space->machine, 7 + which);
 	}
 	COMBINE_DATA(&state->DMActrl[which]);
@@ -443,7 +443,7 @@ INLINE void DMA_w( const address_space *space, int which, UINT32 data, UINT32 me
 
 static READ32_HANDLER( DMA0_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->DMActrl[0];
 }
 
@@ -454,7 +454,7 @@ static WRITE32_HANDLER( DMA0_w )
 
 static READ32_HANDLER( DMA1_r )
 {
-	crystal_state *state = (crystal_state *)space->machine->driver_data;
+	crystal_state *state = space->machine->driver_data<crystal_state>();
 	return state->DMActrl[1];
 }
 
@@ -469,7 +469,7 @@ static ADDRESS_MAP_START( crystal_mem, ADDRESS_SPACE_PROGRAM, 32 )
 
 	AM_RANGE(0x01200000, 0x0120000f) AM_READ(Input_r)
 	AM_RANGE(0x01280000, 0x01280003) AM_WRITE(Banksw_w)
-	AM_RANGE(0x01400000, 0x0140ffff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x01400000, 0x0140ffff) AM_RAM AM_SHARE("nvram")
 
 	AM_RANGE(0x01801400, 0x01801403) AM_READWRITE(Timer0_r, Timer0_w)
 	AM_RANGE(0x01801408, 0x0180140b) AM_READWRITE(Timer1_r, Timer1_w)
@@ -522,7 +522,7 @@ loop:
     JMP Loop1
 */
 
-	crystal_state *state = (crystal_state *)machine->driver_data;
+	crystal_state *state = machine->driver_data<crystal_state>();
 
 #if 1
 	static const UINT32 Patch[] =
@@ -550,17 +550,17 @@ loop:
 
 static STATE_POSTLOAD( crystal_banksw_postload )
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
+	crystal_state *state = machine->driver_data<crystal_state>();
 
 	if (state->Bank <= 2)
-		memory_set_bankptr(machine, "bank1", memory_region(machine, "user1") + state->Bank * 0x1000000);
+		memory_set_bankptr(machine, "bank1", machine->region("user1")->base() + state->Bank * 0x1000000);
 	else
-		memory_set_bankptr(machine, "bank1", memory_region(machine, "user2"));
+		memory_set_bankptr(machine, "bank1", machine->region("user2")->base());
 }
 
 static MACHINE_START( crystal )
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
+	crystal_state *state = machine->driver_data<crystal_state>();
 	int i;
 
 	state->maincpu = machine->device("maincpu");
@@ -590,7 +590,7 @@ static MACHINE_START( crystal )
 
 static MACHINE_RESET( crystal )
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
+	crystal_state *state = machine->driver_data<crystal_state>();
 	int i;
 
 	memset(state->sysregs, 0, 0x10000);
@@ -599,7 +599,7 @@ static MACHINE_RESET( crystal )
 	state->IntHigh = 0;
 	cpu_set_irq_callback(machine->device("maincpu"), icallback);
 	state->Bank = 0;
-	memory_set_bankptr(machine, "bank1", memory_region(machine, "user1") + 0);
+	memory_set_bankptr(machine, "bank1", machine->region("user1")->base() + 0);
 	state->FlashCmd = 0xff;
 	state->OldPort4 = 0;
 
@@ -620,21 +620,21 @@ static MACHINE_RESET( crystal )
 	PatchReset(machine);
 }
 
-static UINT16 GetVidReg( const address_space *space, UINT16 reg )
+static UINT16 GetVidReg( address_space *space, UINT16 reg )
 {
-	return memory_read_word(space, 0x03000000 + reg);
+	return space->read_word(0x03000000 + reg);
 }
 
-static void SetVidReg( const address_space *space, UINT16 reg, UINT16 val )
+static void SetVidReg( address_space *space, UINT16 reg, UINT16 val )
 {
-	memory_write_word(space, 0x03000000 + reg, val);
+	space->write_word(0x03000000 + reg, val);
 }
 
 
 static VIDEO_UPDATE( crystal )
 {
-	crystal_state *state = (crystal_state *)screen->machine->driver_data;
-	const address_space *space = cputag_get_address_space(screen->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	crystal_state *state = screen->machine->driver_data<crystal_state>();
+	address_space *space = cputag_get_address_space(screen->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	int DoFlip;
 
 	UINT32 B0 = 0x0;
@@ -694,8 +694,8 @@ static VIDEO_UPDATE( crystal )
 
 static VIDEO_EOF(crystal)
 {
-	crystal_state *state = (crystal_state *)machine->driver_data;
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	crystal_state *state = machine->driver_data<crystal_state>();
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	UINT16 head, tail;
 	int DoFlip = 0;
 
@@ -703,7 +703,7 @@ static VIDEO_EOF(crystal)
 	tail = GetVidReg(space, 0x80);
 	while ((head & 0x7ff) != (tail & 0x7ff))
 	{
-		UINT16 Packet0 = memory_read_word(space, 0x03800000 + head * 64);
+		UINT16 Packet0 = space->read_word(0x03800000 + head * 64);
 		if (Packet0 & 0x81)
 			DoFlip = 1;
 		head++;
@@ -815,55 +815,52 @@ static const vr0video_interface vr0video_config =
 	"maincpu"
 };
 
-static MACHINE_DRIVER_START( crystal )
+static MACHINE_CONFIG_START( crystal, crystal_state )
 
-	MDRV_DRIVER_DATA(crystal_state)
+	MCFG_CPU_ADD("maincpu", SE3208, 43000000)
+	MCFG_CPU_PROGRAM_MAP(crystal_mem)
+	MCFG_CPU_VBLANK_INT("screen", crystal_interrupt)
 
-	MDRV_CPU_ADD("maincpu", SE3208, 43000000)
-	MDRV_CPU_PROGRAM_MAP(crystal_mem)
-	MDRV_CPU_VBLANK_INT("screen", crystal_interrupt)
+	MCFG_MACHINE_START(crystal)
+	MCFG_MACHINE_RESET(crystal)
 
-	MDRV_MACHINE_START(crystal)
-	MDRV_MACHINE_RESET(crystal)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(320, 240)
+	MCFG_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(320, 240)
-	MDRV_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
+	MCFG_VIDEO_UPDATE(crystal)
+	MCFG_VIDEO_EOF(crystal)
 
-	MDRV_VIDEO_UPDATE(crystal)
-	MDRV_VIDEO_EOF(crystal)
+	MCFG_VIDEO_VRENDER0_ADD("vr0", vr0video_config)
 
-	MDRV_VIDEO_VRENDER0_ADD("vr0", vr0video_config)
+	MCFG_PALETTE_INIT(RRRRR_GGGGGG_BBBBB)
+	MCFG_PALETTE_LENGTH(65536)
 
-	MDRV_PALETTE_INIT(RRRRR_GGGGGG_BBBBB)
-	MDRV_PALETTE_LENGTH(65536)
+	MCFG_DS1302_ADD("rtc")
 
-	MDRV_DS1302_ADD("rtc")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
-
-	MDRV_SOUND_ADD("vrender", VRENDER0, 0)
-	MDRV_SOUND_CONFIG(vr0_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("vrender", VRENDER0, 0)
+	MCFG_SOUND_CONFIG(vr0_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 /*
     Top blade screen is 32 pixels wider
 */
-static MACHINE_DRIVER_START( topbladv )
-	MDRV_IMPORT_FROM(crystal)
+static MACHINE_CONFIG_DERIVED( topbladv, crystal )
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_SIZE(320+32, 240)
-	MDRV_SCREEN_VISIBLE_AREA(0, 319+32, 0, 239)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_SIZE(320+32, 240)
+	MCFG_SCREEN_VISIBLE_AREA(0, 319+32, 0, 239)
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 ROM_START( crysbios )
 	ROM_REGION( 0x20000, "maincpu", 0 ) // bios
@@ -931,7 +928,7 @@ ROM_END
 
 static DRIVER_INIT(crysking)
 {
-	UINT16 *Rom = (UINT16*) memory_region(machine, "user1");
+	UINT16 *Rom = (UINT16*) machine->region("user1")->base();
 
 	//patch the data feed by the protection
 
@@ -950,7 +947,7 @@ static DRIVER_INIT(crysking)
 
 static DRIVER_INIT(evosocc)
 {
-	UINT16 *Rom = (UINT16*) memory_region(machine, "user1");
+	UINT16 *Rom = (UINT16*) machine->region("user1")->base();
 	Rom += 0x1000000 * 2 / 2;
 
 	Rom[WORD_XOR_LE(0x97388E/2)] = 0x90FC;	//PUSH R2..R7
@@ -968,7 +965,7 @@ static DRIVER_INIT(evosocc)
 
 static DRIVER_INIT(topbladv)
 {
-	UINT16 *Rom = (UINT16*) memory_region(machine, "user1");
+	UINT16 *Rom = (UINT16*) machine->region("user1")->base();
 
 	Rom[WORD_XOR_LE(0x12d7a/2)] = 0x90FC;	//PUSH R7-R6-R5-R4-R3-R2
 	Rom[WORD_XOR_LE(0x12d7c/2)] = 0x9001;	//PUSH R0
@@ -986,7 +983,7 @@ static DRIVER_INIT(topbladv)
 
 static DRIVER_INIT(officeye)
 {
-	UINT16 *Rom = (UINT16*) memory_region(machine, "user1");
+	UINT16 *Rom = (UINT16*) machine->region("user1")->base();
 
 	Rom[WORD_XOR_LE(0x9c9e/2)] = 0x901C;	//PUSH R4-R3-R2
 	Rom[WORD_XOR_LE(0x9ca0/2)] = 0x9001;	//PUSH R0
