@@ -292,7 +292,7 @@ static ADDRESS_MAP_START( darkhors_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x580004, 0x580007) AM_READ_PORT("580004")
 	AM_RANGE(0x580008, 0x58000b) AM_READ(darkhors_input_sel_r)
 	AM_RANGE(0x58000c, 0x58000f) AM_WRITE(darkhors_input_sel_w)
-	AM_RANGE(0x580084, 0x580087) AM_DEVREADWRITE8( "oki", okim6295_r, okim6295_w, 0xff000000)
+	AM_RANGE(0x580084, 0x580087) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0xff000000)
 	AM_RANGE(0x580200, 0x580203) AM_READNOP
 	AM_RANGE(0x580400, 0x580403) AM_READ_PORT("580400")
 	AM_RANGE(0x580420, 0x580423) AM_READ_PORT("580420")
@@ -621,33 +621,33 @@ static INTERRUPT_GEN( darkhors )
 	}
 }
 
-static MACHINE_DRIVER_START( darkhors )
-	MDRV_CPU_ADD("maincpu", M68EC020, 12000000) // 36MHz/3 ??
-	MDRV_CPU_PROGRAM_MAP(darkhors_map)
-	MDRV_CPU_VBLANK_INT_HACK(darkhors,3)
+static MACHINE_CONFIG_START( darkhors, driver_device )
+	MCFG_CPU_ADD("maincpu", M68EC020, 12000000) // 36MHz/3 ??
+	MCFG_CPU_PROGRAM_MAP(darkhors_map)
+	MCFG_CPU_VBLANK_INT_HACK(darkhors,3)
 
-	MDRV_EEPROM_ADD("eeprom", eeprom_intf)
+	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(0x190, 0x100)
-	MDRV_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(0x190, 0x100)
+	MCFG_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
 
-	MDRV_GFXDECODE(darkhors)
-	MDRV_PALETTE_LENGTH(0x10000)
+	MCFG_GFXDECODE(darkhors)
+	MCFG_PALETTE_LENGTH(0x10000)
 
-	MDRV_VIDEO_START(darkhors)
-	MDRV_VIDEO_UPDATE(darkhors)
+	MCFG_VIDEO_START(darkhors)
+	MCFG_VIDEO_UPDATE(darkhors)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_OKIM6295_ADD("oki", 528000, OKIM6295_PIN7_HIGH) // clock frequency & pin 7 not verified
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki", 528000, OKIM6295_PIN7_HIGH) // clock frequency & pin 7 not verified
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
 
@@ -671,27 +671,27 @@ static VIDEO_UPDATE(jclub2)
 	return 0;
 }
 
-static MACHINE_DRIVER_START( jclub2 )
-	MDRV_CPU_ADD("maincpu", M68EC020, 12000000)
-	MDRV_CPU_PROGRAM_MAP(jclub2_map)
-	MDRV_CPU_VBLANK_INT_HACK(darkhors,3)
+static MACHINE_CONFIG_START( jclub2, driver_device )
+	MCFG_CPU_ADD("maincpu", M68EC020, 12000000)
+	MCFG_CPU_PROGRAM_MAP(jclub2_map)
+	MCFG_CPU_VBLANK_INT_HACK(darkhors,3)
 
-	MDRV_EEPROM_ADD("eeprom", eeprom_intf)
+	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(0x190, 0x100)
-	MDRV_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(0x190, 0x100)
+	MCFG_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
 
-	MDRV_GFXDECODE(jclub2)
-	MDRV_PALETTE_LENGTH(0x10000)
+	MCFG_GFXDECODE(jclub2)
+	MCFG_PALETTE_LENGTH(0x10000)
 
-	MDRV_VIDEO_START(jclub2)
-	MDRV_VIDEO_UPDATE(jclub2)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(jclub2)
+	MCFG_VIDEO_UPDATE(jclub2)
+MACHINE_CONFIG_END
 
 static ADDRESS_MAP_START( st0016_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
@@ -727,39 +727,39 @@ static VIDEO_UPDATE(jclub2o)
 	return 0;
 }
 
-static MACHINE_DRIVER_START( jclub2o )
-	MDRV_CPU_ADD("st0016",Z80,8000000)
-	MDRV_CPU_PROGRAM_MAP(st0016_mem)
-	MDRV_CPU_IO_MAP(st0016_io)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+static MACHINE_CONFIG_START( jclub2o, driver_device )
+	MCFG_CPU_ADD("st0016",Z80,8000000)
+	MCFG_CPU_PROGRAM_MAP(st0016_mem)
+	MCFG_CPU_IO_MAP(st0016_io)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("maincpu", M68EC020, 12000000)
-	MDRV_CPU_PROGRAM_MAP(jclub2o_map)
-	//MDRV_CPU_VBLANK_INT_HACK(darkhors,3)
+	MCFG_CPU_ADD("maincpu", M68EC020, 12000000)
+	MCFG_CPU_PROGRAM_MAP(jclub2o_map)
+	//MCFG_CPU_VBLANK_INT_HACK(darkhors,3)
 
-	MDRV_EEPROM_ADD("eeprom", eeprom_intf)
+	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(0x190, 0x100)
-	MDRV_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(0x190, 0x100)
+	MCFG_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
 
-	MDRV_GFXDECODE(jclub2)
-	MDRV_PALETTE_LENGTH(0x10000)
+	MCFG_GFXDECODE(jclub2)
+	MCFG_PALETTE_LENGTH(0x10000)
 
-	MDRV_VIDEO_START(jclub2o)
-	MDRV_VIDEO_UPDATE(jclub2o)
+	MCFG_VIDEO_START(jclub2o)
+	MCFG_VIDEO_UPDATE(jclub2o)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("stsnd", ST0016, 0)
-	MDRV_SOUND_CONFIG(st0016_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("stsnd", ST0016, 0)
+	MCFG_SOUND_CONFIG(st0016_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
@@ -920,8 +920,8 @@ ROM_END
 
 static DRIVER_INIT( darkhors )
 {
-	UINT32 *rom    = (UINT32 *) memory_region(machine, "maincpu");
-	UINT8  *eeprom = (UINT8 *)  memory_region(machine, "eeprom");
+	UINT32 *rom    = (UINT32 *) machine->region("maincpu")->base();
+	UINT8  *eeprom = (UINT8 *)  machine->region("eeprom")->base();
 	int i;
 
 #if 1
