@@ -19,20 +19,8 @@
 #include "sound/2203intf.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
+#include "includes/darkseal.h"
 
-VIDEO_START( darkseal );
-VIDEO_UPDATE( darkseal );
-
-WRITE16_HANDLER( darkseal_pf1_data_w );
-WRITE16_HANDLER( darkseal_pf2_data_w );
-WRITE16_HANDLER( darkseal_pf3_data_w );
-WRITE16_HANDLER( darkseal_pf3b_data_w );
-WRITE16_HANDLER( darkseal_control_0_w );
-WRITE16_HANDLER( darkseal_control_1_w );
-WRITE16_HANDLER( darkseal_palette_24bit_rg_w );
-WRITE16_HANDLER( darkseal_palette_24bit_b_w );
-extern UINT16 *darkseal_pf12_row, *darkseal_pf34_row;
-extern UINT16 *darkseal_pf1_data,*darkseal_pf2_data,*darkseal_pf3_data;
 static UINT16 *darkseal_ram;
 
 /******************************************************************************/
@@ -94,8 +82,8 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x000000, 0x00ffff) AM_ROM
 	AM_RANGE(0x100000, 0x100001) AM_DEVREADWRITE("ym1", ym2203_r, ym2203_w)
 	AM_RANGE(0x110000, 0x110001) AM_DEVREADWRITE("ym2", ym2151_r, ym2151_w)
-	AM_RANGE(0x120000, 0x120001) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)
-	AM_RANGE(0x130000, 0x130001) AM_DEVREADWRITE("oki2", okim6295_r, okim6295_w)
+	AM_RANGE(0x120000, 0x120001) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)
+	AM_RANGE(0x130000, 0x130001) AM_DEVREADWRITE_MODERN("oki2", okim6295_device, read, write)
 	AM_RANGE(0x140000, 0x140001) AM_READ(soundlatch_r)
 	AM_RANGE(0x1f0000, 0x1f1fff) AM_RAMBANK("bank8")
 	AM_RANGE(0x1fec00, 0x1fec01) AM_WRITE(h6280_timer_w)
@@ -229,7 +217,7 @@ GFXDECODE_END
 
 /******************************************************************************/
 
-static void sound_irq(running_device *device, int state)
+static void sound_irq(device_t *device, int state)
 {
 	cputag_set_input_line(device->machine, "audiocpu", 1, state); /* IRQ 2 */
 }
@@ -239,49 +227,49 @@ static const ym2151_interface ym2151_config =
 	sound_irq
 };
 
-static MACHINE_DRIVER_START( darkseal )
+static MACHINE_CONFIG_START( darkseal, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000,12000000) /* Custom chip 59 */
-	MDRV_CPU_PROGRAM_MAP(darkseal_map)
-	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)/* VBL */
+	MCFG_CPU_ADD("maincpu", M68000,12000000) /* Custom chip 59 */
+	MCFG_CPU_PROGRAM_MAP(darkseal_map)
+	MCFG_CPU_VBLANK_INT("screen", irq6_line_hold)/* VBL */
 
-	MDRV_CPU_ADD("audiocpu", H6280, 32220000/4) /* Custom chip 45, Audio section crystal is 32.220 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_ADD("audiocpu", H6280, 32220000/4) /* Custom chip 45, Audio section crystal is 32.220 MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(58)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(58)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(darkseal)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_GFXDECODE(darkseal)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(darkseal)
-	MDRV_VIDEO_UPDATE(darkseal)
+	MCFG_VIDEO_START(darkseal)
+	MCFG_VIDEO_UPDATE(darkseal)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ym1", YM2203, 32220000/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
+	MCFG_SOUND_ADD("ym1", YM2203, 32220000/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.45)
 
-	MDRV_SOUND_ADD("ym2", YM2151, 32220000/9)
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(0, "mono", 0.55)
-	MDRV_SOUND_ROUTE(1, "mono", 0.55)
+	MCFG_SOUND_ADD("ym2", YM2151, 32220000/9)
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(0, "mono", 0.55)
+	MCFG_SOUND_ROUTE(1, "mono", 0.55)
 
-	MDRV_OKIM6295_ADD("oki1", 32220000/32, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_OKIM6295_ADD("oki1", 32220000/32, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_OKIM6295_ADD("oki2", 32220000/16, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki2", 32220000/16, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+MACHINE_CONFIG_END
 
 /******************************************************************************/
 
@@ -447,7 +435,7 @@ ROM_END
 
 static DRIVER_INIT( darkseal )
 {
-	UINT8 *RAM = memory_region(machine, "maincpu");
+	UINT8 *RAM = machine->region("maincpu")->base();
 	int i;
 
 	for (i=0x00000; i<0x80000; i++)
