@@ -25,12 +25,11 @@ Protection TODO:
 #include "sound/okim6295.h"
 #include "video/deco16ic.h"
 
-class dblewing_state
+class dblewing_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, dblewing_state(machine)); }
-
-	dblewing_state(running_machine &machine) { }
+	dblewing_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  pf1_rowscroll;
@@ -66,9 +65,9 @@ public:
 	UINT8 sound_irq;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *deco16ic;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *deco16ic;
 };
 
 /*
@@ -103,7 +102,7 @@ x = xpos
 
 static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
-	dblewing_state *state = (dblewing_state *)machine->driver_data;
+	dblewing_state *state = machine->driver_data<dblewing_state>();
 	UINT16 *spriteram = state->spriteram;
 	int offs;
 
@@ -193,7 +192,7 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 
 static VIDEO_UPDATE(dblewing)
 {
-	dblewing_state *state = (dblewing_state *)screen->machine->driver_data;
+	dblewing_state *state = screen->machine->driver_data<dblewing_state>();
 	UINT16 flip = deco16ic_pf12_control_r(state->deco16ic, 0, 0xffff);
 
 	flip_screen_set(screen->machine, BIT(flip, 7));
@@ -220,7 +219,7 @@ static VIDEO_UPDATE(dblewing)
 */
 static READ16_HANDLER ( dblewing_prot_r )
 {
-	dblewing_state *state = (dblewing_state *)space->machine->driver_data;
+	dblewing_state *state = space->machine->driver_data<dblewing_state>();
 
 	switch (offset * 2)
 	{
@@ -279,12 +278,12 @@ static READ16_HANDLER ( dblewing_prot_r )
 
 	mame_printf_debug("dblewing prot r %08x, %04x, %04x\n", cpu_get_pc(space->cpu), offset * 2, mem_mask);
 
-	return 0;//mame_rand(space->machine);
+	return 0;//space->machine->rand();
 }
 
 static WRITE16_HANDLER( dblewing_prot_w )
 {
-	dblewing_state *state = (dblewing_state *)space->machine->driver_data;
+	dblewing_state *state = space->machine->driver_data<dblewing_state>();
 
 //  if (offset * 2 != 0x380)
 //  printf("dblewing prot w %08x, %04x, %04x %04x\n", cpu_get_pc(space->cpu), offset * 2, mem_mask, data);
@@ -432,7 +431,7 @@ ADDRESS_MAP_END
 
 static READ8_HANDLER(irq_latch_r)
 {
-	dblewing_state *state = (dblewing_state *)space->machine->driver_data;
+	dblewing_state *state = space->machine->driver_data<dblewing_state>();
 
 	/* bit 1 of dblewing_sound_irq specifies IRQ command writes */
 	state->sound_irq &= ~0x02;
@@ -444,10 +443,10 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0xa000, 0xa001) AM_DEVREADWRITE("ymsnd", ym2151_status_port_r,ym2151_w)
-	AM_RANGE(0xb000, 0xb000) AM_DEVREADWRITE("oki", okim6295_r,okim6295_w)
+	AM_RANGE(0xb000, 0xb000) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
 	AM_RANGE(0xc000, 0xc000) AM_READ(soundlatch_r)
 	AM_RANGE(0xd000, 0xd000) AM_READ(irq_latch_r) //timing? sound latch?
-	AM_RANGE(0xf000, 0xf000) AM_DEVREADWRITE("oki", okim6295_r,okim6295_w)
+	AM_RANGE(0xf000, 0xf000) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_io, ADDRESS_SPACE_IO, 8 )
@@ -622,9 +621,9 @@ static INPUT_PORTS_START( dblewing )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static void sound_irq( running_device *device, int state )
+static void sound_irq( device_t *device, int state )
 {
-	dblewing_state *driver_state = (dblewing_state *)device->machine->driver_data;
+	dblewing_state *driver_state = device->machine->driver_data<dblewing_state>();
 
 	/* bit 0 of dblewing_sound_irq specifies IRQ from sound chip */
 	if (state)
@@ -659,7 +658,7 @@ static const deco16ic_interface dblewing_deco16ic_intf =
 
 static MACHINE_START( dblewing )
 {
-	dblewing_state *state = (dblewing_state *)machine->driver_data;
+	dblewing_state *state = machine->driver_data<dblewing_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = machine->device("audiocpu");
@@ -698,7 +697,7 @@ static MACHINE_START( dblewing )
 
 static MACHINE_RESET( dblewing )
 {
-	dblewing_state *state = (dblewing_state *)machine->driver_data;
+	dblewing_state *state = machine->driver_data<dblewing_state>();
 
 	state->_008_data = 0;
 	state->_104_data = 0;
@@ -731,50 +730,47 @@ static MACHINE_RESET( dblewing )
 	state->sound_irq = 0;
 }
 
-static MACHINE_DRIVER_START( dblewing )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(dblewing_state)
+static MACHINE_CONFIG_START( dblewing, dblewing_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 14000000)	/* DE102 */
-	MDRV_CPU_PROGRAM_MAP(dblewing_map)
-	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 14000000)	/* DE102 */
+	MCFG_CPU_PROGRAM_MAP(dblewing_map)
+	MCFG_CPU_VBLANK_INT("screen", irq6_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_io)
+	MCFG_CPU_ADD("audiocpu", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_io)
 
-	MDRV_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(HZ(6000))
 
-	MDRV_MACHINE_START(dblewing)
-	MDRV_MACHINE_RESET(dblewing)
+	MCFG_MACHINE_START(dblewing)
+	MCFG_MACHINE_RESET(dblewing)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(58)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(58)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
 
-	MDRV_PALETTE_LENGTH(4096)
-	MDRV_GFXDECODE(dblewing)
+	MCFG_PALETTE_LENGTH(4096)
+	MCFG_GFXDECODE(dblewing)
 
-	MDRV_VIDEO_UPDATE(dblewing)
+	MCFG_VIDEO_UPDATE(dblewing)
 
-	MDRV_DECO16IC_ADD("deco_custom", dblewing_deco16ic_intf)
+	MCFG_DECO16IC_ADD("deco_custom", dblewing_deco16ic_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 32220000/9)
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+	MCFG_SOUND_ADD("ymsnd", YM2151, 32220000/9)
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
-	MDRV_OKIM6295_ADD("oki", 32220000/32, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki", 32220000/32, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+MACHINE_CONFIG_END
 
 
 /*
