@@ -50,7 +50,7 @@ static WRITE16_HANDLER( drgnmst_coin_w )
 
 static WRITE16_HANDLER( drgnmst_snd_command_w )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -61,7 +61,7 @@ static WRITE16_HANDLER( drgnmst_snd_command_w )
 
 static WRITE16_HANDLER( drgnmst_snd_flag_w )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 
 	/* Enables the following 68K write operation to latch through to the PIC */
 	if (ACCESSING_BITS_0_7)
@@ -71,19 +71,19 @@ static WRITE16_HANDLER( drgnmst_snd_flag_w )
 
 static READ8_HANDLER( pic16c5x_port0_r )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	return state->pic16c5x_port0;
 }
 
 static READ8_HANDLER( drgnmst_snd_command_r )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	int data = 0;
 
 	switch (state->oki_control & 0x1f)
 	{
-		case 0x12:	data = (okim6295_r(state->oki_2, 0) & 0x0f); break;
-		case 0x16:	data = (okim6295_r(state->oki_1, 0) & 0x0f); break;
+		case 0x12:	data = (state->oki_2->read(*space, 0) & 0x0f); break;
+		case 0x16:	data = (state->oki_1->read(*space, 0) & 0x0f); break;
 		case 0x0b:
 		case 0x0f:	data = state->snd_command; break;
 		default:	break;
@@ -94,7 +94,7 @@ static READ8_HANDLER( drgnmst_snd_command_r )
 
 static READ8_HANDLER( drgnmst_snd_flag_r )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	if (state->snd_flag)
 	{
 		state->snd_flag = 0;
@@ -106,7 +106,7 @@ static READ8_HANDLER( drgnmst_snd_flag_r )
 
 static WRITE8_HANDLER( drgnmst_pcm_banksel_w )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	/*  This is a 4 bit port.
         Each pair of bits is used in part of the OKI PCM ROM bank selectors.
         See the Port 2 write handler below (drgnmst_snd_control_w) for details.
@@ -117,7 +117,7 @@ static WRITE8_HANDLER( drgnmst_pcm_banksel_w )
 
 static WRITE8_HANDLER( drgnmst_oki_w )
 {
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	state->oki_command = data;
 }
 
@@ -146,7 +146,7 @@ static WRITE8_HANDLER( drgnmst_snd_control_w )
         The OKI0 banks are pre-configured below in the driver init.
     */
 
-	drgnmst_state *state = (drgnmst_state *)space->machine->driver_data;
+	drgnmst_state *state = space->machine->driver_data<drgnmst_state>();
 	int oki_new_bank;
 	state->oki_control = data;
 
@@ -172,12 +172,12 @@ static WRITE8_HANDLER( drgnmst_snd_control_w )
 		case 0x11:
 //                  logerror("Writing %02x to OKI1", state->oki_command);
 //                  logerror(", PortC=%02x, Code=%02x, Bank0=%01x, Bank1=%01x\n", state->oki_control, state->snd_command, state->oki0_bank, state->oki1_bank);
-					okim6295_w(state->oki_2, 0, state->oki_command);
+					state->oki_2->write(*space, 0, state->oki_command);
 					break;
 		case 0x15:
 //                  logerror("Writing %02x to OKI0", state->oki_command);
 //                  logerror(", PortC=%02x, Code=%02x, Bank0=%01x, Bank1=%01x\n", state->oki_control, state->snd_command, state->oki0_bank, state->oki1_bank);
-					okim6295_w(state->oki_1, 0, state->oki_command);
+					state->oki_1->write(*space, 0, state->oki_command);
 					break;
 		default:	break;
 	}
@@ -379,7 +379,7 @@ GFXDECODE_END
 
 static MACHINE_START( drgnmst )
 {
-	drgnmst_state *state = (drgnmst_state *)machine->driver_data;
+	drgnmst_state *state = machine->driver_data<drgnmst_state>();
 
 	state_save_register_global(machine, state->snd_flag);
 	state_save_register_global(machine, state->snd_command);
@@ -392,7 +392,7 @@ static MACHINE_START( drgnmst )
 
 static MACHINE_RESET( drgnmst )
 {
-	drgnmst_state *state = (drgnmst_state *)machine->driver_data;
+	drgnmst_state *state = machine->driver_data<drgnmst_state>();
 
 	state->snd_flag = 0;
 	state->snd_command = 0;
@@ -403,45 +403,44 @@ static MACHINE_RESET( drgnmst )
 	state->oki0_bank = 0;
 }
 
-static MACHINE_DRIVER_START( drgnmst )
-	MDRV_DRIVER_DATA(drgnmst_state)
+static MACHINE_CONFIG_START( drgnmst, drgnmst_state )
 
-	MDRV_CPU_ADD("maincpu", M68000, 12000000) /* Confirmed */
-	MDRV_CPU_PROGRAM_MAP(drgnmst_main_map)
-	MDRV_CPU_VBLANK_INT("screen", irq2_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 12000000) /* Confirmed */
+	MCFG_CPU_PROGRAM_MAP(drgnmst_main_map)
+	MCFG_CPU_VBLANK_INT("screen", irq2_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", PIC16C55, 32000000/8)	/* Confirmed */
+	MCFG_CPU_ADD("audiocpu", PIC16C55, 32000000/8)	/* Confirmed */
 	/* Program and Data Maps are internal to the MCU */
-	MDRV_CPU_IO_MAP(drgnmst_sound_io_map)
+	MCFG_CPU_IO_MAP(drgnmst_sound_io_map)
 
-	MDRV_MACHINE_START(drgnmst)
-	MDRV_MACHINE_RESET(drgnmst)
+	MCFG_MACHINE_START(drgnmst)
+	MCFG_MACHINE_RESET(drgnmst)
 
-	MDRV_GFXDECODE(drgnmst)
+	MCFG_GFXDECODE(drgnmst)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(8*8, 56*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(8*8, 56*8-1, 2*8, 30*8-1)
 
-	MDRV_PALETTE_LENGTH(0x2000)
+	MCFG_PALETTE_LENGTH(0x2000)
 
-	MDRV_VIDEO_START(drgnmst)
-	MDRV_VIDEO_UPDATE(drgnmst)
+	MCFG_VIDEO_START(drgnmst)
+	MCFG_VIDEO_UPDATE(drgnmst)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_OKIM6295_ADD("oki1", 32000000/32, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
+	MCFG_OKIM6295_ADD("oki1", 32000000/32, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
 
-	MDRV_OKIM6295_ADD("oki2", 32000000/32, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki2", 32000000/32, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.50)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.50)
+MACHINE_CONFIG_END
 
 
 ROM_START( drgnmst )
@@ -496,9 +495,9 @@ static UINT8 drgnmst_asciitohex( UINT8 data )
 
 static DRIVER_INIT( drgnmst )
 {
-	UINT8 *drgnmst_PICROM_HEX = memory_region(machine, "user1");
-	UINT16 *drgnmst_PICROM = (UINT16 *)memory_region(machine, "audiocpu");
-	UINT8 *drgnmst_PCM = memory_region(machine, "oki1");
+	UINT8 *drgnmst_PICROM_HEX = machine->region("user1")->base();
+	UINT16 *drgnmst_PICROM = (UINT16 *)machine->region("audiocpu")->base();
+	UINT8 *drgnmst_PCM = machine->region("oki1")->base();
 	INT32   offs, data;
 	UINT16  src_pos = 0;
 	UINT16  dst_pos = 0;
