@@ -20,27 +20,27 @@
 
 static READ8_HANDLER( from_snd_r )
 {
-	flstory_state *state = (flstory_state *)space->machine->driver_data;
+	flstory_state *state = space->machine->driver_data<flstory_state>();
 	state->snd_flag = 0;
 	return state->snd_data;
 }
 
 static READ8_HANDLER( snd_flag_r )
 {
-	flstory_state *state = (flstory_state *)space->machine->driver_data;
+	flstory_state *state = space->machine->driver_data<flstory_state>();
 	return state->snd_flag | 0xfd;
 }
 
 static WRITE8_HANDLER( to_main_w )
 {
-	flstory_state *state = (flstory_state *)space->machine->driver_data;
+	flstory_state *state = space->machine->driver_data<flstory_state>();
 	state->snd_data = data;
 	state->snd_flag = 2;
 }
 
 static TIMER_CALLBACK( nmi_callback )
 {
-	flstory_state *state = (flstory_state *)machine->driver_data;
+	flstory_state *state = machine->driver_data<flstory_state>();
 	if (state->sound_nmi_enable)
 		cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 	else
@@ -56,13 +56,13 @@ static WRITE8_HANDLER( sound_command_w )
 
 static WRITE8_HANDLER( nmi_disable_w )
 {
-	flstory_state *state = (flstory_state *)space->machine->driver_data;
+	flstory_state *state = space->machine->driver_data<flstory_state>();
 	state->sound_nmi_enable = 0;
 }
 
 static WRITE8_HANDLER( nmi_enable_w )
 {
-	flstory_state *state = (flstory_state *)space->machine->driver_data;
+	flstory_state *state = space->machine->driver_data<flstory_state>();
 	state->sound_nmi_enable = 1;
 	if (state->pending_nmi)
 	{
@@ -125,8 +125,8 @@ ADDRESS_MAP_END
 
 static CUSTOM_INPUT( victnine_mcu_status_bit01_r )
 {
-	flstory_state *state = (flstory_state *)field->port->machine->driver_data;
-	const address_space *space = cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM);
+	flstory_state *state = field->port->machine->driver_data<flstory_state>();
+	address_space *space = cpu_get_address_space(state->maincpu, ADDRESS_SPACE_PROGRAM);
 
 	return (victnine_mcu_status_r(space, 0) & 3);
 }
@@ -158,10 +158,220 @@ static ADDRESS_MAP_START( victnine_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_MEMBER(flstory_state, workram) /* work RAM */
 ADDRESS_MAP_END
 
+static UINT8 mcu_cmd,mcu_counter,mcu_b4_cmd;
+static UINT8 mcu_param;
+static UINT8 mcu_b2_res,mcu_b1_res,mcu_bb_res,mcu_b5_res,mcu_b6_res;
+
+static READ8_HANDLER( rumba_mcu_r )
+{
+	//printf("PC=%04x R %02x\n",cpu_get_pc(space->cpu),mcu_cmd);
+
+	if((mcu_cmd & 0xf0) == 0x00) // end packet cmd, value returned is meaningless (probably used for main <-> mcu comms syncronization)
+		return 0;
+
+	switch(mcu_cmd)
+	{
+		case 0x73: return 0xa4; //initial MCU check
+		case 0x33: return mcu_b2_res; //0xb2 result
+		case 0x31: return mcu_b1_res; //0xb1 result
+
+		case 0x35: mcu_b5_res = 1; mcu_b6_res = 1; return 0;
+		case 0x36: return mcu_b4_cmd; //0xb4 command, extra protection for lives (first play only), otherwise game gives one extra life at start-up (!)
+		case 0x37: return mcu_b5_res; //0xb4 / 0xb5 / 0xb6 result y value
+		case 0x38: return mcu_b6_res; //x value
+
+		case 0x3b: return mcu_bb_res; //0xbb result
+		case 0x40: return 0;
+		case 0x41: return 0;
+		case 0x42:
+		{
+			/* TODO: subtle behaviour for transitioning from level 16 to level 17 (loop clear?). Command is:
+            0xc0 -> param -> 0xc1 -> param -> ... 0xc7 -> param -> 0x0e (end of packet) then reads at 0x40 -> 0x41 and 0x42
+
+            Params written doesn't make any sense, they are copies from RAM addresses at 0xe450-7 and they looks like ... garbage.
+            It's possible that all of this it just increments by one an internal RAM address in the MCU and then it sends a six when this counter
+            has bits 0-3 == 0 (BCD operation?), but then the question is ... how it determines game over?
+
+            According to a PCB test, game should roll back to level 1 layout but level counter should say "17" instead of current "11". Some of these ports also appears to control
+            game-play speed and who is playing between player 1 and 2.
+            */
+			//static UINT8 level_val;
+
+			//level_val = space->read_byte(0xe247);
+
+			//popmessage("%02x",level_val);
+
+			//if((level_val & 0x0f) == 0x00)
+			//  return 0; //6
+
+			return 0;
+		}
+		//case 0x42: return 0x06;
+		//default:  printf("PC=%04x R %02x\n",cpu_get_pc(space->cpu),mcu_cmd); break;
+	}
+
+	return 0;
+}
+
+static WRITE8_HANDLER( rumba_mcu_w )
+{
+	//if((mcu_cmd & 0xf0) == 0xc0)
+	//  printf("%02x ",data);
+
+	//if(mcu_cmd == 0x42)
+	//  printf("\n");
+
+	if(mcu_param)
+	{
+		mcu_param = 0; // clear param
+
+		//printf("%02x %02x\n",mcu_cmd,data);
+
+		switch(mcu_cmd)
+		{
+			case 0xb0: // counter, used by command 0xb1 (and something else?
+			{
+				/*
+                sends 0xb0 -> param then 0xb1 -> param -> 0x01 (end of cmd packet?) finally 0x31 for reply
+                */
+
+				mcu_counter = data;
+
+				break;
+			}
+			case 0xb1: // player death sequence, controls X position
+			{
+				mcu_b1_res = data;
+
+				/* TODO: this is pretty hard to simulate ... */
+				if(mcu_counter >= 0x10)
+					mcu_b1_res++; // left
+				else if(mcu_counter >= 0x08)
+					mcu_b1_res--; // right
+				else
+					mcu_b1_res++; // left again
+
+				break;
+			}
+			case 0xb2: // player sprite hook-up param when he throws the wheel
+			{
+				/*
+                sends 0xb2 -> param -> 0x02 (end of cmd packet?) then 0x33 for reply
+                */
+
+				switch(data)
+				{
+					case 1: mcu_b2_res = 0xaa; break; //left
+					case 2: mcu_b2_res = 0xaa; break; //right
+					case 4: mcu_b2_res = 0xab; break; //down
+					case 8: mcu_b2_res = 0xa9; break; //up
+				}
+				break;
+			}
+			case 0xbb: // when you start a level, lives
+			{
+				/*
+                sends 0xbb -> param -> 0x04 (end of cmd packet?) then 0x3b for reply
+                */
+
+				mcu_bb_res = data;
+				//printf("PC=%04x W %02x -> %02x\n",cpu_get_pc(space->cpu),mcu_cmd,data);
+				break;
+			}
+			case 0xb4: // when the bird touches the top / bottom / left / right of the screen, for correct repositioning
+			{
+				mcu_b4_cmd = data;
+
+				//popmessage("%02x",mcu_b4_cmd);
+
+				/*
+                sends 0xb4 -> param -> 0xb5 -> param (bird X coord) -> 0xb6 -> param (bird Y coord) ->
+                */
+
+				#if 0
+				switch(data)
+				{
+					case 1: break; // from up to down
+					case 2: break; // from left to right
+					case 3: break; // from right to left
+					case 4: break; // from down to up
+				}
+				#endif
+				break;
+			}
+			case 0xb5: // bird X coord
+			{
+				/* TODO: values might be off by one */
+				mcu_b5_res = data;
+
+				if(mcu_b4_cmd == 3) // from right to left
+					mcu_b5_res = 0x0d;
+
+				if(mcu_b4_cmd == 2) // from left to right
+					mcu_b5_res = 0xe4;
+
+				break;
+			}
+			case 0xb6: // bird Y coord
+			{
+				mcu_b6_res = data;
+
+				if(mcu_b4_cmd == 1) // from up to down
+					mcu_b6_res = 0x04;
+
+				if(mcu_b4_cmd == 4) // from down to up
+					mcu_b6_res = 0xdc;
+
+				break;
+			}
+		}
+
+		//if((mcu_cmd & 0xf0) == 0xc0)
+		//  printf("%02x ",data);
+
+		//if(mcu_cmd == 0xc7)
+		//  printf("\n");
+
+		return;
+	}
+
+	mcu_cmd = data;
+
+	if(((data & 0xf0) == 0xb0 || (data & 0xf0) == 0xc0) && mcu_param == 0)
+		mcu_param = 1;
+}
+
+static ADDRESS_MAP_START( rumba_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(flstory_videoram_w) AM_BASE_SIZE_MEMBER(flstory_state, videoram, videoram_size)
+//  AM_RANGE(0xc800, 0xcfff) AM_RAM /* unknown */
+	AM_RANGE(0xd000, 0xd000) AM_READWRITE(rumba_mcu_r, rumba_mcu_w)
+	AM_RANGE(0xd001, 0xd001) AM_WRITENOP	/* watchdog? */
+//  AM_RANGE(0xd002, 0xd002) AM_NOP /* unknown read & coin lock out? */
+	AM_RANGE(0xd400, 0xd400) AM_READWRITE(from_snd_r, sound_command_w)
+	AM_RANGE(0xd401, 0xd401) AM_READ(snd_flag_r)
+//  AM_RANGE(0xd403, 0xd403) AM_READNOP /* unknown */
+	AM_RANGE(0xd800, 0xd800) AM_READ_PORT("DSW0")
+	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
+	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
+	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("P1")
+	AM_RANGE(0xd805, 0xd805) AM_READ_PORT("EXTRA_P1")	/* also mcu */
+	AM_RANGE(0xd806, 0xd806) AM_READ_PORT("P2")
+	AM_RANGE(0xd807, 0xd807) AM_READ_PORT("EXTRA_P2")
+//  AM_RANGE(0xda00, 0xda00) AM_WRITEONLY
+	AM_RANGE(0xdc00, 0xdc9f) AM_RAM AM_BASE_SIZE_MEMBER(flstory_state, spriteram, spriteram_size)
+	AM_RANGE(0xdca0, 0xdcbf) AM_RAM_WRITE(flstory_scrlram_w) AM_BASE_MEMBER(flstory_state, scrlram)
+	AM_RANGE(0xdce0, 0xdce0) AM_READWRITE(victnine_gfxctrl_r, victnine_gfxctrl_w)
+//  AM_RANGE(0xdce1, 0xdce1) AM_WRITENOP    /* unknown */
+	AM_RANGE(0xdd00, 0xdeff) AM_READWRITE(flstory_palette_r, flstory_palette_w)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_MEMBER(flstory_state, workram) /* work RAM */
+ADDRESS_MAP_END
+
 
 static MACHINE_RESET( ta7630 )
 {
-	flstory_state *state = (flstory_state *)machine->driver_data;
+	flstory_state *state = machine->driver_data<flstory_state>();
 	int i;
 
 	double db			= 0.0;
@@ -186,7 +396,7 @@ static MACHINE_RESET( ta7630 )
 
 static WRITE8_DEVICE_HANDLER( sound_control_0_w )
 {
-	flstory_state *state = (flstory_state *)device->machine->driver_data;
+	flstory_state *state = device->machine->driver_data<flstory_state>();
 
 	state->snd_ctrl0 = data & 0xff;
 	//  popmessage("SND0 0=%02x 1=%02x 2=%02x 3=%02x", state->snd_ctrl0, state->snd_ctrl1, state->snd_ctrl2, state->snd_ctrl3);
@@ -200,7 +410,7 @@ static WRITE8_DEVICE_HANDLER( sound_control_0_w )
 }
 static WRITE8_DEVICE_HANDLER( sound_control_1_w )
 {
-	flstory_state *state = (flstory_state *)device->machine->driver_data;
+	flstory_state *state = device->machine->driver_data<flstory_state>();
 
 	state->snd_ctrl1 = data & 0xff;
 	//  popmessage("SND1 0=%02x 1=%02x 2=%02x 3=%02x", state->snd_ctrl0, state->snd_ctrl1, state->snd_ctrl2, state->snd_ctrl3);
@@ -212,7 +422,7 @@ static WRITE8_DEVICE_HANDLER( sound_control_1_w )
 
 static WRITE8_DEVICE_HANDLER( sound_control_2_w )
 {
-	flstory_state *state = (flstory_state *)device->machine->driver_data;
+	flstory_state *state = device->machine->driver_data<flstory_state>();
 	int i;
 
 	state->snd_ctrl2 = data & 0xff;
@@ -224,7 +434,7 @@ static WRITE8_DEVICE_HANDLER( sound_control_2_w )
 
 static WRITE8_DEVICE_HANDLER( sound_control_3_w ) /* unknown */
 {
-	flstory_state *state = (flstory_state *)device->machine->driver_data;
+	flstory_state *state = device->machine->driver_data<flstory_state>();
 
 	state->snd_ctrl3 = data & 0xff;
 	//  popmessage("SND3 0=%02x 1=%02x 2=%02x 3=%02x", state->snd_ctrl0, state->snd_ctrl1, state->snd_ctrl2, state->snd_ctrl3);
@@ -608,6 +818,149 @@ static INPUT_PORTS_START( victnine )
 INPUT_PORTS_END
 
 
+
+static INPUT_PORTS_START( rumba )
+	PORT_START("DSW0")      /* D800 */
+	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Bonus_Life ) )
+	PORT_DIPSETTING(    0x00, "20000 50000" )
+	PORT_DIPSETTING(    0x01, "10000 60000" )
+	PORT_DIPSETTING(    0x02, "10000 40000" )
+	PORT_DIPSETTING(    0x03, "10000 20000" )
+	PORT_DIPNAME(0x04, 0x04, DEF_STR( Free_Play ) )
+	PORT_DIPSETTING(   0x04, DEF_STR( Off ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x18, 0x18, DEF_STR( Lives ) )
+	PORT_DIPSETTING(    0x18, "3" )
+	PORT_DIPSETTING(    0x10, "4" )
+	PORT_DIPSETTING(    0x08, "5" )
+	PORT_DIPSETTING(    0x00, "6")
+    PORT_DIPNAME( 0x20,   0x20, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x20, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+    PORT_DIPNAME( 0x40,   0x40, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x40, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+	PORT_DIPNAME(0x80, 0x80, DEF_STR( Cabinet ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( Upright ) )
+	PORT_DIPSETTING(   0x80, DEF_STR( Cocktail ) )
+
+
+	PORT_START("DSW1")      /* D801 */
+	PORT_DIPNAME(0x0f, 0x00, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(   0x0f, DEF_STR( 9C_1C ) )
+	PORT_DIPSETTING(   0x0e, DEF_STR( 8C_1C ) )
+	PORT_DIPSETTING(   0x0d, DEF_STR( 7C_1C ) )
+	PORT_DIPSETTING(   0x0c, DEF_STR( 6C_1C ) )
+	PORT_DIPSETTING(   0x0b, DEF_STR( 5C_1C ) )
+	PORT_DIPSETTING(   0x0a, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(   0x09, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(   0x08, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(   0x01, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(   0x02, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(   0x03, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(   0x04, DEF_STR( 1C_5C ) )
+	PORT_DIPSETTING(   0x05, DEF_STR( 1C_6C ) )
+	PORT_DIPSETTING(   0x06, DEF_STR( 1C_7C ) )
+	PORT_DIPSETTING(   0x07, DEF_STR( 1C_8C ) )
+	PORT_DIPNAME(0xf0, 0x00, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(   0xf0, DEF_STR( 9C_1C ) )
+	PORT_DIPSETTING(   0xe0, DEF_STR( 8C_1C ) )
+	PORT_DIPSETTING(   0xd0, DEF_STR( 7C_1C ) )
+	PORT_DIPSETTING(   0xc0, DEF_STR( 6C_1C ) )
+	PORT_DIPSETTING(   0xb0, DEF_STR( 5C_1C ) )
+	PORT_DIPSETTING(   0xa0, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(   0x90, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(   0x80, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(   0x00, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(   0x10, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(   0x20, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(   0x30, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(   0x40, DEF_STR( 1C_5C ) )
+	PORT_DIPSETTING(   0x50, DEF_STR( 1C_6C ) )
+	PORT_DIPSETTING(   0x60, DEF_STR( 1C_7C ) )
+	PORT_DIPSETTING(   0x70, DEF_STR( 1C_8C ) )
+
+	PORT_START("DSW2")      /* D802 */
+    PORT_DIPNAME( 0x01,   0x01, "Training Stage" )
+    PORT_DIPSETTING(      0x00, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x01, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02,   0x02, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x02, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+    PORT_DIPNAME( 0x04,   0x00, DEF_STR( Language ) )
+    PORT_DIPSETTING(      0x04, DEF_STR( Japanese ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( English ) )
+    PORT_DIPNAME( 0x08,   0x08, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x08, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+    PORT_DIPNAME( 0x10,   0x10, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x10, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+    PORT_DIPNAME( 0x20,   0x20, "Copyright String" )
+    PORT_DIPSETTING(      0x20, "Taito Corp. MCMLXXXIV" )
+    PORT_DIPSETTING(      0x00, "Taito Corporation" )
+    PORT_DIPNAME( 0x40,   0x40, "Infinite Lives" ) //???
+    PORT_DIPSETTING(      0x40, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+    PORT_DIPNAME( 0x80,   0x80, DEF_STR( Unknown ) )
+    PORT_DIPSETTING(      0x80, DEF_STR( Off ) )
+    PORT_DIPSETTING(      0x00, DEF_STR( On ) )
+
+	PORT_START("SYSTEM")      /* D803 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("P1")      /* D804 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )	// A
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 )	// C
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("EXTRA_P1")      /* D805 */
+	/* bits 0,1 are MCU related:
+        - bit 0: mcu is ready to receive data from main cpu
+        - bit 1: mcu has sent data to the main cpu       */
+	PORT_BIT( 0x03, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(victnine_mcu_status_bit01_r, NULL)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("P2")      /* D806 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL	// A
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL	// C
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("EXTRA_P2")      /* D807 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
+
+
 static const gfx_layout charlayout =
 {
 	8,8,
@@ -656,7 +1009,7 @@ static const msm5232_interface msm5232_config =
 
 static MACHINE_START( flstory )
 {
-	flstory_state *state = (flstory_state *)machine->driver_data;
+	flstory_state *state = machine->driver_data<flstory_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = machine->device("audiocpu");
@@ -696,7 +1049,7 @@ static MACHINE_START( flstory )
 
 static MACHINE_RESET( flstory )
 {
-	flstory_state *state = (flstory_state *)machine->driver_data;
+	flstory_state *state = machine->driver_data<flstory_state>();
 
 	MACHINE_RESET_CALL(ta7630);
 
@@ -731,190 +1084,245 @@ static MACHINE_RESET( flstory )
 	state->mcu_select = 0;
 }
 
-static MACHINE_DRIVER_START( flstory )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(flstory_state)
+static MACHINE_CONFIG_START( flstory, flstory_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80,XTAL_10_733MHz/2) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(flstory_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80,XTAL_10_733MHz/2) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(flstory_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,XTAL_8MHz/2) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
+	MCFG_CPU_ADD("audiocpu", Z80,XTAL_8MHz/2) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
 						/* NMI generated by the main CPU */
 
-	MDRV_CPU_ADD("mcu", M68705,XTAL_18_432MHz/6)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(flstory_m68705_map)
+	MCFG_CPU_ADD("mcu", M68705,XTAL_18_432MHz/6)	/* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(flstory_m68705_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
+	MCFG_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
-	MDRV_MACHINE_START(flstory)
-	MDRV_MACHINE_RESET(flstory)
+	MCFG_MACHINE_START(flstory)
+	MCFG_MACHINE_RESET(flstory)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(flstory)
-	MDRV_PALETTE_LENGTH(512)
+	MCFG_GFXDECODE(flstory)
+	MCFG_PALETTE_LENGTH(512)
 
-	MDRV_VIDEO_START(flstory)
-	MDRV_VIDEO_UPDATE(flstory)
+	MCFG_VIDEO_START(flstory)
+	MCFG_VIDEO_UPDATE(flstory)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, XTAL_8MHz/4) /* verified on pcb */
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MCFG_SOUND_ADD("aysnd", AY8910, XTAL_8MHz/4) /* verified on pcb */
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD("msm", MSM5232, XTAL_8MHz/4) /* verified on pcb */
-	MDRV_SOUND_CONFIG(msm5232_config)
-	MDRV_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
-	MDRV_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
-	MDRV_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
-	MDRV_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
-	MDRV_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
-	MDRV_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
-	MDRV_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
-	MDRV_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
+	MCFG_SOUND_ADD("msm", MSM5232, XTAL_8MHz/4) /* verified on pcb */
+	MCFG_SOUND_CONFIG(msm5232_config)
+	MCFG_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
+	MCFG_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
+	MCFG_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
+	MCFG_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
+	MCFG_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
+	MCFG_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
+	MCFG_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
+	MCFG_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
 	// pin 1 SOLO  8'       not mapped
 	// pin 2 SOLO 16'       not mapped
 	// pin 22 Noise Output  not mapped
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( onna34ro )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(flstory_state)
+static MACHINE_CONFIG_START( onna34ro, flstory_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80,10733000/2)		/* ??? */
-	MDRV_CPU_PROGRAM_MAP(onna34ro_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80,10733000/2)		/* ??? */
+	MCFG_CPU_PROGRAM_MAP(onna34ro_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
+	MCFG_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
 						/* NMI generated by the main CPU */
-//  MDRV_CPU_ADD("mcu", M68705,4000000)  /* ??? */
-//  MDRV_CPU_PROGRAM_MAP(m68705_map)
+//  MCFG_CPU_ADD("mcu", M68705,4000000)  /* ??? */
+//  MCFG_CPU_PROGRAM_MAP(m68705_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
+	MCFG_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
-	MDRV_MACHINE_START(flstory)
-	MDRV_MACHINE_RESET(flstory)
+	MCFG_MACHINE_START(flstory)
+	MCFG_MACHINE_RESET(flstory)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(flstory)
-	MDRV_PALETTE_LENGTH(512)
+	MCFG_GFXDECODE(flstory)
+	MCFG_PALETTE_LENGTH(512)
 
-	MDRV_VIDEO_START(flstory)
-	MDRV_VIDEO_UPDATE(flstory)
+	MCFG_VIDEO_START(flstory)
+	MCFG_VIDEO_UPDATE(flstory)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, 8000000/4)
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MCFG_SOUND_ADD("aysnd", AY8910, 8000000/4)
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD("msm", MSM5232, 2000000)
-	MDRV_SOUND_CONFIG(msm5232_config)
-	MDRV_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
-	MDRV_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
-	MDRV_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
-	MDRV_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
-	MDRV_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
-	MDRV_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
-	MDRV_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
-	MDRV_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
+	MCFG_SOUND_ADD("msm", MSM5232, 2000000)
+	MCFG_SOUND_CONFIG(msm5232_config)
+	MCFG_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
+	MCFG_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
+	MCFG_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
+	MCFG_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
+	MCFG_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
+	MCFG_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
+	MCFG_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
+	MCFG_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
 	// pin 1 SOLO  8'       not mapped
 	// pin 2 SOLO 16'       not mapped
 	// pin 22 Noise Output  not mapped
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( victnine )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(flstory_state)
+static MACHINE_CONFIG_START( victnine, flstory_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80,8000000/2)		/* 4 MHz */
-	MDRV_CPU_PROGRAM_MAP(victnine_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80,8000000/2)		/* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(victnine_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
+	MCFG_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
 						/* NMI generated by the main CPU */
-//  MDRV_CPU_ADD("mcu", M68705,4000000)  /* ??? */
-//  MDRV_CPU_PROGRAM_MAP(m68705_map)
+//  MCFG_CPU_ADD("mcu", M68705,4000000)  /* ??? */
+//  MCFG_CPU_PROGRAM_MAP(m68705_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
+	MCFG_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
-	MDRV_MACHINE_START(flstory)
-	MDRV_MACHINE_RESET(flstory)
+	MCFG_MACHINE_START(flstory)
+	MCFG_MACHINE_RESET(flstory)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(flstory)
-	MDRV_PALETTE_LENGTH(512)
+	MCFG_GFXDECODE(flstory)
+	MCFG_PALETTE_LENGTH(512)
 
-	MDRV_VIDEO_START(victnine)
-	MDRV_VIDEO_UPDATE(victnine)
+	MCFG_VIDEO_START(victnine)
+	MCFG_VIDEO_UPDATE(victnine)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, 8000000/4)
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("aysnd", AY8910, 8000000/4)
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("msm", MSM5232, 2000000)
-	MDRV_SOUND_CONFIG(msm5232_config)
-	MDRV_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
-	MDRV_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
-	MDRV_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
-	MDRV_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
-	MDRV_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
-	MDRV_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
-	MDRV_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
-	MDRV_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
+	MCFG_SOUND_ADD("msm", MSM5232, 2000000)
+	MCFG_SOUND_CONFIG(msm5232_config)
+	MCFG_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
+	MCFG_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
+	MCFG_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
+	MCFG_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
+	MCFG_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
+	MCFG_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
+	MCFG_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
+	MCFG_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
 	// pin 1 SOLO  8'       not mapped
 	// pin 2 SOLO 16'       not mapped
 	// pin 22 Noise Output  not mapped
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+MACHINE_CONFIG_END
 
+static MACHINE_RESET( rumba )
+{
+	MACHINE_RESET_CALL(flstory);
+	mcu_cmd = 0;
+}
+
+static MACHINE_CONFIG_START( rumba, flstory_state )
+
+	/* basic machine hardware */
+	MCFG_CPU_ADD("maincpu", Z80,8000000/2)		/* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(rumba_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
+
+	MCFG_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)	/* IRQ generated by ??? */
+						/* NMI generated by the main CPU */
+//  MCFG_CPU_ADD("mcu", M68705,18432000/6)  /* ??? */
+
+//  MCFG_CPU_PROGRAM_MAP(m68705_map)
+
+	MCFG_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame - an high value to ensure proper */
+							/* synchronization of the CPUs */
+	MCFG_MACHINE_START(flstory)
+	MCFG_MACHINE_RESET(rumba)
+
+	/* video hardware */
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+
+	MCFG_GFXDECODE(flstory)
+	MCFG_PALETTE_LENGTH(512)
+
+	MCFG_VIDEO_START(rumba)
+	MCFG_VIDEO_UPDATE(rumba)
+
+	/* sound hardware */
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+
+	MCFG_SOUND_ADD("aysnd", AY8910, 8000000/4)
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+
+	MCFG_SOUND_ADD("msm", MSM5232, 2000000)
+	MCFG_SOUND_CONFIG(msm5232_config)
+	MCFG_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
+	MCFG_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
+	MCFG_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
+	MCFG_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
+	MCFG_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
+	MCFG_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
+	MCFG_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
+	MCFG_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
+	// pin 1 SOLO  8'       not mapped
+	// pin 2 SOLO 16'       not mapped
+	// pin 22 Noise Output  not mapped
+
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+MACHINE_CONFIG_END
 
 /***************************************************************************
 
@@ -1140,8 +1548,74 @@ ROM_START( victnine )
 ROM_END
 
 
+/*
+
+RUMBA LUMBER by TAITO (1984)
+
+Hardware similar to Fairyland Story except for the video board.
+Wiring is the classic Taito one.
+All clocks has been verified using a frequency counter.
+Hardware is capable of playing samples (TTL circuit)
+
+
+SOUND BOARD J1100022A / K1100066A
+
+Xtal: 8mhz
+Z80 NEC D780C-1 running at 8/2 = 4mhz
+YM2149 running at 8/4 = 2mhz  pin 26 high
+OKI M5232 running at 8/4 = 2mhz
+2764 EPROM A23-08-1
+2764 EPROM A23-09
+2764 EPROM A23-10
+
+CPU BOARD J1100024A / K1100065A
+
+Xtal 8mhz
+Z80 NEC D780C-1 running at 8/2 = 4mhz
+MCU A23-11 MC68705P5S running at 18.432/6 = 3.072mhz
+27128 EPROM A23-01-1
+27128 EPROM A23-02-1
+27128 EPROM A23-03-1
+
+VIDEO BOARD J1100023A / K1100064A
+
+xtal: 18.432mhz
+2764 EPROM A23-04
+2764 EPROM A23-05
+2764 EPROM A23-06 (I cannot get a constant read,a couple of bytes differ everytime)
+2764 EPROM A23-07
+
+VSYNC = 60.55hz
+
+Dumped by Corrado Tomaselli on 9/12/2010
+
+*/
+
+ROM_START( rumba )
+	ROM_REGION( 0x10000, "maincpu", 0 )	/* 64k for the first CPU */
+	ROM_LOAD( "a23_01-1.bin",   0x0000, 0x4000, CRC(4bea6e18) SHA1(b9a85e65105773b5f93dcc5fc1e7c588b2d25056) )
+	ROM_LOAD( "a23_02-1.bin",   0x4000, 0x4000, CRC(08f98c6f) SHA1(f2a850b1138cfefab6ff1d1adcda9e084f52e9c2) )
+	ROM_LOAD( "a23_03-1.bin",   0x8000, 0x4000, CRC(ab595427) SHA1(1ff51740e1c7915e1f79a55801d11c8fdce764c8) )
+
+	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 64k for the second CPU */
+	ROM_LOAD( "a23_08-1.bin",     0x0000, 0x2000, CRC(a18eae00) SHA1(6ac1ad07bb5a97c6edaaf0e1fb842e1741f4cf1e) )
+	ROM_LOAD( "a23_09.bin",       0x2000, 0x2000, CRC(d0a101d3) SHA1(c92bb1ce67bec394fd8ce303d9e61eac12493b5d) )
+	ROM_LOAD( "a23_10.bin",       0x4000, 0x2000, CRC(f9447bd4) SHA1(68c02249ca0e5b923cddb4bff8d090963b9c78e4) )
+
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
+	ROM_LOAD( "a23-11.mc68705p5s", 0x0000, 0x0800, NO_DUMP )
+
+	ROM_REGION( 0x8000, "gfx1", ROMREGION_INVERT )
+	ROM_LOAD( "a23_07.bin",   0x02000, 0x2000, CRC(c98fbea6) SHA1(edd1e0b2551f726018ca6e0b2cf629046a482711) )
+	ROM_LOAD( "a23_06.bin",   0x00000, 0x2000, CRC(bf1e3a7f) SHA1(1258be10739cee6e6a8b2ce4d39f89bff1ea7f16) ) // should be a good read
+	ROM_LOAD( "a23_05.bin",   0x06000, 0x2000, CRC(b40db231) SHA1(85204efc05e95334576807e4dab866f4f40081e6) )
+	ROM_LOAD( "a23_04.bin",   0x04000, 0x2000, CRC(1d4f001f) SHA1(c3245650e57138ed89e7de8289fe37c5d933ddca) )
+ROM_END
+
+
 GAME( 1985, flstory,   0,        flstory,  flstory,  0, ROT180, "Taito", "The FairyLand Story", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1985, flstoryj,  flstory,  flstory,  flstory,  0, ROT180, "Taito", "The FairyLand Story (Japan)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1985, onna34ro,  0,        onna34ro, onna34ro, 0, ROT0,   "Taito", "Onna Sansirou - Typhoon Gal (set 1)", GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1985, onna34roa, onna34ro, onna34ro, onna34ro, 0, ROT0,   "Taito", "Onna Sansirou - Typhoon Gal (set 2)", GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1984, victnine,  0,        victnine, victnine, 0, ROT0,   "Taito", "Victorious Nine", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1984, rumba,     0,        rumba,    rumba,    0, ROT270, "Taito", "Rumba Lumber", GAME_IMPERFECT_SOUND | GAME_UNEMULATED_PROTECTION )
