@@ -58,13 +58,13 @@ static WRITE8_HANDLER( coin_w )
 
 static WRITE8_HANDLER( spinner_select_w )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	state->spinner = data & 1;
 }
 
 static READ8_HANDLER( spinner_r )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	return input_port_read(space->machine, state->spinner ? "IN3" : "IN2");
 }
 
@@ -75,20 +75,20 @@ static WRITE8_HANDLER( pbillrd_bankswitch_w )
 
 static WRITE8_HANDLER( nmi_enable_w )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	state->nmi_en = data & 1;
 }
 
 static INTERRUPT_GEN( freekick_irqgen )
 {
-	freekick_state *state = (freekick_state *)device->machine->driver_data;
+	freekick_state *state = device->machine->driver_data<freekick_state>();
 	if (state->nmi_en)
 		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( oigas_5_w )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	if (data > 0xc0 && data < 0xe0)
 		state->cnt = 1;
 
@@ -101,7 +101,7 @@ static WRITE8_HANDLER( oigas_5_w )
 
 static READ8_HANDLER( oigas_3_r )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	switch (++state->cnt)
 	{
 	case 2: return ~(state->inval >> 8);
@@ -144,13 +144,13 @@ static READ8_HANDLER( oigas_2_r )
 
 static READ8_HANDLER( freekick_ff_r )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	return state->ff_data;
 }
 
 static WRITE8_HANDLER( freekick_ff_w )
 {
-	freekick_state *state = (freekick_state *)space->machine->driver_data;
+	freekick_state *state = space->machine->driver_data<freekick_state>();
 	state->ff_data = data;
 }
 
@@ -513,20 +513,20 @@ INPUT_PORTS_END
 
 static WRITE8_DEVICE_HANDLER( snd_rom_addr_l_w )
 {
-	freekick_state *state = (freekick_state *)device->machine->driver_data;
+	freekick_state *state = device->machine->driver_data<freekick_state>();
 	state->romaddr = (state->romaddr & 0xff00) | data;
 }
 
 static WRITE8_DEVICE_HANDLER( snd_rom_addr_h_w )
 {
-	freekick_state *state = (freekick_state *)device->machine->driver_data;
+	freekick_state *state = device->machine->driver_data<freekick_state>();
 	state->romaddr = (state->romaddr & 0x00ff) | (data << 8);
 }
 
 static READ8_DEVICE_HANDLER( snd_rom_r )
 {
-	freekick_state *state = (freekick_state *)device->machine->driver_data;
-	return memory_region(device->machine, "user1")[state->romaddr & 0x7fff];
+	freekick_state *state = device->machine->driver_data<freekick_state>();
+	return device->machine->region("user1")->base()[state->romaddr & 0x7fff];
 }
 
 static const ppi8255_interface ppi8255_intf[2] =
@@ -596,7 +596,7 @@ GFXDECODE_END
 
 static MACHINE_START( freekick )
 {
-	freekick_state *state = (freekick_state *)machine->driver_data;
+	freekick_state *state = machine->driver_data<freekick_state>();
 
 	state_save_register_global(machine, state->romaddr);
 	state_save_register_global(machine, state->spinner);
@@ -606,7 +606,7 @@ static MACHINE_START( freekick )
 
 static MACHINE_RESET( freekick )
 {
-	freekick_state *state = (freekick_state *)machine->driver_data;
+	freekick_state *state = machine->driver_data<freekick_state>();
 
 	state->romaddr = 0;
 	state->spinner = 0;
@@ -616,14 +616,14 @@ static MACHINE_RESET( freekick )
 
 static MACHINE_START( pbillrd )
 {
-	memory_configure_bank(machine, "bank1", 0, 2, memory_region(machine, "maincpu") + 0x10000, 0x4000);
+	memory_configure_bank(machine, "bank1", 0, 2, machine->region("maincpu")->base() + 0x10000, 0x4000);
 
 	MACHINE_START_CALL(freekick);
 }
 
 static MACHINE_START( oigas )
 {
-	freekick_state *state = (freekick_state *)machine->driver_data;
+	freekick_state *state = machine->driver_data<freekick_state>();
 
 	state_save_register_global(machine, state->inval);
 	state_save_register_global(machine, state->outval);
@@ -634,7 +634,7 @@ static MACHINE_START( oigas )
 
 static MACHINE_RESET( oigas )
 {
-	freekick_state *state = (freekick_state *)machine->driver_data;
+	freekick_state *state = machine->driver_data<freekick_state>();
 
 	MACHINE_RESET_CALL(freekick);
 
@@ -643,89 +643,84 @@ static MACHINE_RESET( oigas )
 	state->cnt = 0;
 }
 
-static MACHINE_DRIVER_START( base )
-	MDRV_DRIVER_DATA(freekick_state)
+static MACHINE_CONFIG_START( base, freekick_state )
 
-	MDRV_CPU_ADD("maincpu",Z80, 18432000/6)	//confirmed
-	MDRV_CPU_PROGRAM_MAP(pbillrd_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold, 50*3) //??
-	MDRV_CPU_VBLANK_INT("screen", freekick_irqgen)
+	MCFG_CPU_ADD("maincpu",Z80, 18432000/6)	//confirmed
+	MCFG_CPU_PROGRAM_MAP(pbillrd_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold, 50*3) //??
+	MCFG_CPU_VBLANK_INT("screen", freekick_irqgen)
 
-	MDRV_GFXDECODE(freekick)
+	MCFG_GFXDECODE(freekick)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_PALETTE_LENGTH(0x200)
-	MDRV_PALETTE_INIT(RRRR_GGGG_BBBB)
+	MCFG_PALETTE_LENGTH(0x200)
+	MCFG_PALETTE_INIT(RRRR_GGGG_BBBB)
 
-	MDRV_VIDEO_START(freekick)
-	MDRV_VIDEO_UPDATE(pbillrd)
+	MCFG_VIDEO_START(freekick)
+	MCFG_VIDEO_UPDATE(pbillrd)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("sn1", SN76496, 12000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("sn1", SN76496, 12000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("sn2", SN76496, 12000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("sn2", SN76496, 12000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("sn3", SN76496, 12000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("sn3", SN76496, 12000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("sn4", SN76496, 12000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("sn4", SN76496, 12000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( pbillrd )
-	MDRV_IMPORT_FROM(base)
+static MACHINE_CONFIG_DERIVED( pbillrd, base )
 
-	MDRV_MACHINE_START(pbillrd)
-	MDRV_MACHINE_RESET(freekick)
-MACHINE_DRIVER_END
+	MCFG_MACHINE_START(pbillrd)
+	MCFG_MACHINE_RESET(freekick)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( freekickb )
-	MDRV_IMPORT_FROM(base)
+static MACHINE_CONFIG_DERIVED( freekickb, base )
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(freekickb_map)
-	MDRV_CPU_IO_MAP(freekickb_io_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(freekickb_map)
+	MCFG_CPU_IO_MAP(freekickb_io_map)
 
-	MDRV_MACHINE_START(freekick)
-	MDRV_MACHINE_RESET(freekick)
+	MCFG_MACHINE_START(freekick)
+	MCFG_MACHINE_RESET(freekick)
 
-	MDRV_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
-	MDRV_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
+	MCFG_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
+	MCFG_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
 
-	MDRV_VIDEO_UPDATE(freekick)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_UPDATE(freekick)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( gigas )
-	MDRV_IMPORT_FROM(base)
+static MACHINE_CONFIG_DERIVED( gigas, base )
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(gigas_map)
-	MDRV_CPU_IO_MAP(gigas_io_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(gigas_map)
+	MCFG_CPU_IO_MAP(gigas_io_map)
 
-	MDRV_MACHINE_START(freekick)
-	MDRV_MACHINE_RESET(freekick)
+	MCFG_MACHINE_START(freekick)
+	MCFG_MACHINE_RESET(freekick)
 
-	MDRV_VIDEO_UPDATE(gigas)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_UPDATE(gigas)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( oigas )
-	MDRV_IMPORT_FROM(gigas)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_IO_MAP(oigas_io_map)
+static MACHINE_CONFIG_DERIVED( oigas, gigas )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_IO_MAP(oigas_io_map)
 
-	MDRV_MACHINE_START(oigas)
-	MDRV_MACHINE_RESET(oigas)
-MACHINE_DRIVER_END
+	MCFG_MACHINE_START(oigas)
+	MCFG_MACHINE_RESET(oigas)
+MACHINE_CONFIG_END
 
 
 
@@ -1111,8 +1106,8 @@ ROM_END
 
 static DRIVER_INIT(gigasb)
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	memory_set_decrypted_region(space, 0x0000, 0xbfff, memory_region(machine, "maincpu") + 0x10000);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	space->set_decrypted_region(0x0000, 0xbfff, machine->region("maincpu")->base() + 0x10000);
 }
 
 
