@@ -73,17 +73,17 @@
 #include "machine/pckeybrd.h"
 #include "machine/idectrl.h"
 
-static void ide_interrupt(running_device *device, int state);
+static void ide_interrupt(device_t *device, int state);
 
 static UINT32 *cga_ram;
 static UINT32 *bios_ram;
 
 static struct {
-	running_device	*pit8254;
-	running_device	*pic8259_1;
-	running_device	*pic8259_2;
-	running_device	*dma8237_1;
-	running_device	*dma8237_2;
+	device_t	*pit8254;
+	device_t	*pic8259_1;
+	device_t	*pic8259_2;
+	device_t	*dma8237_1;
+	device_t	*dma8237_2;
 } gamecstl_devices;
 
 
@@ -175,14 +175,14 @@ static WRITE32_DEVICE_HANDLER(at32_dma8237_2_w)
 // Intel 82439TX System Controller (MXTC)
 static UINT8 mxtc_config_reg[256];
 
-static UINT8 mxtc_config_r(running_device *busdevice, running_device *device, int function, int reg)
+static UINT8 mxtc_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
 //  mame_printf_debug("MXTC: read %d, %02X\n", function, reg);
 
 	return mxtc_config_reg[reg];
 }
 
-static void mxtc_config_w(running_device *busdevice, running_device *device, int function, int reg, UINT8 data)
+static void mxtc_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
 //  mame_printf_debug("%s:MXTC: write %d, %02X, %02X\n", cpuexec_describe_context(busdevice->machine), function, reg, data);
 
@@ -196,7 +196,7 @@ static void mxtc_config_w(running_device *busdevice, running_device *device, int
 			}
 			else					// disable RAM access (reads go to BIOS ROM)
 			{
-				memory_set_bankptr(busdevice->machine, "bank1", memory_region(busdevice->machine, "user1") + 0x30000);
+				memory_set_bankptr(busdevice->machine, "bank1", busdevice->machine->region("user1")->base() + 0x30000);
 			}
 			break;
 		}
@@ -215,7 +215,7 @@ static void intel82439tx_init(void)
 	mxtc_config_reg[0x65] = 0x02;
 }
 
-static UINT32 intel82439tx_pci_r(running_device *busdevice, running_device *device, int function, int reg, UINT32 mem_mask)
+static UINT32 intel82439tx_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
 {
 	UINT32 r = 0;
 	if (ACCESSING_BITS_24_31)
@@ -237,7 +237,7 @@ static UINT32 intel82439tx_pci_r(running_device *busdevice, running_device *devi
 	return r;
 }
 
-static void intel82439tx_pci_w(running_device *busdevice, running_device *device, int function, int reg, UINT32 data, UINT32 mem_mask)
+static void intel82439tx_pci_w(device_t *busdevice, device_t *device, int function, int reg, UINT32 data, UINT32 mem_mask)
 {
 	if (ACCESSING_BITS_24_31)
 	{
@@ -260,19 +260,19 @@ static void intel82439tx_pci_w(running_device *busdevice, running_device *device
 // Intel 82371AB PCI-to-ISA / IDE bridge (PIIX4)
 static UINT8 piix4_config_reg[4][256];
 
-static UINT8 piix4_config_r(running_device *busdevice, running_device *device, int function, int reg)
+static UINT8 piix4_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
 //  mame_printf_debug("PIIX4: read %d, %02X\n", function, reg);
 	return piix4_config_reg[function][reg];
 }
 
-static void piix4_config_w(running_device *busdevice, running_device *device, int function, int reg, UINT8 data)
+static void piix4_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
 //  mame_printf_debug("%s:PIIX4: write %d, %02X, %02X\n", cpuexec_describe_context(busdevice->machine), function, reg, data);
 	piix4_config_reg[function][reg] = data;
 }
 
-static UINT32 intel82371ab_pci_r(running_device *busdevice, running_device *device, int function, int reg, UINT32 mem_mask)
+static UINT32 intel82371ab_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
 {
 	UINT32 r = 0;
 	if (ACCESSING_BITS_24_31)
@@ -294,7 +294,7 @@ static UINT32 intel82371ab_pci_r(running_device *busdevice, running_device *devi
 	return r;
 }
 
-static void intel82371ab_pci_w(running_device *busdevice, running_device *device, int function, int reg, UINT32 data, UINT32 mem_mask)
+static void intel82371ab_pci_w(device_t *busdevice, device_t *device, int function, int reg, UINT32 data, UINT32 mem_mask)
 {
 	if (ACCESSING_BITS_24_31)
 	{
@@ -435,7 +435,7 @@ static READ8_HANDLER( pc_dma_read_byte )
 	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
 		& 0xFF0000;
 
-	return memory_read_byte(space, page_offset + offset);
+	return space->read_byte(page_offset + offset);
 }
 
 
@@ -444,10 +444,10 @@ static WRITE8_HANDLER( pc_dma_write_byte )
 	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
 		& 0xFF0000;
 
-	memory_write_byte(space, page_offset + offset, data);
+	space->write_byte(page_offset + offset, data);
 }
 
-static void set_dma_channel(running_device *device, int channel, int state)
+static void set_dma_channel(device_t *device, int channel, int state)
 {
 	if (!state) dma_channel = channel;
 }
@@ -509,7 +509,7 @@ static ADDRESS_MAP_START(gamecstl_io, ADDRESS_SPACE_IO, 32)
 	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8("pic8259_1", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8("pit8254", pit8253_r, pit8253_w, 0xffffffff)
 	AM_RANGE(0x0060, 0x006f) AM_READWRITE(kbdc8042_32le_r,			kbdc8042_32le_w)
-	AM_RANGE(0x0070, 0x007f) AM_READWRITE(mc146818_port32le_r,		mc146818_port32le_w)
+	AM_RANGE(0x0070, 0x007f) AM_DEVREADWRITE8_MODERN("rtc", mc146818_device, read, write, 0xffffffff)
 	AM_RANGE(0x0080, 0x009f) AM_READWRITE(at_page32_r,				at_page32_w)
 	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8("pic8259_2", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE("dma8237_2", at32_dma8237_2_r, at32_dma8237_2_w)
@@ -603,7 +603,7 @@ static MACHINE_START(gamecstl)
 
 static MACHINE_RESET(gamecstl)
 {
-	memory_set_bankptr(machine, "bank1", memory_region(machine, "user1") + 0x30000);
+	memory_set_bankptr(machine, "bank1", machine->region("user1")->base() + 0x30000);
 
 	cpu_set_irq_callback(machine->device("maincpu"), irq_callback);
 }
@@ -656,49 +656,49 @@ static const struct pit8253_config gamecstl_pit8254_config =
 	}
 };
 
-static MACHINE_DRIVER_START(gamecstl)
+static MACHINE_CONFIG_START( gamecstl, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", PENTIUM, 200000000)
-	MDRV_CPU_PROGRAM_MAP(gamecstl_map)
-	MDRV_CPU_IO_MAP(gamecstl_io)
+	MCFG_CPU_ADD("maincpu", PENTIUM, 200000000)
+	MCFG_CPU_PROGRAM_MAP(gamecstl_map)
+	MCFG_CPU_IO_MAP(gamecstl_io)
 
-	MDRV_MACHINE_START(gamecstl)
-	MDRV_MACHINE_RESET(gamecstl)
+	MCFG_MACHINE_START(gamecstl)
+	MCFG_MACHINE_RESET(gamecstl)
 
-	MDRV_PCI_BUS_ADD("pcibus", 0)
-	MDRV_PCI_BUS_DEVICE(0, NULL, intel82439tx_pci_r, intel82439tx_pci_w)
-	MDRV_PCI_BUS_DEVICE(7, NULL, intel82371ab_pci_r, intel82371ab_pci_w)
+	MCFG_PCI_BUS_ADD("pcibus", 0)
+	MCFG_PCI_BUS_DEVICE(0, NULL, intel82439tx_pci_r, intel82439tx_pci_w)
+	MCFG_PCI_BUS_DEVICE(7, NULL, intel82371ab_pci_r, intel82371ab_pci_w)
 
-	MDRV_PIT8254_ADD( "pit8254", gamecstl_pit8254_config )
+	MCFG_PIT8254_ADD( "pit8254", gamecstl_pit8254_config )
 
-	MDRV_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
+	MCFG_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
 
-	MDRV_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
+	MCFG_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
 
-	MDRV_PIC8259_ADD( "pic8259_1", gamecstl_pic8259_1_config )
+	MCFG_PIC8259_ADD( "pic8259_1", gamecstl_pic8259_1_config )
 
-	MDRV_PIC8259_ADD( "pic8259_2", gamecstl_pic8259_2_config )
+	MCFG_PIC8259_ADD( "pic8259_2", gamecstl_pic8259_2_config )
 
-	MDRV_IDE_CONTROLLER_ADD("ide", ide_interrupt)
+	MCFG_IDE_CONTROLLER_ADD("ide", ide_interrupt)
 
-	MDRV_NVRAM_HANDLER( mc146818 )
+	MCFG_MC146818_ADD( "rtc", MC146818_STANDARD )
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(640, 480)
-	MDRV_SCREEN_VISIBLE_AREA(0, 639, 0, 199)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(640, 480)
+	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 199)
 
-	MDRV_GFXDECODE(CGA)
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_GFXDECODE(CGA)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_VIDEO_START(gamecstl)
-	MDRV_VIDEO_UPDATE(gamecstl)
+	MCFG_VIDEO_START(gamecstl)
+	MCFG_VIDEO_UPDATE(gamecstl)
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 static void set_gate_a20(running_machine *machine, int a20)
 {
@@ -710,7 +710,7 @@ static void keyboard_interrupt(running_machine *machine, int state)
 	pic8259_ir1_w(gamecstl_devices.pic8259_1, state);
 }
 
-static void ide_interrupt(running_device *device, int state)
+static void ide_interrupt(device_t *device, int state)
 {
 	pic8259_ir6_w(gamecstl_devices.pic8259_2, state);
 }
@@ -735,7 +735,6 @@ static DRIVER_INIT( gamecstl )
 	bios_ram = auto_alloc_array(machine, UINT32, 0x10000/4);
 
 	init_pc_common(machine, PCCOMMON_KEYBOARD_AT, gamecstl_set_keyb_int);
-	mc146818_init(machine, MC146818_STANDARD);
 
 	intel82439tx_init();
 
