@@ -92,7 +92,7 @@ static MACHINE_RESET( grchamp )
 
 static INTERRUPT_GEN( grchamp_cpu0_interrupt )
 {
-	grchamp_state *state = (grchamp_state *)device->machine->driver_data;
+	grchamp_state *state = device->machine->driver_data<grchamp_state>();
 
 	if (state->cpu0_out[0] & 0x01)
 		cpu_set_input_line(device, 0, ASSERT_LINE);
@@ -101,7 +101,7 @@ static INTERRUPT_GEN( grchamp_cpu0_interrupt )
 
 static INTERRUPT_GEN( grchamp_cpu1_interrupt )
 {
-	grchamp_state *state = (grchamp_state *)device->machine->driver_data;
+	grchamp_state *state = device->machine->driver_data<grchamp_state>();
 
 	if (state->cpu1_out[4] & 0x01)
 		cpu_set_input_line(device, 0, ASSERT_LINE);
@@ -117,7 +117,7 @@ static INTERRUPT_GEN( grchamp_cpu1_interrupt )
 
 static WRITE8_HANDLER( cpu0_outputs_w )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	UINT8 diff = data ^ state->cpu0_out[offset];
 	state->cpu0_out[offset] = data;
 
@@ -201,7 +201,7 @@ static WRITE8_HANDLER( led_board_w )
 {
 	static const UINT8 ls247_map[16] =
 		{ 0x3f,0x06,0x5b,0x4f,0x66,0x6d,0x7d,0x07,0x7f,0x6f,0x58,0x4c,0x62,0x69,0x78,0x00 };
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 
 	switch (offset)
 	{
@@ -244,8 +244,8 @@ static WRITE8_HANDLER( led_board_w )
 
 static WRITE8_HANDLER( cpu1_outputs_w )
 {
-	running_device *discrete = space->machine->device("discrete");
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	device_t *discrete = space->machine->device("discrete");
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	UINT8 diff = data ^ state->cpu1_out[offset];
 	state->cpu1_out[offset] = data;
 
@@ -354,28 +354,28 @@ INLINE UINT8 get_pc3259_bits(running_machine *machine, grchamp_state *state, int
 
 static READ8_HANDLER( pc3259_0_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return get_pc3259_bits(space->machine, state, 0);
 }
 
 
 static READ8_HANDLER( pc3259_1_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return get_pc3259_bits(space->machine, state, 1);
 }
 
 
 static READ8_HANDLER( pc3259_2_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return get_pc3259_bits(space->machine, state, 2);
 }
 
 
 static READ8_HANDLER( pc3259_3_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return get_pc3259_bits(space->machine, state, 3);
 }
 
@@ -389,14 +389,14 @@ static READ8_HANDLER( pc3259_3_r )
 
 static READ8_HANDLER( sub_to_main_comm_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return state->comm_latch;
 }
 
 
 static TIMER_CALLBACK( main_to_sub_comm_sync_w )
 {
-	grchamp_state *state = (grchamp_state *)machine->driver_data;
+	grchamp_state *state = machine->driver_data<grchamp_state>();
 	int offset = param >> 8;
 	state->comm_latch2[offset & 3] = param;
 }
@@ -410,7 +410,7 @@ static WRITE8_HANDLER( main_to_sub_comm_w )
 
 static READ8_HANDLER( main_to_sub_comm_r )
 {
-	grchamp_state *state = (grchamp_state *)space->machine->driver_data;
+	grchamp_state *state = space->machine->driver_data<grchamp_state>();
 	return state->comm_latch2[offset];
 }
 
@@ -671,61 +671,60 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static MACHINE_DRIVER_START( grchamp )
-	MDRV_DRIVER_DATA(grchamp_state)
+static MACHINE_CONFIG_START( grchamp, grchamp_state )
 
 	/* basic machine hardware */
 	/* CPU BOARD */
-	MDRV_CPU_ADD("maincpu", Z80, PIXEL_CLOCK/2)
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_IO_MAP(main_portmap)
-	MDRV_CPU_VBLANK_INT("screen", grchamp_cpu0_interrupt)
+	MCFG_CPU_ADD("maincpu", Z80, PIXEL_CLOCK/2)
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_IO_MAP(main_portmap)
+	MCFG_CPU_VBLANK_INT("screen", grchamp_cpu0_interrupt)
 
 	/* GAME BOARD */
-	MDRV_CPU_ADD("sub", Z80, PIXEL_CLOCK/2)
-	MDRV_CPU_PROGRAM_MAP(sub_map)
-	MDRV_CPU_IO_MAP(sub_portmap)
-	MDRV_CPU_VBLANK_INT("screen", grchamp_cpu1_interrupt)
+	MCFG_CPU_ADD("sub", Z80, PIXEL_CLOCK/2)
+	MCFG_CPU_PROGRAM_MAP(sub_map)
+	MCFG_CPU_IO_MAP(sub_portmap)
+	MCFG_CPU_VBLANK_INT("screen", grchamp_cpu1_interrupt)
 
 	/* SOUND BOARD */
-	MDRV_CPU_ADD("audiocpu", Z80, SOUND_CLOCK/2)
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold, (double)SOUND_CLOCK/4/16/16/10/16)
+	MCFG_CPU_ADD("audiocpu", Z80, SOUND_CLOCK/2)
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold, (double)SOUND_CLOCK/4/16/16/10/16)
 
-	MDRV_MACHINE_RESET(grchamp)
-	MDRV_WATCHDOG_VBLANK_INIT(8)
-	MDRV_QUANTUM_TIME(HZ(6000))
+	MCFG_MACHINE_RESET(grchamp)
+	MCFG_WATCHDOG_VBLANK_INIT(8)
+	MCFG_QUANTUM_TIME(HZ(6000))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
-	MDRV_GFXDECODE(grchamp)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_ALWAYS_UPDATE)
+	MCFG_GFXDECODE(grchamp)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
-	MDRV_PALETTE_INIT(grchamp)
-	MDRV_VIDEO_START(grchamp)
-	MDRV_VIDEO_UPDATE(grchamp)
+	MCFG_PALETTE_INIT(grchamp)
+	MCFG_VIDEO_START(grchamp)
+	MCFG_VIDEO_UPDATE(grchamp)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, SOUND_CLOCK/4)	/* 3B */
-	MDRV_SOUND_CONFIG(ay8910_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
+	MCFG_SOUND_ADD("ay1", AY8910, SOUND_CLOCK/4)	/* 3B */
+	MCFG_SOUND_CONFIG(ay8910_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
-	MDRV_SOUND_ADD("ay2", AY8910, SOUND_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
+	MCFG_SOUND_ADD("ay2", AY8910, SOUND_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
-	MDRV_SOUND_ADD("ay3", AY8910, SOUND_CLOCK/4)	/* 1B */
-	MDRV_SOUND_CONFIG(ay8910_interface_3)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
+	MCFG_SOUND_ADD("ay3", AY8910, SOUND_CLOCK/4)	/* 1B */
+	MCFG_SOUND_CONFIG(ay8910_interface_3)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.2)
 
-	MDRV_SOUND_ADD("discrete", DISCRETE, 0)
-	MDRV_SOUND_CONFIG_DISCRETE(grchamp)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("discrete", DISCRETE, 0)
+	MCFG_SOUND_CONFIG_DISCRETE(grchamp)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
 
