@@ -274,8 +274,8 @@ GFXDECODE_END
 
 static MACHINE_START( gunsmoke )
 {
-	gunsmoke_state *state = (gunsmoke_state *)machine->driver_data;
-	UINT8 *rombase = memory_region(machine, "maincpu");
+	gunsmoke_state *state = machine->driver_data<gunsmoke_state>();
+	UINT8 *rombase = machine->region("maincpu")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 4, &rombase[0x10000], 0x4000);
 
@@ -287,7 +287,7 @@ static MACHINE_START( gunsmoke )
 
 static MACHINE_RESET( gunsmoke )
 {
-	gunsmoke_state *state = (gunsmoke_state *)machine->driver_data;
+	gunsmoke_state *state = machine->driver_data<gunsmoke_state>();
 
 	state->chon = 0;
 	state->objon = 0;
@@ -295,53 +295,50 @@ static MACHINE_RESET( gunsmoke )
 	state->sprite3bank = 0;
 }
 
-static MACHINE_DRIVER_START( gunsmoke )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(gunsmoke_state)
+static MACHINE_CONFIG_START( gunsmoke, gunsmoke_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000)	// 4 MHz
-	MDRV_CPU_PROGRAM_MAP(gunsmoke_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000)	// 4 MHz
+	MCFG_CPU_PROGRAM_MAP(gunsmoke_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3000000)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold, 4)
+	MCFG_CPU_ADD("audiocpu", Z80, 3000000)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold, 4)
 
-	MDRV_MACHINE_START(gunsmoke)
-	MDRV_MACHINE_RESET(gunsmoke)
+	MCFG_MACHINE_START(gunsmoke)
+	MCFG_MACHINE_RESET(gunsmoke)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(gunsmoke)
-	MDRV_PALETTE_LENGTH(32*4+16*16+16*16)
+	MCFG_GFXDECODE(gunsmoke)
+	MCFG_PALETTE_LENGTH(32*4+16*16+16*16)
 
-	MDRV_PALETTE_INIT(gunsmoke)
-	MDRV_VIDEO_START(gunsmoke)
-	MDRV_VIDEO_UPDATE(gunsmoke)
+	MCFG_PALETTE_INIT(gunsmoke)
+	MCFG_VIDEO_START(gunsmoke)
+	MCFG_VIDEO_UPDATE(gunsmoke)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ym1", YM2203, 1500000)
-	MDRV_SOUND_ROUTE(0, "mono", 0.22)
-	MDRV_SOUND_ROUTE(1, "mono", 0.22)
-	MDRV_SOUND_ROUTE(2, "mono", 0.22)
-	MDRV_SOUND_ROUTE(3, "mono", 0.14)
+	MCFG_SOUND_ADD("ym1", YM2203, 1500000)
+	MCFG_SOUND_ROUTE(0, "mono", 0.22)
+	MCFG_SOUND_ROUTE(1, "mono", 0.22)
+	MCFG_SOUND_ROUTE(2, "mono", 0.22)
+	MCFG_SOUND_ROUTE(3, "mono", 0.14)
 
-	MDRV_SOUND_ADD("ym2", YM2203, 1500000)
-	MDRV_SOUND_ROUTE(0, "mono", 0.22)
-	MDRV_SOUND_ROUTE(1, "mono", 0.22)
-	MDRV_SOUND_ROUTE(2, "mono", 0.22)
-	MDRV_SOUND_ROUTE(3, "mono", 0.14)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ym2", YM2203, 1500000)
+	MCFG_SOUND_ROUTE(0, "mono", 0.22)
+	MCFG_SOUND_ROUTE(1, "mono", 0.22)
+	MCFG_SOUND_ROUTE(2, "mono", 0.22)
+	MCFG_SOUND_ROUTE(3, "mono", 0.14)
+MACHINE_CONFIG_END
 
 /* ROMs */
 
