@@ -1123,7 +1123,7 @@ static void halleys_decode_rgb(running_machine *machine, UINT32 *r, UINT32 *g, U
 	sram_189 = machine->generic.paletteram.u8;
 
 	// each of the three 32-byte 6330 PROM is wired to an RGB component output
-	prom_6330 = memory_region(machine, "proms");
+	prom_6330 = machine->region("proms")->base();
 
 	// latch1 holds 8 bits from the selected palette RAM address
 	latch1_273 = sram_189[addr];
@@ -1933,57 +1933,56 @@ static const ay8910_interface ay8910_config =
 };
 
 
-static MACHINE_DRIVER_START( halleys )
-	MDRV_CPU_ADD("maincpu", M6809, XTAL_19_968MHz/12) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(halleys_map)
-	MDRV_CPU_VBLANK_INT_HACK(halleys_interrupt, 4)
+static MACHINE_CONFIG_START( halleys, driver_device )
+	MCFG_CPU_ADD("maincpu", M6809, XTAL_19_968MHz/12) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(halleys_map)
+	MCFG_CPU_VBLANK_INT_HACK(halleys_interrupt, 4)
 
-	MDRV_CPU_ADD("audiocpu", Z80, XTAL_6MHz/2) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold, (double)6000000/(4*16*16*10*16))
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_6MHz/2) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold, (double)6000000/(4*16*16*10*16))
 
-	MDRV_MACHINE_RESET(halleys)
+	MCFG_MACHINE_RESET(halleys)
 
 	// video hardware
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(59.50)	/* verified on PCB */
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(SCREEN_WIDTH, SCREEN_HEIGHT)
-	MDRV_SCREEN_VISIBLE_AREA(VIS_MINX, VIS_MAXX, VIS_MINY, VIS_MAXY)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(59.50)	/* verified on PCB */
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(SCREEN_WIDTH, SCREEN_HEIGHT)
+	MCFG_SCREEN_VISIBLE_AREA(VIS_MINX, VIS_MAXX, VIS_MINY, VIS_MAXY)
 
-	MDRV_PALETTE_LENGTH(PALETTE_SIZE)
-	MDRV_PALETTE_INIT(halleys)
+	MCFG_PALETTE_LENGTH(PALETTE_SIZE)
+	MCFG_PALETTE_INIT(halleys)
 
-	MDRV_VIDEO_START(halleys)
-	MDRV_VIDEO_UPDATE(halleys)
+	MCFG_VIDEO_START(halleys)
+	MCFG_VIDEO_UPDATE(halleys)
 
 	// sound hardware
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, XTAL_6MHz/4) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_SOUND_ADD("ay1", AY8910, XTAL_6MHz/4) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("ay2", AY8910, XTAL_6MHz/4) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_SOUND_ADD("ay2", AY8910, XTAL_6MHz/4) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("ay3", AY8910, XTAL_6MHz/4) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_SOUND_ADD("ay3", AY8910, XTAL_6MHz/4) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("ay4", AY8910, XTAL_6MHz/4) /* verified on pcb */
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay4", AY8910, XTAL_6MHz/4) /* verified on pcb */
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( benberob )
-	MDRV_IMPORT_FROM(halleys)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_CLOCK(XTAL_19_968MHz/12) /* not verified but pcb identical to halley's comet */
-	MDRV_CPU_VBLANK_INT_HACK(benberob_interrupt, 4)
-	MDRV_VIDEO_UPDATE(benberob)
-MACHINE_DRIVER_END
+static MACHINE_CONFIG_DERIVED( benberob, halleys )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_CLOCK(XTAL_19_968MHz/12) /* not verified but pcb identical to halley's comet */
+	MCFG_CPU_VBLANK_INT_HACK(benberob_interrupt, 4)
+	MCFG_VIDEO_UPDATE(benberob)
+MACHINE_CONFIG_END
 
 
 //**************************************************************************
@@ -2165,7 +2164,7 @@ static void init_common(running_machine *machine)
 
 
 	// decrypt main program ROM
-	rom = cpu1_base = memory_region(machine, "maincpu");
+	rom = cpu1_base = machine->region("maincpu")->base();
 	buf = gfx1_base;
 
 	for (i=0; i<0x10000; i++)
@@ -2178,7 +2177,7 @@ static void init_common(running_machine *machine)
 
 
 	// swap graphics ROM addresses and unpack each pixel
-	rom = memory_region(machine, "gfx1");
+	rom = machine->region("gfx1")->base();
 	buf = gfx_plane02;
 
 	for (i=0xffff; i>=0; i--)
