@@ -74,7 +74,7 @@ static VIDEO_START( itgambl2 )
 static VIDEO_UPDATE( itgambl2 )
 {
 	int x,y,count;
-	const UINT8 *blit_ram = memory_region(screen->machine,"gfx1");
+	const UINT8 *blit_ram = screen->machine->region("gfx1")->base();
 
 	if(input_code_pressed(screen->machine, KEYCODE_Z))
 		test_x++;
@@ -247,32 +247,32 @@ static PALETTE_INIT( itgambl2 )
 *     Machine Drivers     *
 **************************/
 
-static MACHINE_DRIVER_START( itgambl2 )
+static MACHINE_CONFIG_START( itgambl2, driver_device )
 
     /* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", H83044, MAIN_CLOCK)	/* wrong CPU, but we have not a H8/3337 core ATM */
-	MDRV_CPU_PROGRAM_MAP(itgambl2_map)
+	MCFG_CPU_ADD("maincpu", H83044, MAIN_CLOCK)	/* wrong CPU, but we have not a H8/3337 core ATM */
+	MCFG_CPU_PROGRAM_MAP(itgambl2_map)
 
     /* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(512, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
-	MDRV_MACHINE_RESET( itgambl2 )
-	MDRV_PALETTE_INIT( itgambl2 )
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
+	MCFG_MACHINE_RESET( itgambl2 )
+	MCFG_PALETTE_INIT( itgambl2 )
 
-	MDRV_GFXDECODE(itgambl2)
-	MDRV_PALETTE_LENGTH(0x200)
-	MDRV_VIDEO_START( itgambl2 )
-	MDRV_VIDEO_UPDATE( itgambl2 )
+	MCFG_GFXDECODE(itgambl2)
+	MCFG_PALETTE_LENGTH(0x200)
+	MCFG_VIDEO_START( itgambl2 )
+	MCFG_VIDEO_UPDATE( itgambl2 )
 
     /* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("upd", UPD7759, UPD7759_STANDARD_CLOCK)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("upd", UPD7759, UPD7759_STANDARD_CLOCK)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
 /*************************
