@@ -786,7 +786,7 @@ static void cde_handle_reports(void)
 	}
 }
 
-static void cde_dma_transfer(const address_space *space, int channel, int next)
+static void cde_dma_transfer(address_space *space, int channel, int next)
 {
 	UINT32 address;
 	//int length;
@@ -805,7 +805,7 @@ static void cde_dma_transfer(const address_space *space, int channel, int next)
 
 	for (i=0; i < cde_dma[channel].next_length; i++)
 	{
-		memory_write_byte(space, address, 0xff);		// TODO: do the real transfer...
+		space->write_byte(address, 0xff);		// TODO: do the real transfer...
 		address++;
 	}
 }
@@ -1130,33 +1130,33 @@ static INTERRUPT_GEN(m2)
 	cpu_set_input_line(device, INPUT_LINE_IRQ0, ASSERT_LINE);
 }
 
-static MACHINE_DRIVER_START( m2 )
+static MACHINE_CONFIG_START( m2, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", PPC602, 33000000)	/* actually PPC602, 66MHz */
-	MDRV_CPU_CONFIG(ppc602_config)
-	MDRV_CPU_PROGRAM_MAP(m2_main)
-	MDRV_CPU_VBLANK_INT("screen", m2)
+	MCFG_CPU_ADD("maincpu", PPC602, 33000000)	/* actually PPC602, 66MHz */
+	MCFG_CPU_CONFIG(ppc602_config)
+	MCFG_CPU_PROGRAM_MAP(m2_main)
+	MCFG_CPU_VBLANK_INT("screen", m2)
 
-	MDRV_CPU_ADD("sub", PPC602, 33000000)	/* actually PPC602, 66MHz */
-	MDRV_CPU_CONFIG(ppc602_config)
-	MDRV_CPU_PROGRAM_MAP(m2_main)
+	MCFG_CPU_ADD("sub", PPC602, 33000000)	/* actually PPC602, 66MHz */
+	MCFG_CPU_CONFIG(ppc602_config)
+	MCFG_CPU_PROGRAM_MAP(m2_main)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(640, 480)
-	MDRV_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(640, 480)
+	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
 
-	MDRV_PALETTE_LENGTH(32768)
-	MDRV_PALETTE_INIT(RRRRR_GGGGG_BBBBB)
+	MCFG_PALETTE_LENGTH(32768)
+	MCFG_PALETTE_INIT(RRRRR_GGGGG_BBBBB)
 
-	MDRV_VIDEO_START(m2)
-	MDRV_VIDEO_UPDATE(m2)
+	MCFG_VIDEO_START(m2)
+	MCFG_VIDEO_UPDATE(m2)
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 
 ROM_START( polystar )
