@@ -65,13 +65,13 @@ Notes:
 #include "emu.h"
 #include "deprecat.h"
 #include "cpu/h83002/h8.h"
+#include "machine/nvram.h"
 
-class lastfght_state
+class lastfght_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, lastfght_state(machine)); }
-
-	lastfght_state(running_machine &machine) { }
+	lastfght_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  colorram;
@@ -88,7 +88,7 @@ public:
 	UINT16 c00006;
 
 	/* devices */
-	running_device *maincpu;
+	device_t *maincpu;
 };
 
 
@@ -98,7 +98,7 @@ public:
 
 static VIDEO_START( lastfght )
 {
-	lastfght_state *state = (lastfght_state *)machine->driver_data;
+	lastfght_state *state = machine->driver_data<lastfght_state>();
 	int i;
 	for (i = 0; i < 2; i++)
 		state->bitmap[i] = machine->primary_screen->alloc_compatible_bitmap();
@@ -113,7 +113,7 @@ static VIDEO_START( lastfght )
 
 static VIDEO_UPDATE( lastfght )
 {
-	lastfght_state *state = (lastfght_state *)screen->machine->driver_data;
+	lastfght_state *state = screen->machine->driver_data<lastfght_state>();
 
 #ifdef MAME_DEBUG
 #if 1
@@ -121,7 +121,7 @@ static VIDEO_UPDATE( lastfght )
 	int x, y, count = 0;
 	static unsigned base = 0;
 	static int view_roms = 0;
-	UINT8 *gfxdata = memory_region(screen->machine, "gfx1");
+	UINT8 *gfxdata = screen->machine->region("gfx1")->base();
 	UINT8 data;
 
 	if (input_code_pressed_once(screen->machine, KEYCODE_ENTER))	view_roms ^= 1;
@@ -129,7 +129,7 @@ static VIDEO_UPDATE( lastfght )
 	{
 		if (input_code_pressed_once(screen->machine, KEYCODE_PGDN))	base += 512 * 256;
 		if (input_code_pressed_once(screen->machine, KEYCODE_PGUP))	base -= 512 * 256;
-		base %= memory_region_length(screen->machine, "gfx1");
+		base %= screen->machine->region("gfx1")->bytes();
 
 		count = base;
 
@@ -158,7 +158,7 @@ static VIDEO_UPDATE( lastfght )
 
 static WRITE16_HANDLER( colordac_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -181,7 +181,7 @@ static WRITE16_HANDLER( colordac_w )
 // high byte of a 16 bit register
 static WRITE16_HANDLER( lastfght_hi_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 		logerror("%06x: 600000.b = %02x\n", cpu_get_pc(space->cpu), data >> 8);
@@ -195,7 +195,7 @@ static WRITE16_HANDLER( lastfght_hi_w )
 // screen x
 static WRITE16_HANDLER( lastfght_x_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 		logerror("%06x: 800008.b = %02x\n", cpu_get_pc(space->cpu), data >> 8);
@@ -209,7 +209,7 @@ static WRITE16_HANDLER( lastfght_x_w )
 // screen y, screen width - 1
 static WRITE16_HANDLER( lastfght_yw_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -226,7 +226,7 @@ static WRITE16_HANDLER( lastfght_yw_w )
 // screen height - 1
 static WRITE16_HANDLER( lastfght_h_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -240,7 +240,7 @@ static WRITE16_HANDLER( lastfght_h_w )
 // source delta x << 6, source x << 6
 static WRITE16_HANDLER( lastfght_sx_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -257,7 +257,7 @@ static WRITE16_HANDLER( lastfght_sx_w )
 // source y << 6, source y1 << 6
 static WRITE16_HANDLER( lastfght_sy_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -274,7 +274,7 @@ static WRITE16_HANDLER( lastfght_sy_w )
 // source rom (0x200000 bytes), source page (512x256 bytes)
 static WRITE16_HANDLER( lastfght_sr_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -291,7 +291,7 @@ static WRITE16_HANDLER( lastfght_sr_w )
 // source x1 << 6, source delta y << 6
 static WRITE16_HANDLER( lastfght_sd_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
@@ -308,12 +308,12 @@ static WRITE16_HANDLER( lastfght_sd_w )
 // start blit
 static WRITE16_HANDLER( lastfght_blit_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
 		int x, y, addr;
-		UINT8 *gfxdata = memory_region( space->machine, "gfx1" );
+		UINT8 *gfxdata = space->machine->region( "gfx1" )->base();
 		bitmap_t *dest = state->bitmap[state->dest];
 
 #if 0
@@ -347,7 +347,7 @@ static WRITE16_HANDLER( lastfght_blit_w )
 // toggle framebuffer
 static WRITE16_HANDLER( lastfght_dest_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 
 	if (ACCESSING_BITS_0_7)
 		state->dest ^= 1;
@@ -366,7 +366,7 @@ static READ16_HANDLER( lastfght_c00002_r )
 {
 	// high byte:
 	// mask 0x1c: from sound?
-	return (mame_rand(space->machine) & 0x1c00) | input_port_read(space->machine, "IN0");
+	return (space->machine->rand() & 0x1c00) | input_port_read(space->machine, "IN0");
 }
 
 static READ16_HANDLER( lastfght_c00004_r )
@@ -384,7 +384,7 @@ static READ16_HANDLER( lastfght_c00006_r )
 
 static WRITE16_HANDLER( lastfght_c00006_w )
 {
-	lastfght_state *state = (lastfght_state *)space->machine->driver_data;
+	lastfght_state *state = space->machine->driver_data<lastfght_state>();
 	COMBINE_DATA(&state->c00006);
 	//  popmessage("%04x", state->c00006);
 }
@@ -414,7 +414,7 @@ static ADDRESS_MAP_START( lastfght_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE( 0x000000, 0x07ffff ) AM_ROM AM_REGION("maincpu", 0)
 	AM_RANGE( 0x080000, 0x0fffff ) AM_ROM AM_REGION("maincpu", 0)
 
-	AM_RANGE( 0x200000, 0x20ffff ) AM_RAM AM_BASE_SIZE_GENERIC(nvram)	// battery
+	AM_RANGE( 0x200000, 0x20ffff ) AM_RAM AM_SHARE("nvram")	// battery
 
 	AM_RANGE( 0x600000, 0x600001 ) AM_WRITE( lastfght_hi_w )
 	AM_RANGE( 0x600002, 0x600003 ) AM_READWRITE( lastfght_sound_r, lastfght_sound_w )
@@ -511,7 +511,7 @@ INPUT_PORTS_END
 
 static INTERRUPT_GEN( unknown_interrupt )
 {
-	lastfght_state *state = (lastfght_state *)device->machine->driver_data;
+	lastfght_state *state = device->machine->driver_data<lastfght_state>();
 	switch (cpu_getiloops(device))
 	{
 		case 0:
@@ -525,7 +525,7 @@ static INTERRUPT_GEN( unknown_interrupt )
 
 static MACHINE_START( lastfght )
 {
-	lastfght_state *state = (lastfght_state *)machine->driver_data;
+	lastfght_state *state = machine->driver_data<lastfght_state>();
 
 	state->maincpu = machine->device("maincpu");
 
@@ -549,7 +549,7 @@ static MACHINE_START( lastfght )
 
 static MACHINE_RESET( lastfght )
 {
-	lastfght_state *state = (lastfght_state *)machine->driver_data;
+	lastfght_state *state = machine->driver_data<lastfght_state>();
 
 	state->clr_offset = 0;
 	state->dest = 0;
@@ -569,33 +569,30 @@ static MACHINE_RESET( lastfght )
 	state->c00006 = 0;
 }
 
-static MACHINE_DRIVER_START( lastfght )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(lastfght_state)
+static MACHINE_CONFIG_START( lastfght, lastfght_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", H83044, 32000000/2)
-	MDRV_CPU_PROGRAM_MAP( lastfght_map)
-	MDRV_CPU_VBLANK_INT_HACK(unknown_interrupt,2)
+	MCFG_CPU_ADD("maincpu", H83044, 32000000/2)
+	MCFG_CPU_PROGRAM_MAP( lastfght_map)
+	MCFG_CPU_VBLANK_INT_HACK(unknown_interrupt,2)
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_MACHINE_START(lastfght)
-	MDRV_MACHINE_RESET(lastfght)
+	MCFG_MACHINE_START(lastfght)
+	MCFG_MACHINE_RESET(lastfght)
 
 	/* video hardware */
-	MDRV_PALETTE_LENGTH( 256 )
+	MCFG_PALETTE_LENGTH( 256 )
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE( 512, 256 )
-	MDRV_SCREEN_VISIBLE_AREA( 0, 512-1, 0, 256-16-1 )
-	MDRV_SCREEN_REFRESH_RATE( 60 )
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE( 512, 256 )
+	MCFG_SCREEN_VISIBLE_AREA( 0, 512-1, 0, 256-16-1 )
+	MCFG_SCREEN_REFRESH_RATE( 60 )
 
-	MDRV_VIDEO_START( lastfght )
-	MDRV_VIDEO_UPDATE( lastfght )
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START( lastfght )
+	MCFG_VIDEO_UPDATE( lastfght )
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
@@ -618,7 +615,7 @@ ROM_END
 
 static DRIVER_INIT(lastfght)
 {
-	UINT16 *rom = (UINT16*)memory_region(machine, "maincpu");
+	UINT16 *rom = (UINT16*)machine->region("maincpu")->base();
 
 	// pass initial check (protection ? hw?)
 	rom[0x00354 / 2] = 0x403e;
