@@ -27,8 +27,8 @@
 
 static READ8_HANDLER( deco16_bank_r )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
-	const UINT8 *ROM = memory_region(space->machine, "user1");
+	liberate_state *state = space->machine->driver_data<liberate_state>();
+	const UINT8 *ROM = space->machine->region("user1")->base();
 
 	/* The tilemap bank can be swapped into main memory */
 	if (state->bank)
@@ -67,7 +67,7 @@ static READ8_HANDLER( deco16_io_r )
 
 static WRITE8_HANDLER( deco16_bank_w )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
+	liberate_state *state = space->machine->driver_data<liberate_state>();
 	state->bank = data;
 
 	if (state->bank)
@@ -78,8 +78,8 @@ static WRITE8_HANDLER( deco16_bank_w )
 
 static READ8_HANDLER( prosoccr_bank_r )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
-	const UINT8 *ROM = memory_region(space->machine, "user1");
+	liberate_state *state = space->machine->driver_data<liberate_state>();
+	const UINT8 *ROM = space->machine->region("user1")->base();
 
 	/* The tilemap bank can be swapped into main memory */
 	if (state->bank)
@@ -108,8 +108,8 @@ static READ8_HANDLER( prosoccr_bank_r )
 
 static READ8_HANDLER( prosoccr_charram_r )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
-	UINT8 *SRC_GFX = memory_region(space->machine, "shared_gfx");
+	liberate_state *state = space->machine->driver_data<liberate_state>();
+	UINT8 *SRC_GFX = space->machine->region("shared_gfx")->base();
 
 	if (state->gfx_rom_readback)
 	{
@@ -130,8 +130,8 @@ static READ8_HANDLER( prosoccr_charram_r )
 
 static WRITE8_HANDLER( prosoccr_charram_w )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
-	UINT8 *FG_GFX = memory_region(space->machine, "fg_gfx");
+	liberate_state *state = space->machine->driver_data<liberate_state>();
+	UINT8 *FG_GFX = space->machine->region("fg_gfx")->base();
 
 	if (state->bank)
 	{
@@ -168,7 +168,7 @@ static WRITE8_HANDLER( prosoccr_charram_w )
 
 static WRITE8_HANDLER( prosoccr_char_bank_w )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
+	liberate_state *state = space->machine->driver_data<liberate_state>();
 	state->gfx_rom_readback = data & 1; //enable GFX rom read-back
 
 	if (data & 0xfe)
@@ -177,7 +177,7 @@ static WRITE8_HANDLER( prosoccr_char_bank_w )
 
 static WRITE8_HANDLER( prosoccr_io_bank_w )
 {
-	liberate_state *state = (liberate_state *)space->machine->driver_data;
+	liberate_state *state = space->machine->driver_data<liberate_state>();
 	state->bank = data & 1;
 
 	if (state->bank)
@@ -189,7 +189,7 @@ static WRITE8_HANDLER( prosoccr_io_bank_w )
 
 static READ8_HANDLER( prosport_charram_r )
 {
-	UINT8 *FG_GFX = memory_region(space->machine, "progolf_fg_gfx");
+	UINT8 *FG_GFX = space->machine->region("progolf_fg_gfx")->base();
 
 	switch (offset & 0x1800)
 	{
@@ -209,7 +209,7 @@ static READ8_HANDLER( prosport_charram_r )
 
 static WRITE8_HANDLER( prosport_charram_w )
 {
-	UINT8 *FG_GFX = memory_region(space->machine, "progolf_fg_gfx");
+	UINT8 *FG_GFX = space->machine->region("progolf_fg_gfx")->base();
 
 	switch (offset & 0x1800)
 	{
@@ -769,7 +769,7 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( deco16_interrupt )
 {
-	liberate_state *state = (liberate_state *)device->machine->driver_data;
+	liberate_state *state = device->machine->driver_data<liberate_state>();
 	int p = ~input_port_read(device->machine, "IN3");
 	if ((p & 0x43) && !state->latch)
 	{
@@ -799,7 +799,7 @@ static INTERRUPT_GEN( prosport_interrupt )
 
 static MACHINE_START( liberate )
 {
-	liberate_state *state = (liberate_state *)machine->driver_data;
+	liberate_state *state = machine->driver_data<liberate_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = machine->device("audiocpu");
@@ -815,7 +815,7 @@ static MACHINE_START( liberate )
 
 static MACHINE_RESET( liberate )
 {
-	liberate_state *state = (liberate_state *)machine->driver_data;
+	liberate_state *state = machine->driver_data<liberate_state>();
 
 	memset(state->io_ram, 0, ARRAY_LENGTH(state->io_ram));
 
@@ -826,133 +826,125 @@ static MACHINE_RESET( liberate )
 	state->bank = 0;
 }
 
-static MACHINE_DRIVER_START( liberate )
-
-	MDRV_DRIVER_DATA(liberate_state)
+static MACHINE_CONFIG_START( liberate, liberate_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu",DECO16, 2000000)
-	MDRV_CPU_PROGRAM_MAP(liberate_map)
-	MDRV_CPU_IO_MAP(deco16_io_map)
-	MDRV_CPU_VBLANK_INT("screen", deco16_interrupt)
+	MCFG_CPU_ADD("maincpu",DECO16, 2000000)
+	MCFG_CPU_PROGRAM_MAP(liberate_map)
+	MCFG_CPU_IO_MAP(deco16_io_map)
+	MCFG_CPU_VBLANK_INT("screen", deco16_interrupt)
 
-	MDRV_CPU_ADD("audiocpu",M6502, 1500000)
-	MDRV_CPU_PROGRAM_MAP(liberate_sound_map)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
+	MCFG_CPU_ADD("audiocpu",M6502, 1500000)
+	MCFG_CPU_PROGRAM_MAP(liberate_sound_map)
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
 
-	MDRV_QUANTUM_TIME(HZ(12000))
+	MCFG_QUANTUM_TIME(HZ(12000))
 
-	MDRV_MACHINE_START(liberate)
-	MDRV_MACHINE_RESET(liberate)
+	MCFG_MACHINE_START(liberate)
+	MCFG_MACHINE_RESET(liberate)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529) /* 529ms Vblank duration?? */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529) /* 529ms Vblank duration?? */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(liberate)
-	MDRV_PALETTE_LENGTH(33)
-	MDRV_PALETTE_INIT(liberate)
+	MCFG_GFXDECODE(liberate)
+	MCFG_PALETTE_LENGTH(33)
+	MCFG_PALETTE_INIT(liberate)
 
-	MDRV_VIDEO_START(liberate)
-	MDRV_VIDEO_UPDATE(liberate)
+	MCFG_VIDEO_START(liberate)
+	MCFG_VIDEO_UPDATE(liberate)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( liberatb )
-	MDRV_IMPORT_FROM(liberate)
+static MACHINE_CONFIG_DERIVED( liberatb, liberate )
 
 	/* basic machine hardware */
-	MDRV_CPU_REPLACE("maincpu", M6502, 2000000)
-	MDRV_CPU_PROGRAM_MAP(liberatb_map)
-	MDRV_CPU_VBLANK_INT("screen", deco16_interrupt)
-MACHINE_DRIVER_END
+	MCFG_CPU_REPLACE("maincpu", M6502, 2000000)
+	MCFG_CPU_PROGRAM_MAP(liberatb_map)
+	MCFG_CPU_VBLANK_INT("screen", deco16_interrupt)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( boomrang )
-	MDRV_IMPORT_FROM(liberate)
+static MACHINE_CONFIG_DERIVED( boomrang, liberate )
 
-	MDRV_VIDEO_START(boomrang)
-	MDRV_VIDEO_UPDATE(boomrang)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(boomrang)
+	MCFG_VIDEO_UPDATE(boomrang)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( prosoccr )
-
-	MDRV_IMPORT_FROM(liberate)
+static MACHINE_CONFIG_DERIVED( prosoccr, liberate )
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_CLOCK(10000000/8) //xtal is unknown?
-	MDRV_CPU_PROGRAM_MAP(prosoccr_map)
-	MDRV_CPU_IO_MAP(prosoccr_io_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_CLOCK(10000000/8) //xtal is unknown?
+	MCFG_CPU_PROGRAM_MAP(prosoccr_map)
+	MCFG_CPU_IO_MAP(prosoccr_io_map)
 
-	MDRV_CPU_MODIFY("audiocpu")
-	MDRV_CPU_CLOCK(10000000/8) //xtal is 12 Mhz, divider is unknown
-	MDRV_CPU_PROGRAM_MAP(prosoccr_sound_map)
+	MCFG_CPU_MODIFY("audiocpu")
+	MCFG_CPU_CLOCK(10000000/8) //xtal is 12 Mhz, divider is unknown
+	MCFG_CPU_PROGRAM_MAP(prosoccr_sound_map)
 
-	MDRV_QUANTUM_TIME(HZ(12000))
+	MCFG_QUANTUM_TIME(HZ(12000))
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0*8, 32*8-1)
 
-	MDRV_GFXDECODE(prosoccr)
+	MCFG_GFXDECODE(prosoccr)
 
-	MDRV_VIDEO_START(prosoccr)
-	MDRV_VIDEO_UPDATE(prosoccr)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(prosoccr)
+	MCFG_VIDEO_UPDATE(prosoccr)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( prosport )
-
-	MDRV_DRIVER_DATA(liberate_state)
+static MACHINE_CONFIG_START( prosport, liberate_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", DECO16, 2000000)
-	MDRV_CPU_PROGRAM_MAP(prosport_map)
-	MDRV_CPU_IO_MAP(deco16_io_map)
-	MDRV_CPU_VBLANK_INT("screen", deco16_interrupt)
+	MCFG_CPU_ADD("maincpu", DECO16, 2000000)
+	MCFG_CPU_PROGRAM_MAP(prosport_map)
+	MCFG_CPU_IO_MAP(deco16_io_map)
+	MCFG_CPU_VBLANK_INT("screen", deco16_interrupt)
 
-	MDRV_CPU_ADD("audiocpu", M6502, 1500000/2)
-	MDRV_CPU_PROGRAM_MAP(liberate_sound_map)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
+	MCFG_CPU_ADD("audiocpu", M6502, 1500000/2)
+	MCFG_CPU_PROGRAM_MAP(liberate_sound_map)
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse,16*60) /* ??? */
 
-//  MDRV_QUANTUM_TIME(HZ(12000))
+//  MCFG_QUANTUM_TIME(HZ(12000))
 
-	MDRV_MACHINE_START(liberate)
-	MDRV_MACHINE_RESET(liberate)
+	MCFG_MACHINE_START(liberate)
+	MCFG_MACHINE_RESET(liberate)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(1529) /* 529ms Vblank duration?? */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(1529) /* 529ms Vblank duration?? */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(prosport)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE(prosport)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_VIDEO_START(prosport)
-	MDRV_VIDEO_UPDATE(prosport)
+	MCFG_VIDEO_START(prosport)
+	MCFG_VIDEO_UPDATE(prosport)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
 /*************************************
@@ -1364,21 +1356,21 @@ ROM_END
 
 static void sound_cpu_decrypt(running_machine *machine)
 {
-	const address_space *space = cputag_get_address_space(machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x4000);
-	UINT8 *rom = memory_region(machine, "audiocpu");
+	UINT8 *rom = machine->region("audiocpu")->base();
 	int i;
 
 	/* Bit swapping on sound cpu - Opcodes only */
 	for (i = 0xc000; i < 0x10000; i++)
 		decrypted[i - 0xc000] = ((rom[i] & 0x20) << 1) | ((rom[i] & 0x40) >> 1) | (rom[i] & 0x9f);
 
-	memory_set_decrypted_region(space, 0xc000, 0xffff, decrypted);
+	space->set_decrypted_region(0xc000, 0xffff, decrypted);
 }
 
 static DRIVER_INIT( prosport )
 {
-	UINT8 *RAM = memory_region(machine, "maincpu");
+	UINT8 *RAM = machine->region("maincpu")->base();
 	int i;
 
 	/* Main cpu has the nibbles swapped */
@@ -1398,11 +1390,11 @@ static DRIVER_INIT( yellowcb )
 static DRIVER_INIT( liberate )
 {
 	int A;
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x10000);
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	UINT8 *ROM = machine->region("maincpu")->base();
 
-	memory_set_decrypted_region(space, 0x0000, 0xffff, decrypted);
+	space->set_decrypted_region(0x0000, 0xffff, decrypted);
 
 	/* Swap bits for opcodes only, not data */
 	for (A = 0; A < 0x10000; A++) {
