@@ -815,36 +815,36 @@ static INTERRUPT_GEN( luckgrln_irq )
 		cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static MACHINE_DRIVER_START( luckgrln )
-	MDRV_CPU_ADD("maincpu", Z180,8000000)
-	MDRV_CPU_PROGRAM_MAP(mainmap)
-	MDRV_CPU_IO_MAP(portmap)
-	MDRV_CPU_VBLANK_INT("screen", luckgrln_irq)
+static MACHINE_CONFIG_START( luckgrln, driver_device )
+	MCFG_CPU_ADD("maincpu", Z180,8000000)
+	MCFG_CPU_PROGRAM_MAP(mainmap)
+	MCFG_CPU_IO_MAP(portmap)
+	MCFG_CPU_VBLANK_INT("screen", luckgrln_irq)
 
-	MDRV_MC6845_ADD("crtc", H46505, 6000000/4, mc6845_intf)	/* unknown clock, hand tuned to get ~60 fps */
+	MCFG_MC6845_ADD("crtc", H46505, 6000000/4, mc6845_intf)	/* unknown clock, hand tuned to get ~60 fps */
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
 
-	MDRV_GFXDECODE(luckgrln)
-	MDRV_PALETTE_LENGTH(0x8000)
+	MCFG_GFXDECODE(luckgrln)
+	MCFG_PALETTE_LENGTH(0x8000)
 
-	MDRV_VIDEO_START(luckgrln)
-	MDRV_VIDEO_UPDATE(luckgrln)
+	MCFG_VIDEO_START(luckgrln)
+	MCFG_VIDEO_UPDATE(luckgrln)
 
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 static DRIVER_INIT( luckgrln )
 {
 	int i;
 	UINT8 x,v;
-	UINT8* rom = memory_region(machine,"rom_data");
+	UINT8* rom = machine->region("rom_data")->base();
 
 	for (i=0;i<0x20000;i++)
 	{
