@@ -76,16 +76,8 @@ TODO:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
-
-extern UINT8 *lvcards_videoram;
-extern UINT8 *lvcards_colorram;
-extern WRITE8_HANDLER( lvcards_videoram_w );
-extern WRITE8_HANDLER( lvcards_colorram_w );
-
-extern PALETTE_INIT( lvcards );
-extern PALETTE_INIT( ponttehk );
-extern VIDEO_START( lvcards );
-extern VIDEO_UPDATE( lvcards );
+#include "machine/nvram.h"
+#include "includes/lvcards.h"
 
 static UINT8 payout;
 static UINT8 pulse;
@@ -158,7 +150,7 @@ static READ8_HANDLER( payout_r )
 
 static ADDRESS_MAP_START( ponttehk_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
-	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x8000, 0x83ff) AM_RAM_WRITE(lvcards_videoram_w) AM_BASE(&lvcards_videoram)
 	AM_RANGE(0x8400, 0x87ff) AM_RAM_WRITE(lvcards_colorram_w) AM_BASE(&lvcards_colorram)
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("IN0")
@@ -168,7 +160,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( lvcards_map, ADDRESS_SPACE_PROGRAM, 8  )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
-	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x9000, 0x93ff) AM_RAM_WRITE(lvcards_videoram_w) AM_BASE(&lvcards_videoram)
 	AM_RANGE(0x9400, 0x97ff) AM_RAM_WRITE(lvcards_colorram_w) AM_BASE(&lvcards_colorram)
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("IN0")
@@ -185,7 +177,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( lvpoker_map, ADDRESS_SPACE_PROGRAM, 8  )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
-	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x6000, 0x67ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x9000, 0x93ff) AM_RAM_WRITE(lvcards_videoram_w) AM_BASE(&lvcards_videoram)
 	AM_RANGE(0x9400, 0x97ff) AM_RAM_WRITE(lvcards_colorram_w) AM_BASE(&lvcards_colorram)
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("IN0")
@@ -470,61 +462,59 @@ static const ay8910_interface lcay8910_interface =
 };
 
 
-static MACHINE_DRIVER_START( lvcards )
+static MACHINE_CONFIG_START( lvcards, driver_device )
 	// basic machine hardware
-	MDRV_CPU_ADD("maincpu",Z80, 18432000/6)	// 3.072 MHz ?
+	MCFG_CPU_ADD("maincpu",Z80, 18432000/6)	// 3.072 MHz ?
 
-	MDRV_CPU_PROGRAM_MAP(lvcards_map)
-	MDRV_CPU_IO_MAP(lvcards_io_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_PROGRAM_MAP(lvcards_map)
+	MCFG_CPU_IO_MAP(lvcards_io_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	// video hardware
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(8*0, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(8*0, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(lvcards)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE(lvcards)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_PALETTE_INIT(lvcards)
-	MDRV_VIDEO_START(lvcards)
-	MDRV_VIDEO_UPDATE(lvcards)
+	MCFG_PALETTE_INIT(lvcards)
+	MCFG_VIDEO_START(lvcards)
+	MCFG_VIDEO_UPDATE(lvcards)
 
 	// sound hardware
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("aysnd", AY8910, 18432000/12)
-	MDRV_SOUND_CONFIG(lcay8910_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("aysnd", AY8910, 18432000/12)
+	MCFG_SOUND_CONFIG(lcay8910_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( lvpoker )
-	MDRV_IMPORT_FROM( lvcards )
+static MACHINE_CONFIG_DERIVED( lvpoker, lvcards )
 
 	// basic machine hardware
-	MDRV_NVRAM_HANDLER(generic_1fill)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(lvpoker_map)
-	MDRV_MACHINE_START(lvpoker)
-	MDRV_MACHINE_RESET(lvpoker)
-MACHINE_DRIVER_END
+	MCFG_NVRAM_ADD_1FILL("nvram")
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(lvpoker_map)
+	MCFG_MACHINE_START(lvpoker)
+	MCFG_MACHINE_RESET(lvpoker)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( ponttehk )
-	MDRV_IMPORT_FROM( lvcards )
+static MACHINE_CONFIG_DERIVED( ponttehk, lvcards )
 
 	// basic machine hardware
-	MDRV_NVRAM_HANDLER(generic_1fill)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(ponttehk_map)
-	MDRV_MACHINE_RESET(lvpoker)
+	MCFG_NVRAM_ADD_1FILL("nvram")
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(ponttehk_map)
+	MCFG_MACHINE_RESET(lvpoker)
 
 	// video hardware
-	MDRV_PALETTE_INIT(ponttehk)
-MACHINE_DRIVER_END
+	MCFG_PALETTE_INIT(ponttehk)
+MACHINE_CONFIG_END
 
 ROM_START( lvpoker )
 	ROM_REGION( 0x10000, "maincpu", 0 )
