@@ -121,12 +121,11 @@ Dip locations verified for:
 #include "sound/ay8910.h"
 #include "sound/samples.h"
 
-class m63_state
+class m63_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, m63_state(machine)); }
-
-	m63_state(running_machine &machine) { }
+	m63_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	UINT8 *  videoram;
 	UINT8 *  colorram;
@@ -146,10 +145,10 @@ public:
 	INT16    *samplebuf;
 
 	/* sound devices */
-	running_device *soundcpu;
-	running_device *ay1;
-	running_device *ay2;
-	running_device *samples;
+	device_t *soundcpu;
+	device_t *ay1;
+	device_t *ay2;
+	device_t *samples;
 };
 
 
@@ -210,7 +209,7 @@ static PALETTE_INIT( m63 )
 
 static WRITE8_HANDLER( m63_videoram_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	state->videoram[offset] = data;
 	tilemap_mark_tile_dirty(state->bg_tilemap, offset);
@@ -218,7 +217,7 @@ static WRITE8_HANDLER( m63_videoram_w )
 
 static WRITE8_HANDLER( m63_colorram_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	state->colorram[offset] = data;
 	tilemap_mark_tile_dirty(state->bg_tilemap, offset);
@@ -226,7 +225,7 @@ static WRITE8_HANDLER( m63_colorram_w )
 
 static WRITE8_HANDLER( m63_videoram2_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	state->videoram2[offset] = data;
 	tilemap_mark_tile_dirty(state->fg_tilemap, offset);
@@ -234,7 +233,7 @@ static WRITE8_HANDLER( m63_videoram2_w )
 
 static WRITE8_HANDLER( m63_palbank_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	if (state->pal_bank != (data & 0x01))
 	{
@@ -254,7 +253,7 @@ static WRITE8_HANDLER( m63_flipscreen_w )
 
 static WRITE8_HANDLER( fghtbskt_flipscreen_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	flip_screen_set(space->machine, data);
 	state->fg_flag = flip_screen_get(space->machine) ? TILE_FLIPX : 0;
@@ -263,7 +262,7 @@ static WRITE8_HANDLER( fghtbskt_flipscreen_w )
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 
 	int attr = state->colorram[tile_index];
 	int code = state->videoram[tile_index] | ((attr & 0x30) << 4);
@@ -274,7 +273,7 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static TILE_GET_INFO( get_fg_tile_info )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 
 	int code = state->videoram2[tile_index];
 
@@ -283,7 +282,7 @@ static TILE_GET_INFO( get_fg_tile_info )
 
 static VIDEO_START( m63 )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 
 	state->bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 	state->fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
@@ -294,7 +293,7 @@ static VIDEO_START( m63 )
 
 static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 	int offs;
 
 	for (offs = 0; offs < state->spriteram_size; offs += 4)
@@ -335,7 +334,7 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 
 static VIDEO_UPDATE( m63 )
 {
-	m63_state *state = (m63_state *)screen->machine->driver_data;
+	m63_state *state = screen->machine->driver_data<m63_state>();
 
 	int col;
 
@@ -356,14 +355,14 @@ static WRITE8_HANDLER( coin_w )
 
 static WRITE8_HANDLER( snd_irq_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 	cpu_set_input_line(state->soundcpu, 0, ASSERT_LINE);
 	timer_call_after_resynch(space->machine, NULL, 0, NULL);
 }
 
 static WRITE8_HANDLER( snddata_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	if ((state->p2 & 0xf0) == 0xe0)
 		ay8910_address_w(state->ay1, 0, offset);
@@ -379,13 +378,13 @@ static WRITE8_HANDLER( snddata_w )
 
 static WRITE8_HANDLER( p1_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 	state->p1 = data;
 }
 
 static WRITE8_HANDLER( p2_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	state->p2 = data;
 	if((state->p2 & 0xf0) == 0x50)
@@ -396,13 +395,13 @@ static WRITE8_HANDLER( p2_w )
 
 static READ8_HANDLER( snd_status_r )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 	return state->sound_status;
 }
 
 static READ8_HANDLER( irq_r )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	if (state->sound_irq)
 	{
@@ -414,18 +413,18 @@ static READ8_HANDLER( irq_r )
 
 static READ8_HANDLER( snddata_r )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 	switch (state->p2 & 0xf0)
 	{
 		case 0x60:	return soundlatch_r(space, 0); ;
-		case 0x70:	return memory_region(space->machine, "user1")[((state->p1 & 0x1f) << 8) | offset];
+		case 0x70:	return space->machine->region("user1")->base()[((state->p1 & 0x1f) << 8) | offset];
 	}
 	return 0xff;
 }
 
 static WRITE8_HANDLER( fghtbskt_samples_w )
 {
-	m63_state *state = (m63_state *)space->machine->driver_data;
+	m63_state *state = space->machine->driver_data<m63_state>();
 
 	if (data & 1)
 		sample_start_raw(state->samples, 0, state->samplebuf + ((data & 0xf0) << 8), 0x2000, 8000, 0);
@@ -675,9 +674,9 @@ GFXDECODE_END
 static SAMPLES_START( fghtbskt_sh_start )
 {
 	running_machine *machine = device->machine;
-	m63_state *state = (m63_state *)machine->driver_data;
-	int i, len = memory_region_length(machine, "samples");
-	UINT8 *ROM = memory_region(machine, "samples");
+	m63_state *state = machine->driver_data<m63_state>();
+	int i, len = machine->region("samples")->bytes();
+	UINT8 *ROM = machine->region("samples")->base();
 
 	state->samplebuf = auto_alloc_array(machine, INT16, len);
 	state_save_register_global_pointer(machine, state->samplebuf, len);
@@ -695,13 +694,13 @@ static const samples_interface fghtbskt_samples_interface =
 
 static INTERRUPT_GEN( snd_irq )
 {
-	m63_state *state = (m63_state *)device->machine->driver_data;
+	m63_state *state = device->machine->driver_data<m63_state>();
 	state->sound_irq = 1;
 }
 
 static MACHINE_START( m63 )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 
 	state->soundcpu = machine->device("soundcpu");
 	state->ay1 = machine->device("ay1");
@@ -721,7 +720,7 @@ static MACHINE_START( m63 )
 
 static MACHINE_RESET( m63 )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 
 	state->pal_bank = 0;
 	state->fg_flag = 0;
@@ -731,98 +730,91 @@ static MACHINE_RESET( m63 )
 	state->p2 = 0;
 }
 
-static MACHINE_DRIVER_START( m63 )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(m63_state)
+static MACHINE_CONFIG_START( m63, m63_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu",Z80,XTAL_12MHz/4)     /* 3 MHz */
-	MDRV_CPU_PROGRAM_MAP(m63_map)
-	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_ADD("maincpu",Z80,XTAL_12MHz/4)     /* 3 MHz */
+	MCFG_CPU_PROGRAM_MAP(m63_map)
+	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
-	MDRV_CPU_ADD("soundcpu",I8039,XTAL_12MHz/4)	/* ????? */
-	MDRV_CPU_PROGRAM_MAP(i8039_map)
-	MDRV_CPU_IO_MAP(i8039_port_map)
-	MDRV_CPU_PERIODIC_INT(snd_irq, 60)
+	MCFG_CPU_ADD("soundcpu",I8039,XTAL_12MHz/4)	/* ????? */
+	MCFG_CPU_PROGRAM_MAP(i8039_map)
+	MCFG_CPU_IO_MAP(i8039_port_map)
+	MCFG_CPU_PERIODIC_INT(snd_irq, 60)
 
-	MDRV_MACHINE_START(m63)
-	MDRV_MACHINE_RESET(m63)
+	MCFG_MACHINE_START(m63)
+	MCFG_MACHINE_RESET(m63)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(m63)
-	MDRV_PALETTE_LENGTH(256+4)
+	MCFG_GFXDECODE(m63)
+	MCFG_PALETTE_LENGTH(256+4)
 
-	MDRV_PALETTE_INIT(m63)
-	MDRV_VIDEO_START(m63)
-	MDRV_VIDEO_UPDATE(m63)
+	MCFG_PALETTE_INIT(m63)
+	MCFG_VIDEO_START(m63)
+	MCFG_VIDEO_UPDATE(m63)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono") /* ????? */
+	MCFG_SPEAKER_STANDARD_MONO("mono") /* ????? */
 
-	MDRV_SOUND_ADD("ay1", AY8910, XTAL_12MHz/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, XTAL_12MHz/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, XTAL_12MHz/8) /* ????? */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, XTAL_12MHz/8) /* ????? */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( atomboy )
-	MDRV_IMPORT_FROM(m63)
-	MDRV_CPU_MODIFY("soundcpu")
-	MDRV_CPU_PERIODIC_INT(snd_irq, 60/2)
-MACHINE_DRIVER_END
+static MACHINE_CONFIG_DERIVED( atomboy, m63 )
+	MCFG_CPU_MODIFY("soundcpu")
+	MCFG_CPU_PERIODIC_INT(snd_irq, 60/2)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( fghtbskt )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(m63_state)
+static MACHINE_CONFIG_START( fghtbskt, m63_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_12MHz/4)     /* 3 MHz */
-	MDRV_CPU_PROGRAM_MAP(fghtbskt_map)
-	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_12MHz/4)     /* 3 MHz */
+	MCFG_CPU_PROGRAM_MAP(fghtbskt_map)
+	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
-	MDRV_CPU_ADD("soundcpu", I8039,XTAL_12MHz/4)	/* ????? */
-	MDRV_CPU_PROGRAM_MAP(i8039_map)
-	MDRV_CPU_IO_MAP(i8039_port_map)
-	MDRV_CPU_PERIODIC_INT(snd_irq, 60/2)
+	MCFG_CPU_ADD("soundcpu", I8039,XTAL_12MHz/4)	/* ????? */
+	MCFG_CPU_PROGRAM_MAP(i8039_map)
+	MCFG_CPU_IO_MAP(i8039_port_map)
+	MCFG_CPU_PERIODIC_INT(snd_irq, 60/2)
 
-	MDRV_MACHINE_START(m63)
-	MDRV_MACHINE_RESET(m63)
+	MCFG_MACHINE_START(m63)
+	MCFG_MACHINE_RESET(m63)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(fghtbskt)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE(fghtbskt)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_PALETTE_INIT(RRRR_GGGG_BBBB)
-	MDRV_VIDEO_START(m63)
-	MDRV_VIDEO_UPDATE(m63)
+	MCFG_PALETTE_INIT(RRRR_GGGG_BBBB)
+	MCFG_VIDEO_START(m63)
+	MCFG_VIDEO_UPDATE(m63)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, XTAL_12MHz/8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("ay1", AY8910, XTAL_12MHz/8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(fghtbskt_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(fghtbskt_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
@@ -1000,13 +992,13 @@ ROM_END
 
 static DRIVER_INIT( wilytowr )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 	state->sy_offset = 238;
 }
 
 static DRIVER_INIT( fghtbskt )
 {
-	m63_state *state = (m63_state *)machine->driver_data;
+	m63_state *state = machine->driver_data<m63_state>();
 	state->sy_offset = 240;
 }
 
