@@ -306,7 +306,7 @@ Notes:
 
 static WRITE32_HANDLER( paletteram32_macrossp_w )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 	int r,g,b;
 	COMBINE_DATA(&state->paletteram[offset]);
 
@@ -320,7 +320,7 @@ static WRITE32_HANDLER( paletteram32_macrossp_w )
 
 static READ32_HANDLER ( macrossp_soundstatus_r )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	//  logerror("%08x read soundstatus\n", cpu_get_pc(space->cpu));
 
@@ -334,7 +334,7 @@ static READ32_HANDLER ( macrossp_soundstatus_r )
 
 static WRITE32_HANDLER( macrossp_soundcmd_w )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	if (ACCESSING_BITS_16_31)
 	{
@@ -349,7 +349,7 @@ static WRITE32_HANDLER( macrossp_soundcmd_w )
 
 static READ16_HANDLER( macrossp_soundcmd_r )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	//  logerror("%06x read soundcmd\n",cpu_get_pc(space->cpu));
 	state->sndpending = 0;
@@ -358,7 +358,7 @@ static READ16_HANDLER( macrossp_soundcmd_r )
 
 static void update_colors( running_machine *machine )
 {
-	macrossp_state *state = (macrossp_state *)machine->driver_data;
+	macrossp_state *state = machine->driver_data<macrossp_state>();
 	int i, r, g, b;
 
 	for (i = 0; i < 0x1000; i++)
@@ -388,7 +388,7 @@ static void update_colors( running_machine *machine )
 
 static WRITE32_HANDLER( macrossp_palette_fade_w )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	state->fade_effect = ((data & 0xff00) >> 8) - 0x28; //it writes two times, first with a -0x28 then with the proper data
 	//  popmessage("%02x",fade_effect);
@@ -582,9 +582,9 @@ GFXDECODE_END
 
 /*** MACHINE DRIVER **********************************************************/
 
-static void irqhandler(running_device *device, int irq)
+static void irqhandler(device_t *device, int irq)
 {
-	// macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	// macrossp_state *state = space->machine->driver_data<macrossp_state>();
 	logerror("ES5506 irq %d\n", irq);
 
 	/* IRQ lines 1 & 4 on the sound 68000 are definitely triggered by the ES5506,
@@ -604,7 +604,7 @@ static const es5506_interface es5506_config =
 
 static MACHINE_START( macrossp )
 {
-	macrossp_state *state = (macrossp_state *)machine->driver_data;
+	macrossp_state *state = machine->driver_data<macrossp_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = machine->device("audiocpu");
@@ -617,7 +617,7 @@ static MACHINE_START( macrossp )
 
 static MACHINE_RESET( macrossp )
 {
-	macrossp_state *state = (macrossp_state *)machine->driver_data;
+	macrossp_state *state = machine->driver_data<macrossp_state>();
 
 	state->sndpending = 0;
 	state->snd_toggle = 0;
@@ -625,52 +625,48 @@ static MACHINE_RESET( macrossp )
 	state->old_fade = 0;
 }
 
-static MACHINE_DRIVER_START( macrossp )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(macrossp_state)
+static MACHINE_CONFIG_START( macrossp, macrossp_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68EC020, 50000000/2)	/* 25 MHz */
-	MDRV_CPU_PROGRAM_MAP(macrossp_map)
-	MDRV_CPU_VBLANK_INT("screen", irq3_line_hold) // there are others ...
+	MCFG_CPU_ADD("maincpu", M68EC020, 50000000/2)	/* 25 MHz */
+	MCFG_CPU_PROGRAM_MAP(macrossp_map)
+	MCFG_CPU_VBLANK_INT("screen", irq3_line_hold) // there are others ...
 
-	MDRV_CPU_ADD("audiocpu", M68000, 32000000/2)	/* 16 MHz */
-	MDRV_CPU_PROGRAM_MAP(macrossp_sound_map)
+	MCFG_CPU_ADD("audiocpu", M68000, 32000000/2)	/* 16 MHz */
+	MCFG_CPU_PROGRAM_MAP(macrossp_sound_map)
 
-	MDRV_MACHINE_START(macrossp)
-	MDRV_MACHINE_RESET(macrossp)
+	MCFG_MACHINE_START(macrossp)
+	MCFG_MACHINE_RESET(macrossp)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(32*16, 16*16)
-	MDRV_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 0*16, 15*16-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(32*16, 16*16)
+	MCFG_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 0*16, 15*16-1)
 
-	MDRV_GFXDECODE(macrossp)
-	MDRV_PALETTE_LENGTH(0x1000)
+	MCFG_GFXDECODE(macrossp)
+	MCFG_PALETTE_LENGTH(0x1000)
 
-	MDRV_VIDEO_START(macrossp)
-	MDRV_VIDEO_EOF(macrossp)
-	MDRV_VIDEO_UPDATE(macrossp)
+	MCFG_VIDEO_START(macrossp)
+	MCFG_VIDEO_EOF(macrossp)
+	MCFG_VIDEO_UPDATE(macrossp)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ensoniq", ES5506, 16000000)
-	MDRV_SOUND_CONFIG(es5506_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ensoniq", ES5506, 16000000)
+	MCFG_SOUND_CONFIG(es5506_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( quizmoon )
-	MDRV_IMPORT_FROM(macrossp)
+static MACHINE_CONFIG_DERIVED( quizmoon, macrossp )
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VISIBLE_AREA(0, 24*16-1, 0*8, 14*16-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VISIBLE_AREA(0, 24*16-1, 0*8, 14*16-1)
+MACHINE_CONFIG_END
 
 
 
@@ -778,7 +774,7 @@ PC :00018104 018104: addq.w  #1, $f1015a.l
 PC :0001810A 01810A: cmp.w   $f10140.l, D0
 PC :00018110 018110: beq     18104
 */
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	COMBINE_DATA(&state->mainram[0x10158 / 4]);
 	if (cpu_get_pc(space->cpu) == 0x001810A) cpu_spinuntil_int(space->cpu);
@@ -787,7 +783,7 @@ PC :00018110 018110: beq     18104
 #ifdef UNUSED_FUNCTION
 static WRITE32_HANDLER( quizmoon_speedup_w )
 {
-	macrossp_state *state = (macrossp_state *)space->machine->driver_data;
+	macrossp_state *state = space->machine->driver_data<macrossp_state>();
 
 	COMBINE_DATA(&state->mainram[0x00020 / 4]);
 	if (cpu_get_pc(space->cpu) == 0x1cc) cpu_spinuntil_int(space->cpu);
