@@ -27,14 +27,7 @@ Stephh's notes (based on the game M68000 code and some tests) :
 #include "cpu/z80/z80.h"
 #include "cpu/m68000/m68000.h"
 #include "sound/ay8910.h"
-
-PALETTE_INIT( magmax );
-VIDEO_UPDATE( magmax );
-VIDEO_START( magmax );
-
-extern UINT16 *magmax_vreg;
-extern UINT16 *magmax_scroll_x;
-extern UINT16 *magmax_scroll_y;
+#include "includes/magmax.h"
 
 
 static UINT8 sound_latch = 0;
@@ -116,9 +109,9 @@ static MACHINE_RESET( magmax )
 
 static WRITE8_DEVICE_HANDLER( ay8910_portA_0_w )
 {
-running_device *ay1 = device->machine->device("ay1");
-running_device *ay2 = device->machine->device("ay2");
-running_device *ay3 = device->machine->device("ay3");
+device_t *ay1 = device->machine->device("ay1");
+device_t *ay2 = device->machine->device("ay2");
+device_t *ay3 = device->machine->device("ay3");
 float percent;
 
 /*There are three AY8910 chips and four(!) separate amplifiers on the board
@@ -213,7 +206,7 @@ static WRITE16_HANDLER( magmax_vreg_w )
 static ADDRESS_MAP_START( magmax_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x013fff) AM_ROM
 	AM_RANGE(0x018000, 0x018fff) AM_RAM
-	AM_RANGE(0x020000, 0x0207ff) AM_RAM AM_BASE_GENERIC(videoram) AM_SIZE_GENERIC(videoram)
+	AM_RANGE(0x020000, 0x0207ff) AM_RAM AM_BASE_MEMBER(magmax_state, videoram)
 	AM_RANGE(0x028000, 0x0281ff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
 	AM_RANGE(0x030000, 0x030001) AM_READ_PORT("P1")
 	AM_RANGE(0x030002, 0x030003) AM_READ_PORT("P2")
@@ -355,49 +348,49 @@ static const ay8910_interface ay8910_config =
 };
 
 
-static MACHINE_DRIVER_START( magmax )
+static MACHINE_CONFIG_START( magmax, magmax_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, XTAL_16MHz/2)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(magmax_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, XTAL_16MHz/2)	/* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(magmax_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,XTAL_20MHz/8) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(magmax_sound_map)
-	MDRV_CPU_IO_MAP(magmax_sound_io_map)
+	MCFG_CPU_ADD("audiocpu", Z80,XTAL_20MHz/8) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(magmax_sound_map)
+	MCFG_CPU_IO_MAP(magmax_sound_io_map)
 
-	MDRV_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(HZ(600))
 
-	MDRV_MACHINE_START(magmax)
-	MDRV_MACHINE_RESET(magmax)
+	MCFG_MACHINE_START(magmax)
+	MCFG_MACHINE_RESET(magmax)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(magmax)
-	MDRV_PALETTE_LENGTH(1*16 + 16*16 + 256)
+	MCFG_GFXDECODE(magmax)
+	MCFG_PALETTE_LENGTH(1*16 + 16*16 + 256)
 
-	MDRV_PALETTE_INIT(magmax)
-	MDRV_VIDEO_START(magmax)
-	MDRV_VIDEO_UPDATE(magmax)
+	MCFG_PALETTE_INIT(magmax)
+	MCFG_VIDEO_START(magmax)
+	MCFG_VIDEO_UPDATE(magmax)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, XTAL_20MHz/16) /* verified on pcb */
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("ay1", AY8910, XTAL_20MHz/16) /* verified on pcb */
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("ay2", AY8910, XTAL_20MHz/16) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("ay2", AY8910, XTAL_20MHz/16) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("ay3", AY8910, XTAL_20MHz/16) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay3", AY8910, XTAL_20MHz/16) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+MACHINE_CONFIG_END
 
 
 ROM_START( magmax )
