@@ -146,7 +146,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 
 static WRITE16_HANDLER( mcat_soundlatch_w )
 {
-	mcatadv_state *state = (mcatadv_state *)space->machine->driver_data;
+	mcatadv_state *state = space->machine->driver_data<mcatadv_state>();
 
 	soundlatch_w(space, 0, data);
 	cpu_set_input_line(state->soundcpu, INPUT_LINE_NMI, PULSE_LINE);
@@ -414,9 +414,9 @@ GFXDECODE_END
 
 
 /* Stolen from Psikyo.c */
-static void sound_irq( running_device *device, int irq )
+static void sound_irq( device_t *device, int irq )
 {
-	mcatadv_state *state = (mcatadv_state *)device->machine->driver_data;
+	mcatadv_state *state = device->machine->driver_data<mcatadv_state>();
 	cpu_set_input_line(state->soundcpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
@@ -428,8 +428,8 @@ static const ym2610_interface mcatadv_ym2610_interface =
 
 static MACHINE_START( mcatadv )
 {
-	mcatadv_state *state = (mcatadv_state *)machine->driver_data;
-	UINT8 *ROM = memory_region(machine, "soundcpu");
+	mcatadv_state *state = machine->driver_data<mcatadv_state>();
+	UINT8 *ROM = machine->region("soundcpu")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 8, &ROM[0x10000], 0x4000);
 	memory_set_bank(machine, "bank1", 1);
@@ -441,57 +441,53 @@ static MACHINE_START( mcatadv )
 	state_save_register_global(machine, state->palette_bank2);
 }
 
-static MACHINE_DRIVER_START( mcatadv )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(mcatadv_state)
+static MACHINE_CONFIG_START( mcatadv, mcatadv_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, XTAL_16MHz) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(mcatadv_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, XTAL_16MHz) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(mcatadv_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("soundcpu", Z80, XTAL_16MHz/4) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(mcatadv_sound_map)
-	MDRV_CPU_IO_MAP(mcatadv_sound_io_map)
+	MCFG_CPU_ADD("soundcpu", Z80, XTAL_16MHz/4) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(mcatadv_sound_map)
+	MCFG_CPU_IO_MAP(mcatadv_sound_io_map)
 
-	MDRV_MACHINE_START(mcatadv)
+	MCFG_MACHINE_START(mcatadv)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(320, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 320-1, 0, 224-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(320, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 224-1)
 
-	MDRV_GFXDECODE(mcatadv)
-	MDRV_PALETTE_LENGTH(0x2000/2)
+	MCFG_GFXDECODE(mcatadv)
+	MCFG_PALETTE_LENGTH(0x2000/2)
 
-	MDRV_WATCHDOG_TIME_INIT(SEC(3))	/* a guess, and certainly wrong */
+	MCFG_WATCHDOG_TIME_INIT(SEC(3))	/* a guess, and certainly wrong */
 
-	MDRV_VIDEO_START(mcatadv)
-	MDRV_VIDEO_EOF(mcatadv) // Buffer Spriteram
-	MDRV_VIDEO_UPDATE(mcatadv)
+	MCFG_VIDEO_START(mcatadv)
+	MCFG_VIDEO_EOF(mcatadv) // Buffer Spriteram
+	MCFG_VIDEO_UPDATE(mcatadv)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM2610, XTAL_16MHz/2) /* verified on pcb */
-	MDRV_SOUND_CONFIG(mcatadv_ym2610_interface)
-	MDRV_SOUND_ROUTE(0, "lspeaker",  0.32)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 0.32)
-	MDRV_SOUND_ROUTE(1, "lspeaker",  0.5)
-	MDRV_SOUND_ROUTE(2, "rspeaker", 0.5)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM2610, XTAL_16MHz/2) /* verified on pcb */
+	MCFG_SOUND_CONFIG(mcatadv_ym2610_interface)
+	MCFG_SOUND_ROUTE(0, "lspeaker",  0.32)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 0.32)
+	MCFG_SOUND_ROUTE(1, "lspeaker",  0.5)
+	MCFG_SOUND_ROUTE(2, "rspeaker", 0.5)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( nost )
-	MDRV_IMPORT_FROM( mcatadv )
+static MACHINE_CONFIG_DERIVED( nost, mcatadv )
 
-	MDRV_CPU_MODIFY("soundcpu")
-	MDRV_CPU_PROGRAM_MAP(nost_sound_map)
-	MDRV_CPU_IO_MAP(nost_sound_io_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("soundcpu")
+	MCFG_CPU_PROGRAM_MAP(nost_sound_map)
+	MCFG_CPU_IO_MAP(nost_sound_io_map)
+MACHINE_CONFIG_END
 
 
 ROM_START( mcatadv )
