@@ -36,6 +36,7 @@ The Grid         v1.2   10/18/2000
 #include "machine/midwayic.h"
 #include "machine/timekpr.h"
 #include "audio/dcs.h"
+#include "machine/nvram.h"
 
 #include "crusnexo.lh"
 
@@ -56,8 +57,6 @@ static UINT8			keypad_select;
 static UINT8			bitlatch[10];
 
 static UINT32 *ram_base;
-static UINT32 *zpram;
-static size_t zpram_size;
 static UINT8 cmos_protected;
 
 static UINT32 *linkram;
@@ -96,7 +95,7 @@ static MACHINE_START( midzeus )
 
 static MACHINE_RESET( midzeus )
 {
-	memcpy(ram_base, memory_region(machine, "user1"), 0x40000*4);
+	memcpy(ram_base, machine->region("user1")->base(), 0x40000*4);
 	*ram_base <<= 1;
 	machine->device("maincpu")->reset();
 
@@ -132,8 +131,9 @@ static INTERRUPT_GEN( display_irq )
 
 static WRITE32_HANDLER( cmos_w )
 {
+	midzeus_state *state = space->machine->driver_data<midzeus_state>();
 	if (bitlatch[2] && !cmos_protected)
-		COMBINE_DATA(&space->machine->generic.nvram.u32[offset]);
+		COMBINE_DATA(&state->m_nvram[offset]);
 	else
 		logerror("%06X:timekeeper_w with bitlatch[2] = %d, cmos_protected = %d\n", cpu_get_pc(space->cpu), bitlatch[2], cmos_protected);
 	cmos_protected = TRUE;
@@ -142,7 +142,8 @@ static WRITE32_HANDLER( cmos_w )
 
 static READ32_HANDLER( cmos_r )
 {
-	return space->machine->generic.nvram.u32[offset] | 0xffffff00;
+	midzeus_state *state = space->machine->driver_data<midzeus_state>();
+	return state->m_nvram[offset] | 0xffffff00;
 }
 
 
@@ -178,38 +179,22 @@ static WRITE32_DEVICE_HANDLER( zeus2_timekeeper_w )
 
 static READ32_HANDLER( zpram_r )
 {
-	return zpram[offset] | 0xffffff00;
+	midzeus_state *state = space->machine->driver_data<midzeus_state>();
+	return state->m_nvram[offset] | 0xffffff00;
 }
 
 
 static WRITE32_HANDLER( zpram_w )
 {
+	midzeus_state *state = space->machine->driver_data<midzeus_state>();
 	if (bitlatch[2])
-		COMBINE_DATA(&zpram[offset]);
+		COMBINE_DATA(&state->m_nvram[offset]);
 	else
 		logerror("%06X:zpram_w with bitlatch[2] = %d\n", cpu_get_pc(space->cpu), bitlatch[2]);
 }
 
 
 
-/*************************************
- *
- *  NVRAM handler (Zeus 2 only)
- *
- *************************************/
-
-static NVRAM_HANDLER( midzeus2 )
-{
-	if (read_or_write)
-		mame_fwrite(file, zpram, zpram_size);
-	else if (file)
-		mame_fread(file, zpram, zpram_size);
-	else
-		memset(zpram, 0xff, zpram_size);
-}
-
-
-
 /*************************************
  *
  *  Miscellaneous bit latches
@@ -591,7 +576,7 @@ static ADDRESS_MAP_START( zeus_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x8d0000, 0x8d0004) AM_READWRITE(bitlatches_r, bitlatches_w)
 	AM_RANGE(0x990000, 0x99000f) AM_READWRITE(midway_ioasic_r, midway_ioasic_w)
 	AM_RANGE(0x9e0000, 0x9e0000) AM_WRITENOP		// watchdog?
-	AM_RANGE(0x9f0000, 0x9f7fff) AM_READWRITE(cmos_r, cmos_w) AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x9f0000, 0x9f7fff) AM_READWRITE(cmos_r, cmos_w) AM_SHARE("nvram")
 	AM_RANGE(0x9f8000, 0x9f8000) AM_WRITE(cmos_protect_w)
 	AM_RANGE(0xa00000, 0xffffff) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
@@ -605,7 +590,7 @@ static ADDRESS_MAP_START( zeus2_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x880000, 0x88007f) AM_READWRITE(zeus2_r, zeus2_w) AM_BASE(&zeusbase)
 	AM_RANGE(0x8a0000, 0x8a003f) AM_READWRITE(linkram_r, linkram_w) AM_BASE(&linkram)
 	AM_RANGE(0x8d0000, 0x8d000a) AM_READWRITE(bitlatches_r, bitlatches_w)
-	AM_RANGE(0x900000, 0x91ffff) AM_READWRITE(zpram_r, zpram_w) AM_BASE(&zpram) AM_SIZE(&zpram_size) AM_MIRROR(0x020000)
+	AM_RANGE(0x900000, 0x91ffff) AM_READWRITE(zpram_r, zpram_w) AM_SHARE("nvram") AM_MIRROR(0x020000)
 	AM_RANGE(0x990000, 0x99000f) AM_READWRITE(midway_ioasic_r, midway_ioasic_w)
 	AM_RANGE(0x9c0000, 0x9c000f) AM_READWRITE(analog_r, analog_w)
 	AM_RANGE(0x9e0000, 0x9e0000) AM_WRITENOP		// watchdog?
@@ -1107,30 +1092,30 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static MACHINE_DRIVER_START( midzeus )
+static MACHINE_CONFIG_START( midzeus, midzeus_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", TMS32032, CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(zeus_map)
-	MDRV_CPU_VBLANK_INT("screen", display_irq)
+	MCFG_CPU_ADD("maincpu", TMS32032, CPU_CLOCK)
+	MCFG_CPU_PROGRAM_MAP(zeus_map)
+	MCFG_CPU_VBLANK_INT("screen", display_irq)
 
-	MDRV_MACHINE_START(midzeus)
-	MDRV_MACHINE_RESET(midzeus)
-	MDRV_NVRAM_HANDLER(generic_1fill)
+	MCFG_MACHINE_START(midzeus)
+	MCFG_MACHINE_RESET(midzeus)
+	MCFG_NVRAM_ADD_1FILL("nvram")
 
 	/* video hardware */
-	MDRV_PALETTE_LENGTH(32768)
+	MCFG_PALETTE_LENGTH(32768)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_RAW_PARAMS(MIDZEUS_VIDEO_CLOCK/8, 529, 0, 400, 278, 0, 256)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_RAW_PARAMS(MIDZEUS_VIDEO_CLOCK/8, 529, 0, 400, 278, 0, 256)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 
-	MDRV_VIDEO_START(midzeus)
-	MDRV_VIDEO_UPDATE(midzeus)
+	MCFG_VIDEO_START(midzeus)
+	MCFG_VIDEO_UPDATE(midzeus)
 
 	/* sound hardware */
-	MDRV_IMPORT_FROM(dcs2_audio_2104)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(dcs2_audio_2104)
+MACHINE_CONFIG_END
 
 static READ8_HANDLER( PIC16C5X_T0_clk_r )
 {
@@ -1142,38 +1127,36 @@ static ADDRESS_MAP_START( pic_io_map, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static MACHINE_DRIVER_START( invasn )
+static MACHINE_CONFIG_DERIVED( invasn, midzeus )
 
-	MDRV_IMPORT_FROM(midzeus)
+	MCFG_CPU_ADD("pic", PIC16C57, 8000000)	/* ? */
+	MCFG_CPU_IO_MAP(pic_io_map)
+MACHINE_CONFIG_END
 
-	MDRV_CPU_ADD("pic", PIC16C57, 8000000)	/* ? */
-	MDRV_CPU_IO_MAP(pic_io_map)
-MACHINE_DRIVER_END
-
-static MACHINE_DRIVER_START( midzeus2 )
+static MACHINE_CONFIG_START( midzeus2, midzeus_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", TMS32032, CPU_CLOCK)
-	MDRV_CPU_PROGRAM_MAP(zeus2_map)
-	MDRV_CPU_VBLANK_INT("screen", display_irq)
+	MCFG_CPU_ADD("maincpu", TMS32032, CPU_CLOCK)
+	MCFG_CPU_PROGRAM_MAP(zeus2_map)
+	MCFG_CPU_VBLANK_INT("screen", display_irq)
 
-	MDRV_MACHINE_START(midzeus)
-	MDRV_MACHINE_RESET(midzeus)
-	MDRV_NVRAM_HANDLER(midzeus2)
+	MCFG_MACHINE_START(midzeus)
+	MCFG_MACHINE_RESET(midzeus)
+	MCFG_NVRAM_ADD_1FILL("nvram")
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_RAW_PARAMS(MIDZEUS_VIDEO_CLOCK/4, 666, 0, 512, 438, 0, 400)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_RAW_PARAMS(MIDZEUS_VIDEO_CLOCK/4, 666, 0, 512, 438, 0, 400)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 
-	MDRV_VIDEO_START(midzeus2)
-	MDRV_VIDEO_UPDATE(midzeus2)
+	MCFG_VIDEO_START(midzeus2)
+	MCFG_VIDEO_UPDATE(midzeus2)
 
 	/* sound hardware */
-	MDRV_IMPORT_FROM(dcs2_audio_2104)
+	MCFG_FRAGMENT_ADD(dcs2_audio_2104)
 
-	MDRV_M48T35_ADD( "m48t35" )
-MACHINE_DRIVER_END
+	MCFG_M48T35_ADD( "m48t35" )
+MACHINE_CONFIG_END
 
 
 
@@ -1438,7 +1421,7 @@ static DRIVER_INIT( crusnexo )
 {
 	dcs2_init(machine, 0, 0);
 	midway_ioasic_init(machine, MIDWAY_IOASIC_STANDARD, 472/* or 476,477,478,110 */, 99, NULL);
-	memory_configure_bank(machine, "bank1", 0, 3, memory_region(machine, "user2"), 0x400000*4);
+	memory_configure_bank(machine, "bank1", 0, 3, machine->region("user2")->base(), 0x400000*4);
 
 	memory_install_readwrite32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x9b0004, 0x9b0007, 0, 0, crusnexo_leds_r, crusnexo_leds_w);
 	memory_install_write32_handler    (cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x8d0009, 0x8d000a, 0, 0, keypad_select_w);
@@ -1449,7 +1432,7 @@ static DRIVER_INIT( thegrid )
 {
 	dcs2_init(machine, 0, 0);
 	midway_ioasic_init(machine, MIDWAY_IOASIC_STANDARD, 474/* or 491 */, 99, NULL);
-	memory_configure_bank(machine, "bank1", 0, 3, memory_region(machine, "user2"), 0x400000*4);
+	memory_configure_bank(machine, "bank1", 0, 3, machine->region("user2")->base(), 0x400000*4);
 }
 
 
