@@ -246,6 +246,7 @@ TODO: - Fix lamp timing, MAME doesn't update fast enough to see everything
 #include "emu.h"
 #include "machine/6821pia.h"
 #include "machine/6840ptm.h"
+#include "machine/nvram.h"
 
 #include "deprecat.h"
 #include "cpu/m6809/m6809.h"
@@ -439,7 +440,7 @@ static MACHINE_RESET( mpu4 )
 
 /* init rom bank, some games don't set this */
 	{
-		UINT8 *rom = memory_region(machine, "maincpu");
+		UINT8 *rom = machine->region("maincpu")->base();
 
 		memory_configure_bank(machine, "bank1", 0, 8, &rom[0x01000], 0x10000);
 
@@ -453,13 +454,13 @@ static MACHINE_RESET( mpu4 )
 /* 6809 IRQ handler */
 static WRITE_LINE_DEVICE_HANDLER( cpu0_irq )
 {
-	running_device *pia3 = device->machine->device("pia_ic3");
-	running_device *pia4 = device->machine->device("pia_ic4");
-	running_device *pia5 = device->machine->device("pia_ic5");
-	running_device *pia6 = device->machine->device("pia_ic6");
-	running_device *pia7 = device->machine->device("pia_ic7");
-	running_device *pia8 = device->machine->device("pia_ic8");
-	running_device *ptm6840 = device->machine->device("6840ptm");
+	device_t *pia3 = device->machine->device("pia_ic3");
+	device_t *pia4 = device->machine->device("pia_ic4");
+	device_t *pia5 = device->machine->device("pia_ic5");
+	device_t *pia6 = device->machine->device("pia_ic6");
+	device_t *pia7 = device->machine->device("pia_ic7");
+	device_t *pia8 = device->machine->device("pia_ic8");
+	device_t *ptm6840 = device->machine->device("6840ptm");
 
 	/* The PIA and PTM IRQ lines are all connected to a common PCB track, leading directly to the 6809 IRQ line. */
 	int combined_state = pia6821_get_irq_a(pia3) | pia6821_get_irq_b(pia3) |
@@ -513,7 +514,7 @@ static WRITE8_DEVICE_HANDLER( ic2_o1_callback )
 
 static WRITE8_DEVICE_HANDLER( ic2_o2_callback )
 {
-	running_device *pia = device->machine->device("pia_ic3");
+	device_t *pia = device->machine->device("pia_ic3");
 	pia6821_ca1_w(pia, data); /* copy output value to IC3 ca1 */
 
 	/* the output from timer2 is the input clock for timer3 */
@@ -755,7 +756,7 @@ static READ8_DEVICE_HANDLER( pia_ic5_porta_r )
 
 static READ8_DEVICE_HANDLER( pia_ic5_portb_r )
 {
-	running_device *pia_ic5 = device->machine->device("pia_ic5");
+	device_t *pia_ic5 = device->machine->device("pia_ic5");
 	LOG(("%s: IC5 PIA Read of Port B (coin input AUX2)\n",cpuexec_describe_context(device->machine)));
 	coin_lockout_w(device->machine, 0, (pia6821_get_output_b(pia_ic5) & 0x01) );
 	coin_lockout_w(device->machine, 1, (pia6821_get_output_b(pia_ic5) & 0x02) );
@@ -795,7 +796,7 @@ BDIR BC1       |
 */
 
 /* PSG function selected */
-static void update_ay(running_device *device)
+static void update_ay(device_t *device)
 {
 	if (!pia6821_get_output_cb2(device))
 	{
@@ -808,14 +809,14 @@ static void update_ay(running_device *device)
 		    }
 			case 0x01:
 			{	/* CA2 = 1 CB2 = 0? : Read from selected PSG register and make the register data available to Port A */
-				running_device *pia_ic6 = device->machine->device("pia_ic6");
+				device_t *pia_ic6 = device->machine->device("pia_ic6");
 				LOG(("AY8913 address = %d \n",pia6821_get_output_a(pia_ic6)&0x0f));
 				break;
 			}
 			case 0x02:
 			{/* CA2 = 0 CB2 = 1? : Write to selected PSG register and write data to Port A */
-				running_device *pia_ic6 = device->machine->device("pia_ic6");
-				running_device *ay = device->machine->device("ay8913");
+				device_t *pia_ic6 = device->machine->device("pia_ic6");
+				device_t *ay = device->machine->device("ay8913");
 				ay8910_data_w(ay, 0, pia6821_get_output_a(pia_ic6));
 				LOG(("AY Chip Write \n"));
 				break;
@@ -823,8 +824,8 @@ static void update_ay(running_device *device)
 			case 0x03:
 			{/* CA2 = 1 CB2 = 1? : The register will now be selected and the user can read from or write to it.
              The register will remain selected until another is chosen.*/
-				running_device *pia_ic6 = device->machine->device("pia_ic6");
-				running_device *ay = device->machine->device("ay8913");
+				device_t *pia_ic6 = device->machine->device("pia_ic6");
+				device_t *ay = device->machine->device("ay8913");
 				ay8910_address_w(ay, 0, pia6821_get_output_a(pia_ic6));
 				LOG(("AY Chip Select \n"));
 				break;
@@ -1027,7 +1028,7 @@ static const pia6821_interface pia_ic7_intf =
 static READ8_DEVICE_HANDLER( pia_ic8_porta_r )
 {
 	static const char *const portnames[] = { "ORANGE1", "ORANGE2", "BLACK1", "BLACK2", "ORANGE1", "ORANGE2", "DIL1", "DIL2" };
-	running_device *pia_ic5 = device->machine->device("pia_ic5");
+	device_t *pia_ic5 = device->machine->device("pia_ic5");
 
 	LOG_IC8(("%s: IC8 PIA Read of Port A (MUX input data)\n", cpuexec_describe_context(device->machine)));
 /* The orange inputs are polled twice as often as the black ones, for reasons of efficiency.
@@ -1088,7 +1089,7 @@ static const pia6821_interface pia_ic8_intf =
 
 static WRITE8_DEVICE_HANDLER( pia_gb_porta_w )
 {
-	running_device *msm6376 = device->machine->device("msm6376");
+	device_t *msm6376 = device->machine->device("msm6376");
 
 	LOG(("%s: GAMEBOARD: PIA Port A Set to %2x\n", cpuexec_describe_context(device->machine),data));
 	okim6376_w(msm6376, 0, data);
@@ -1750,7 +1751,7 @@ static TIMER_DEVICE_CALLBACK( gen_50hz )
 
 
 static ADDRESS_MAP_START( mod2_memmap, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x0800, 0x0810) AM_READWRITE(characteriser_r,characteriser_w)
 
 	AM_RANGE(0x0850, 0x0850) AM_READWRITE(bankswitch_r,bankswitch_w)	/* write bank (rom page select) */
@@ -1770,7 +1771,7 @@ static ADDRESS_MAP_START( mod2_memmap, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mod4_yam_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")
 
 	AM_RANGE(0x0800, 0x0810) AM_READWRITE(characteriser_r,characteriser_w)
 
@@ -1793,7 +1794,7 @@ static ADDRESS_MAP_START( mod4_yam_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mod4_oki_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")
 
 	AM_RANGE(0x0800, 0x0810) AM_READWRITE(characteriser_r,characteriser_w)
 
@@ -1821,7 +1822,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dutch_memmap, ADDRESS_SPACE_PROGRAM, 8 )
 
-	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")
 
 //  AM_RANGE(0x0800, 0x0810) AM_READWRITE(characteriser_r,characteriser_w)
 
@@ -1856,67 +1857,64 @@ static const ay8910_interface ay8910_config =
 
 
 /* machine driver for MOD 2 board */
-static MACHINE_DRIVER_START( mpu4mod2 )
+static MACHINE_CONFIG_START( mpu4mod2, driver_device )
 
-	MDRV_MACHINE_START(mpu4mod2)
-	MDRV_MACHINE_RESET(mpu4)
-	MDRV_CPU_ADD("maincpu", M6809, MPU4_MASTER_CLOCK/4)
-	MDRV_CPU_PROGRAM_MAP(mod2_memmap)
+	MCFG_MACHINE_START(mpu4mod2)
+	MCFG_MACHINE_RESET(mpu4)
+	MCFG_CPU_ADD("maincpu", M6809, MPU4_MASTER_CLOCK/4)
+	MCFG_CPU_PROGRAM_MAP(mod2_memmap)
 
-	MDRV_TIMER_ADD_PERIODIC("50hz",gen_50hz, HZ(100))
+	MCFG_TIMER_ADD_PERIODIC("50hz",gen_50hz, HZ(100))
 
 	/* 6840 PTM */
-	MDRV_PTM6840_ADD("6840ptm", ptm_ic2_intf)
+	MCFG_PTM6840_ADD("6840ptm", ptm_ic2_intf)
 
-	MDRV_PIA6821_ADD("pia_ic3", pia_ic3_intf)
-	MDRV_PIA6821_ADD("pia_ic4", pia_ic4_intf)
-	MDRV_PIA6821_ADD("pia_ic5", pia_ic5_intf)
-	MDRV_PIA6821_ADD("pia_ic6", pia_ic6_intf)
-	MDRV_PIA6821_ADD("pia_ic7", pia_ic7_intf)
-	MDRV_PIA6821_ADD("pia_ic8", pia_ic8_intf)
+	MCFG_PIA6821_ADD("pia_ic3", pia_ic3_intf)
+	MCFG_PIA6821_ADD("pia_ic4", pia_ic4_intf)
+	MCFG_PIA6821_ADD("pia_ic5", pia_ic5_intf)
+	MCFG_PIA6821_ADD("pia_ic6", pia_ic6_intf)
+	MCFG_PIA6821_ADD("pia_ic7", pia_ic7_intf)
+	MCFG_PIA6821_ADD("pia_ic8", pia_ic8_intf)
 
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD("ay8913",AY8913, MPU4_MASTER_CLOCK/4)
-	MDRV_SOUND_CONFIG(ay8910_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SOUND_ADD("ay8913",AY8913, MPU4_MASTER_CLOCK/4)
+	MCFG_SOUND_CONFIG(ay8910_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_DEFAULT_LAYOUT(layout_mpu4)
-MACHINE_DRIVER_END
+	MCFG_DEFAULT_LAYOUT(layout_mpu4)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( mod4yam )
-	MDRV_IMPORT_FROM( mpu4mod2 )
-	MDRV_MACHINE_START(mpu4mod4)
+static MACHINE_CONFIG_DERIVED( mod4yam, mpu4mod2 )
+	MCFG_MACHINE_START(mpu4mod4)
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(mod4_yam_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(mod4_yam_map)
 
-	MDRV_DEVICE_REMOVE("ay8913")
-	MDRV_SOUND_ADD("ym2413", YM2413, MPU4_MASTER_CLOCK/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("ay8913")
+	MCFG_SOUND_ADD("ym2413", YM2413, MPU4_MASTER_CLOCK/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( mod4oki )
-	MDRV_IMPORT_FROM( mpu4mod2 )
-	MDRV_MACHINE_START(mpu4mod4)
+static MACHINE_CONFIG_DERIVED( mod4oki, mpu4mod2 )
+	MCFG_MACHINE_START(mpu4mod4)
 
-	MDRV_PIA6821_ADD("pia_gamebd", pia_gameboard_intf)
+	MCFG_PIA6821_ADD("pia_gamebd", pia_gameboard_intf)
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(mod4_oki_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(mod4_oki_map)
 
-	MDRV_DEVICE_REMOVE("ay8913")
-	MDRV_SOUND_ADD("msm6376", OKIM6376, 4000000) //?
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("ay8913")
+	MCFG_SOUND_ADD("msm6376", OKIM6376, 4000000) //?
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( mpu4dutch )
-	MDRV_IMPORT_FROM( mod4oki )
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(dutch_memmap)				// setup read and write memorymap
-	MDRV_MACHINE_START(mpu4dutch)						// main mpu4 board initialisation
-MACHINE_DRIVER_END
+static MACHINE_CONFIG_DERIVED( mpu4dutch, mod4oki )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(dutch_memmap)				// setup read and write memorymap
+	MCFG_MACHINE_START(mpu4dutch)						// main mpu4 board initialisation
+MACHINE_CONFIG_END
 
 static DRIVER_INIT (connect4)
 {
