@@ -11,7 +11,8 @@
 #include "cpu/m6805/m6805.h"
 #include "sound/ay8910.h"
 #include "sound/msm5232.h"
-#include "includes/buggychl.h"
+#include "machine/buggychl.h"
+#include "includes/msisaac.h"
 
 /*
 TO DO:
@@ -23,7 +24,7 @@ TO DO:
 
 static TIMER_CALLBACK( nmi_callback )
 {
-	buggychl_state *state = (buggychl_state *)machine->driver_data;
+	msisaac_state *state = machine->driver_data<msisaac_state>();
 	if (state->sound_nmi_enable)
 		cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 	else
@@ -38,13 +39,13 @@ static WRITE8_HANDLER( sound_command_w )
 
 static WRITE8_HANDLER( nmi_disable_w )
 {
-	buggychl_state *state = (buggychl_state *)space->machine->driver_data;
+	msisaac_state *state = space->machine->driver_data<msisaac_state>();
 	state->sound_nmi_enable = 0;
 }
 
 static WRITE8_HANDLER( nmi_enable_w )
 {
-	buggychl_state *state = (buggychl_state *)space->machine->driver_data;
+	msisaac_state *state = space->machine->driver_data<msisaac_state>();
 	state->sound_nmi_enable = 1;
 	if (state->pending_nmi)
 	{
@@ -78,8 +79,6 @@ static WRITE8_HANDLER( ms_unknown_w )
 /* If good MCU dump will be available, it should be fully working game */
 /* To test the game without the MCU simply comment out #define USE_MCU */
 
-/* Disabled because the mcu dump is currently unavailable. -AS */
-//#define USE_MCU
 
 
 static READ8_HANDLER( msisaac_mcu_r )
@@ -93,7 +92,7 @@ MCU simulation TODO:
 \-Fix some graphics imperfections(*not* confirmed if they are caused by unhandled
   commands or imperfect video emulation).
 */
-	buggychl_state *state = (buggychl_state *)space->machine->driver_data;
+	msisaac_state *state = space->machine->driver_data<msisaac_state>();
 
 	switch (state->mcu_val)
 	{
@@ -169,7 +168,7 @@ static WRITE8_HANDLER( msisaac_mcu_w )
 #ifdef USE_MCU
 	buggychl_mcu_w(offset,data);
 #else
-	buggychl_state *state = (buggychl_state *)space->machine->driver_data;
+	msisaac_state *state = space->machine->driver_data<msisaac_state>();
 	//if(data != 0x0a && data != 0x42 && data != 0x02)
 	//  popmessage("PC = %04x %02x", cpu_get_pc(space->cpu), data);
 	state->mcu_val = data;
@@ -206,10 +205,10 @@ static ADDRESS_MAP_START( msisaac_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf084, 0xf084) AM_READ_PORT("IN1")
 //  AM_RANGE(0xf086, 0xf086) AM_READ_PORT("IN2")
 
-	AM_RANGE(0xf100, 0xf17f) AM_RAM AM_BASE_MEMBER(buggychl_state, spriteram)	//sprites
-	AM_RANGE(0xf400, 0xf7ff) AM_RAM_WRITE(msisaac_fg_videoram_w) AM_BASE_MEMBER(buggychl_state, videoram)
-	AM_RANGE(0xf800, 0xfbff) AM_RAM_WRITE(msisaac_bg2_videoram_w) AM_BASE_MEMBER(buggychl_state, videoram3)
-	AM_RANGE(0xfc00, 0xffff) AM_RAM_WRITE(msisaac_bg_videoram_w) AM_BASE_MEMBER(buggychl_state, videoram2)
+	AM_RANGE(0xf100, 0xf17f) AM_RAM AM_BASE_MEMBER(msisaac_state, spriteram)	//sprites
+	AM_RANGE(0xf400, 0xf7ff) AM_RAM_WRITE(msisaac_fg_videoram_w) AM_BASE_MEMBER(msisaac_state, videoram)
+	AM_RANGE(0xf800, 0xfbff) AM_RAM_WRITE(msisaac_bg2_videoram_w) AM_BASE_MEMBER(msisaac_state, videoram3)
+	AM_RANGE(0xfc00, 0xffff) AM_RAM_WRITE(msisaac_bg_videoram_w) AM_BASE_MEMBER(msisaac_state, videoram2)
 //  AM_RANGE(0xf801, 0xf801) AM_WRITE(msisaac_bgcolor_w)
 //  AM_RANGE(0xfc00, 0xfc00) AM_WRITE(flip_screen_w)
 //  AM_RANGE(0xfc03, 0xfc04) AM_WRITE(msisaac_coin_counter_w)
@@ -217,7 +216,7 @@ ADDRESS_MAP_END
 
 static MACHINE_RESET( ta7630 )
 {
-	buggychl_state *state = (buggychl_state *)machine->driver_data;
+	msisaac_state *state = machine->driver_data<msisaac_state>();
 	int i;
 
 	double db			= 0.0;
@@ -243,7 +242,7 @@ static MACHINE_RESET( ta7630 )
 
 static WRITE8_DEVICE_HANDLER( sound_control_0_w )
 {
-	buggychl_state *state = (buggychl_state *)device->machine->driver_data;
+	msisaac_state *state = device->machine->driver_data<msisaac_state>();
 	state->snd_ctrl0 = data & 0xff;
 	//popmessage("SND0 0=%2x 1=%2x", state->snd_ctrl0, state->snd_ctrl1);
 
@@ -258,7 +257,7 @@ static WRITE8_DEVICE_HANDLER( sound_control_0_w )
 }
 static WRITE8_HANDLER( sound_control_1_w )
 {
-	buggychl_state *state = (buggychl_state *)space->machine->driver_data;
+	msisaac_state *state = space->machine->driver_data<msisaac_state>();
 	state->snd_ctrl1 = data & 0xff;
 	//popmessage("SND1 0=%2x 1=%2x", state->snd_ctrl0, state->snd_ctrl1);
 }
@@ -278,22 +277,6 @@ static ADDRESS_MAP_START( msisaac_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xffff) AM_READNOP /*space for diagnostic ROM (not dumped, not reachable) */
 ADDRESS_MAP_END
 
-#ifdef USE_MCU
-
-static ADDRESS_MAP_START( msisaac_mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_GLOBAL_MASK(0x7ff)
-	AM_RANGE(0x0000, 0x0000) AM_READ(buggychl_68705_port_a_r,buggychl_68705_port_a_w)
-	AM_RANGE(0x0001, 0x0001) AM_READ(buggychl_68705_port_b_r,buggychl_68705_port_b_w)
-	AM_RANGE(0x0002, 0x0002) AM_READ(buggychl_68705_port_c_r,buggychl_68705_port_c_w)
-	AM_RANGE(0x0004, 0x0004) AM_WRITE(buggychl_68705_ddr_a_w)
-	AM_RANGE(0x0005, 0x0005) AM_WRITE(buggychl_68705_ddr_b_w)
-	AM_RANGE(0x0006, 0x0006) AM_WRITE(buggychl_68705_ddr_c_w)
-	AM_RANGE(0x0010, 0x007f) AM_RAM
-	AM_RANGE(0x0080, 0x07ff) AM_ROM
-ADDRESS_MAP_END
-
-#endif
-
 static INPUT_PORTS_START( msisaac )
 	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x00, "DSW1 Unknown 0" )
@@ -453,7 +436,7 @@ static const msm5232_interface msm5232_config =
 
 static MACHINE_START( msisaac )
 {
-	buggychl_state *state = (buggychl_state *)machine->driver_data;
+	msisaac_state *state = machine->driver_data<msisaac_state>();
 
 	state->audiocpu = machine->device("audiocpu");
 
@@ -467,22 +450,6 @@ static MACHINE_START( msisaac )
 	state_save_register_global(machine, state->snd_ctrl1);
 
 #ifdef USE_MCU
-	state->mcu = machine->device("mcu");
-
-	/* mcu */
-	state_save_register_global(machine, state->from_main);
-	state_save_register_global(machine, state->from_mcu);
-	state_save_register_global(machine, state->mcu_sent);
-	state_save_register_global(machine, state->main_sent);
-	state_save_register_global(machine, state->port_a_in);
-	state_save_register_global(machine, state->port_a_out);
-	state_save_register_global(machine, state->ddr_a);
-	state_save_register_global(machine, state->port_b_in);
-	state_save_register_global(machine, state->port_b_out);
-	state_save_register_global(machine, state->ddr_b);
-	state_save_register_global(machine, state->port_c_in);
-	state_save_register_global(machine, state->port_c_out);
-	state_save_register_global(machine, state->ddr_c);
 #else
 	state_save_register_global(machine, state->mcu_val);
 	state_save_register_global(machine, state->direction);
@@ -491,7 +458,7 @@ static MACHINE_START( msisaac )
 
 static MACHINE_RESET( msisaac )
 {
-	buggychl_state *state = (buggychl_state *)machine->driver_data;
+	msisaac_state *state = machine->driver_data<msisaac_state>();
 
 	MACHINE_RESET_CALL(ta7630);
 
@@ -505,86 +472,69 @@ static MACHINE_RESET( msisaac )
 
 #ifdef USE_MCU
 	cputag_set_input_line(machine, "mcu", 0, CLEAR_LINE);
-
-	/* mcu */
-	state->mcu_sent = 0;
-	state->main_sent = 0;
-	state->from_main = 0;
-	state->from_mcu = 0;
-	state->port_a_in = 0;
-	state->port_a_out = 0;
-	state->ddr_a = 0;
-	state->port_b_in = 0;
-	state->port_b_out = 0;
-	state->ddr_b = 0;
-	state->port_c_in = 0;
-	state->port_c_out = 0;
-	state->ddr_c = 0;
 #else
 	state->mcu_val = 0;
 	state->direction = 0;
 #endif
 }
 
-static MACHINE_DRIVER_START( msisaac )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(buggychl_state)
+static MACHINE_CONFIG_START( msisaac, msisaac_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(msisaac_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(msisaac_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(msisaac_sound_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)	/* source of IRQs is unknown */
+	MCFG_CPU_ADD("audiocpu", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(msisaac_sound_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)	/* source of IRQs is unknown */
 
 #ifdef USE_MCU
-	MDRV_CPU_ADD("mcu", M68705,8000000/2)  /* 4 MHz */
-	MDRV_CPU_PROGRAM_MAP(msisaac_mcu_map)
+	MCFG_CPU_ADD("mcu", M68705,8000000/2)  /* 4 MHz */
+	MCFG_CPU_PROGRAM_MAP(buggychl_mcu_map)
+	MCFG_DEVICE_ADD("bmcu", BUGGYCHL_MCU, 0)
 #endif
 
-	MDRV_MACHINE_START(msisaac)
-	MDRV_MACHINE_RESET(msisaac)
+	MCFG_MACHINE_START(msisaac)
+	MCFG_MACHINE_RESET(msisaac)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0, 32*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(msisaac)
-	MDRV_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE(msisaac)
+	MCFG_PALETTE_LENGTH(1024)
 
-	MDRV_VIDEO_START(msisaac)
-	MDRV_VIDEO_UPDATE(msisaac)
+	MCFG_VIDEO_START(msisaac)
+	MCFG_VIDEO_UPDATE(msisaac)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 2000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_SOUND_ADD("ay1", AY8910, 2000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 2000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_SOUND_ADD("ay2", AY8910, 2000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("msm", MSM5232, 2000000)
-	MDRV_SOUND_CONFIG(msm5232_config)
-	MDRV_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
-	MDRV_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
-	MDRV_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
-	MDRV_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
-	MDRV_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
-	MDRV_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
-	MDRV_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
-	MDRV_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
+	MCFG_SOUND_ADD("msm", MSM5232, 2000000)
+	MCFG_SOUND_CONFIG(msm5232_config)
+	MCFG_SOUND_ROUTE(0, "mono", 1.0)	// pin 28  2'-1
+	MCFG_SOUND_ROUTE(1, "mono", 1.0)	// pin 29  4'-1
+	MCFG_SOUND_ROUTE(2, "mono", 1.0)	// pin 30  8'-1
+	MCFG_SOUND_ROUTE(3, "mono", 1.0)	// pin 31 16'-1
+	MCFG_SOUND_ROUTE(4, "mono", 1.0)	// pin 36  2'-2
+	MCFG_SOUND_ROUTE(5, "mono", 1.0)	// pin 35  4'-2
+	MCFG_SOUND_ROUTE(6, "mono", 1.0)	// pin 34  8'-2
+	MCFG_SOUND_ROUTE(7, "mono", 1.0)	// pin 33 16'-2
 	// pin 1 SOLO  8'       not mapped
 	// pin 2 SOLO 16'       not mapped
 	// pin 22 Noise Output  not mapped
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 
 /*******************************************************************************/
