@@ -136,7 +136,7 @@ static void set_videorom_bank(running_machine* machine, int start, int count, in
 	/* count determines the size of the area mapped in KB */
 	for (i = 0; i < count; i++, offset += 0x400)
 	{
-		memory_set_bankptr(machine, banknames[i + start], memory_region(machine, "gfx1") + offset);
+		memory_set_bankptr(machine, banknames[i + start], machine->region("gfx1")->base() + offset);
 	}
 }
 
@@ -238,8 +238,8 @@ static int multigam_game_gfx_bank = 0;
 static WRITE8_HANDLER(multigam_switch_prg_rom)
 {
 	/* switch PRG rom */
-	UINT8* dst = memory_region(space->machine, "maincpu");
-	UINT8* src = memory_region(space->machine, "user1");
+	UINT8* dst = space->machine->region("maincpu")->base();
+	UINT8* src = space->machine->region("user1")->base();
 
 	if (data & 0x80)
 	{
@@ -258,7 +258,7 @@ static WRITE8_HANDLER(multigam_switch_prg_rom)
 
 static WRITE8_HANDLER(multigam_switch_gfx_rom)
 {
-	memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "gfx1") + (0x2000 * (data & 0x3f)));
+	memory_set_bankptr(space->machine, "bank1", space->machine->region("gfx1")->base() + (0x2000 * (data & 0x3f)));
 	set_mirroring(data & 0x40 ? PPU_MIRROR_HORZ : PPU_MIRROR_VERT);
 	multigam_game_gfx_bank = data;
 };
@@ -268,7 +268,7 @@ static WRITE8_HANDLER(multigam_mapper2_w)
 {
 	if (multigam_game_gfx_bank & 0x80)
 	{
-		memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "gfx1") + (0x2000 * ((data & 0x3) + (multigam_game_gfx_bank & 0x3c))));
+		memory_set_bankptr(space->machine, "bank1", space->machine->region("gfx1")->base() + (0x2000 * ((data & 0x3) + (multigam_game_gfx_bank & 0x3c))));
 	}
 	else
 	{
@@ -334,7 +334,7 @@ static UINT8* multigam3_mmc3_prg_base;
 static int multigam3_mmc3_prg_size;
 static int multigam3_mmc3_chr_bank_base;
 
-static void multigam3_mmc3_scanline_cb( running_device *device, int scanline, int vblank, int blanked )
+static void multigam3_mmc3_scanline_cb( device_t *device, int scanline, int vblank, int blanked )
 {
 	if (!vblank && !blanked)
 	{
@@ -348,7 +348,7 @@ static void multigam3_mmc3_scanline_cb( running_device *device, int scanline, in
 
 static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 {
-	running_device *ppu = space->machine->device("ppu");
+	device_t *ppu = space->machine->device("ppu");
 
 	/* basically, a MMC3 mapper from the nes */
 	static int multigam3_mmc3_command;
@@ -362,7 +362,7 @@ static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 			if (multigam3_mmc3_last_bank != (data & 0xc0))
 			{
 				int bank;
-				UINT8 *prg = memory_region(space->machine, "maincpu");
+				UINT8 *prg = space->machine->region("maincpu")->base();
 
 				/* reset the banks */
 				if (multigam3_mmc3_command & 0x40)
@@ -415,7 +415,7 @@ static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 
 					case 6: /* program banking */
 					{
-						UINT8 *prg = memory_region(space->machine, "maincpu");
+						UINT8 *prg = space->machine->region("maincpu")->base();
 						if (multigam3_mmc3_command & 0x40)
 						{
 							/* high bank */
@@ -440,7 +440,7 @@ static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 					case 7: /* program banking */
 						{
 							/* mid bank */
-							UINT8 *prg = memory_region(space->machine, "maincpu");
+							UINT8 *prg = space->machine->region("maincpu")->base();
 
 							multigam3_mmc3_banks[1] = data & bankmask;
 							bank = multigam3_mmc3_banks[1] * 0x2000;
@@ -469,7 +469,7 @@ static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 			}
 			else
 			{
-				memory_set_bankptr(space->machine, "bank10", memory_region(space->machine, "maincpu") + 0x6000);
+				memory_set_bankptr(space->machine, "bank10", space->machine->region("maincpu")->base() + 0x6000);
 			}
 			if (data & 0x40)
 			{
@@ -497,7 +497,7 @@ static WRITE8_HANDLER( multigam3_mmc3_rom_switch_w )
 
 static void multigam_init_mmc3(running_machine *machine, UINT8 *prg_base, int prg_size, int chr_bank_base)
 {
-	UINT8* dst = memory_region(machine, "maincpu");
+	UINT8* dst = machine->region("maincpu")->base();
 
 	// Tom & Jerry in Super Game III enables 6000 ram, but does not read/write it
 	// however, it expects ROM from 6000 there (code jumps to $6xxx)
@@ -541,8 +541,8 @@ static WRITE8_HANDLER(multigm3_switch_gfx_rom)
 static WRITE8_HANDLER(multigm3_switch_prg_rom)
 {
 	/* switch PRG rom */
-	UINT8* dst = memory_region(space->machine, "maincpu");
-	UINT8* src = memory_region(space->machine, "user1");
+	UINT8* dst = space->machine->region("maincpu")->base();
+	UINT8* src = space->machine->region("user1")->base();
 
 	if (data == 0xa8)
 	{
@@ -552,7 +552,7 @@ static WRITE8_HANDLER(multigm3_switch_prg_rom)
 	else
 	{
 		memory_install_write8_handler(space, 0x8000, 0xffff, 0, 0, multigm3_mapper2_w );
-		memory_set_bankptr(space->machine, "bank10", memory_region(space->machine, "maincpu") + 0x6000);
+		memory_set_bankptr(space->machine, "bank10", space->machine->region("maincpu")->base() + 0x6000);
 	}
 
 	if (data & 0x80)
@@ -606,14 +606,14 @@ static int multigam_mapper02_prg_size;
 
 static WRITE8_HANDLER(multigam3_mapper02_rom_switch_w)
 {
-	UINT8* mem = memory_region(space->machine, "maincpu");
+	UINT8* mem = space->machine->region("maincpu")->base();
 	int bankmask = (multigam_mapper02_prg_size/0x4000) - 1;
 	memcpy(mem + 0x8000, multigam_mapper02_prg_base + 0x4000*(data & bankmask), 0x4000);
 }
 
 static void multigam_init_mapper02(running_machine *machine, UINT8* prg_base, int prg_size)
 {
-	UINT8* mem = memory_region(machine, "maincpu");
+	UINT8* mem = machine->region("maincpu")->base();
 	memcpy(mem + 0x8000, prg_base + prg_size - 0x8000, 0x8000);
 	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, multigam3_mapper02_rom_switch_w );
 
@@ -741,7 +741,7 @@ static WRITE8_HANDLER( mmc1_rom_switch_w )
 			case 3:	/* program banking */
 				{
 					int bank = (mmc1_shiftreg & mmc1_rom_mask) * 0x4000;
-					UINT8 *prg = memory_region(space->machine, "maincpu");
+					UINT8 *prg = space->machine->region("maincpu")->base();
 
 					if (!size16k)
 					{
@@ -773,7 +773,7 @@ static WRITE8_HANDLER( mmc1_rom_switch_w )
 
 static void multigam_init_mmc1(running_machine *machine, UINT8 *prg_base, int prg_size, int chr_bank_base)
 {
-	UINT8* dst = memory_region(machine, "maincpu");
+	UINT8* dst = machine->region("maincpu")->base();
 
 	memcpy(&dst[0x8000], prg_base + (prg_size - 0x8000), 0x8000);
 
@@ -816,8 +816,8 @@ static UINT8 supergm3_chr_bank;
 
 static void supergm3_set_bank(running_machine *machine)
 {
-	running_device *ppu = machine->device("ppu");
-	UINT8* mem = memory_region(machine, "maincpu");
+	device_t *ppu = machine->device("ppu");
+	UINT8* mem = machine->region("maincpu")->base();
 
 	// video bank
 	if (supergm3_chr_bank == 0x10 ||
@@ -858,14 +858,14 @@ static void supergm3_set_bank(running_machine *machine)
 	{
 		// mapper 02
 		multigam_init_mapper02(machine,
-			memory_region(machine, "user1") + (supergm3_prg_bank & 0x1f)*0x20000,
+			machine->region("user1")->base() + (supergm3_prg_bank & 0x1f)*0x20000,
 			0x20000);
 	}
 	else if (supergm3_chr_bank & 0x10)
 	{
 		// MMC3
 		multigam_init_mmc3(machine,
-			memory_region(machine, "user1") + (supergm3_prg_bank & 0x1f)*0x20000,
+			machine->region("user1")->base() + (supergm3_prg_bank & 0x1f)*0x20000,
 			(supergm3_prg_bank & 0x20) ? 0x20000 : 0x40000,
 			(supergm3_chr_bank & 0x0f)*0x80);
 	}
@@ -873,7 +873,7 @@ static void supergm3_set_bank(running_machine *machine)
 	{
 		//MMC1
 		multigam_init_mmc1(machine,
-			memory_region(machine, "user1") + (supergm3_prg_bank & 0x1f)*0x20000,
+			machine->region("user1")->base() + (supergm3_prg_bank & 0x1f)*0x20000,
 			0x20000,
 			(supergm3_chr_bank & 0x0f)*0x80/4 );
 	}
@@ -1038,7 +1038,7 @@ static PALETTE_INIT( multigam )
 	ppu2c0x_init_palette(machine, 0);
 }
 
-static void ppu_irq( running_device *device, int *ppu_regs )
+static void ppu_irq( device_t *device, int *ppu_regs )
 {
 	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 }
@@ -1079,7 +1079,7 @@ static MACHINE_RESET( multigam )
 
 static MACHINE_RESET( multigm3 )
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	/* reset the ppu */
 	multigm3_switch_prg_rom(space, 0, 0x01 );
 };
@@ -1094,7 +1094,7 @@ static MACHINE_START( multigam )
 
 	memory_install_readwrite8_handler(cpu_get_address_space(machine->device("ppu"), ADDRESS_SPACE_PROGRAM), 0x2000, 0x3eff, 0, 0, multigam_nt_r, multigam_nt_w);
 	memory_install_read_bank(cpu_get_address_space(machine->device("ppu"), ADDRESS_SPACE_PROGRAM), 0x0000, 0x1fff, 0, 0, "bank1");
-	memory_set_bankptr(machine, "bank1", memory_region(machine, "gfx1"));
+	memory_set_bankptr(machine, "bank1", machine->region("gfx1")->base());
 }
 
 static MACHINE_START( multigm3 )
@@ -1133,63 +1133,60 @@ static MACHINE_START( supergm3 )
 	multigmc_mmc3_6000_ram = auto_alloc_array(machine, UINT8, 0x2000);
 }
 
-static MACHINE_DRIVER_START( multigam )
+static MACHINE_CONFIG_START( multigam, driver_device )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", N2A03, N2A03_DEFAULTCLOCK)
-	MDRV_CPU_PROGRAM_MAP(multigam_map)
+	MCFG_CPU_ADD("maincpu", N2A03, N2A03_DEFAULTCLOCK)
+	MCFG_CPU_PROGRAM_MAP(multigam_map)
 
-	MDRV_MACHINE_START( multigam )
-	MDRV_MACHINE_RESET( multigam )
+	MCFG_MACHINE_START( multigam )
+	MCFG_MACHINE_RESET( multigam )
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 262)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 262)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 30*8-1)
 
-	MDRV_GFXDECODE(multigam)
-	MDRV_PALETTE_LENGTH(8*4*16)
+	MCFG_GFXDECODE(multigam)
+	MCFG_PALETTE_LENGTH(8*4*16)
 
-	MDRV_PALETTE_INIT(multigam)
-	MDRV_VIDEO_START(multigam)
-	MDRV_VIDEO_UPDATE(multigam)
+	MCFG_PALETTE_INIT(multigam)
+	MCFG_VIDEO_START(multigam)
+	MCFG_VIDEO_UPDATE(multigam)
 
-	MDRV_PPU2C04_ADD("ppu", ppu_interface)
+	MCFG_PPU2C04_ADD("ppu", ppu_interface)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("nes", NES, N2A03_DEFAULTCLOCK)
-	MDRV_SOUND_CONFIG(multigam_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("nes", NES, N2A03_DEFAULTCLOCK)
+	MCFG_SOUND_CONFIG(multigam_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( multigm3 )
-	MDRV_IMPORT_FROM(multigam)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(multigm3_map)
+static MACHINE_CONFIG_DERIVED( multigm3, multigam )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(multigm3_map)
 
-	MDRV_MACHINE_START( multigm3 )
-	MDRV_MACHINE_RESET( multigm3 )
-MACHINE_DRIVER_END
+	MCFG_MACHINE_START( multigm3 )
+	MCFG_MACHINE_RESET( multigm3 )
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( multigmt )
-	MDRV_IMPORT_FROM(multigam)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(multigmt_map)
-MACHINE_DRIVER_END
+static MACHINE_CONFIG_DERIVED( multigmt, multigam )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(multigmt_map)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( supergm3 )
-	MDRV_IMPORT_FROM(multigam)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(supergm3_map)
+static MACHINE_CONFIG_DERIVED( supergm3, multigam )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(supergm3_map)
 
-	MDRV_MACHINE_START(supergm3)
-MACHINE_DRIVER_END
+	MCFG_MACHINE_START(supergm3)
+MACHINE_CONFIG_END
 
 ROM_START( multigam )
 	ROM_REGION( 0x10000, "maincpu", 0 )
@@ -1309,7 +1306,7 @@ ROM_END
 
 static DRIVER_INIT( multigam )
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 	multigam_switch_prg_rom(space, 0x0, 0x01);
 }
 
@@ -1324,12 +1321,12 @@ static void multigm3_decrypt(UINT8* mem, int memsize, const UINT8* decode_nibble
 
 static DRIVER_INIT(multigm3)
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	const UINT8 decode[16]  = { 0x09, 0x08, 0x07, 0x06, 0x05, 0x04, 0x03, 0x02, 0x01, 0x00, 0x0f, 0x0e, 0x0d, 0x0c, 0x0b, 0x0a };
 
-	multigm3_decrypt(memory_region(machine, "maincpu"), memory_region_length(machine, "maincpu"), decode );
-	multigm3_decrypt(memory_region(machine, "user1"), memory_region_length(machine, "user1"), decode );
+	multigm3_decrypt(machine->region("maincpu")->base(), machine->region("maincpu")->bytes(), decode );
+	multigm3_decrypt(machine->region("user1")->base(), machine->region("user1")->bytes(), decode );
 
 	multigmc_mmc3_6000_ram = auto_alloc_array(machine, UINT8, 0x2000);
 
@@ -1338,7 +1335,7 @@ static DRIVER_INIT(multigm3)
 
 static DRIVER_INIT(multigmt)
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	UINT8* buf = auto_alloc_array(machine, UINT8, 0x80000);
 	UINT8 *rom;
@@ -1346,7 +1343,7 @@ static DRIVER_INIT(multigmt)
 	int i;
 	int addr;
 
-	rom = memory_region(machine, "maincpu");
+	rom = machine->region("maincpu")->base();
 	size = 0x8000;
 	memcpy(buf, rom, size);
 	for (i = 0; i < size; i++)
@@ -1356,7 +1353,7 @@ static DRIVER_INIT(multigmt)
 		rom[i] = buf[addr];
 	}
 
-	rom = memory_region(machine, "user1");
+	rom = machine->region("user1")->base();
 	size = 0x80000;
 	memcpy(buf, rom, size);
 	for (i = 0; i < size; i++)
@@ -1364,7 +1361,7 @@ static DRIVER_INIT(multigmt)
 		addr = BITSWAP24(i,23,22,21,20,19,18,17,16,15,14,13,8,11,12,10,9,7,6,5,4,3,2,1,0);
 		rom[i] = buf[addr];
 	}
-	rom = memory_region(machine, "gfx1");
+	rom = machine->region("gfx1")->base();
 	size = 0x80000;
 	memcpy(buf, rom, size);
 	for (i = 0; i < size; i++)
