@@ -31,25 +31,7 @@
 #include "machine/eeprom.h"
 #include "sound/k054539.h"
 #include "includes/konamipt.h"
-
-VIDEO_START(gaiapols);
-VIDEO_START(dadandrn);
-VIDEO_START(viostorm);
-VIDEO_START(metamrph);
-VIDEO_START(martchmp);
-VIDEO_START(mystwarr);
-VIDEO_UPDATE(dadandrn);
-VIDEO_UPDATE(mystwarr);
-VIDEO_UPDATE(metamrph);
-VIDEO_UPDATE(martchmp);
-
-WRITE16_HANDLER(ddd_053936_enable_w);
-WRITE16_HANDLER(ddd_053936_clip_w);
-READ16_HANDLER(gai_053936_tilerom_0_r);
-READ16_HANDLER(ddd_053936_tilerom_0_r);
-READ16_HANDLER(ddd_053936_tilerom_1_r);
-READ16_HANDLER(gai_053936_tilerom_2_r);
-READ16_HANDLER(ddd_053936_tilerom_2_r);
+#include "includes/mystwarr.h"
 
 static UINT16 *gx_workram;
 
@@ -588,7 +570,7 @@ static int cur_sound_region;
 
 static void reset_sound_region(running_machine *machine)
 {
-	memory_set_bankptr(machine, "bank2", memory_region(machine, "soundcpu") + 0x10000 + cur_sound_region*0x4000);
+	memory_set_bankptr(machine, "bank2", machine->region("soundcpu")->base() + 0x10000 + cur_sound_region*0x4000);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
@@ -762,7 +744,7 @@ static INPUT_PORTS_START( dadandrn )
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_SERVICE_NO_TOGGLE( 0x0800, IP_ACTIVE_LOW )
+	PORT_SERVICE_NO_TOGGLE( 0x0800, IP_ACTIVE_LOW )	/* duplicate required for use */
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_SERVICE2 )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -888,8 +870,8 @@ static MACHINE_START( mystwarr )
 
 static MACHINE_RESET(mystwarr)
 {
-	running_device *k054539_1 = machine->device("konami1");
-	running_device *k054539_2 = machine->device("konami2");
+	device_t *k054539_1 = machine->device("konami1");
+	device_t *k054539_2 = machine->device("konami2");
 	int i;
 
 	// soften chorus(chip 0 channel 0-3), boost voice(chip 0 channel 4-7)
@@ -905,7 +887,7 @@ static MACHINE_RESET(mystwarr)
 
 static MACHINE_RESET(dadandrn)
 {
-	running_device *k054539_1 = machine->device("konami1");
+	device_t *k054539_1 = machine->device("konami1");
 	int i;
 
 	// boost voice(chip 0 channel 4-7)
@@ -914,7 +896,7 @@ static MACHINE_RESET(dadandrn)
 
 static MACHINE_RESET(viostorm)
 {
-	running_device *k054539_1 = machine->device("konami1");
+	device_t *k054539_1 = machine->device("konami1");
 	int i;
 
 	// boost voice(chip 0 channel 4-7)
@@ -923,8 +905,8 @@ static MACHINE_RESET(viostorm)
 
 static MACHINE_RESET(metamrph)
 {
-	running_device *k054539_1 = machine->device("konami1");
-	running_device *k054539_2 = machine->device("konami2");
+	device_t *k054539_1 = machine->device("konami1");
+	device_t *k054539_2 = machine->device("konami2");
 	int i;
 
 	// boost voice(chip 0 channel 4-7) and soften other channels
@@ -939,7 +921,7 @@ static MACHINE_RESET(metamrph)
 
 static MACHINE_RESET(martchmp)
 {
-	running_device *k054539_1 = machine->device("konami1");
+	device_t *k054539_1 = machine->device("konami1");
 	int i;
 
 	k054539_init_flags(k054539_1, K054539_REVERSE_STEREO);
@@ -950,170 +932,165 @@ static MACHINE_RESET(martchmp)
 
 static MACHINE_RESET(gaiapols)
 {
-	running_device *k054539_1 = machine->device("konami1");
+	device_t *k054539_1 = machine->device("konami1");
 	int i;
 
 	// boost voice(chip 0 channel 5-7)
 	for (i=5; i<=7; i++) k054539_set_gain(k054539_1, i, 2.0);
 }
 
-static MACHINE_DRIVER_START( mystwarr )
+static MACHINE_CONFIG_START( mystwarr, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 16000000)	/* 16 MHz (confirmed) */
-	MDRV_CPU_PROGRAM_MAP(mystwarr_map)
-	MDRV_CPU_VBLANK_INT_HACK(mystwarr_interrupt, 3)
+	MCFG_CPU_ADD("maincpu", M68000, 16000000)	/* 16 MHz (confirmed) */
+	MCFG_CPU_PROGRAM_MAP(mystwarr_map)
+	MCFG_CPU_VBLANK_INT_HACK(mystwarr_interrupt, 3)
 
-	MDRV_CPU_ADD("soundcpu", Z80, 8000000)
-	MDRV_CPU_PROGRAM_MAP(mystwarr_sound_map)
-	MDRV_CPU_PERIODIC_INT(nmi_line_pulse, 480)
+	MCFG_CPU_ADD("soundcpu", Z80, 8000000)
+	MCFG_CPU_PROGRAM_MAP(mystwarr_sound_map)
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse, 480)
 
-	MDRV_QUANTUM_TIME(HZ(1920))
+	MCFG_QUANTUM_TIME(HZ(1920))
 
-	MDRV_EEPROM_ADD("eeprom", eeprom_intf)
+	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
-	MDRV_MACHINE_START(mystwarr)
-	MDRV_MACHINE_RESET(mystwarr)
+	MCFG_MACHINE_START(mystwarr)
+	MCFG_MACHINE_RESET(mystwarr)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_AFTER_VBLANK)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_AFTER_VBLANK)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-//  MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_RAW_PARAMS(6000000, 288+16+32+48, 0, 287, 224+16+8+16, 0, 223)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(24, 24+288-1, 16, 16+224-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+//  MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_RAW_PARAMS(6000000, 288+16+32+48, 0, 287, 224+16+8+16, 0, 223)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(24, 24+288-1, 16, 16+224-1)
 
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(mystwarr)
-	MDRV_VIDEO_UPDATE(mystwarr)
+	MCFG_VIDEO_START(mystwarr)
+	MCFG_VIDEO_UPDATE(mystwarr)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("konami1", K054539, 48000)
-	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 1.0)	/* stereo channels are inverted */
-	MDRV_SOUND_ROUTE(1, "lspeaker", 1.0)
+	MCFG_SOUND_ADD("konami1", K054539, 48000)
+	MCFG_SOUND_CONFIG(k054539_config)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 1.0)	/* stereo channels are inverted */
+	MCFG_SOUND_ROUTE(1, "lspeaker", 1.0)
 
-	MDRV_SOUND_ADD("konami2", K054539, 48000)
-	MDRV_SOUND_CONFIG(k054539_config)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 1.0)	/* stereo channels are inverted */
-	MDRV_SOUND_ROUTE(1, "lspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("konami2", K054539, 48000)
+	MCFG_SOUND_CONFIG(k054539_config)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 1.0)	/* stereo channels are inverted */
+	MCFG_SOUND_ROUTE(1, "lspeaker", 1.0)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( viostorm )
-	MDRV_IMPORT_FROM(mystwarr)
+static MACHINE_CONFIG_DERIVED( viostorm, mystwarr )
 
-	MDRV_MACHINE_RESET(viostorm)
+	MCFG_MACHINE_RESET(viostorm)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(viostorm_map)
-	MDRV_CPU_VBLANK_INT_HACK(metamrph_interrupt, 40)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(viostorm_map)
+	MCFG_CPU_VBLANK_INT_HACK(metamrph_interrupt, 40)
 
 	/* video hardware */
-	MDRV_VIDEO_START(viostorm)
-	MDRV_VIDEO_UPDATE(metamrph)
+	MCFG_VIDEO_START(viostorm)
+	MCFG_VIDEO_UPDATE(metamrph)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(900))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(900))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( metamrph )
-	MDRV_IMPORT_FROM(mystwarr)
+static MACHINE_CONFIG_DERIVED( metamrph, mystwarr )
 
-	MDRV_MACHINE_RESET(metamrph)
+	MCFG_MACHINE_RESET(metamrph)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(metamrph_map)
-	MDRV_CPU_VBLANK_INT_HACK(metamrph_interrupt, 40)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(metamrph_map)
+	MCFG_CPU_VBLANK_INT_HACK(metamrph_interrupt, 40)
 
 	/* video hardware */
-	MDRV_VIDEO_START(metamrph)
-	MDRV_VIDEO_UPDATE(metamrph)
+	MCFG_VIDEO_START(metamrph)
+	MCFG_VIDEO_UPDATE(metamrph)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(900))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(24, 24+288-1, 17, 17+224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(900))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(24, 24+288-1, 17, 17+224-1)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( dadandrn )
-	MDRV_IMPORT_FROM(mystwarr)
+static MACHINE_CONFIG_DERIVED( dadandrn, mystwarr )
 
-	MDRV_MACHINE_RESET(dadandrn)
+	MCFG_MACHINE_RESET(dadandrn)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(dadandrn_map)
-	MDRV_CPU_VBLANK_INT("screen", ddd_interrupt)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(dadandrn_map)
+	MCFG_CPU_VBLANK_INT("screen", ddd_interrupt)
 
-	MDRV_GFXDECODE(dadandrn)
+	MCFG_GFXDECODE(dadandrn)
 
 	/* video hardware */
-	MDRV_VIDEO_START(dadandrn)
-	MDRV_VIDEO_UPDATE(dadandrn)
+	MCFG_VIDEO_START(dadandrn)
+	MCFG_VIDEO_UPDATE(dadandrn)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(24, 24+288-1, 17, 17+224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(24, 24+288-1, 17, 17+224-1)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( gaiapols )
-	MDRV_IMPORT_FROM(mystwarr)
+static MACHINE_CONFIG_DERIVED( gaiapols, mystwarr )
 
-	MDRV_MACHINE_RESET(gaiapols)
+	MCFG_MACHINE_RESET(gaiapols)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(gaiapols_map)
-	MDRV_CPU_VBLANK_INT("screen", ddd_interrupt)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(gaiapols_map)
+	MCFG_CPU_VBLANK_INT("screen", ddd_interrupt)
 
-	MDRV_GFXDECODE(gaiapols)
+	MCFG_GFXDECODE(gaiapols)
 
-	MDRV_DEVICE_REMOVE("eeprom")
-	MDRV_EEPROM_ADD("eeprom", gaia_eeprom_intf)
+	MCFG_DEVICE_REMOVE("eeprom")
+	MCFG_EEPROM_ADD("eeprom", gaia_eeprom_intf)
 
 	/* video hardware */
-	MDRV_VIDEO_START(gaiapols)
-	MDRV_VIDEO_UPDATE(dadandrn)
+	MCFG_VIDEO_START(gaiapols)
+	MCFG_VIDEO_UPDATE(dadandrn)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_RAW_PARAMS(8000000, 384+24+64+40, 0, 383, 224+16+8+16, 0, 223)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(40, 40+376-1, 16, 16+224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_RAW_PARAMS(8000000, 384+24+64+40, 0, 383, 224+16+8+16, 0, 223)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(600))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(40, 40+376-1, 16, 16+224-1)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( martchmp )
-	MDRV_IMPORT_FROM(mystwarr)
+static MACHINE_CONFIG_DERIVED( martchmp, mystwarr )
 
-	MDRV_MACHINE_RESET(martchmp)
+	MCFG_MACHINE_RESET(martchmp)
 
 	/* basic machine hardware */
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(martchmp_map)
-	MDRV_CPU_VBLANK_INT_HACK(mchamp_interrupt, 2)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(martchmp_map)
+	MCFG_CPU_VBLANK_INT_HACK(mchamp_interrupt, 2)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_BEFORE_VBLANK)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_BEFORE_VBLANK)
 
-	MDRV_VIDEO_START(martchmp)
-	MDRV_VIDEO_UPDATE(martchmp)
+	MCFG_VIDEO_START(martchmp)
+	MCFG_VIDEO_UPDATE(martchmp)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(32, 32+384-1, 16, 16+224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(32, 32+384-1, 16, 16+224-1)
+MACHINE_CONFIG_END
 
 /**********************************************************************************/
 
