@@ -607,7 +607,7 @@ static MACHINE_START(namconb)
 
 static DRIVER_INIT( nebulray )
 {
-	UINT8 *pMem = (UINT8 *)memory_region(machine, NAMCONB1_TILEMASKREGION);
+	UINT8 *pMem = (UINT8 *)machine->region(NAMCONB1_TILEMASKREGION)->base();
 	size_t numBytes = (0xfe7-0xe6f)*8;
 	memset( &pMem[0xe6f*8], 0, numBytes );
 
@@ -666,7 +666,7 @@ static READ32_HANDLER( custom_key_r )
 
 	do
 	{ /* pick a random number, but don't pick the same twice in a row */
-		count = mame_rand(space->machine);
+		count = space->machine->rand();
 	} while( count==old_count );
 
 	switch( namcos2_gametype )
@@ -824,7 +824,7 @@ static READ32_HANDLER( gunbulet_gun_r )
 static
 READ32_HANDLER( randgen_r )
 {
-	return mame_rand(space->machine);
+	return space->machine->rand();
 } /* randgen_r */
 
 static
@@ -1011,71 +1011,71 @@ ADDRESS_MAP_END
 
 #define MASTER_CLOCK_HZ 48384000
 
-static MACHINE_DRIVER_START( namconb1 )
-	MDRV_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
-	MDRV_CPU_PROGRAM_MAP(namconb1_am)
-	MDRV_CPU_VBLANK_INT("screen", namconb1_interrupt)
+static MACHINE_CONFIG_START( namconb1, driver_device )
+	MCFG_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
+	MCFG_CPU_PROGRAM_MAP(namconb1_am)
+	MCFG_CPU_VBLANK_INT("screen", namconb1_interrupt)
 
-	MDRV_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
-	MDRV_CPU_PROGRAM_MAP(namcoc75_am)
-	MDRV_CPU_IO_MAP(namcoc75_io)
-	MDRV_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
+	MCFG_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
+	MCFG_CPU_PROGRAM_MAP(namcoc75_am)
+	MCFG_CPU_IO_MAP(namcoc75_io)
+	MCFG_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
 
-	MDRV_NVRAM_HANDLER(namconb1)
-	MDRV_MACHINE_START(namconb)
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+	MCFG_NVRAM_HANDLER(namconb1)
+	MCFG_MACHINE_START(namconb)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(59.7)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
-	MDRV_SCREEN_VISIBLE_AREA(0, NAMCONB1_HBSTART-1, 0, NAMCONB1_VBSTART-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(59.7)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
+	MCFG_SCREEN_VISIBLE_AREA(0, NAMCONB1_HBSTART-1, 0, NAMCONB1_VBSTART-1)
 
-	MDRV_GFXDECODE(namconb1)
-	MDRV_PALETTE_LENGTH(0x2000)
-	MDRV_VIDEO_START(namconb1)
-	MDRV_VIDEO_UPDATE(namconb1)
+	MCFG_GFXDECODE(namconb1)
+	MCFG_PALETTE_LENGTH(0x2000)
+	MCFG_VIDEO_START(namconb1)
+	MCFG_VIDEO_UPDATE(namconb1)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
-	MDRV_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
-	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
-	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
-	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MCFG_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MCFG_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MCFG_SOUND_ROUTE(3, "lspeaker", 1.00)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( namconb2 )
-	MDRV_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
-	MDRV_CPU_PROGRAM_MAP(namconb2_am)
-	MDRV_CPU_VBLANK_INT("screen", namconb2_interrupt)
+static MACHINE_CONFIG_START( namconb2, driver_device )
+	MCFG_CPU_ADD("maincpu", M68EC020,MASTER_CLOCK_HZ/2)
+	MCFG_CPU_PROGRAM_MAP(namconb2_am)
+	MCFG_CPU_VBLANK_INT("screen", namconb2_interrupt)
 
-	MDRV_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
-	MDRV_CPU_PROGRAM_MAP(namcoc75_am)
-	MDRV_CPU_IO_MAP(namcoc75_io)
-	MDRV_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
+	MCFG_CPU_ADD("mcu", M37702, MASTER_CLOCK_HZ/3)
+	MCFG_CPU_PROGRAM_MAP(namcoc75_am)
+	MCFG_CPU_IO_MAP(namcoc75_io)
+	MCFG_CPU_VBLANK_INT_HACK(mcu_interrupt, 3)
 
-	MDRV_NVRAM_HANDLER(namconb1)
-	MDRV_MACHINE_START(namconb)
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+	MCFG_NVRAM_HANDLER(namconb1)
+	MCFG_MACHINE_START(namconb)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(59.7)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
-	MDRV_SCREEN_VISIBLE_AREA(0, NAMCONB1_HBSTART-1, 0, NAMCONB1_VBSTART-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(59.7)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
+	MCFG_SCREEN_VISIBLE_AREA(0, NAMCONB1_HBSTART-1, 0, NAMCONB1_VBSTART-1)
 
-	MDRV_GFXDECODE(2)
-	MDRV_PALETTE_LENGTH(0x2000)
-	MDRV_VIDEO_START(namconb2)
-	MDRV_VIDEO_UPDATE(namconb2)
+	MCFG_GFXDECODE(2)
+	MCFG_PALETTE_LENGTH(0x2000)
+	MCFG_VIDEO_START(namconb2)
+	MCFG_VIDEO_UPDATE(namconb2)
 
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
-	MDRV_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
-	MDRV_SOUND_ROUTE(0, "rspeaker", 1.00)
-	MDRV_SOUND_ROUTE(1, "lspeaker", 1.00)
-	MDRV_SOUND_ROUTE(2, "rspeaker", 1.00)
-	MDRV_SOUND_ROUTE(3, "lspeaker", 1.00)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SOUND_ADD("c352", C352, MASTER_CLOCK_HZ/3)
+	MCFG_SOUND_ROUTE(0, "rspeaker", 1.00)
+	MCFG_SOUND_ROUTE(1, "lspeaker", 1.00)
+	MCFG_SOUND_ROUTE(2, "rspeaker", 1.00)
+	MCFG_SOUND_ROUTE(3, "lspeaker", 1.00)
+MACHINE_CONFIG_END
 
 /***************************************************************/
 
