@@ -680,152 +680,152 @@ static const ay8910_interface pkunwar_ay8910_interface_2 =
  *
  *************************************/
 
-static MACHINE_DRIVER_START( nova2001 )
+static MACHINE_CONFIG_START( nova2001, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz verified on schematics
-	MDRV_CPU_PROGRAM_MAP(nova2001_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz verified on schematics
+	MCFG_CPU_PROGRAM_MAP(nova2001_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
 
-	MDRV_GFXDECODE(nova2001)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(nova2001)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(nova2001)
-	MDRV_VIDEO_START(nova2001)
-	MDRV_VIDEO_UPDATE(nova2001)
+	MCFG_PALETTE_INIT(nova2001)
+	MCFG_VIDEO_START(nova2001)
+	MCFG_VIDEO_UPDATE(nova2001)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/6)	// 2 MHz verified on schematics
-	MDRV_SOUND_CONFIG(nova2001_ay8910_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/6)	// 2 MHz verified on schematics
+	MCFG_SOUND_CONFIG(nova2001_ay8910_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/6)
-	MDRV_SOUND_CONFIG(nova2001_ay8910_interface_2)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/6)
+	MCFG_SOUND_CONFIG(nova2001_ay8910_interface_2)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( ninjakun )
+static MACHINE_CONFIG_START( ninjakun, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(ninjakun_cpu1_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(ninjakun_cpu1_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("sub", Z80, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(ninjakun_cpu2_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4) /* ? */
+	MCFG_CPU_ADD("sub", Z80, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(ninjakun_cpu2_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,4) /* ? */
 
-	MDRV_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame */
+	MCFG_QUANTUM_TIME(HZ(6000))	/* 100 CPU slices per frame */
 
-	MDRV_MACHINE_START(ninjakun)
+	MCFG_MACHINE_START(ninjakun)
 
     /* video hardware */
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1 )
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1 )
 
-	MDRV_GFXDECODE(ninjakun)
-	MDRV_PALETTE_LENGTH(0x300)
+	MCFG_GFXDECODE(ninjakun)
+	MCFG_PALETTE_LENGTH(0x300)
 
-	MDRV_VIDEO_START(ninjakun)
-	MDRV_VIDEO_UPDATE(ninjakun)
+	MCFG_VIDEO_START(ninjakun)
+	MCFG_VIDEO_UPDATE(ninjakun)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_SOUND_CONFIG(nova2001_ay8910_interface_2)	// note swapped order wrt nova2001
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+	MCFG_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_SOUND_CONFIG(nova2001_ay8910_interface_2)	// note swapped order wrt nova2001
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_SOUND_CONFIG(nova2001_ay8910_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_SOUND_CONFIG(nova2001_ay8910_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( pkunwar )
+static MACHINE_CONFIG_START( pkunwar, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(pkunwar_map)
-	MDRV_CPU_IO_MAP(pkunwar_io)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(pkunwar_map)
+	MCFG_CPU_IO_MAP(pkunwar_io)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
 
-	MDRV_GFXDECODE(pkunwar)
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_GFXDECODE(pkunwar)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_PALETTE_INIT(nova2001)
-	MDRV_VIDEO_START(pkunwar)
-	MDRV_VIDEO_UPDATE(pkunwar)
+	MCFG_PALETTE_INIT(nova2001)
+	MCFG_VIDEO_START(pkunwar)
+	MCFG_VIDEO_UPDATE(pkunwar)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/8)	// 1.5MHz (correct?)
-	MDRV_SOUND_CONFIG(pkunwar_ay8910_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/8)	// 1.5MHz (correct?)
+	MCFG_SOUND_CONFIG(pkunwar_ay8910_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/8)
-	MDRV_SOUND_CONFIG(pkunwar_ay8910_interface_2)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/8)
+	MCFG_SOUND_CONFIG(pkunwar_ay8910_interface_2)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( raiders5 )
+static MACHINE_CONFIG_START( raiders5, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(raiders5_cpu1_map)
-	MDRV_CPU_IO_MAP(raiders5_io)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(raiders5_cpu1_map)
+	MCFG_CPU_IO_MAP(raiders5_io)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("sub", Z80, MAIN_CLOCK/4)	// 3 MHz
-	MDRV_CPU_PROGRAM_MAP(raiders5_cpu2_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)	/* ? */
+	MCFG_CPU_ADD("sub", Z80, MAIN_CLOCK/4)	// 3 MHz
+	MCFG_CPU_PROGRAM_MAP(raiders5_cpu2_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,4)	/* ? */
 
-	MDRV_QUANTUM_TIME(HZ(24000))
+	MCFG_QUANTUM_TIME(HZ(24000))
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
 
-	MDRV_GFXDECODE(raiders5)
-	MDRV_PALETTE_LENGTH(0x300)
+	MCFG_GFXDECODE(raiders5)
+	MCFG_PALETTE_LENGTH(0x300)
 
-	MDRV_VIDEO_START(raiders5)
-	MDRV_VIDEO_UPDATE(raiders5)
+	MCFG_VIDEO_START(raiders5)
+	MCFG_VIDEO_UPDATE(raiders5)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/8)	// 1.5MHz
-	MDRV_SOUND_CONFIG(pkunwar_ay8910_interface_1)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, MAIN_CLOCK/8)	// 1.5MHz
+	MCFG_SOUND_CONFIG(pkunwar_ay8910_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/8)
-	MDRV_SOUND_CONFIG(pkunwar_ay8910_interface_2)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, MAIN_CLOCK/8)
+	MCFG_SOUND_CONFIG(pkunwar_ay8910_interface_2)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
 
 
@@ -985,9 +985,9 @@ This code is overly generic because it is used for several games in ninjakd2.c
 
 static void lineswap_gfx_roms(running_machine *machine, const char *region, const int bit)
 {
-	const int length = memory_region_length(machine, region);
+	const int length = machine->region(region)->bytes();
 
-	UINT8* const src = memory_region(machine, region);
+	UINT8* const src = machine->region(region)->base();
 
 	UINT8* const temp = auto_alloc_array(machine, UINT8, length);
 
