@@ -44,7 +44,7 @@ paradise: I'm not sure it's working correctly:
 static WRITE8_HANDLER( paradise_rombank_w )
 {
 	int bank = data;
-	int bank_n = memory_region_length(space->machine, "maincpu") / 0x4000 - 1;
+	int bank_n = space->machine->region("maincpu")->bytes() / 0x4000 - 1;
 
 	if (bank >= bank_n)
 	{
@@ -103,13 +103,13 @@ static ADDRESS_MAP_START( paradise_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x2004, 0x2004) AM_WRITE(paradise_palbank_w)	// Layers palette bank
 	AM_RANGE(0x2006, 0x2006) AM_WRITE(paradise_rombank_w)	// ROM bank
 	AM_RANGE(0x2007, 0x2007) AM_DEVWRITE("oki2", paradise_okibank_w)	// OKI 1 samples bank
-	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)	// OKI 0
+	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)	// OKI 0
 	AM_RANGE(0x2020, 0x2020) AM_READ_PORT("DSW1")
 	AM_RANGE(0x2021, 0x2021) AM_READ_PORT("DSW2")
 	AM_RANGE(0x2022, 0x2022) AM_READ_PORT("P1")
 	AM_RANGE(0x2023, 0x2023) AM_READ_PORT("P2")
 	AM_RANGE(0x2024, 0x2024) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0x2030, 0x2030) AM_DEVREADWRITE("oki2", okim6295_r, okim6295_w)	// OKI 1
+	AM_RANGE(0x2030, 0x2030) AM_DEVREADWRITE_MODERN("oki2", okim6295_device, read, write)	// OKI 1
 	AM_RANGE(0x8000, 0xffff) AM_RAM_WRITE(paradise_pixmap_w) AM_BASE_MEMBER(paradise_state, videoram)	// Pixmap
 ADDRESS_MAP_END
 
@@ -119,7 +119,7 @@ static ADDRESS_MAP_START( torus_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x2001, 0x2001) AM_WRITE(paradise_flipscreen_w)	// Flip Screen
 	AM_RANGE(0x2004, 0x2004) AM_WRITE(paradise_palbank_w)	// Layers palette bank
 	AM_RANGE(0x2006, 0x2006) AM_WRITE(paradise_rombank_w)	// ROM bank
-	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)	// OKI 0
+	AM_RANGE(0x2010, 0x2010) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)	// OKI 0
 	AM_RANGE(0x2020, 0x2020) AM_READ_PORT("DSW1")
 	AM_RANGE(0x2021, 0x2021) AM_READ_PORT("DSW2")
 	AM_RANGE(0x2022, 0x2022) AM_READ_PORT("P1")
@@ -543,9 +543,9 @@ GFXDECODE_END
 
 static MACHINE_START( paradise )
 {
-	paradise_state *state = (paradise_state *)machine->driver_data;
-	int bank_n = memory_region_length(machine, "maincpu") / 0x4000 - 1;
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	paradise_state *state = machine->driver_data<paradise_state>();
+	int bank_n = machine->region("maincpu")->bytes() / 0x4000 - 1;
+	UINT8 *ROM = machine->region("maincpu")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 3, &ROM[0x00000], 0x4000);
 	memory_configure_bank(machine, "bank1", 3, bank_n - 3, &ROM[0x10000], 0x4000);
@@ -556,84 +556,81 @@ static MACHINE_START( paradise )
 
 static MACHINE_RESET( paradise )
 {
-	paradise_state *state = (paradise_state *)machine->driver_data;
+	paradise_state *state = machine->driver_data<paradise_state>();
 
 	state->palbank = 0;
 	state->priority = 0;
 }
 
-static MACHINE_DRIVER_START( paradise )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(paradise_state)
+static MACHINE_CONFIG_START( paradise, paradise_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_12MHz/2)			/* Z8400B - 6mhz Verified */
-	MDRV_CPU_PROGRAM_MAP(paradise_map)
-	MDRV_CPU_IO_MAP(paradise_io_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)	/* No nmi routine */
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_12MHz/2)			/* Z8400B - 6mhz Verified */
+	MCFG_CPU_PROGRAM_MAP(paradise_map)
+	MCFG_CPU_IO_MAP(paradise_io_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,4)	/* No nmi routine */
 
-	MDRV_MACHINE_START(paradise)
-	MDRV_MACHINE_RESET(paradise)
+	MCFG_MACHINE_START(paradise)
+	MCFG_MACHINE_RESET(paradise)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(54) /* 54 verified */
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */	/* we're using IPT_VBLANK */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(256, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 0+16, 256-1-16)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(54) /* 54 verified */
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */	/* we're using IPT_VBLANK */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(256, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 256-1, 0+16, 256-1-16)
 
-	MDRV_GFXDECODE(paradise)
-	MDRV_PALETTE_LENGTH(0x800 + 16)
+	MCFG_GFXDECODE(paradise)
+	MCFG_PALETTE_LENGTH(0x800 + 16)
 
-	MDRV_VIDEO_START(paradise)
-	MDRV_VIDEO_UPDATE(paradise)
+	MCFG_VIDEO_START(paradise)
+	MCFG_VIDEO_UPDATE(paradise)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_OKIM6295_ADD("oki1", XTAL_12MHz/12, OKIM6295_PIN7_HIGH)	/* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_OKIM6295_ADD("oki1", XTAL_12MHz/12, OKIM6295_PIN7_HIGH)	/* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_OKIM6295_ADD("oki2", XTAL_12MHz/12, OKIM6295_PIN7_HIGH) /* verified on pcb */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki2", XTAL_12MHz/12, OKIM6295_PIN7_HIGH) /* verified on pcb */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
+
+static MACHINE_CONFIG_DERIVED( tgtball, paradise )
 
-static MACHINE_DRIVER_START( tgtball )
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(tgtball_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(tgtball_map)
+MACHINE_CONFIG_END
+
+static MACHINE_CONFIG_DERIVED( torus, paradise )
 
-static MACHINE_DRIVER_START( torus )
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(torus_map)
-	MDRV_CPU_IO_MAP(torus_io_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(torus_map)
+	MCFG_CPU_IO_MAP(torus_io_map)
 
-	MDRV_GFXDECODE(torus)
+	MCFG_GFXDECODE(torus)
 
-	MDRV_VIDEO_UPDATE(torus)
+	MCFG_VIDEO_UPDATE(torus)
 
-	MDRV_DEVICE_REMOVE("oki2")
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("oki2")
+MACHINE_CONFIG_END
+
+static MACHINE_CONFIG_DERIVED( madball, paradise )
 
-static MACHINE_DRIVER_START( madball )
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(paradise)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(torus_map)
-	MDRV_CPU_IO_MAP(torus_io_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(torus_map)
+	MCFG_CPU_IO_MAP(torus_io_map)
 
-	MDRV_GFXDECODE(madball)
+	MCFG_GFXDECODE(madball)
 
-	MDRV_VIDEO_UPDATE(madball)
+	MCFG_VIDEO_UPDATE(madball)
 
-	MDRV_DEVICE_REMOVE("oki2")
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("oki2")
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
@@ -1043,21 +1040,21 @@ ROM_END
 
 static DRIVER_INIT (paradise)
 {
-	paradise_state *state = (paradise_state *)machine->driver_data;
+	paradise_state *state = machine->driver_data<paradise_state>();
 	state->sprite_inc = 0x20;
 }
 
 // Inverted flipscreen and sprites are packed in less memory (same number though)
 static DRIVER_INIT (tgtball)
 {
-	paradise_state *state = (paradise_state *)machine->driver_data;
+	paradise_state *state = machine->driver_data<paradise_state>();
 	state->sprite_inc = 4;
 	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x2001, 0x2001, 0, 0, tgtball_flipscreen_w );
 }
 
 static DRIVER_INIT (torus)
 {
-	paradise_state *state = (paradise_state *)machine->driver_data;
+	paradise_state *state = machine->driver_data<paradise_state>();
 	state->sprite_inc = 4;
 	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x2070, 0x2070, 0, 0, torus_coin_counter_w);
 }
