@@ -73,7 +73,7 @@ Stephh's notes (based on the game Z80 code and some tests) :
 
 static WRITE8_HANDLER( pbaction_sh_command_w )
 {
-	pbaction_state *state = (pbaction_state *)space->machine->driver_data;
+	pbaction_state *state = space->machine->driver_data<pbaction_state>();
 	soundlatch_w(space, offset, data);
 	cpu_set_input_line_and_vector(state->audiocpu, 0, HOLD_LINE, 0x00);
 }
@@ -254,7 +254,7 @@ static INTERRUPT_GEN( pbaction_interrupt )
 
 static MACHINE_START( pbaction )
 {
-	pbaction_state *state = (pbaction_state *)machine->driver_data;
+	pbaction_state *state = machine->driver_data<pbaction_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = machine->device("audiocpu");
@@ -264,56 +264,53 @@ static MACHINE_START( pbaction )
 
 static MACHINE_RESET( pbaction )
 {
-	pbaction_state *state = (pbaction_state *)machine->driver_data;
+	pbaction_state *state = machine->driver_data<pbaction_state>();
 
 	state->scroll = 0;
 }
 
-static MACHINE_DRIVER_START( pbaction )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(pbaction_state)
+static MACHINE_CONFIG_START( pbaction, pbaction_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000)	/* 4 MHz? */
-	MDRV_CPU_PROGRAM_MAP(pbaction_map)
-	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000)	/* 4 MHz? */
+	MCFG_CPU_PROGRAM_MAP(pbaction_map)
+	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3072000)
-	MDRV_CPU_PROGRAM_MAP(pbaction_sound_map)
-	MDRV_CPU_IO_MAP(pbaction_sound_io_map)
-	MDRV_CPU_VBLANK_INT_HACK(pbaction_interrupt,2)	/* ??? */
+	MCFG_CPU_ADD("audiocpu", Z80, 3072000)
+	MCFG_CPU_PROGRAM_MAP(pbaction_sound_map)
+	MCFG_CPU_IO_MAP(pbaction_sound_io_map)
+	MCFG_CPU_VBLANK_INT_HACK(pbaction_interrupt,2)	/* ??? */
 									/* IRQs are caused by the main CPU */
 
-	MDRV_MACHINE_START(pbaction)
-	MDRV_MACHINE_RESET(pbaction)
+	MCFG_MACHINE_START(pbaction)
+	MCFG_MACHINE_RESET(pbaction)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(pbaction)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE(pbaction)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_VIDEO_START(pbaction)
-	MDRV_VIDEO_UPDATE(pbaction)
+	MCFG_VIDEO_START(pbaction)
+	MCFG_VIDEO_UPDATE(pbaction)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay3", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay3", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
 
 
@@ -463,7 +460,7 @@ ROM_END
 
 static READ8_HANDLER( pbactio3_prot_kludge_r )
 {
-	pbaction_state *state = (pbaction_state *)space->machine->driver_data;
+	pbaction_state *state = space->machine->driver_data<pbaction_state>();
 
 	/* on startup, the game expect this location to NOT act as RAM */
 	if (cpu_get_pc(space->cpu) == 0xab80)
@@ -475,7 +472,7 @@ static READ8_HANDLER( pbactio3_prot_kludge_r )
 static DRIVER_INIT( pbactio3 )
 {
 	int i;
-	UINT8 *rom = memory_region(machine, "maincpu");
+	UINT8 *rom = machine->region("maincpu")->base();
 
 	/* first of all, do a simple bitswap */
 	for (i = 0; i < 0xc000; i++)
