@@ -109,11 +109,11 @@ static VIDEO_UPDATE(pcat_dyn)
 }
 
 static struct {
-	running_device	*pit8253;
-	running_device	*pic8259_1;
-	running_device	*pic8259_2;
-	running_device	*dma8237_1;
-	running_device	*dma8237_2;
+	device_t	*pit8253;
+	device_t	*pic8259_1;
+	device_t	*pic8259_2;
+	device_t	*dma8237_1;
+	device_t	*dma8237_2;
 } pcat_dyn_devices;
 
 /******************
@@ -184,7 +184,7 @@ static READ8_HANDLER( pc_dma_read_byte )
 	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
 		& 0xFF0000;
 
-	return memory_read_byte(space, page_offset + offset);
+	return space->read_byte(page_offset + offset);
 }
 
 
@@ -193,10 +193,10 @@ static WRITE8_HANDLER( pc_dma_write_byte )
 	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
 		& 0xFF0000;
 
-	memory_write_byte(space, page_offset + offset, data);
+	space->write_byte(page_offset + offset, data);
 }
 
-static void set_dma_channel(running_device *device, int channel, int state)
+static void set_dma_channel(device_t *device, int channel, int state)
 {
 	if (!state) dma_channel = channel;
 }
@@ -313,7 +313,7 @@ ADDRESS_MAP_END
 
 static READ32_HANDLER( kludge_r )
 {
-	return mame_rand(space->machine);
+	return space->machine->rand();
 }
 
 /* 3c8-3c9 -> ramdac*/
@@ -373,7 +373,7 @@ static ADDRESS_MAP_START( pcat_io, ADDRESS_SPACE_IO, 32 )
 	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8("pic8259_1", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8("pit8254", pit8253_r, pit8253_w, 0xffffffff)
 	AM_RANGE(0x0060, 0x006f) AM_READWRITE(kbdc8042_32le_r,			kbdc8042_32le_w)
-	AM_RANGE(0x0070, 0x007f) AM_READWRITE(mc146818_port32le_r,     mc146818_port32le_w)
+	AM_RANGE(0x0070, 0x007f) AM_DEVREADWRITE8_MODERN("rtc", mc146818_device, read, write, 0xffffffff)
 	AM_RANGE(0x0080, 0x009f) AM_READWRITE8(dma_page_select_r,dma_page_select_w, 0xffffffff)
 	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8("pic8259_2", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE8("dma8237_2", i8237_r, i8237_w, 0xffff)
@@ -491,7 +491,6 @@ static MACHINE_START( pcat_dyn )
 	pcat_dyn_devices.dma8237_2 = machine->device( "dma8237_2" );
 
 	init_pc_common(machine, PCCOMMON_KEYBOARD_AT, pcat_dyn_set_keyb_int);
-	mc146818_init(machine, MC146818_STANDARD);
 }
 
 static const gfx_layout CGA_charlayout =
@@ -510,38 +509,38 @@ static GFXDECODE_START( pcat_dyn )
 	// there's a 8x16 charset just after the 8x8 one
 GFXDECODE_END
 
-static MACHINE_DRIVER_START( pcat_dyn )
+static MACHINE_CONFIG_START( pcat_dyn, driver_device )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", I486, 40000000)	/* Am486 DX-40 */
-	MDRV_CPU_PROGRAM_MAP(pcat_map)
-	MDRV_CPU_IO_MAP(pcat_io)
+	MCFG_CPU_ADD("maincpu", I486, 40000000)	/* Am486 DX-40 */
+	MCFG_CPU_PROGRAM_MAP(pcat_map)
+	MCFG_CPU_IO_MAP(pcat_io)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
-	MDRV_GFXDECODE( pcat_dyn )
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
+	MCFG_GFXDECODE( pcat_dyn )
 
-	MDRV_MACHINE_START(pcat_dyn)
-	MDRV_NVRAM_HANDLER( mc146818 )
+	MCFG_MACHINE_START(pcat_dyn)
+	MCFG_MC146818_ADD( "rtc", MC146818_STANDARD )
 
-//  MDRV_IMPORT_FROM( at_kbdc8042 )
-	MDRV_PIC8259_ADD( "pic8259_1", pic8259_1_config )
-	MDRV_PIC8259_ADD( "pic8259_2", pic8259_2_config )
-	MDRV_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
-	MDRV_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
-	MDRV_PIT8254_ADD( "pit8254", at_pit8254_config )
+//  MCFG_FRAGMENT_ADD( at_kbdc8042 )
+	MCFG_PIC8259_ADD( "pic8259_1", pic8259_1_config )
+	MCFG_PIC8259_ADD( "pic8259_2", pic8259_2_config )
+	MCFG_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
+	MCFG_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
+	MCFG_PIT8254_ADD( "pit8254", at_pit8254_config )
 
-	MDRV_PALETTE_INIT(pcat_286)
+	MCFG_PALETTE_INIT(pcat_286)
 
-	MDRV_PALETTE_LENGTH(0x300)
+	MCFG_PALETTE_LENGTH(0x300)
 
-	MDRV_VIDEO_START(pcat_dyn)
-	MDRV_VIDEO_UPDATE(pcat_dyn)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(pcat_dyn)
+	MCFG_VIDEO_UPDATE(pcat_dyn)
+MACHINE_CONFIG_END
 
 /***************************************
 *
