@@ -34,25 +34,7 @@ TODO:
 #include "machine/nmk112.h"
 #include "sound/okim6295.h"
 #include "sound/2203intf.h"
-
-/* Variables that video has access to */
-
-/* Variables defined in video */
-extern UINT16 *powerins_vram_0, *powerins_vctrl_0;
-extern UINT16 *powerins_vram_1, *powerins_vctrl_1;
-
-/* Functions defined in video */
-
-WRITE16_HANDLER( powerins_flipscreen_w );
-WRITE16_HANDLER( powerins_tilebank_w );
-
-WRITE16_HANDLER( powerins_paletteram16_w );
-
-WRITE16_HANDLER( powerins_vram_0_w );
-WRITE16_HANDLER( powerins_vram_1_w );
-
-VIDEO_START( powerins );
-VIDEO_UPDATE( powerins );
+#include "includes/powerins.h"
 
 
 /***************************************************************************
@@ -67,7 +49,7 @@ static WRITE16_HANDLER( powerins_okibank_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		UINT8 *RAM = memory_region(space->machine, "oki1");
+		UINT8 *RAM = space->machine->region("oki1")->base();
 		int new_bank = data & 0x7;
 
 		if (new_bank != oki_bank)
@@ -121,7 +103,7 @@ static ADDRESS_MAP_START( powerina_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x100018, 0x100019) AM_WRITE(powerins_tilebank_w)									// Tiles Banking (VRAM 0)
 	AM_RANGE(0x10001e, 0x10001f) AM_WRITENOP													// Sound Latch, NOPed since there is no sound cpu
 	AM_RANGE(0x100030, 0x100031) AM_WRITE(powerins_okibank_w)									// Sound
-	AM_RANGE(0x10003e, 0x10003f) AM_DEVREADWRITE8("oki1", okim6295_r,okim6295_w, 0x00ff)		// (used by powerina)
+	AM_RANGE(0x10003e, 0x10003f) AM_DEVREADWRITE8_MODERN("oki1", okim6295_device, read, write, 0x00ff)		// (used by powerina)
 	AM_RANGE(0x120000, 0x120fff) AM_RAM_WRITE(powerins_paletteram16_w) AM_BASE_GENERIC(paletteram)	// Palette
 	AM_RANGE(0x130000, 0x130007) AM_RAM AM_BASE(&powerins_vctrl_0)								// VRAM 0 Control
 	AM_RANGE(0x140000, 0x143fff) AM_RAM_WRITE(powerins_vram_0_w) AM_BASE(&powerins_vram_0)		// VRAM 0
@@ -141,8 +123,8 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( powerins_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x01) AM_DEVREADWRITE("ym2203", ym2203_r, ym2203_w)
-	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)
-	AM_RANGE(0x88, 0x88) AM_DEVREADWRITE("oki2", okim6295_r, okim6295_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)
+	AM_RANGE(0x88, 0x88) AM_DEVREADWRITE_MODERN("oki2", okim6295_device, read, write)
 	AM_RANGE(0x90, 0x97) AM_DEVWRITE("nmk112", nmk112_okibank_w)
 ADDRESS_MAP_END
 
@@ -150,8 +132,8 @@ static ADDRESS_MAP_START( powerinb_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(powerinb_fake_ym2203_r) AM_WRITENOP
 	AM_RANGE(0x01, 0x01) AM_NOP
-	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE("oki1", okim6295_r, okim6295_w)
-	AM_RANGE(0x88, 0x88) AM_DEVREADWRITE("oki2", okim6295_r, okim6295_w)
+	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)
+	AM_RANGE(0x88, 0x88) AM_DEVREADWRITE_MODERN("oki2", okim6295_device, read, write)
 	AM_RANGE(0x90, 0x97) AM_DEVWRITE("nmk112", nmk112_okibank_w)
 ADDRESS_MAP_END
 
@@ -336,7 +318,7 @@ static MACHINE_RESET( powerins )
 	oki_bank = -1;	// samples bank "unitialised"
 }
 
-static void irqhandler(running_device *device, int irq)
+static void irqhandler(device_t *device, int irq)
 {
 	cputag_set_input_line(device->machine, "soundcpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
@@ -357,83 +339,81 @@ static const nmk112_interface powerins_nmk112_intf =
 };
 
 
-static MACHINE_DRIVER_START( powerins )
+static MACHINE_CONFIG_START( powerins, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 12000000)	/* 12MHz */
-	MDRV_CPU_PROGRAM_MAP(powerins_map)
-	MDRV_CPU_VBLANK_INT("screen", irq4_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 12000000)	/* 12MHz */
+	MCFG_CPU_PROGRAM_MAP(powerins_map)
+	MCFG_CPU_VBLANK_INT("screen", irq4_line_hold)
 
-	MDRV_CPU_ADD("soundcpu", Z80, 6000000) /* 6 MHz */
-	MDRV_CPU_PROGRAM_MAP(powerins_sound_map)
-	MDRV_CPU_IO_MAP(powerins_sound_io_map)
+	MCFG_CPU_ADD("soundcpu", Z80, 6000000) /* 6 MHz */
+	MCFG_CPU_PROGRAM_MAP(powerins_sound_map)
+	MCFG_CPU_IO_MAP(powerins_sound_io_map)
 
-	MDRV_MACHINE_RESET(powerins)
+	MCFG_MACHINE_RESET(powerins)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(56)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(320, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 320-1, 0+16, 256-16-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(56)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(320, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0+16, 256-16-1)
 
-	MDRV_GFXDECODE(powerins)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_GFXDECODE(powerins)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(powerins)
-	MDRV_VIDEO_UPDATE(powerins)
+	MCFG_VIDEO_START(powerins)
+	MCFG_VIDEO_UPDATE(powerins)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_OKIM6295_ADD("oki1", 4000000, OKIM6295_PIN7_LOW)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_OKIM6295_ADD("oki1", 4000000, OKIM6295_PIN7_LOW)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_OKIM6295_ADD("oki2", 4000000, OKIM6295_PIN7_LOW)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+	MCFG_OKIM6295_ADD("oki2", 4000000, OKIM6295_PIN7_LOW)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
 
-	MDRV_SOUND_ADD("ym2203", YM2203, 12000000 / 8)
-	MDRV_SOUND_CONFIG(ym2203_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 2.0)
+	MCFG_SOUND_ADD("ym2203", YM2203, 12000000 / 8)
+	MCFG_SOUND_CONFIG(ym2203_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 2.0)
 
-	MDRV_NMK112_ADD("nmk112", powerins_nmk112_intf)
-MACHINE_DRIVER_END
+	MCFG_NMK112_ADD("nmk112", powerins_nmk112_intf)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( powerina )
+static MACHINE_CONFIG_DERIVED( powerina, powerins )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(powerins)
 
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(powerina_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(powerina_map)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_REFRESH_RATE(60)
 
-	MDRV_DEVICE_REMOVE("soundcpu")
+	MCFG_DEVICE_REMOVE("soundcpu")
 
-	MDRV_OKIM6295_REPLACE("oki1", 990000, OKIM6295_PIN7_LOW) // pin7 not verified
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_OKIM6295_REPLACE("oki1", 990000, OKIM6295_PIN7_LOW) // pin7 not verified
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_DEVICE_REMOVE("oki2")
-	MDRV_DEVICE_REMOVE("ym2203")
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("oki2")
+	MCFG_DEVICE_REMOVE("ym2203")
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( powerinb )
+static MACHINE_CONFIG_DERIVED( powerinb, powerins )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(powerins)
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_REFRESH_RATE(60)
 
-	MDRV_CPU_MODIFY("soundcpu") /* 6 MHz */
-	MDRV_CPU_IO_MAP(powerinb_sound_io_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold, 120)	// YM2203 rate is at 150??
+	MCFG_CPU_MODIFY("soundcpu") /* 6 MHz */
+	MCFG_CPU_IO_MAP(powerinb_sound_io_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold, 120)	// YM2203 rate is at 150??
 
-	MDRV_DEVICE_REMOVE("ym2203")	// Sound code talks to one, but it's not fitted on the board
-MACHINE_DRIVER_END
+	MCFG_DEVICE_REMOVE("ym2203")	// Sound code talks to one, but it's not fitted on the board
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
