@@ -172,9 +172,9 @@ static WRITE8_DEVICE_HANDLER( rastan_bankswitch_w )
 }
 
 
-static void rastan_msm5205_vck( running_device *device )
+static void rastan_msm5205_vck( device_t *device )
 {
-	rastan_state *state = (rastan_state *)device->machine->driver_data;
+	rastan_state *state = device->machine->driver_data<rastan_state>();
 	if (state->adpcm_data != -1)
 	{
 		msm5205_data_w(device, state->adpcm_data & 0x0f);
@@ -182,7 +182,7 @@ static void rastan_msm5205_vck( running_device *device )
 	}
 	else
 	{
-		state->adpcm_data = memory_region(device->machine, "adpcm")[state->adpcm_pos];
+		state->adpcm_data = device->machine->region("adpcm")->base()[state->adpcm_pos];
 		state->adpcm_pos = (state->adpcm_pos + 1) & 0xffff;
 		msm5205_data_w(device, state->adpcm_data >> 4);
 	}
@@ -190,7 +190,7 @@ static void rastan_msm5205_vck( running_device *device )
 
 static WRITE8_HANDLER( rastan_msm5205_address_w )
 {
-	rastan_state *state = (rastan_state *)space->machine->driver_data;
+	rastan_state *state = space->machine->driver_data<rastan_state>();
 	state->adpcm_pos = (state->adpcm_pos & 0x00ff) | (data << 8);
 }
 
@@ -201,7 +201,7 @@ static WRITE8_DEVICE_HANDLER( rastan_msm5205_start_w )
 
 static WRITE8_DEVICE_HANDLER( rastan_msm5205_stop_w )
 {
-	rastan_state *state = (rastan_state *)device->machine->driver_data;
+	rastan_state *state = device->machine->driver_data<rastan_state>();
 	msm5205_reset_w(device, 1);
 	state->adpcm_pos &= 0xff00;
 }
@@ -344,9 +344,9 @@ GFXDECODE_END
 
 
 /* handler called by the YM2151 emulator when the internal timers cause an IRQ */
-static void irqhandler( running_device *device, int irq )
+static void irqhandler( device_t *device, int irq )
 {
-	rastan_state *state = (rastan_state *)device->machine->driver_data;
+	rastan_state *state = device->machine->driver_data<rastan_state>();
 	cpu_set_input_line(state->audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
@@ -364,8 +364,8 @@ static const msm5205_interface msm5205_config =
 
 static MACHINE_START( rastan )
 {
-	rastan_state *state = (rastan_state *)machine->driver_data;
-	UINT8 *ROM = memory_region(machine, "audiocpu");
+	rastan_state *state = machine->driver_data<rastan_state>();
+	UINT8 *ROM = machine->region("audiocpu")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 1, &ROM[0x00000], 0x4000);
 	memory_configure_bank(machine, "bank1", 1, 3, &ROM[0x10000], 0x4000);
@@ -384,7 +384,7 @@ static MACHINE_START( rastan )
 
 static MACHINE_RESET( rastan )
 {
-	rastan_state *state = (rastan_state *)machine->driver_data;
+	rastan_state *state = machine->driver_data<rastan_state>();
 
 	state->sprite_ctrl = 0;
 	state->sprites_flipscreen = 0;
@@ -409,54 +409,51 @@ static const tc0140syt_interface rastan_tc0140syt_intf =
 	"maincpu", "audiocpu"
 };
 
-static MACHINE_DRIVER_START( rastan )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(rastan_state)
+static MACHINE_CONFIG_START( rastan, rastan_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, XTAL_16MHz/2)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(rastan_map)
-	MDRV_CPU_VBLANK_INT("screen", irq5_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, XTAL_16MHz/2)	/* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(rastan_map)
+	MCFG_CPU_VBLANK_INT("screen", irq5_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, XTAL_16MHz/4)	/* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(rastan_s_map)
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_16MHz/4)	/* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(rastan_s_map)
 
-	MDRV_QUANTUM_TIME(HZ(600))	/* 10 CPU slices per frame - enough for the sound CPU to read all commands */
+	MCFG_QUANTUM_TIME(HZ(600))	/* 10 CPU slices per frame - enough for the sound CPU to read all commands */
 
-	MDRV_MACHINE_START(rastan)
-	MDRV_MACHINE_RESET(rastan)
+	MCFG_MACHINE_START(rastan)
+	MCFG_MACHINE_RESET(rastan)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(40*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(40*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(rastan)
-	MDRV_PALETTE_LENGTH(8192)
+	MCFG_GFXDECODE(rastan)
+	MCFG_PALETTE_LENGTH(8192)
 
-	MDRV_VIDEO_UPDATE(rastan)
+	MCFG_VIDEO_UPDATE(rastan)
 
-	MDRV_PC080SN_ADD("pc080sn", rastan_pc080sn_intf)
-	MDRV_PC090OJ_ADD("pc090oj", rastan_pc090oj_intf)
+	MCFG_PC080SN_ADD("pc080sn", rastan_pc080sn_intf)
+	MCFG_PC090OJ_ADD("pc090oj", rastan_pc090oj_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, XTAL_16MHz/4)	/* verified on pcb */
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(0, "mono", 0.50)
-	MDRV_SOUND_ROUTE(1, "mono", 0.50)
+	MCFG_SOUND_ADD("ymsnd", YM2151, XTAL_16MHz/4)	/* verified on pcb */
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(0, "mono", 0.50)
+	MCFG_SOUND_ROUTE(1, "mono", 0.50)
 
-	MDRV_SOUND_ADD("msm", MSM5205, XTAL_384kHz)	/* verified on pcb */
-	MDRV_SOUND_CONFIG(msm5205_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+	MCFG_SOUND_ADD("msm", MSM5205, XTAL_384kHz)	/* verified on pcb */
+	MCFG_SOUND_CONFIG(msm5205_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 
-	MDRV_TC0140SYT_ADD("tc0140syt", rastan_tc0140syt_intf)
-MACHINE_DRIVER_END
+	MCFG_TC0140SYT_ADD("tc0140syt", rastan_tc0140syt_intf)
+MACHINE_CONFIG_END
 
 
 
