@@ -202,7 +202,7 @@ GFXDECODE_END
 
 static MACHINE_START( scregg )
 {
-	btime_state *state = (btime_state *)machine->driver_data;
+	btime_state *state = machine->driver_data<btime_state>();
 
 	state->maincpu = machine->device("maincpu");
 	state->audiocpu = NULL;
@@ -215,7 +215,7 @@ static MACHINE_START( scregg )
 
 static MACHINE_RESET( scregg )
 {
-	btime_state *state = (btime_state *)machine->driver_data;
+	btime_state *state = machine->driver_data<btime_state>();
 
 	state->btime_palette = 0;
 	state->bnj_scroll1 = 0;
@@ -226,82 +226,76 @@ static MACHINE_RESET( scregg )
 	state->btime_tilemap[3] = 0;
 }
 
-static MACHINE_DRIVER_START( dommy )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(btime_state)
+static MACHINE_CONFIG_START( dommy, btime_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M6502, 1500000)
-	MDRV_CPU_PROGRAM_MAP(dommy_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold,16*60) //???
+	MCFG_CPU_ADD("maincpu", M6502, 1500000)
+	MCFG_CPU_PROGRAM_MAP(dommy_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,16*60) //???
 
-	MDRV_MACHINE_START(scregg)
-	MDRV_MACHINE_RESET(scregg)
+	MCFG_MACHINE_START(scregg)
+	MCFG_MACHINE_RESET(scregg)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3072)        /* frames per second, vblank duration taken from Burger Time */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(57)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3072)        /* frames per second, vblank duration taken from Burger Time */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 31*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(scregg)
-	MDRV_PALETTE_LENGTH(8)
+	MCFG_GFXDECODE(scregg)
+	MCFG_PALETTE_LENGTH(8)
 
-	MDRV_PALETTE_INIT(btime)
-	MDRV_VIDEO_START(btime)
-	MDRV_VIDEO_UPDATE(eggs)
+	MCFG_PALETTE_INIT(btime)
+	MCFG_VIDEO_START(btime)
+	MCFG_VIDEO_UPDATE(eggs)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( scregg )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(btime_state)
+static MACHINE_CONFIG_START( scregg, btime_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M6502, 1500000)
-	MDRV_CPU_PROGRAM_MAP(eggs_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold,16*60) //???
+	MCFG_CPU_ADD("maincpu", M6502, 1500000)
+	MCFG_CPU_PROGRAM_MAP(eggs_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,16*60) //???
 
-	MDRV_MACHINE_START(scregg)
-	MDRV_MACHINE_RESET(scregg)
+	MCFG_MACHINE_START(scregg)
+	MCFG_MACHINE_RESET(scregg)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3072)        /* frames per second, vblank duration taken from Burger Time */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(57)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(3072)        /* frames per second, vblank duration taken from Burger Time */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 1*8, 31*8-1)
 
-	MDRV_GFXDECODE(scregg)
-	MDRV_PALETTE_LENGTH(8)
+	MCFG_GFXDECODE(scregg)
+	MCFG_PALETTE_LENGTH(8)
 
-	MDRV_PALETTE_INIT(btime)
-	MDRV_VIDEO_START(btime)
-	MDRV_VIDEO_UPDATE(eggs)
+	MCFG_PALETTE_INIT(btime)
+	MCFG_VIDEO_START(btime)
+	MCFG_VIDEO_UPDATE(eggs)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.23)
+MACHINE_CONFIG_END
 
 
 ROM_START( dommy )
@@ -397,7 +391,7 @@ static DRIVER_INIT( rockduck )
 {
 	// rd2.rdh and rd1.rdj are bitswapped, but not rd3.rdg .. are they really from the same board?
 	int x;
-	UINT8 *src = memory_region( machine, "gfx1" );
+	UINT8 *src = machine->region( "gfx1" )->base();
 
 	for (x = 0x2000; x < 0x6000; x++)
 	{
