@@ -137,7 +137,6 @@
 #include "sound/ay8910.h"
 #include "sound/samples.h"
 #include "audio/segasnd.h"
-#include "video/vector.h"
 #include "includes/segag80r.h"
 #include "includes/segag80v.h"
 
@@ -159,8 +158,6 @@
  *
  *************************************/
 
-extern UINT8 (*sega_decrypt)(offs_t, UINT8);
-
 static UINT8 *mainram;
 static UINT8 has_usb;
 
@@ -213,20 +210,20 @@ static MACHINE_RESET( g80v )
  *
  *************************************/
 
-static offs_t decrypt_offset(const address_space *space, offs_t offset)
+static offs_t decrypt_offset(address_space *space, offs_t offset)
 {
 	/* ignore anything but accesses via opcode $32 (LD $(XXYY),A) */
 	offs_t pc = cpu_get_previouspc(space->cpu);
-	if ((UINT16)pc == 0xffff || memory_read_byte(space, pc) != 0x32)
+	if ((UINT16)pc == 0xffff || space->read_byte(pc) != 0x32)
 		return offset;
 
 	/* fetch the low byte of the address and munge it */
-	return (offset & 0xff00) | (*sega_decrypt)(pc, memory_read_byte(space, pc + 1));
+	return (offset & 0xff00) | (*sega_decrypt)(pc, space->read_byte(pc + 1));
 }
 
 static WRITE8_HANDLER( mainram_w ) { mainram[decrypt_offset(space, offset)] = data; }
 static WRITE8_HANDLER( usb_ram_w ) { sega_usb_ram_w(space, decrypt_offset(space, offset), data); }
-static WRITE8_HANDLER( vectorram_w ) { vectorram[decrypt_offset(space, offset)] = data; }
+static WRITE8_HANDLER( vectorram_w ) { segag80v_vectorram[decrypt_offset(space, offset)] = data; }
 
 
 
@@ -396,7 +393,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_ROM		/* CPU board ROM */
 	AM_RANGE(0x0800, 0xbfff) AM_ROM		/* PROM board ROM area */
 	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(mainram_w) AM_BASE(&mainram)
-	AM_RANGE(0xe000, 0xefff) AM_RAM_WRITE(vectorram_w) AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
+	AM_RANGE(0xe000, 0xefff) AM_RAM_WRITE(vectorram_w) AM_BASE(&segag80v_vectorram) AM_SIZE(&segag80v_vectorram_size)
 ADDRESS_MAP_END
 
 
@@ -912,87 +909,82 @@ static const samples_interface zektor_samples_interface =
  *
  *************************************/
 
-static MACHINE_DRIVER_START( g80v_base )
+static MACHINE_CONFIG_START( g80v_base, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, CPU_CLOCK/2)
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_IO_MAP(main_portmap)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, CPU_CLOCK/2)
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_IO_MAP(main_portmap)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_MACHINE_START(g80v)
-	MDRV_MACHINE_RESET(g80v)
+	MCFG_MACHINE_START(g80v)
+	MCFG_MACHINE_RESET(g80v)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", VECTOR)
-	MDRV_SCREEN_REFRESH_RATE(40)
-	MDRV_SCREEN_SIZE(400, 300)
-	MDRV_SCREEN_VISIBLE_AREA(512, 1536, 640-32, 1408+32)
+	MCFG_SCREEN_ADD("screen", VECTOR)
+	MCFG_SCREEN_REFRESH_RATE(40)
+	MCFG_SCREEN_SIZE(400, 300)
+	MCFG_SCREEN_VISIBLE_AREA(512, 1536, 640-32, 1408+32)
 
-	MDRV_VIDEO_START(sega)
-	MDRV_VIDEO_UPDATE(sega)
+	MCFG_VIDEO_START(segag80v)
+	MCFG_VIDEO_UPDATE(segag80v)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_MONO("mono")
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( elim2 )
-	MDRV_IMPORT_FROM(g80v_base)
+static MACHINE_CONFIG_DERIVED( elim2, g80v_base )
 
 	/* custom sound board */
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(elim2_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(elim2_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( spacfury )
-	MDRV_IMPORT_FROM(g80v_base)
+static MACHINE_CONFIG_DERIVED( spacfury, g80v_base )
 
 	/* custom sound board */
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(spacfury_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(spacfury_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
 	/* speech board */
-	MDRV_IMPORT_FROM(sega_speech_board)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(sega_speech_board)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( zektor )
-	MDRV_IMPORT_FROM(g80v_base)
+static MACHINE_CONFIG_DERIVED( zektor, g80v_base )
 
 	/* custom sound board */
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(zektor_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(zektor_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD("aysnd", AY8910, CPU_CLOCK/2/2)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
+	MCFG_SOUND_ADD("aysnd", AY8910, CPU_CLOCK/2/2)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 
 	/* speech board */
-	MDRV_IMPORT_FROM(sega_speech_board)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(sega_speech_board)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( tacscan )
-	MDRV_IMPORT_FROM(g80v_base)
+static MACHINE_CONFIG_DERIVED( tacscan, g80v_base )
 
 	/* universal sound board */
-	MDRV_IMPORT_FROM(sega_universal_sound_board)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(sega_universal_sound_board)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( startrek )
-	MDRV_IMPORT_FROM(g80v_base)
+static MACHINE_CONFIG_DERIVED( startrek, g80v_base )
 
 	/* speech board */
-	MDRV_IMPORT_FROM(sega_speech_board)
+	MCFG_FRAGMENT_ADD(sega_speech_board)
 
 	/* universal sound board */
-	MDRV_IMPORT_FROM(sega_universal_sound_board)
-MACHINE_DRIVER_END
+	MCFG_FRAGMENT_ADD(sega_universal_sound_board)
+MACHINE_CONFIG_END
 
 
 
@@ -1318,7 +1310,7 @@ ROM_END
 
 static DRIVER_INIT( elim2 )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	/* configure security */
 	sega_security(70);
@@ -1332,7 +1324,7 @@ static DRIVER_INIT( elim2 )
 
 static DRIVER_INIT( elim4 )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	/* configure security */
 	sega_security(76);
@@ -1350,7 +1342,7 @@ static DRIVER_INIT( elim4 )
 
 static DRIVER_INIT( spacfury )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	/* configure security */
 	sega_security(64);
@@ -1366,8 +1358,8 @@ static DRIVER_INIT( spacfury )
 
 static DRIVER_INIT( zektor )
 {
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
-	running_device *ay = machine->device("aysnd");
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	device_t *ay = machine->device("aysnd");
 
 	/* configure security */
 	sega_security(82);
@@ -1388,8 +1380,8 @@ static DRIVER_INIT( zektor )
 
 static DRIVER_INIT( tacscan )
 {
-	const address_space *pgmspace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *pgmspace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	/* configure security */
 	sega_security(76);
@@ -1407,8 +1399,8 @@ static DRIVER_INIT( tacscan )
 
 static DRIVER_INIT( startrek )
 {
-	const address_space *pgmspace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	const address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	address_space *pgmspace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
 
 	/* configure security */
 	sega_security(64);
