@@ -485,7 +485,7 @@ static UINT8 vdp_data_r(struct sms_vdp *chip)
 	return retdata;
 }
 
-static void vdp_data_w(const address_space *space, UINT8 data, struct sms_vdp* chip)
+static void vdp_data_w(address_space *space, UINT8 data, struct sms_vdp* chip)
 {
 	/* data writes clear the pending flag */
 	chip->cmd_pend = 0;
@@ -549,7 +549,7 @@ static void vdp_data_w(const address_space *space, UINT8 data, struct sms_vdp* c
 
 }
 
-static UINT8 vdp_ctrl_r(const address_space *space, struct sms_vdp *chip)
+static UINT8 vdp_ctrl_r(address_space *space, struct sms_vdp *chip)
 {
 	UINT8 retvalue;
 
@@ -613,7 +613,7 @@ static void vdp_set_register(running_machine *machine, struct sms_vdp *chip)
 //  printf("VDP: setting register %01x to %02x\n",reg, chip->cmd_part1);
 }
 
-static void vdp_ctrl_w(const address_space *space, UINT8 data, struct sms_vdp *chip)
+static void vdp_ctrl_w(address_space *space, UINT8 data, struct sms_vdp *chip)
 {
 	if (chip->cmd_pend)
 	{ /* Part 2 of a command word write */
@@ -1480,7 +1480,7 @@ READ8_HANDLER( sms_ioport_gg00_r )
 
 void init_extra_gg_ports(running_machine* machine, const char* tag)
 {
-	const address_space *io = cputag_get_address_space(machine, tag, ADDRESS_SPACE_IO);
+	address_space *io = cputag_get_address_space(machine, tag, ADDRESS_SPACE_IO);
 	memory_install_read8_handler     (io, 0x00, 0x00, 0, 0, sms_ioport_gg00_r);
 }
 
@@ -1608,13 +1608,13 @@ static WRITE8_HANDLER( mt_sms_standard_rom_bank_w )
 			//printf("bank ram??\n");
 			break;
 		case 1:
-			memcpy(sms_rom+0x0000, memory_region(space->machine, "maincpu")+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x0000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 			break;
 		case 2:
-			memcpy(sms_rom+0x4000, memory_region(space->machine, "maincpu")+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x4000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 			break;
 		case 3:
-			memcpy(sms_rom+0x8000, memory_region(space->machine, "maincpu")+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x8000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 			break;
 
 	}
@@ -1623,19 +1623,19 @@ static WRITE8_HANDLER( mt_sms_standard_rom_bank_w )
 static WRITE8_HANDLER( codemasters_rom_bank_0000_w )
 {
 	int bank = data&0x1f;
-	memcpy(sms_rom+0x0000, memory_region(space->machine,"maincpu")+bank*0x4000, 0x4000);
+	memcpy(sms_rom+0x0000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 }
 
 static WRITE8_HANDLER( codemasters_rom_bank_4000_w )
 {
 	int bank = data&0x1f;
-	memcpy(sms_rom+0x4000, memory_region(space->machine,"maincpu")+bank*0x4000, 0x4000);
+	memcpy(sms_rom+0x4000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 }
 
 static WRITE8_HANDLER( codemasters_rom_bank_8000_w )
 {
 	int bank = data&0x1f;
-	memcpy(sms_rom+0x8000, memory_region(space->machine,"maincpu")+bank*0x4000, 0x4000);
+	memcpy(sms_rom+0x8000, space->machine->region("maincpu")->base()+bank*0x4000, 0x4000);
 }
 
 
@@ -1643,8 +1643,8 @@ static void megatech_set_genz80_as_sms_standard_ports(running_machine *machine,
 {
 	/* INIT THE PORTS *********************************************************************************************/
 
-	const address_space *io = cputag_get_address_space(machine, tag, ADDRESS_SPACE_IO);
-	running_device *sn = machine->device("snsnd");
+	address_space *io = cputag_get_address_space(machine, tag, ADDRESS_SPACE_IO);
+	device_t *sn = machine->device("snsnd");
 
 	memory_install_readwrite8_handler(io, 0x0000, 0xffff, 0, 0, z80_unmapped_port_r, z80_unmapped_port_w);
 
@@ -1677,7 +1677,7 @@ void megatech_set_genz80_as_sms_standard_map(running_machine *machine, const cha
 	/* fixed rom bank area */
 	sms_rom = (UINT8 *)memory_install_rom(cputag_get_address_space(machine, tag, ADDRESS_SPACE_PROGRAM), 0x0000, 0xbfff, 0, 0, NULL);
 
-	memcpy(sms_rom, memory_region(machine, "maincpu"), 0xc000);
+	memcpy(sms_rom, machine->region("maincpu")->base(), 0xc000);
 
 	if (mapper == MAPPER_STANDARD )
 	{
@@ -1711,35 +1711,35 @@ static NVRAM_HANDLER( sms )
 	}
 }
 
-MACHINE_DRIVER_START( sms )
-	MDRV_CPU_ADD("maincpu", Z80, 3579540)
-	//MDRV_CPU_PROGRAM_MAP(sms_map)
-	MDRV_CPU_IO_MAP(sms_io_map)
+MACHINE_CONFIG_START( sms, driver_device )
+	MCFG_CPU_ADD("maincpu", Z80, 3579540)
+	//MCFG_CPU_PROGRAM_MAP(sms_map)
+	MCFG_CPU_IO_MAP(sms_io_map)
 
 	/* IRQ handled via the timers */
-	MDRV_MACHINE_RESET(sms)
+	MCFG_MACHINE_RESET(sms)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)) // Vblank handled manually.
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
-	MDRV_SCREEN_SIZE(256, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0, 255, 0, 223)
-//  MDRV_SCREEN_VISIBLE_AREA(0, 255, 0, 191)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)) // Vblank handled manually.
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MCFG_SCREEN_SIZE(256, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0, 255, 0, 223)
+//  MCFG_SCREEN_VISIBLE_AREA(0, 255, 0, 191)
 
-	MDRV_PALETTE_LENGTH(0x200)
+	MCFG_PALETTE_LENGTH(0x200)
 
-	MDRV_VIDEO_START(sms)
-	MDRV_VIDEO_UPDATE(megatech_md_sms) /* Copies a bitmap */
-	MDRV_VIDEO_EOF(sms) /* Used to Sync the timing */
+	MCFG_VIDEO_START(sms)
+	MCFG_VIDEO_UPDATE(megatech_md_sms) /* Copies a bitmap */
+	MCFG_VIDEO_EOF(sms) /* Used to Sync the timing */
 
-	MDRV_NVRAM_HANDLER( sms )
+	MCFG_NVRAM_HANDLER( sms )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("snsnd", SN76496, 3579540)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("snsnd", SN76496, 3579540)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
