@@ -41,7 +41,7 @@ static WRITE16_HANDLER( sf_coin_w )
 
 static WRITE16_HANDLER( soundcmd_w )
 {
-	sf_state *state = (sf_state *)space->machine->driver_data;
+	sf_state *state = space->machine->driver_data<sf_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -54,10 +54,10 @@ static WRITE16_HANDLER( soundcmd_w )
 /* The protection of the Japanese (and alt US) version */
 /* I'd love to see someone dump the 68705 / i8751 roms */
 
-static void write_dword( const address_space *space, offs_t offset, UINT32 data )
+static void write_dword( address_space *space, offs_t offset, UINT32 data )
 {
-	memory_write_word(space, offset, data >> 16);
-	memory_write_word(space, offset + 2, data);
+	space->write_word(offset, data >> 16);
+	space->write_word(offset + 2, data);
 }
 
 static WRITE16_HANDLER( protection_w )
@@ -71,10 +71,10 @@ static WRITE16_HANDLER( protection_w )
 	int map;
 
 	map = maplist
-		[memory_read_byte(space, 0xffc006)]
-		[(memory_read_byte(space, 0xffc003) << 1) + (memory_read_word(space, 0xffc004) >> 8)];
+		[space->read_byte(0xffc006)]
+		[(space->read_byte(0xffc003) << 1) + (space->read_word(0xffc004) >> 8)];
 
-	switch (memory_read_byte(space, 0xffc684))
+	switch (space->read_byte(0xffc684))
 	{
 	case 1:
 		{
@@ -111,10 +111,10 @@ static WRITE16_HANDLER( protection_w )
 			int d1 = delta1[map] + 0xc0;
 			int d2 = delta2[map];
 
-			memory_write_word(space, 0xffc680, d1);
-			memory_write_word(space, 0xffc682, d2);
-			memory_write_word(space, 0xffc00c, 0xc0);
-			memory_write_word(space, 0xffc00e, 0);
+			space->write_word(0xffc680, d1);
+			space->write_word(0xffc682, d2);
+			space->write_word(0xffc00c, 0xc0);
+			space->write_word(0xffc00e, 0);
 
 			sf_fg_scroll_w(space, 0, d1, 0xffff);
 			sf_bg_scroll_w(space, 0, d2, 0xffff);
@@ -122,13 +122,13 @@ static WRITE16_HANDLER( protection_w )
 		}
 	case 4:
 		{
-			int pos = memory_read_byte(space, 0xffc010);
+			int pos = space->read_byte(0xffc010);
 			pos = (pos + 1) & 3;
-			memory_write_byte(space, 0xffc010, pos);
+			space->write_byte(0xffc010, pos);
 			if(!pos)
 			{
-				int d1 = memory_read_word(space, 0xffc682);
-				int off = memory_read_word(space, 0xffc00e);
+				int d1 = space->read_word(0xffc682);
+				int off = space->read_word(0xffc00e);
 				if (off!=512)
 				{
 					off++;
@@ -139,8 +139,8 @@ static WRITE16_HANDLER( protection_w )
 					off = 0;
 					d1 -= 512;
 				}
-				memory_write_word(space, 0xffc682, d1);
-				memory_write_word(space, 0xffc00e, off);
+				space->write_word(0xffc682, d1);
+				space->write_word(0xffc00e, off);
 				sf_bg_scroll_w(space, 0, d1, 0xffff);
 			}
 			break;
@@ -148,7 +148,7 @@ static WRITE16_HANDLER( protection_w )
 	default:
 		{
 			logerror("Write protection at %06x (%04x)\n", cpu_get_pc(space->cpu), data & 0xffff);
-			logerror("*** Unknown protection %d\n", memory_read_byte(space, 0xffc684));
+			logerror("*** Unknown protection %d\n", space->read_byte(0xffc684));
 			break;
 		}
 	}
@@ -174,7 +174,7 @@ static READ16_HANDLER( button2_r )
 
 static WRITE8_HANDLER( sound2_bank_w )
 {
-	memory_set_bankptr(space->machine, "bank1", memory_region(space->machine, "audio2") + 0x8000 * (data + 1));
+	memory_set_bankptr(space->machine, "bank1", space->machine->region("audio2")->base() + 0x8000 * (data + 1));
 }
 
 
@@ -787,9 +787,9 @@ GFXDECODE_END
 
 
 
-static void irq_handler( running_device *device, int irq )
+static void irq_handler( device_t *device, int irq )
 {
-	sf_state *state = (sf_state *)device->machine->driver_data;
+	sf_state *state = device->machine->driver_data<sf_state>();
 	cpu_set_input_line(state->audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
@@ -806,7 +806,7 @@ static const msm5205_interface msm5205_config =
 
 static MACHINE_START( sf )
 {
-	sf_state *state = (sf_state *)machine->driver_data;
+	sf_state *state = machine->driver_data<sf_state>();
 
 	/* devices */
 	state->maincpu = machine->device("maincpu");
@@ -819,94 +819,88 @@ static MACHINE_START( sf )
 
 static MACHINE_RESET( sf )
 {
-	sf_state *state = (sf_state *)machine->driver_data;
+	sf_state *state = machine->driver_data<sf_state>();
 
 	state->sf_active = 0;
 	state->bgscroll = 0;
 	state->fgscroll = 0;
 }
 
-static MACHINE_DRIVER_START( sf )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(sf_state)
+static MACHINE_CONFIG_START( sf, sf_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 8000000)	/* 8 MHz ? (xtal is 16MHz) */
-	MDRV_CPU_PROGRAM_MAP(sf_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000, 8000000)	/* 8 MHz ? (xtal is 16MHz) */
+	MCFG_CPU_PROGRAM_MAP(sf_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3579545)	/* ? xtal is 3.579545MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_ADD("audiocpu", Z80, 3579545)	/* ? xtal is 3.579545MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
 								/* NMIs are caused by the main CPU */
 
-	MDRV_MACHINE_START(sf)
-	MDRV_MACHINE_RESET(sf)
+	MCFG_MACHINE_START(sf)
+	MCFG_MACHINE_RESET(sf)
 
-	MDRV_CPU_ADD("audio2", Z80, 3579545)	/* ? xtal is 3.579545MHz */
-	MDRV_CPU_PROGRAM_MAP(sound2_map)
-	MDRV_CPU_IO_MAP(sound2_io_map)
-	MDRV_CPU_PERIODIC_INT(irq0_line_hold,8000)
+	MCFG_CPU_ADD("audio2", Z80, 3579545)	/* ? xtal is 3.579545MHz */
+	MCFG_CPU_PROGRAM_MAP(sound2_map)
+	MCFG_CPU_IO_MAP(sound2_io_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,8000)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(8*8, (64-8)*8-1, 2*8, 30*8-1 )
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(8*8, (64-8)*8-1, 2*8, 30*8-1 )
 
-	MDRV_GFXDECODE(sf)
-	MDRV_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE(sf)
+	MCFG_PALETTE_LENGTH(1024)
 
-	MDRV_VIDEO_START(sf)
-	MDRV_VIDEO_UPDATE(sf)
+	MCFG_VIDEO_START(sf)
+	MCFG_VIDEO_UPDATE(sf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 3579545)
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.60)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 0.60)
+	MCFG_SOUND_ADD("ymsnd", YM2151, 3579545)
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.60)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 0.60)
 
-	MDRV_SOUND_ADD("msm1", MSM5205, 384000)
-	MDRV_SOUND_CONFIG(msm5205_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("msm1", MSM5205, 384000)
+	MCFG_SOUND_CONFIG(msm5205_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("msm2", MSM5205, 384000)
-	MDRV_SOUND_CONFIG(msm5205_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("msm2", MSM5205, 384000)
+	MCFG_SOUND_CONFIG(msm5205_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( sfus )
+static MACHINE_CONFIG_DERIVED( sfus, sf )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(sf)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(sfus_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(sfus_map)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( sfjp )
+static MACHINE_CONFIG_DERIVED( sfjp, sf )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(sf)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_PROGRAM_MAP(sfjp_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(sfjp_map)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( sfp )
+static MACHINE_CONFIG_DERIVED( sfp, sf )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(sf)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_VBLANK_INT("screen", irq6_line_hold)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_VBLANK_INT("screen", irq6_line_hold)
+MACHINE_CONFIG_END
 
 
 ROM_START( sf )
