@@ -11,13 +11,7 @@ driver by Nicola Salmoria
 #include "audio/m72.h"
 #include "sound/dac.h"
 #include "sound/2151intf.h"
-
-extern WRITE8_HANDLER( sichuan2_videoram_w );
-extern WRITE8_HANDLER( sichuan2_bankswitch_w );
-extern WRITE8_HANDLER( sichuan2_paletteram_w );
-
-extern VIDEO_START( sichuan2 );
-extern VIDEO_UPDATE( sichuan2 );
+#include "includes/shisen.h"
 
 static READ8_HANDLER( sichuan2_dsw1_r )
 {
@@ -51,8 +45,8 @@ static WRITE8_HANDLER( sichuan2_coin_w )
 static ADDRESS_MAP_START( shisen_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
-	AM_RANGE(0xc800, 0xcaff) AM_RAM_WRITE(sichuan2_paletteram_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0xd000, 0xdfff) AM_RAM_WRITE(sichuan2_videoram_w) AM_BASE_GENERIC(videoram)
+	AM_RANGE(0xc800, 0xcaff) AM_RAM_WRITE(sichuan2_paletteram_w) AM_BASE_MEMBER(shisen_state, paletteram)
+	AM_RANGE(0xd000, 0xdfff) AM_RAM_WRITE(sichuan2_videoram_w) AM_BASE_MEMBER(shisen_state, videoram)
 	AM_RANGE(0xe000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -215,49 +209,49 @@ static const ym2151_interface ym2151_config =
 
 
 
-static MACHINE_DRIVER_START( shisen )
+static MACHINE_CONFIG_START( shisen, shisen_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 6000000)	/* 6 MHz ? */
-	MDRV_CPU_PROGRAM_MAP(shisen_map)
-	MDRV_CPU_IO_MAP(shisen_io_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, 6000000)	/* 6 MHz ? */
+	MCFG_CPU_PROGRAM_MAP(shisen_map)
+	MCFG_CPU_IO_MAP(shisen_io_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("soundcpu", Z80, 3579645)
-	MDRV_CPU_PROGRAM_MAP(shisen_sound_map)
-	MDRV_CPU_IO_MAP(shisen_sound_io_map)
-	MDRV_CPU_VBLANK_INT_HACK(nmi_line_pulse,128)	/* clocked by V1? (Vigilante) */
+	MCFG_CPU_ADD("soundcpu", Z80, 3579645)
+	MCFG_CPU_PROGRAM_MAP(shisen_sound_map)
+	MCFG_CPU_IO_MAP(shisen_sound_io_map)
+	MCFG_CPU_VBLANK_INT_HACK(nmi_line_pulse,128)	/* clocked by V1? (Vigilante) */
 								/* IRQs are generated by main Z80 and YM2151 */
 
-	MDRV_SOUND_START(m72)
-	MDRV_SOUND_RESET(m72)
+	MCFG_SOUND_START(m72)
+	MCFG_SOUND_RESET(m72)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(55)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(55)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
 
-	MDRV_GFXDECODE(shisen)
-	MDRV_PALETTE_LENGTH(256)
+	MCFG_GFXDECODE(shisen)
+	MCFG_PALETTE_LENGTH(256)
 
-	MDRV_VIDEO_START(sichuan2)
-	MDRV_VIDEO_UPDATE(sichuan2)
+	MCFG_VIDEO_START(sichuan2)
+	MCFG_VIDEO_UPDATE(sichuan2)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 3579545)
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 0.5)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 0.5)
+	MCFG_SOUND_ADD("ymsnd", YM2151, 3579545)
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 0.5)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 0.5)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.25)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.25)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.25)
+MACHINE_CONFIG_END
 
 
 
