@@ -84,7 +84,7 @@ ADDRESS_MAP_END
 
 static INPUT_CHANGED( coin_inserted )
 {
-	skyfox_state *state = (skyfox_state *)field->port->machine->driver_data;
+	skyfox_state *state = field->port->machine->driver_data<skyfox_state>();
 	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
 }
 
@@ -214,7 +214,7 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( skyfox_interrupt )
 {
-	skyfox_state *state = (skyfox_state *)device->machine->driver_data;
+	skyfox_state *state = device->machine->driver_data<skyfox_state>();
 
 	/* Scroll the bg */
 	state->bg_pos += (state->bg_ctrl >> 1) & 0x7;	// maybe..
@@ -222,7 +222,7 @@ static INTERRUPT_GEN( skyfox_interrupt )
 
 static MACHINE_START( skyfox )
 {
-	skyfox_state *state = (skyfox_state *)machine->driver_data;
+	skyfox_state *state = machine->driver_data<skyfox_state>();
 
 	state->maincpu = machine->device("maincpu");
 
@@ -232,51 +232,48 @@ static MACHINE_START( skyfox )
 
 static MACHINE_RESET( skyfox )
 {
-	skyfox_state *state = (skyfox_state *)machine->driver_data;
+	skyfox_state *state = machine->driver_data<skyfox_state>();
 
 	state->bg_pos = 0;
 	state->bg_ctrl = 0;
 }
 
-static MACHINE_DRIVER_START( skyfox )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(skyfox_state)
+static MACHINE_CONFIG_START( skyfox, skyfox_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_8MHz/2) /* Verified at 4MHz */
-	MDRV_CPU_PROGRAM_MAP(skyfox_map)
-	MDRV_CPU_VBLANK_INT("screen", skyfox_interrupt)		/* NMI caused by coin insertion */
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_8MHz/2) /* Verified at 4MHz */
+	MCFG_CPU_PROGRAM_MAP(skyfox_map)
+	MCFG_CPU_VBLANK_INT("screen", skyfox_interrupt)		/* NMI caused by coin insertion */
 
-	MDRV_CPU_ADD("audiocpu", Z80, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
-	MDRV_CPU_PROGRAM_MAP(skyfox_sound_map)
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
+	MCFG_CPU_PROGRAM_MAP(skyfox_sound_map)
 
-	MDRV_MACHINE_START(skyfox)
-	MDRV_MACHINE_RESET(skyfox)
+	MCFG_MACHINE_START(skyfox)
+	MCFG_MACHINE_RESET(skyfox)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(62.65)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0+0x60, 320-1+0x60, 0+16, 256-1-16)	// from $30*2 to $CC*2+8
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(62.65)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)	// we're using IPT_VBLANK
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0+0x60, 320-1+0x60, 0+16, 256-1-16)	// from $30*2 to $CC*2+8
 
-	MDRV_GFXDECODE(skyfox)
-	MDRV_PALETTE_LENGTH(256+256)	/* 256 static colors (+256 for the background??) */
+	MCFG_GFXDECODE(skyfox)
+	MCFG_PALETTE_LENGTH(256+256)	/* 256 static colors (+256 for the background??) */
 
-	MDRV_PALETTE_INIT(skyfox)
-	MDRV_VIDEO_UPDATE(skyfox)
+	MCFG_PALETTE_INIT(skyfox)
+	MCFG_VIDEO_UPDATE(skyfox)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ym1", YM2203, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+	MCFG_SOUND_ADD("ym1", YM2203, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 
-	MDRV_SOUND_ADD("ym2", YM2203, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ym2", YM2203, XTAL_14_31818MHz/8) /* Verified at 1.789772MHz */
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+MACHINE_CONFIG_END
 
 
 
@@ -437,8 +434,8 @@ ROM_END
 /* Untangle the graphics: cut each 32x32x8 tile in 16 8x8x8 tiles */
 static DRIVER_INIT( skyfox )
 {
-	UINT8 *RAM = memory_region(machine, "gfx1");
-	UINT8 *end = RAM + memory_region_length(machine, "gfx1");
+	UINT8 *RAM = machine->region("gfx1")->base();
+	UINT8 *end = RAM + machine->region("gfx1")->bytes();
 	UINT8 buf[32 * 32];
 
 	while (RAM < end)
