@@ -232,7 +232,7 @@ cpu #2 (PC=0000060E): unmapped memory word read from 0000683A & FFFF
 
 static WRITE16_HANDLER( system_control_w )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 
 	if ((ACCESSING_BITS_0_7 == 0) && ACCESSING_BITS_8_15)
 		data >>= 8;
@@ -246,13 +246,13 @@ static WRITE16_HANDLER( system_control_w )
 
 static READ16_HANDLER( lineram_r )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 	return state->line_ram[offset];
 }
 
 static WRITE16_HANDLER( lineram_w )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 
 	if (ACCESSING_BITS_8_15 && ACCESSING_BITS_0_7)
 		state->line_ram[offset] = data;
@@ -260,13 +260,13 @@ static WRITE16_HANDLER( lineram_w )
 
 static READ16_HANDLER( dspram_r )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 	return state->dsp_ram[offset];
 }
 
 static WRITE16_HANDLER( dspram_w )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 
 	if (ACCESSING_BITS_8_15 && ACCESSING_BITS_0_7)
 		state->dsp_ram[offset] = data;
@@ -274,7 +274,7 @@ static WRITE16_HANDLER( dspram_w )
 
 static READ16_HANDLER( dsp_HOLD_signal_r )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 
 	/* HOLD signal is active low */
 	//  logerror("TMS32025:%04x Reading %01x level from HOLD signal\n", cpu_get_previouspc(space->cpu), state->dsp_hold_signal);
@@ -291,7 +291,7 @@ static WRITE16_HANDLER( dsp_HOLDA_signal_w )
 
 static WRITE16_HANDLER( airsys_paletteram16_w )	/* xxBBBBxRRRRxGGGG */
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 	int a;
 
 	COMBINE_DATA(&state->paletteram[offset]);
@@ -347,13 +347,13 @@ static READ16_HANDLER( stick2_input_r )
 
 static void reset_sound_region( running_machine *machine )
 {
-	taitoair_state *state = (taitoair_state *)machine->driver_data;
+	taitoair_state *state = machine->driver_data<taitoair_state>();
 	memory_set_bank(machine, "bank1", state->banknum);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
-	taitoair_state *state = (taitoair_state *)space->machine->driver_data;
+	taitoair_state *state = space->machine->driver_data<taitoair_state>();
 
 	state->banknum = data & 3;
 	reset_sound_region(space->machine);
@@ -569,9 +569,9 @@ GFXDECODE_END
 ************************************************************/
 
 /* Handler called by the YM2610 emulator when the internal timers cause an IRQ */
-static void irqhandler( running_device *device, int irq )
+static void irqhandler( device_t *device, int irq )
 {
-	taitoair_state *state = (taitoair_state *)device->machine->driver_data;
+	taitoair_state *state = device->machine->driver_data<taitoair_state>();
 	cpu_set_input_line(state->audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
@@ -610,8 +610,8 @@ static STATE_POSTLOAD( taitoair_postload )
 
 static MACHINE_START( taitoair )
 {
-	taitoair_state *state = (taitoair_state *)machine->driver_data;
-	UINT8 *ROM = memory_region(machine, "audiocpu");
+	taitoair_state *state = machine->driver_data<taitoair_state>();
+	UINT8 *ROM = machine->region("audiocpu")->base();
 	int i;
 
 	memory_configure_bank(machine, "bank1", 0, 4, &ROM[0xc000], 0x4000);
@@ -635,7 +635,7 @@ static MACHINE_START( taitoair )
 
 static MACHINE_RESET( taitoair )
 {
-	taitoair_state *state = (taitoair_state *)machine->driver_data;
+	taitoair_state *state = machine->driver_data<taitoair_state>();
 	int i;
 
 	state->dsp_hold_signal = ASSERT_LINE;
@@ -648,57 +648,54 @@ static MACHINE_RESET( taitoair )
 	}
 }
 
-static MACHINE_DRIVER_START( airsys )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(taitoair_state)
+static MACHINE_CONFIG_START( airsys, taitoair_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000,24000000 / 2)		/* 12 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(airsys_map)
-	MDRV_CPU_VBLANK_INT("screen", irq5_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000,24000000 / 2)		/* 12 MHz ??? */
+	MCFG_CPU_PROGRAM_MAP(airsys_map)
+	MCFG_CPU_VBLANK_INT("screen", irq5_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,8000000 / 2)			/* 4 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_ADD("audiocpu", Z80,8000000 / 2)			/* 4 MHz ??? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
 
-	MDRV_CPU_ADD("dsp", TMS32025,24000000)			/* 24 MHz ??? *///
-	MDRV_CPU_PROGRAM_MAP(DSP_map_program)
-	MDRV_CPU_DATA_MAP(DSP_map_data)
-	MDRV_CPU_IO_MAP(DSP_map_io)
+	MCFG_CPU_ADD("dsp", TMS32025,24000000)			/* 24 MHz ??? *///
+	MCFG_CPU_PROGRAM_MAP(DSP_map_program)
+	MCFG_CPU_DATA_MAP(DSP_map_data)
+	MCFG_CPU_IO_MAP(DSP_map_io)
 
-	MDRV_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(HZ(600))
 
-	MDRV_MACHINE_START(taitoair)
-	MDRV_MACHINE_RESET(taitoair)
+	MCFG_MACHINE_START(taitoair)
+	MCFG_MACHINE_RESET(taitoair)
 
-	MDRV_TC0220IOC_ADD("tc0220ioc", airsys_io_intf)
+	MCFG_TC0220IOC_ADD("tc0220ioc", airsys_io_intf)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*16, 64*16)
-	MDRV_SCREEN_VISIBLE_AREA(0*16, 32*16-1, 3*16, 28*16-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*16, 64*16)
+	MCFG_SCREEN_VISIBLE_AREA(0*16, 32*16-1, 3*16, 28*16-1)
 
-	MDRV_GFXDECODE(airsys)
-	MDRV_PALETTE_LENGTH(512*16)
+	MCFG_GFXDECODE(airsys)
+	MCFG_PALETTE_LENGTH(512*16)
 
-	MDRV_VIDEO_UPDATE(taitoair)
+	MCFG_VIDEO_UPDATE(taitoair)
 
-	MDRV_TC0080VCO_ADD("tc0080vco", airsys_tc0080vco_intf)
+	MCFG_TC0080VCO_ADD("tc0080vco", airsys_tc0080vco_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2610, 8000000)
-	MDRV_SOUND_CONFIG(airsys_ym2610_interface)
-	MDRV_SOUND_ROUTE(0, "mono", 0.30)
-	MDRV_SOUND_ROUTE(1, "mono", 0.60)
-	MDRV_SOUND_ROUTE(2, "mono", 0.60)
+	MCFG_SOUND_ADD("ymsnd", YM2610, 8000000)
+	MCFG_SOUND_CONFIG(airsys_ym2610_interface)
+	MCFG_SOUND_ROUTE(0, "mono", 0.30)
+	MCFG_SOUND_ROUTE(1, "mono", 0.60)
+	MCFG_SOUND_ROUTE(2, "mono", 0.60)
 
-	MDRV_TC0140SYT_ADD("tc0140syt", airsys_tc0140syt_intf)
-MACHINE_DRIVER_END
+	MCFG_TC0140SYT_ADD("tc0140syt", airsys_tc0140syt_intf)
+MACHINE_CONFIG_END
 
 
 /*************************************************************
