@@ -324,39 +324,39 @@ static GFXDECODE_START( tank8 )
 GFXDECODE_END
 
 
-static MACHINE_DRIVER_START( tank8 )
+static MACHINE_CONFIG_START( tank8, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M6800, 11055000 / 10) /* ? */
-	MDRV_CPU_PROGRAM_MAP(tank8_cpu_map)
+	MCFG_CPU_ADD("maincpu", M6800, 11055000 / 10) /* ? */
+	MCFG_CPU_PROGRAM_MAP(tank8_cpu_map)
 
-	MDRV_MACHINE_RESET(tank8)
+	MCFG_MACHINE_RESET(tank8)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_AFTER_VBLANK)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_AFTER_VBLANK)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(30 * 1000000 / 15681))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512, 524)
-	MDRV_SCREEN_VISIBLE_AREA(16, 495, 0, 463)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(30 * 1000000 / 15681))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512, 524)
+	MCFG_SCREEN_VISIBLE_AREA(16, 495, 0, 463)
 
-	MDRV_GFXDECODE(tank8)
-	MDRV_PALETTE_LENGTH(20)
+	MCFG_GFXDECODE(tank8)
+	MCFG_PALETTE_LENGTH(20)
 
-	MDRV_PALETTE_INIT(tank8)
-	MDRV_VIDEO_START(tank8)
-	MDRV_VIDEO_UPDATE(tank8)
-	MDRV_VIDEO_EOF(tank8)
+	MCFG_PALETTE_INIT(tank8)
+	MCFG_VIDEO_START(tank8)
+	MCFG_VIDEO_UPDATE(tank8)
+	MCFG_VIDEO_EOF(tank8)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("discrete", DISCRETE, 0)
-	MDRV_SOUND_CONFIG_DISCRETE(tank8)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("discrete", DISCRETE, 0)
+	MCFG_SOUND_CONFIG_DISCRETE(tank8)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+MACHINE_CONFIG_END
 
 
 ROM_START( tank8a )
@@ -464,10 +464,10 @@ ROM_END
 
 static DRIVER_INIT( decode )
 {
-	const UINT8* DECODE = memory_region(machine, "user1");
+	const UINT8* DECODE = machine->region("user1")->base();
 
-	UINT8* p1 = memory_region(machine, "maincpu") + 0x00000;
-	UINT8* p2 = memory_region(machine, "maincpu") + 0x10000;
+	UINT8* p1 = machine->region("maincpu")->base() + 0x00000;
+	UINT8* p2 = machine->region("maincpu")->base() + 0x10000;
 
 	int i;
 
