@@ -27,28 +27,13 @@ Credits:
 #include "sound/ay8910.h"
 #include "sound/samples.h"
 #include "video/tms9927.h"
+#include "includes/thief.h"
 
 #define MASTER_CLOCK	XTAL_20MHz
 
 
 static UINT8 thief_input_select;
 
-READ8_HANDLER( thief_context_ram_r );
-WRITE8_HANDLER( thief_context_ram_w );
-WRITE8_HANDLER( thief_context_bank_w );
-WRITE8_HANDLER( thief_video_control_w );
-WRITE8_HANDLER( thief_color_map_w );
-WRITE8_HANDLER( thief_color_plane_w );
-READ8_HANDLER( thief_videoram_r );
-WRITE8_HANDLER( thief_videoram_w );
-WRITE8_HANDLER( thief_blit_w );
-READ8_HANDLER( thief_coprocessor_r );
-WRITE8_HANDLER( thief_coprocessor_w );
-
-VIDEO_START( thief );
-VIDEO_UPDATE( thief );
-
-
 static INTERRUPT_GEN( thief_interrupt )
 {
 	/* SLAM switch causes an NMI if it's pressed */
@@ -75,12 +60,12 @@ enum
 	kTalkTrack, kCrashTrack
 };
 
-static void tape_set_audio( running_device *samples, int track, int bOn )
+static void tape_set_audio( device_t *samples, int track, int bOn )
 {
 	sample_set_volume(samples, track, bOn ? 1.0 : 0.0 );
 }
 
-static void tape_set_motor( running_device *samples, int bOn )
+static void tape_set_motor( device_t *samples, int bOn )
 {
 	if( bOn )
 	{
@@ -448,118 +433,118 @@ static const tms9927_interface tms9927_intf =
 };
 
 
-static MACHINE_DRIVER_START( sharkatt )
+static MACHINE_CONFIG_START( sharkatt, thief_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000)        /* 4 MHz? */
-	MDRV_CPU_PROGRAM_MAP(sharkatt_main_map)
-	MDRV_CPU_IO_MAP(io_map)
-	MDRV_CPU_VBLANK_INT("screen", thief_interrupt)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000)        /* 4 MHz? */
+	MCFG_CPU_PROGRAM_MAP(sharkatt_main_map)
+	MCFG_CPU_IO_MAP(io_map)
+	MCFG_CPU_VBLANK_INT("screen", thief_interrupt)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 24*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 24*8-1)
 
-	MDRV_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
+	MCFG_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
 
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_VIDEO_START(thief)
-	MDRV_VIDEO_UPDATE(thief)
+	MCFG_VIDEO_START(thief)
+	MCFG_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay1", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay2", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(sharkatt_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(sharkatt_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( thief )
+static MACHINE_CONFIG_START( thief, thief_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000) /* 4 MHz? */
-	MDRV_CPU_PROGRAM_MAP(thief_main_map)
-	MDRV_CPU_IO_MAP(io_map)
-	MDRV_CPU_VBLANK_INT("screen", thief_interrupt)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000) /* 4 MHz? */
+	MCFG_CPU_PROGRAM_MAP(thief_main_map)
+	MCFG_CPU_IO_MAP(io_map)
+	MCFG_CPU_VBLANK_INT("screen", thief_interrupt)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
 
-	MDRV_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
+	MCFG_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
 
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_VIDEO_START(thief)
-	MDRV_VIDEO_UPDATE(thief)
+	MCFG_VIDEO_START(thief)
+	MCFG_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay1", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay2", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(thief_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(thief_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( natodef )
+static MACHINE_CONFIG_START( natodef, thief_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000) /* 4 MHz? */
-	MDRV_CPU_PROGRAM_MAP(thief_main_map)
-	MDRV_CPU_IO_MAP(io_map)
-	MDRV_CPU_VBLANK_INT("screen", thief_interrupt)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000) /* 4 MHz? */
+	MCFG_CPU_PROGRAM_MAP(thief_main_map)
+	MCFG_CPU_IO_MAP(io_map)
+	MCFG_CPU_VBLANK_INT("screen", thief_interrupt)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
 
-	MDRV_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
+	MCFG_TMS9927_ADD("tms", MASTER_CLOCK/4, tms9927_intf)
 
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_VIDEO_START(thief)
-	MDRV_VIDEO_UPDATE(thief)
+	MCFG_VIDEO_START(thief)
+	MCFG_VIDEO_UPDATE(thief)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay1", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 4000000/4)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MCFG_SOUND_ADD("ay2", AY8910, 4000000/4)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(natodef_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(natodef_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 /**********************************************************/
 
@@ -658,8 +643,8 @@ ROM_END
 
 static DRIVER_INIT( thief )
 {
-	UINT8 *dest = memory_region( machine, "maincpu" );
-	const UINT8 *source = memory_region( machine, "cpu1" );
+	UINT8 *dest = machine->region( "maincpu" )->base();
+	const UINT8 *source = machine->region( "cpu1" )->base();
 
 	/* C8 is mapped (banked) in CPU1's address space; it contains Z80 code */
 	memcpy( &dest[0xe010], &source[0x290], 0x20 );
