@@ -36,24 +36,24 @@ static INPUT_PORTS_START( tokyocop )
 INPUT_PORTS_END
 
 
-static MACHINE_DRIVER_START( tokyocop )
+static MACHINE_CONFIG_START( tokyocop, driver_device )
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", PENTIUM, 2000000000) /* Pentium4? */
-	MDRV_CPU_PROGRAM_MAP(tokyocop_map)
+	MCFG_CPU_ADD("maincpu", PENTIUM, 2000000000) /* Pentium4? */
+	MCFG_CPU_PROGRAM_MAP(tokyocop_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_SIZE(64*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
 
-	MDRV_PALETTE_LENGTH(0x100)
+	MCFG_PALETTE_LENGTH(0x100)
 
-	MDRV_VIDEO_START(tokyocop)
-	MDRV_VIDEO_UPDATE(tokyocop)
-MACHINE_DRIVER_END
+	MCFG_VIDEO_START(tokyocop)
+	MCFG_VIDEO_UPDATE(tokyocop)
+MACHINE_CONFIG_END
 
 
 ROM_START(tokyocop)
