@@ -276,8 +276,8 @@ static ADDRESS_MAP_START( main_program_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x030000, 0x033fff) AM_RAM		/* 68K and DSP shared RAM */
 	AM_RANGE(0x040000, 0x040fff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
 	AM_RANGE(0x050000, 0x050dff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x060000, 0x060001) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x060002, 0x060003) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x060000, 0x060001) AM_DEVWRITE8("crtc", mc6845_address_w, 0x00ff)
+	AM_RANGE(0x060002, 0x060003) AM_DEVWRITE8("crtc", mc6845_register_w, 0x00ff)
 	AM_RANGE(0x070000, 0x070003) AM_WRITE(twincobr_txscroll_w)	/* text layer scroll */
 	AM_RANGE(0x070004, 0x070005) AM_WRITE(twincobr_txoffs_w)	/* offset in text video RAM */
 	AM_RANGE(0x072000, 0x072003) AM_WRITE(twincobr_bgscroll_w)	/* bg layer scroll */
@@ -544,7 +544,7 @@ GFXDECODE_END
 
 
 /* handler called by the 3812 emulator when the internal timers cause an IRQ */
-static void irqhandler(running_device *device, int linestate)
+static void irqhandler(device_t *device, int linestate)
 {
 	cputag_set_input_line(device->machine, "audiocpu", 0, linestate);
 }
@@ -556,64 +556,63 @@ static const ym3812_interface ym3812_config =
 
 
 
-static MACHINE_DRIVER_START( twincobr )
+static MACHINE_CONFIG_START( twincobr, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, XTAL_28MHz/4)		/* 7MHz - Main board Crystal is 28MHz */
-	MDRV_CPU_PROGRAM_MAP(main_program_map)
-	MDRV_CPU_VBLANK_INT("screen", twincobr_interrupt)
+	MCFG_CPU_ADD("maincpu", M68000, XTAL_28MHz/4)		/* 7MHz - Main board Crystal is 28MHz */
+	MCFG_CPU_PROGRAM_MAP(main_program_map)
+	MCFG_CPU_VBLANK_INT("screen", twincobr_interrupt)
 
-	MDRV_CPU_ADD("audiocpu", Z80, XTAL_28MHz/8)			/* 3.5MHz */
-	MDRV_CPU_PROGRAM_MAP(sound_program_map)
-	MDRV_CPU_IO_MAP(sound_io_map)
+	MCFG_CPU_ADD("audiocpu", Z80, XTAL_28MHz/8)			/* 3.5MHz */
+	MCFG_CPU_PROGRAM_MAP(sound_program_map)
+	MCFG_CPU_IO_MAP(sound_io_map)
 
-	MDRV_CPU_ADD("dsp", TMS32010, XTAL_28MHz/2)			/* 14MHz CLKin */
-	MDRV_CPU_PROGRAM_MAP(DSP_program_map)
+	MCFG_CPU_ADD("dsp", TMS32010, XTAL_28MHz/2)			/* 14MHz CLKin */
+	MCFG_CPU_PROGRAM_MAP(DSP_program_map)
 	/* Data Map is internal to the CPU */
-	MDRV_CPU_IO_MAP(DSP_io_map)
+	MCFG_CPU_IO_MAP(DSP_io_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(HZ(6000))
 
-	MDRV_MACHINE_RESET(twincobr)
+	MCFG_MACHINE_RESET(twincobr)
 
 	/* video hardware */
-	MDRV_MC6845_ADD("crtc", HD6845, XTAL_28MHz/8, twincobr_mc6845_intf)	/* 3.5MHz measured on CLKin */
+	MCFG_MC6845_ADD("crtc", HD6845, XTAL_28MHz/8, twincobr_mc6845_intf)	/* 3.5MHz measured on CLKin */
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_BUFFERS_SPRITERAM)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_BUFFERS_SPRITERAM)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE( (XTAL_28MHz / 4) / (446 * 286) )
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 64*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE( (XTAL_28MHz / 4) / (446 * 286) )
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 64*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
 
-	MDRV_GFXDECODE(twincobr)
-	MDRV_PALETTE_LENGTH(1792)
+	MCFG_GFXDECODE(twincobr)
+	MCFG_PALETTE_LENGTH(1792)
 
-	MDRV_VIDEO_START(toaplan0)
-	MDRV_VIDEO_EOF(toaplan0)
-	MDRV_VIDEO_UPDATE(toaplan0)
+	MCFG_VIDEO_START(toaplan0)
+	MCFG_VIDEO_EOF(toaplan0)
+	MCFG_VIDEO_UPDATE(toaplan0)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, XTAL_28MHz/8)
-	MDRV_SOUND_CONFIG(ym3812_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM3812, XTAL_28MHz/8)
+	MCFG_SOUND_CONFIG(ym3812_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( fsharkbt )
-	MDRV_IMPORT_FROM( twincobr )
+static MACHINE_CONFIG_DERIVED( fsharkbt, twincobr )
 
-	MDRV_CPU_ADD("mcu", I8741, XTAL_28MHz/16)
+	MCFG_CPU_ADD("mcu", I8741, XTAL_28MHz/16)
 	/* Program Map is internal to the CPU */
-	MDRV_CPU_IO_MAP(fsharkbt_i8741_io_map)
-	MDRV_DEVICE_DISABLE()		/* Internal program code is not dumped */
+	MCFG_CPU_IO_MAP(fsharkbt_i8741_io_map)
+	MCFG_DEVICE_DISABLE()		/* Internal program code is not dumped */
 
-	MDRV_MACHINE_RESET(fsharkbt)	/* Reset fshark bootleg 8741 MCU data */
-MACHINE_DRIVER_END
+	MCFG_MACHINE_RESET(fsharkbt)	/* Reset fshark bootleg 8741 MCU data */
+MACHINE_CONFIG_END
 
 
 
