@@ -43,20 +43,7 @@ c001      YM2203 #2 write
 #include "cpu/z80/z80.h"
 #include "deprecat.h"
 #include "sound/ay8910.h"
-
-
-extern UINT8 *vulgus_fgvideoram;
-extern UINT8 *vulgus_bgvideoram;
-extern UINT8 *vulgus_scroll_low,*vulgus_scroll_high;
-
-WRITE8_HANDLER( vulgus_fgvideoram_w );
-WRITE8_HANDLER( vulgus_bgvideoram_w );
-WRITE8_HANDLER( vulgus_c804_w );
-WRITE8_HANDLER( vulgus_palette_bank_w );
-VIDEO_START( vulgus );
-PALETTE_INIT( vulgus );
-VIDEO_UPDATE( vulgus );
-
+#include "includes/vulgus.h"
 
 
 static INTERRUPT_GEN( vulgus_interrupt )
@@ -230,41 +217,41 @@ GFXDECODE_END
 
 
 
-static MACHINE_DRIVER_START( vulgus )
+static MACHINE_CONFIG_START( vulgus, driver_device )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 4000000)	/* 4 MHz (?) */
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_VBLANK_INT_HACK(vulgus_interrupt,2)
+	MCFG_CPU_ADD("maincpu", Z80, 4000000)	/* 4 MHz (?) */
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_VBLANK_INT_HACK(vulgus_interrupt,2)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 3000000)	/* 3 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
+	MCFG_CPU_ADD("audiocpu", Z80, 3000000)	/* 3 MHz ??? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
 
-	MDRV_GFXDECODE(vulgus)
-	MDRV_PALETTE_LENGTH(64*4+16*16+4*32*8)
+	MCFG_GFXDECODE(vulgus)
+	MCFG_PALETTE_LENGTH(64*4+16*16+4*32*8)
 
-	MDRV_PALETTE_INIT(vulgus)
-	MDRV_VIDEO_START(vulgus)
-	MDRV_VIDEO_UPDATE(vulgus)
+	MCFG_PALETTE_INIT(vulgus)
+	MCFG_VIDEO_START(vulgus)
+	MCFG_VIDEO_UPDATE(vulgus)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+MACHINE_CONFIG_END
 
 
 
