@@ -322,7 +322,7 @@ TODO:
 
 static WRITE8_HANDLER( welltris_sh_bankswitch_w )
 {
-	UINT8 *rom = memory_region(space->machine, "audiocpu") + 0x10000;
+	UINT8 *rom = space->machine->region("audiocpu")->base() + 0x10000;
 
 	memory_set_bankptr(space->machine, "bank1",rom + (data & 0x03) * 0x8000);
 }
@@ -332,7 +332,7 @@ static WRITE16_HANDLER( sound_command_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		welltris_state *state = (welltris_state *)space->machine->driver_data;
+		welltris_state *state = space->machine->driver_data<welltris_state>();
 
 		state->pending_command = 1;
 		soundlatch_w(space, 0, data & 0xff);
@@ -342,13 +342,13 @@ static WRITE16_HANDLER( sound_command_w )
 
 static CUSTOM_INPUT( pending_sound_r )
 {
-	welltris_state *state = (welltris_state *)field->port->machine->driver_data;
+	welltris_state *state = field->port->machine->driver_data<welltris_state>();
 	return state->pending_command ? 1 : 0;
 }
 
 static WRITE8_HANDLER( pending_command_clear_w )
 {
-	welltris_state *state = (welltris_state *)space->machine->driver_data;
+	welltris_state *state = space->machine->driver_data<welltris_state>();
 
 	state->pending_command = 0;
 }
@@ -676,7 +676,7 @@ GFXDECODE_END
 
 
 
-static void irqhandler(running_device *device, int irq)
+static void irqhandler(device_t *device, int irq)
 {
 	cputag_set_input_line(device->machine, "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
@@ -692,7 +692,7 @@ static DRIVER_INIT( welltris )
 {
 #if WELLTRIS_4P_HACK
 	/* A Hack which shows 4 player mode in code which is disabled */
-	UINT16 *RAM = (UINT16 *)memory_region(machine, "maincpu");
+	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
 	RAM[0xB91C/2] = 0x4e71;
 	RAM[0xB91E/2] = 0x4e71;
 #endif
@@ -705,51 +705,48 @@ static DRIVER_INIT( quiz18k )
 
 
 
-static MACHINE_DRIVER_START( welltris )
-
-	MDRV_DRIVER_DATA( welltris_state )
+static MACHINE_CONFIG_START( welltris, welltris_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000,20000000/2)	/* 10 MHz */
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_VBLANK_INT("screen", irq1_line_hold)
+	MCFG_CPU_ADD("maincpu", M68000,20000000/2)	/* 10 MHz */
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold)
 
-	MDRV_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz ??? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_IO_MAP(sound_port_map)	/* IRQs are triggered by the YM2610 */
+	MCFG_CPU_ADD("audiocpu", Z80,8000000/2)		/* 4 MHz ??? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_IO_MAP(sound_port_map)	/* IRQs are triggered by the YM2610 */
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512, 256)
-	MDRV_SCREEN_VISIBLE_AREA(15, 367-1, 8, 248-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(15, 367-1, 8, 248-1)
 
-	MDRV_GFXDECODE(welltris)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_GFXDECODE(welltris)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(welltris)
-	MDRV_VIDEO_UPDATE(welltris)
+	MCFG_VIDEO_START(welltris)
+	MCFG_VIDEO_UPDATE(welltris)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM2610, 8000000)
-	MDRV_SOUND_CONFIG(ym2610_config)
-	MDRV_SOUND_ROUTE(0, "mono", 0.25)
-	MDRV_SOUND_ROUTE(1, "mono", 0.75)
-	MDRV_SOUND_ROUTE(2, "mono", 0.75)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM2610, 8000000)
+	MCFG_SOUND_CONFIG(ym2610_config)
+	MCFG_SOUND_ROUTE(0, "mono", 0.25)
+	MCFG_SOUND_ROUTE(1, "mono", 0.75)
+	MCFG_SOUND_ROUTE(2, "mono", 0.75)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( quiz18k )
+static MACHINE_CONFIG_DERIVED( quiz18k, welltris )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM( welltris )
 
-	MDRV_SCREEN_MODIFY("screen")
-	MDRV_SCREEN_VISIBLE_AREA(15, 335-1, 0, 224-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_VISIBLE_AREA(15, 335-1, 0, 224-1)
+MACHINE_CONFIG_END
 
 
 
