@@ -46,7 +46,7 @@ To Do:
 
 static WRITE8_HANDLER( yunsung8_bankswitch_w )
 {
-	yunsung8_state *state = (yunsung8_state *)space->machine->driver_data;
+	yunsung8_state *state = space->machine->driver_data<yunsung8_state>();
 
 	state->layers_ctrl = data & 0x30;	// Layers enable
 
@@ -107,7 +107,7 @@ static WRITE8_DEVICE_HANDLER( yunsung8_sound_bankswitch_w )
 
 static WRITE8_HANDLER( yunsung8_adpcm_w )
 {
-	yunsung8_state *state = (yunsung8_state *)space->machine->driver_data;
+	yunsung8_state *state = space->machine->driver_data<yunsung8_state>();
 
 	/* Swap the nibbles */
 	state->adpcm = ((data & 0xf) << 4) | ((data >> 4) & 0xf);
@@ -446,9 +446,9 @@ GFXDECODE_END
 ***************************************************************************/
 
 
-static void yunsung8_adpcm_int( running_device *device )
+static void yunsung8_adpcm_int( device_t *device )
 {
-	yunsung8_state *state = (yunsung8_state *)device->machine->driver_data;
+	yunsung8_state *state = device->machine->driver_data<yunsung8_state>();
 
 	msm5205_data_w(device, state->adpcm >> 4);
 	state->adpcm <<= 4;
@@ -467,9 +467,9 @@ static const msm5205_interface yunsung8_msm5205_interface =
 
 static MACHINE_START( yunsung8 )
 {
-	yunsung8_state *state = (yunsung8_state *)machine->driver_data;
-	UINT8 *MAIN = memory_region(machine, "maincpu");
-	UINT8 *AUDIO = memory_region(machine, "audiocpu");
+	yunsung8_state *state = machine->driver_data<yunsung8_state>();
+	UINT8 *MAIN = machine->region("maincpu")->base();
+	UINT8 *AUDIO = machine->region("audiocpu")->base();
 
 	state->videoram = auto_alloc_array(machine, UINT8, 0x4000);
 	state->videoram_0 = state->videoram + 0x0000;	// Ram is banked
@@ -491,7 +491,7 @@ static MACHINE_START( yunsung8 )
 
 static MACHINE_RESET( yunsung8 )
 {
-	yunsung8_state *state = (yunsung8_state *)machine->driver_data;
+	yunsung8_state *state = machine->driver_data<yunsung8_state>();
 
 	state->videobank = 0;
 	state->layers_ctrl = 0;
@@ -500,50 +500,47 @@ static MACHINE_RESET( yunsung8 )
 }
 
 
-static MACHINE_DRIVER_START( yunsung8 )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(yunsung8_state)
+static MACHINE_CONFIG_START( yunsung8, yunsung8_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, 8000000)			/* Z80B */
-	MDRV_CPU_PROGRAM_MAP(main_map)
-	MDRV_CPU_IO_MAP(port_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)	/* No nmi routine */
+	MCFG_CPU_ADD("maincpu", Z80, 8000000)			/* Z80B */
+	MCFG_CPU_PROGRAM_MAP(main_map)
+	MCFG_CPU_IO_MAP(port_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)	/* No nmi routine */
 
-	MDRV_CPU_ADD("audiocpu", Z80, 4000000)			/* ? */
-	MDRV_CPU_PROGRAM_MAP(sound_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)	/* NMI caused by the MSM5205? */
+	MCFG_CPU_ADD("audiocpu", Z80, 4000000)			/* ? */
+	MCFG_CPU_PROGRAM_MAP(sound_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)	/* NMI caused by the MSM5205? */
 
-	MDRV_MACHINE_START(yunsung8)
-	MDRV_MACHINE_RESET(yunsung8)
+	MCFG_MACHINE_START(yunsung8)
+	MCFG_MACHINE_RESET(yunsung8)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(512, 256)
-	MDRV_SCREEN_VISIBLE_AREA(0+64, 512-64-1, 0+8, 256-8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(512, 256)
+	MCFG_SCREEN_VISIBLE_AREA(0+64, 512-64-1, 0+8, 256-8-1)
 
-	MDRV_GFXDECODE(yunsung8)
-	MDRV_PALETTE_LENGTH(2048)
+	MCFG_GFXDECODE(yunsung8)
+	MCFG_PALETTE_LENGTH(2048)
 
-	MDRV_VIDEO_START(yunsung8)
-	MDRV_VIDEO_UPDATE(yunsung8)
+	MCFG_VIDEO_START(yunsung8)
+	MCFG_VIDEO_UPDATE(yunsung8)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("ymsnd", YM3812, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 
-	MDRV_SOUND_ADD("msm", MSM5205, XTAL_400kHz) /* verified on pcb */
-	MDRV_SOUND_CONFIG(yunsung8_msm5205_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.80)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.80)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("msm", MSM5205, XTAL_400kHz) /* verified on pcb */
+	MCFG_SOUND_CONFIG(yunsung8_msm5205_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 0.80)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 0.80)
+MACHINE_CONFIG_END
 
 
 /***************************************************************************
