@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class _1942_state
+class _1942_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, _1942_state(machine)); }
-
-	_1942_state(running_machine &machine) { }
+	_1942_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 * fg_videoram;
@@ -23,7 +22,7 @@ public:
 	UINT8 scroll[2];
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
