@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class _88games_state
+class _88games_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, _88games_state(machine)); }
-
-	_88games_state(running_machine &machine) { }
+	_88games_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *      ram;
@@ -25,12 +24,12 @@ public:
 	int          speech_chip;
 
 	/* devices */
-	running_device *audiocpu;
-	running_device *k052109;
-	running_device *k051960;
-	running_device *k051316;
-	running_device *upd_1;
-	running_device *upd_2;
+	device_t *audiocpu;
+	device_t *k052109;
+	device_t *k051960;
+	device_t *k051316;
+	device_t *upd_1;
+	device_t *upd_2;
 };
 
 
