@@ -1,11 +1,10 @@
 
 
-class appoooh_state
+class appoooh_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, appoooh_state(machine)); }
-
-	appoooh_state(running_machine &machine) { }
+	appoooh_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  bg_videoram;
@@ -25,7 +24,7 @@ public:
 	UINT32   adpcm_address;
 
 	/* devices */
-	running_device *adpcm;
+	device_t *adpcm;
 };
 
 #define CHR1_OFST   0x00  /* palette page of char set #1 */
