@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class ashnojoe_state
+class ashnojoe_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, ashnojoe_state(machine)); }
-
-	ashnojoe_state(running_machine &machine) { }
+	ashnojoe_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *    tileram;
@@ -32,7 +31,7 @@ public:
 	int         msm5205_vclk_toggle;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
