@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class asterix_state
+class asterix_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, asterix_state(machine)); }
-
-	asterix_state(running_machine &machine) { }
+	asterix_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 //  UINT16 *    paletteram;    // currently this uses generic palette handling
@@ -26,12 +25,12 @@ public:
 	UINT16      prot[2];
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k053260;
-	running_device *k056832;
-	running_device *k053244;
-	running_device *k053251;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k053260;
+	device_t *k056832;
+	device_t *k053244;
+	device_t *k053251;
 };
 
 
