@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class asuka_state
+class asuka_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, asuka_state(machine)); }
-
-	asuka_state(running_machine &machine) { }
+	asuka_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 //  UINT16 *    paletteram; // this currently uses generic palette handlers
@@ -31,10 +30,10 @@ public:
 	int         adpcm_data;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *pc090oj;
-	running_device *tc0100scn;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *pc090oj;
+	device_t *tc0100scn;
 };
 
 
