@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class battlane_state
+class battlane_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, battlane_state(machine)); }
-
-	battlane_state(running_machine &machine) { }
+	battlane_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *     tileram;
@@ -22,8 +21,8 @@ public:
 	int         cpu_control;	/* CPU interrupt control register */
 
 	/* devices */
-	running_device *maincpu;
-	running_device *subcpu;
+	device_t *maincpu;
+	device_t *subcpu;
 };
 
 
