@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class battlex_state
+class battlex_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, battlex_state(machine)); }
-
-	battlex_state(running_machine &machine) { }
+	battlex_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 * videoram;
