@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class battlnts_state
+class battlnts_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, battlnts_state(machine)); }
-
-	battlnts_state(running_machine &machine) { }
+	battlnts_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 //  UINT8 *      paletteram;    // this currently uses generic palette handling
@@ -20,9 +19,9 @@ public:
 
 
 	/* devices */
-	running_device *audiocpu;
-	running_device *k007342;
-	running_device *k007420;
+	device_t *audiocpu;
+	device_t *k007342;
+	device_t *k007420;
 };
 
 /*----------- defined in video/battlnts.c -----------*/
