@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class bionicc_state
+class bionicc_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, bionicc_state(machine)); }
-
-	bionicc_state(running_machine &machine) { }
+	bionicc_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  bgvideoram;
