@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class ddribble_state
+class ddribble_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, ddribble_state(machine)); }
-
-	ddribble_state(running_machine &machine) { }
+	ddribble_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *     sharedram;
@@ -29,9 +28,9 @@ public:
 	int         int_enable_0, int_enable_1;
 
 	/* devices */
-	running_device *filter1;
-	running_device *filter2;
-	running_device *filter3;
+	device_t *filter1;
+	device_t *filter2;
+	device_t *filter3;
 };
 
 /*----------- defined in video/ddribble.c -----------*/
