@@ -1,11 +1,10 @@
 
 
-class docastle_state
+class docastle_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, docastle_state(machine)); }
-
-	docastle_state(running_machine &machine) { }
+	docastle_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  videoram;
