@@ -5,12 +5,11 @@
 *************************************************************************/
 
 
-class exprraid_state
+class exprraid_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, exprraid_state(machine)); }
-
-	exprraid_state(running_machine &machine) { }
+	exprraid_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *        main_ram;
@@ -27,8 +26,8 @@ public:
 	//int          coin;    // used in the commented out INTERRUPT_GEN - can this be removed?
 
 	/* devices */
-	running_device *maincpu;
-	running_device *slave;
+	device_t *maincpu;
+	device_t *slave;
 };
 
 
