@@ -1,10 +1,9 @@
 
-class fitfight_state
+class fitfight_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, fitfight_state(machine)); }
-
-	fitfight_state(running_machine &machine) { }
+	fitfight_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  fof_100000;
