@@ -1,11 +1,10 @@
 
 
-class funkybee_state
+class funkybee_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, funkybee_state(machine)); }
-
-	funkybee_state(running_machine &machine) { }
+	funkybee_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    videoram;
