@@ -9,12 +9,11 @@
 /* NOTE: YMF278B_STD_CLOCK is defined in /src/emu/sound/ymf278b.h */
 
 
-class fuuki32_state
+class fuuki32_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, fuuki32_state(machine)); }
-
-	fuuki32_state(running_machine &machine) { }
+	fuuki32_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT32 *    vram_0;
@@ -39,8 +38,8 @@ public:
 	UINT8       shared_ram[16];
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
+	device_t *maincpu;
+	device_t *audiocpu;
 };
 
 
