@@ -5,12 +5,11 @@
 
 *************************************************************************/
 
-class galspnbl_state
+class galspnbl_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, galspnbl_state(machine)); }
-
-	galspnbl_state(running_machine &machine) { }
+	galspnbl_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *    videoram;
@@ -22,7 +21,7 @@ public:
 	size_t      spriteram_size;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
