@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class gbusters_state
+class gbusters_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, gbusters_state(machine)); }
-
-	gbusters_state(running_machine &machine) { }
+	gbusters_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    ram;
@@ -23,11 +22,11 @@ public:
 	int        priority;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k007232;
-	running_device *k052109;
-	running_device *k051960;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k007232;
+	device_t *k052109;
+	device_t *k051960;
 };
 
 /*----------- defined in video/gbusters.c -----------*/
