@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class ginganin_state
+class ginganin_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, ginganin_state(machine)); }
-
-	ginganin_state(running_machine &machine) { }
+	ginganin_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *    fgram;
@@ -36,7 +35,7 @@ public:
 	int         MC6809_FLAG;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
