@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class holeland_state
+class holeland_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, holeland_state(machine)); }
-
-	holeland_state(running_machine &machine) { }
+	holeland_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    videoram;
