@@ -1,10 +1,9 @@
 
-class inufuku_state
+class inufuku_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, inufuku_state(machine)); }
-
-	inufuku_state(running_machine &machine) { }
+	inufuku_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  bg_videoram;
@@ -26,7 +25,7 @@ public:
 	UINT16    pending_command;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
