@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class labyrunr_state
+class labyrunr_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, labyrunr_state(machine)); }
-
-	labyrunr_state(running_machine &machine) { }
+	labyrunr_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    videoram1;
@@ -23,7 +22,7 @@ public:
 	rectangle  clip0, clip1;
 
 	/* devices */
-	running_device *k007121;
+	device_t *k007121;
 };
 
 
