@@ -4,12 +4,11 @@
 
 ***************************************************************************/
 
-class lasso_state
+class lasso_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, lasso_state(machine)); }
-
-	lasso_state(running_machine &machine) { }
+	lasso_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  videoram;
@@ -28,10 +27,10 @@ public:
 	UINT8    track_enable;	/* used by wwjgtin */
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *sn_1;
-	running_device *sn_2;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *sn_1;
+	device_t *sn_2;
 };
 
 
