@@ -1,10 +1,9 @@
 
-class lemmings_state
+class lemmings_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, lemmings_state(machine)); }
-
-	lemmings_state(running_machine &machine) { }
+	lemmings_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  pixel_0_data;
@@ -22,7 +21,7 @@ public:
 	UINT8 *vram_buffer;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *audiocpu;
 };
 
 
