@@ -1,10 +1,9 @@
 
-class lwings_state
+class lwings_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, lwings_state(machine)); }
-
-	lwings_state(running_machine &machine) { }
+	lwings_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  fgvideoram;
