@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class megazone_state
+class megazone_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, megazone_state(machine)); }
-
-	megazone_state(running_machine &machine) { }
+	megazone_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *       scrollx;
