@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class mrdo_state
+class mrdo_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, mrdo_state(machine)); }
-
-	mrdo_state(running_machine &machine) { }
+	mrdo_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    bgvideoram;
