@@ -6,14 +6,11 @@
 
 #include "machine/atarigen.h"
 
-class offtwall_state
+class offtwall_state : public atarigen_state
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, offtwall_state(machine)); }
-
-	offtwall_state(running_machine &machine) { }
-
-	atarigen_state	atarigen;
+	offtwall_state(running_machine &machine, const driver_device_config_base &config)
+		: atarigen_state(machine, config) { }
 
 	UINT16 *bankswitch_base;
 	UINT16 *bankrom_base;
