@@ -1,10 +1,9 @@
 
-class paradise_state
+class paradise_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, paradise_state(machine)); }
-
-	paradise_state(running_machine &machine) { }
+	paradise_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *  vram_0;
