@@ -7,14 +7,12 @@
 #include "machine/atarigen.h"
 
 /* shared with arcadecl hardware */
-class rampart_state
+class rampart_state : public atarigen_state
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, rampart_state(machine)); }
+	rampart_state(running_machine &machine, const driver_device_config_base &config)
+		: atarigen_state(machine, config) { }
 
-	rampart_state(running_machine &machine) { }
-
-	atarigen_state	atarigen;
 	UINT16 *		bitmap;
 	UINT8			has_mo;
 };
