@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class rollerg_state
+class rollerg_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, rollerg_state(machine)); }
-
-	rollerg_state(running_machine &machine) { }
+	rollerg_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 //  UINT8 *    paletteram;    // currently this uses generic palette handling
@@ -21,11 +20,11 @@ public:
 	int        readzoomroms;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k053260;
-	running_device *k053244;
-	running_device *k051316;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k053260;
+	device_t *k053244;
+	device_t *k051316;
 };
 
 /*----------- defined in video/rollerg.c -----------*/
