@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class sf_state
+class sf_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, sf_state(machine)); }
-
-	sf_state(running_machine &machine) { }
+	sf_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *    videoram;
@@ -23,8 +22,8 @@ public:
 	UINT16      bgscroll, fgscroll;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
+	device_t *maincpu;
+	device_t *audiocpu;
 };
 
 
