@@ -6,14 +6,11 @@
 
 #include "machine/atarigen.h"
 
-class shuuz_state
+class shuuz_state : public atarigen_state
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, shuuz_state(machine)); }
-
-	shuuz_state(running_machine &machine) { }
-
-	atarigen_state	atarigen;
+	shuuz_state(running_machine &machine, const driver_device_config_base &config)
+		: atarigen_state(machine, config) { }
 };
 
 
