@@ -1,10 +1,9 @@
 
-class simpsons_state
+class simpsons_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, simpsons_state(machine)); }
-
-	simpsons_state(running_machine &machine) { }
+	simpsons_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    ram;
@@ -22,12 +21,12 @@ public:
 	//int        nmi_enabled;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k053260;
-	running_device *k052109;
-	running_device *k053246;
-	running_device *k053251;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k053260;
+	device_t *k052109;
+	device_t *k053246;
+	device_t *k053251;
 };
 
 /*----------- defined in machine/simpsons.c -----------*/
