@@ -1,9 +1,8 @@
-class spbactn_state
+class spbactn_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, spbactn_state(machine)); }
-
-	spbactn_state(running_machine &machine) { }
+	spbactn_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	UINT16 *bgvideoram;
 	UINT16 *fgvideoram;
