@@ -1,9 +1,8 @@
-class sslam_state
+class sslam_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, sslam_state(machine)); }
-
-	sslam_state(running_machine &machine) { }
+	sslam_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	emu_timer *music_timer;
 
