@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class tail2nos_state
+class tail2nos_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, tail2nos_state(machine)); }
-
-	tail2nos_state(running_machine &machine) { }
+	tail2nos_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *    bgvideoram;
@@ -23,9 +22,9 @@ public:
 	int         charbank, charpalette, video_enable;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k051316;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k051316;
 };
 
 
