@@ -1,11 +1,10 @@
 #include "video/poly.h"
 
-class taitojc_state
+class taitojc_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, taitojc_state(machine)); }
-
-	taitojc_state(running_machine &machine) { }
+	taitojc_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	int texture_x;
 	int texture_y;
