@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class thunderx_state
+class thunderx_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, thunderx_state(machine)); }
-
-	thunderx_state(running_machine &machine) { }
+	thunderx_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT8 *    ram;
@@ -26,11 +25,11 @@ public:
 	int        rambank, pmcbank;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *k007232;
-	running_device *k052109;
-	running_device *k051960;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *k007232;
+	device_t *k052109;
+	device_t *k051960;
 };
 
 
