@@ -4,12 +4,11 @@
 
 *************************************************************************/
 
-class tumblep_state
+class tumblep_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, tumblep_state(machine)); }
-
-	tumblep_state(running_machine &machine) { }
+	tumblep_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	/* memory pointers */
 	UINT16 *  pf1_rowscroll;
@@ -19,9 +18,9 @@ public:
 	size_t    spriteram_size;
 
 	/* devices */
-	running_device *maincpu;
-	running_device *audiocpu;
-	running_device *deco16ic;
+	device_t *maincpu;
+	device_t *audiocpu;
+	device_t *deco16ic;
 };
 
 
