@@ -1,9 +1,8 @@
-class xyonix_state
+class xyonix_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, xyonix_state(machine)); }
-
-	xyonix_state(running_machine &machine) { }
+	xyonix_state(running_machine &machine, const driver_device_config_base &config)
+		: driver_device(machine, config) { }
 
 	UINT8 *vidram;
 	tilemap_t *tilemap;
