@@ -304,7 +304,7 @@ static const struct cchip_mapping *const levelData[]=
 
 static void WriteLevelData( running_machine *machine )
 {
-	asuka_state *state = (asuka_state *)machine->driver_data;
+	asuka_state *state = machine->driver_data<asuka_state>();
 	int i;
 
 	for (i = 0; i < 13; i++)
@@ -329,7 +329,7 @@ static void WriteRestartPos( running_machine *machine, int level )
         for the restart position to be returned.
     */
 
-	asuka_state *state = (asuka_state *)machine->driver_data;
+	asuka_state *state = machine->driver_data<asuka_state>();
 	int x = state->cval[0] + 256 * state->cval[1] + state->cval[4] + 256 * state->cval[5];
 	int y = state->cval[2] + 256 * state->cval[3] + state->cval[6] + 256 * state->cval[7];
 
@@ -376,13 +376,13 @@ WRITE16_HANDLER( bonzeadv_cchip_ctrl_w )
 
 WRITE16_HANDLER( bonzeadv_cchip_bank_w )
 {
-	asuka_state *state = (asuka_state *)space->machine->driver_data;
+	asuka_state *state = space->machine->driver_data<asuka_state>();
 	state->current_bank = data & 7;
 }
 
 WRITE16_HANDLER( bonzeadv_cchip_ram_w )
 {
-	asuka_state *state = (asuka_state *)space->machine->driver_data;
+	asuka_state *state = space->machine->driver_data<asuka_state>();
 
 //  if (cpu_get_pc(space->cpu)!=0xa028)
 //  logerror("%08x:  write %04x %04x cchip\n", cpu_get_pc(space->cpu), offset, data);
@@ -438,7 +438,7 @@ READ16_HANDLER( bonzeadv_cchip_ctrl_r )
 
 READ16_HANDLER( bonzeadv_cchip_ram_r )
 {
-	asuka_state *state = (asuka_state *)space->machine->driver_data;
+	asuka_state *state = space->machine->driver_data<asuka_state>();
 
 //  logerror("%08x:  read %04x cchip\n", cpu_get_pc(space->cpu), offset);
 
