@@ -29,14 +29,14 @@
  *
  *************************************/
 
-void micro3d_duart_irq_handler(running_device *device, UINT8 vector)
+void micro3d_duart_irq_handler(device_t *device, UINT8 vector)
 {
 	cputag_set_input_line_and_vector(device->machine, "maincpu", 3, HOLD_LINE, vector);
 };
 
-void micro3d_duart_tx(running_device *device, int channel, UINT8 data)
+void micro3d_duart_tx(device_t *device, int channel, UINT8 data)
 {
-	micro3d_state *state = (micro3d_state*)device->machine->driver_data;
+	micro3d_state *state = device->machine->driver_data<micro3d_state>();
 
 	if (channel == 0)
 	{
@@ -51,15 +51,15 @@ void micro3d_duart_tx(running_device *device, int channel, UINT8 data)
 	}
 };
 
-static int data_to_i8031(running_device *device)
+static int data_to_i8031(device_t *device)
 {
-	micro3d_state *state = (micro3d_state*)device->machine->driver_data;
+	micro3d_state *state = device->machine->driver_data<micro3d_state>();
 	return state->m68681_tx0;
 }
 
-static void data_from_i8031(running_device *device, int data)
+static void data_from_i8031(device_t *device, int data)
 {
-	micro3d_state *state = (micro3d_state*)device->machine->driver_data;
+	micro3d_state *state = device->machine->driver_data<micro3d_state>();
 	duart68681_rx_data(state->duart68681, 1, data);
 }
 
@@ -71,7 +71,7 @@ static void data_from_i8031(running_device *device, int data)
  * 4: -
  * 5: -
  */
-UINT8 micro3d_duart_input_r(running_device *device)
+UINT8 micro3d_duart_input_r(device_t *device)
 {
 	return 0x2;
 }
@@ -80,7 +80,7 @@ UINT8 micro3d_duart_input_r(running_device *device)
  * 5: /I8051 reset
  * 7: Status LED
 */
-void micro3d_duart_output_w(running_device *device, UINT8 data)
+void micro3d_duart_output_w(device_t *device, UINT8 data)
 {
 	cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_RESET, data & 0x20 ? CLEAR_LINE : ASSERT_LINE);
 }
@@ -115,7 +115,7 @@ enum
 
 static void micro3d_mc68901_int_gen(running_machine *machine, int source)
 {
-	micro3d_state *state = (micro3d_state*)machine->driver_data;
+	micro3d_state *state = machine->driver_data<micro3d_state>();
 	UINT8 *ien = source & 8 ? &state->mc68901.ierb : &state->mc68901.iera;
 	UINT8 *ipend = source & 8 ? &state->mc68901.iprb : &state->mc68901.ipra;
 	UINT8 *imask = source & 8 ? &state->mc68901.imrb : &state->mc68901.imra;
@@ -139,7 +139,7 @@ static TIMER_CALLBACK( mfp_timer_a_cb )
 
 READ16_HANDLER( micro3d_mc68901_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 	UINT16 val = 0;
 
 	switch (offset)
@@ -156,7 +156,7 @@ READ16_HANDLER( micro3d_mc68901_r )
 
 WRITE16_HANDLER( micro3d_mc68901_w )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	data >>= 8;
 	state->mc68901.regs[offset] = data;
@@ -220,7 +220,7 @@ enum
 
 WRITE16_HANDLER( micro3d_ti_uart_w )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	switch (offset)
 	{
@@ -278,7 +278,7 @@ WRITE16_HANDLER( micro3d_ti_uart_w )
 
 READ16_HANDLER( micro3d_ti_uart_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	switch (offset)
 	{
@@ -382,7 +382,7 @@ INLINE INT64 normalised_multiply(INT32 a, INT32 b)
 
 static TIMER_CALLBACK( mac_done_callback )
 {
-	micro3d_state *state = (micro3d_state*)machine->driver_data;
+	micro3d_state *state = machine->driver_data<micro3d_state>();
 
 	cputag_set_input_line(machine, "drmath", AM29000_INTR0, ASSERT_LINE);
 	state->mac_stat = 0;
@@ -391,7 +391,7 @@ static TIMER_CALLBACK( mac_done_callback )
 
 WRITE32_HANDLER( micro3d_mac1_w )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	state->vtx_addr = (data & 0x3ffff);
 	state->sram_w_addr = (data >> 18) & 0xfff;
@@ -399,14 +399,14 @@ WRITE32_HANDLER( micro3d_mac1_w )
 
 READ32_HANDLER( micro3d_mac2_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	return (state->mac_inst << 1) | state->mac_stat;
 }
 
 WRITE32_HANDLER( micro3d_mac2_w )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	UINT32 cnt = data & 0xff;
 	UINT32 inst = (data >> 8) & 0x1f;
@@ -443,7 +443,7 @@ WRITE32_HANDLER( micro3d_mac2_w )
 		case 0x08:
 		{
 			int i;
-			const UINT16 *rom = (UINT16*)memory_region(space->machine, "vertex");
+			const UINT16 *rom = (UINT16*)space->machine->region("vertex")->base();
 
 			for (i = 0; i <= cnt; ++i)
 			{
@@ -482,7 +482,7 @@ WRITE32_HANDLER( micro3d_mac2_w )
 		case 0x0c:
 		{
 			int i;
-			const UINT16 *rom = (UINT16*)memory_region(space->machine, "vertex");
+			const UINT16 *rom = (UINT16*)space->machine->region("vertex")->base();
 
 			for (i = 0; i <= cnt; ++i)
 			{
@@ -515,7 +515,7 @@ WRITE32_HANDLER( micro3d_mac2_w )
 		case 0x0f:
 		{
 			int i;
-			const UINT16 *rom = (UINT16*)memory_region(space->machine, "vertex");
+			const UINT16 *rom = (UINT16*)space->machine->region("vertex")->base();
 
 			for (i = 0; i <= cnt; ++i, vtx_addr += 4)
 			{
@@ -627,7 +627,7 @@ READ16_HANDLER( micro3d_encoder_l_r )
 
 static TIMER_CALLBACK( adc_done_callback )
 {
-	micro3d_state *state = (micro3d_state*)machine->driver_data;
+	micro3d_state *state = machine->driver_data<micro3d_state>();
 
 	switch (param)
 	{
@@ -644,7 +644,7 @@ static TIMER_CALLBACK( adc_done_callback )
 
 READ16_HANDLER( micro3d_adc_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	return state->adc_val;
 }
@@ -663,14 +663,14 @@ WRITE16_HANDLER( micro3d_adc_w )
 
 CUSTOM_INPUT( botssa_hwchk_r )
 {
-	micro3d_state *state = (micro3d_state*)field->port->machine->driver_data;
+	micro3d_state *state = field->port->machine->driver_data<micro3d_state>();
 
 	return state->botssa_latch;
 }
 
 READ16_HANDLER( botssa_140000_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	state->botssa_latch = 0;
 	return 0xffff;
@@ -678,7 +678,7 @@ READ16_HANDLER( botssa_140000_r )
 
 READ16_HANDLER( botssa_180000_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	state->botssa_latch = 1;
 	return 0xffff;
@@ -713,7 +713,7 @@ WRITE16_HANDLER( host_drmath_int_w )
 
 WRITE32_HANDLER( micro3d_shared_w )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	state->shared_ram[offset * 2 + 1] = data & 0xffff;
 	state->shared_ram[offset * 2 + 0] = data >> 16;
@@ -721,7 +721,7 @@ WRITE32_HANDLER( micro3d_shared_w )
 
 READ32_HANDLER( micro3d_shared_r )
 {
-	micro3d_state *state = (micro3d_state*)space->machine->driver_data;
+	micro3d_state *state = space->machine->driver_data<micro3d_state>();
 
 	return (state->shared_ram[offset * 2] << 16) | state->shared_ram[offset * 2 + 1];
 }
@@ -745,8 +745,8 @@ WRITE32_HANDLER( drmath_intr2_ack )
 
 DRIVER_INIT( micro3d )
 {
-	micro3d_state *state = (micro3d_state*)machine->driver_data;
-	const address_space *space = cputag_get_address_space(machine, "drmath", ADDRESS_SPACE_DATA);
+	micro3d_state *state = machine->driver_data<micro3d_state>();
+	address_space *space = cputag_get_address_space(machine, "drmath", ADDRESS_SPACE_DATA);
 
 	i8051_set_serial_tx_callback(machine->device("audiocpu"), data_from_i8031);
 	i8051_set_serial_rx_callback(machine->device("audiocpu"), data_to_i8031);
@@ -755,7 +755,7 @@ DRIVER_INIT( micro3d )
 
 	/* The Am29000 program seems to rely on RAM from 0x00470000 onwards being
     non-zero on a reset, otherwise the 3D object data doesn't get uploaded! */
-	memory_write_dword(space, 0x00470000, 0xa5a5a5a5);
+	space->write_dword(0x00470000, 0xa5a5a5a5);
 
 	state->mc68901.timer_a = timer_alloc(machine, mfp_timer_a_cb, NULL);
 
@@ -767,7 +767,7 @@ DRIVER_INIT( micro3d )
 
 DRIVER_INIT( botssa )
 {
-	const address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
 
 	/* Required to pass the hardware version check */
 	memory_install_read16_handler(space, 0x140000, 0x140001, 0, 0, botssa_140000_r );
@@ -778,7 +778,7 @@ DRIVER_INIT( botssa )
 
 MACHINE_RESET( micro3d )
 {
-	micro3d_state *state = (micro3d_state*)machine->driver_data;
+	micro3d_state *state = machine->driver_data<micro3d_state>();
 
 	state->ti_uart[STATUS] = 1;
 
