@@ -532,7 +532,7 @@ static READ8_HANDLER( key_type3_r )
 	op = (offset & 0x70) >> 4;
 
 	if (op == key_reg)		return key_id;
-	if (op == key_rng)		return mame_rand(space->machine);
+	if (op == key_rng)		return space->machine->rand();
 	if (op == key_swap4)	return (key[key_swap4_arg] << 4) | (key[key_swap4_arg] >> 4);
 	if (op == key_bottom4)	return (offset << 4) | (key[key_swap4_arg] & 0x0f);
 	if (op == key_top4)		return (offset << 4) | (key[key_swap4_arg] >> 4);
@@ -559,7 +559,7 @@ static WRITE8_HANDLER( key_type3_w )
 
 WRITE8_HANDLER( namcos1_sound_bankswitch_w )
 {
-	UINT8 *rom = memory_region(space->machine, "audiocpu") + 0xc000;
+	UINT8 *rom = space->machine->region("audiocpu")->base() + 0xc000;
 
 	int bank = (data & 0x70) >> 4;
 	memory_set_bankptr(space->machine, "bank17",rom + 0x4000 * bank);
@@ -678,7 +678,7 @@ static void set_bank(running_machine *machine, int banknum, const bankhandler *h
 		"bank9", "bank10", "bank11", "bank12", "bank13", "bank14", "bank15", "bank16"
 	};
 	static const char *const cputags[] = { "maincpu", "sub" };
-	const address_space *space = cputag_get_address_space(machine, cputags[(banknum >> 3) & 1], ADDRESS_SPACE_PROGRAM);
+	address_space *space = cputag_get_address_space(machine, cputags[(banknum >> 3) & 1], ADDRESS_SPACE_PROGRAM);
 	int bankstart = (banknum & 7) * 0x2000;
 
 	/* for BANK handlers , memory direct and OP-code base */
@@ -827,7 +827,7 @@ static void namcos1_build_banks(running_machine *machine,read8_space_func key_r,
 
 	/* PRG0-PRG7 */
 	{
-		UINT8 *rom = memory_region(machine, "user1");
+		UINT8 *rom = machine->region("user1")->base();
 
 		namcos1_install_bank(0x200,0x3ff,0,rom_w,0,rom);
 
@@ -919,7 +919,7 @@ WRITE8_HANDLER( namcos1_mcu_bankswitch_w )
 	/* bit 0-1 : address line A15-A16 */
 	addr += (data & 3) * 0x8000;
 
-	memory_set_bankptr(space->machine, "bank20", memory_region(space->machine, "mcu") + addr);
+	memory_set_bankptr(space->machine, "bank20", space->machine->region("mcu")->base() + addr);
 }
 
 
@@ -1124,7 +1124,7 @@ DRIVER_INIT( bakutotu )
 		static const UINT8 target[8] = {0x34,0x37,0x35,0x37,0x96,0x00,0x2e,0xed};
 		UINT8 *rombase, *srcptr, *endptr, *scanptr;
 
-		rombase = memory_region(machine, "user1");
+		rombase = machine->region("user1")->base();
 		srcptr = rombase + 0x1e000;
 		endptr = srcptr + 0xa000;
 
