@@ -28,7 +28,7 @@ MACHINE_RESET( scramble )
 
 MACHINE_RESET( explorer )
 {
-	UINT8 *RAM = memory_region(machine, "maincpu");
+	UINT8 *RAM = machine->region("maincpu")->base();
 	RAM[0x47ff] = 0; /* If not set, it doesn't reset after the 1st time */
 
 	MACHINE_RESET_CALL(galaxold);
@@ -140,12 +140,12 @@ static WRITE8_HANDLER( cavelon_banksw_w )
 
 READ8_HANDLER( hunchbks_mirror_r )
 {
-	return memory_read_byte(space, 0x1000+offset);
+	return space->read_byte(0x1000+offset);
 }
 
 WRITE8_HANDLER( hunchbks_mirror_w )
 {
-	memory_write_byte(space, 0x1000+offset,data);
+	space->write_byte(0x1000+offset,data);
 }
 
 const ppi8255_interface scramble_ppi_0_intf =
@@ -244,7 +244,7 @@ DRIVER_INIT( mariner )
 	/* extra ROM */
 	memory_install_read_bank(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x5800, 0x67ff, 0, 0, "bank1");
 	memory_unmap_write(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x5800, 0x67ff, 0, 0);
-	memory_set_bankptr(machine, "bank1", memory_region(machine, "maincpu") + 0x5800);
+	memory_set_bankptr(machine, "bank1", machine->region("maincpu")->base() + 0x5800);
 
 	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x9008, 0x9008, 0, 0, mariner_protection_2_r);
 	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb401, 0xb401, 0, 0, mariner_protection_1_r);
@@ -260,12 +260,12 @@ DRIVER_INIT( frogger )
 	UINT8 *ROM;
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
-	ROM = memory_region(machine, "audiocpu");
+	ROM = machine->region("audiocpu")->base();
 	for (A = 0;A < 0x0800;A++)
 		ROM[A] = BITSWAP8(ROM[A],7,6,5,4,3,2,0,1);
 
 	/* likewise, the 2nd gfx ROM has data lines D0 and D1 swapped. Decode it. */
-	ROM = memory_region(machine, "gfx1");
+	ROM = machine->region("gfx1")->base();
 	for (A = 0x0800;A < 0x1000;A++)
 		ROM[A] = BITSWAP8(ROM[A],7,6,5,4,3,2,0,1);
 }
@@ -276,7 +276,7 @@ DRIVER_INIT( froggers )
 	UINT8 *ROM;
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
-	ROM = memory_region(machine, "audiocpu");
+	ROM = machine->region("audiocpu")->base();
 	for (A = 0;A < 0x0800;A++)
 		ROM[A] = BITSWAP8(ROM[A],7,6,5,4,3,2,0,1);
 }
@@ -294,7 +294,7 @@ DRIVER_INIT( devilfsh )
 	/* A2 -> A3 */
 	/* A3 -> A1 */
 
-	RAM = memory_region(machine, "maincpu");
+	RAM = machine->region("maincpu")->base();
 	for (i = 0; i < 0x10000; i += 16)
 	{
 		offs_t j;
@@ -320,12 +320,12 @@ DRIVER_INIT( hotshock )
 {
 	/* protection??? The game jumps into never-neverland here. I think
        it just expects a RET there */
-	memory_region(machine, "maincpu")[0x2ef9] = 0xc9;
+	machine->region("maincpu")->base()[0x2ef9] = 0xc9;
 }
 
 DRIVER_INIT( cavelon )
 {
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	UINT8 *ROM = machine->region("maincpu")->base();
 
 	/* banked ROM */
 	memory_install_read_bank(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0000, 0x3fff, 0, 0, "bank1");
@@ -370,7 +370,7 @@ DRIVER_INIT( mimonkey )
 		{ 0x80,0x87,0x81,0x87,0x83,0x00,0x84,0x01,0x01,0x86,0x86,0x80,0x86,0x00,0x86,0x86 }
 	};
 
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	UINT8 *ROM = machine->region("maincpu")->base();
 	int A, ctr = 0, line, col;
 
 	for( A = 0; A < 0x4000; A++ )
@@ -416,8 +416,8 @@ DRIVER_INIT( anteater )
     *   Optimizations done by Fabio Buffoni
     */
 
-	RAM = memory_region(machine, "gfx1");
-	len = memory_region_length(machine, "gfx1");
+	RAM = machine->region("gfx1")->base();
+	len = machine->region("gfx1")->bytes();
 
 	scratch = alloc_array_or_die(UINT8, len);
 
@@ -454,8 +454,8 @@ DRIVER_INIT( rescue )
     *   Optimizations done by Fabio Buffoni
     */
 
-	RAM = memory_region(machine, "gfx1");
-	len = memory_region_length(machine, "gfx1");
+	RAM = machine->region("gfx1")->base();
+	len = machine->region("gfx1")->bytes();
 
 	scratch = auto_alloc_array(machine, UINT8, len);
 
@@ -490,8 +490,8 @@ DRIVER_INIT( minefld )
     *   Code To Decode Minefield by Mike Balfour and Nicola Salmoria
     */
 
-	RAM = memory_region(machine, "gfx1");
-	len = memory_region_length(machine, "gfx1");
+	RAM = machine->region("gfx1")->base();
+	len = machine->region("gfx1")->bytes();
 
 	scratch = auto_alloc_array(machine, UINT8, len);
 
@@ -529,8 +529,8 @@ DRIVER_INIT( losttomb )
     *   Optimizations done by Fabio Buffoni
     */
 
-	RAM = memory_region(machine, "gfx1");
-	len = memory_region_length(machine, "gfx1");
+	RAM = machine->region("gfx1")->base();
+	len = machine->region("gfx1")->bytes();
 
 	scratch = alloc_array_or_die(UINT8, len);
 
@@ -556,7 +556,7 @@ DRIVER_INIT( losttomb )
 DRIVER_INIT( hustler )
 {
 	offs_t A;
-	UINT8 *rom = memory_region(machine, "maincpu");
+	UINT8 *rom = machine->region("maincpu")->base();
 
 
 	for (A = 0;A < 0x4000;A++)
@@ -584,7 +584,7 @@ DRIVER_INIT( hustler )
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
 	{
-		rom = memory_region(machine, "audiocpu");
+		rom = machine->region("audiocpu")->base();
 
 
 		for (A = 0;A < 0x0800;A++)
@@ -595,7 +595,7 @@ DRIVER_INIT( hustler )
 DRIVER_INIT( billiard )
 {
 	offs_t A;
-	UINT8 *rom = memory_region(machine, "maincpu");
+	UINT8 *rom = machine->region("maincpu")->base();
 
 
 	for (A = 0;A < 0x4000;A++)
@@ -625,7 +625,7 @@ DRIVER_INIT( billiard )
 
 	/* the first ROM of the second CPU has data lines D0 and D1 swapped. Decode it. */
 	{
-		rom = memory_region(machine, "audiocpu");
+		rom = machine->region("audiocpu")->base();
 
 
 		for (A = 0;A < 0x0800;A++)
@@ -653,8 +653,8 @@ DRIVER_INIT( mrkougb )
 DRIVER_INIT( ad2083 )
 {
 	UINT8 c;
-	int i, len = memory_region_length(machine, "maincpu");
-	UINT8 *ROM = memory_region(machine, "maincpu");
+	int i, len = machine->region("maincpu")->bytes();
+	UINT8 *ROM = machine->region("maincpu")->base();
 
 	for (i=0; i<len; i++)
 	{
