@@ -4,8 +4,8 @@
 
 static TILE_GET_INFO( glfgreat_get_roz_tile_info )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
-	UINT8 *rom = memory_region(machine, "user1");
+	tmnt_state *state = machine->driver_data<tmnt_state>();
+	UINT8 *rom = machine->region("user1")->base();
 	int code;
 
 	tile_index += 0x40000 * state->glfgreat_roz_rom_bank;
@@ -17,7 +17,7 @@ static TILE_GET_INFO( glfgreat_get_roz_tile_info )
 
 static TILE_GET_INFO( prmrsocr_get_roz_tile_info )
 {
-	UINT8 *rom = memory_region(machine, "user1");
+	UINT8 *rom = machine->region("user1")->base();
 	int code = rom[tile_index + 0x20000] + 256 * rom[tile_index];
 
 	SET_TILE_INFO(0, code & 0x1fff, code >> 13, 0);
@@ -35,7 +35,7 @@ static TILE_GET_INFO( prmrsocr_get_roz_tile_info )
 
 void mia_tile_callback( running_machine *machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	*flags = (*color & 0x04) ? TILE_FLIPX : 0;
 	if (layer == 0)
 	{
@@ -51,7 +51,7 @@ void mia_tile_callback( running_machine *machine, int layer, int bank, int *code
 
 void cuebrick_tile_callback( running_machine *machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	if ((k052109_get_rmrd_line(state->k052109) == CLEAR_LINE) && (layer == 0))
 	{
@@ -67,14 +67,14 @@ void cuebrick_tile_callback( running_machine *machine, int layer, int bank, int
 
 void tmnt_tile_callback( running_machine *machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	*code |= ((*color & 0x03) << 8) | ((*color & 0x10) << 6) | ((*color & 0x0c) << 9) | (bank << 13);
 	*color = state->layer_colorbase[layer] + ((*color & 0xe0) >> 5);
 }
 
 void ssbl_tile_callback( running_machine *machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	if (layer == 0)
 	{
 		*code |= ((*color & 0x03) << 8) | ((*color & 0x10) << 6) | ((*color & 0x0c) << 9) | (bank << 13);
@@ -90,7 +90,7 @@ void ssbl_tile_callback( running_machine *machine, int layer, int bank, int *cod
 
 void blswhstl_tile_callback( running_machine *machine, int layer, int bank, int *code, int *color, int *flags, int *priority )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	/* (color & 0x02) is flip y handled internally by the 052109 */
 	*code |= ((*color & 0x01) << 8) | ((*color & 0x10) << 5) | ((*color & 0x0c) << 8) | (bank << 12) | state->blswhstl_rombank << 14;
@@ -107,20 +107,20 @@ void blswhstl_tile_callback( running_machine *machine, int layer, int bank, int
 
 void mia_sprite_callback( running_machine *machine, int *code, int *color, int *priority, int *shadow )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	*color = state->sprite_colorbase + (*color & 0x0f);
 }
 
 void tmnt_sprite_callback( running_machine *machine, int *code, int *color, int *priority, int *shadow )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	*code |= (*color & 0x10) << 9;
 	*color = state->sprite_colorbase + (*color & 0x0f);
 }
 
 void punkshot_sprite_callback( running_machine *machine, int *code, int *color, int *priority_mask, int *shadow )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	int pri = 0x20 | ((*color & 0x60) >> 2);
 	if (pri <= state->layerpri[2])
 		*priority_mask = 0;
@@ -137,7 +137,7 @@ void punkshot_sprite_callback( running_machine *machine, int *code, int *color,
 
 void thndrx2_sprite_callback( running_machine *machine, int *code, int *color, int *priority_mask, int *shadow )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	int pri = 0x20 | ((*color & 0x60) >> 2);
 	if (pri <= state->layerpri[2])
 		*priority_mask = 0;
@@ -160,7 +160,7 @@ void thndrx2_sprite_callback( running_machine *machine, int *code, int *color, i
 
 void lgtnfght_sprite_callback( running_machine *machine, int *code, int *color, int *priority_mask )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	int pri = 0x20 | ((*color & 0x60) >> 2);
 	if (pri <= state->layerpri[2])
 		*priority_mask = 0;
@@ -176,7 +176,7 @@ void lgtnfght_sprite_callback( running_machine *machine, int *code, int *color,
 
 void blswhstl_sprite_callback( running_machine *machine, int *code, int *color, int *priority_mask )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 #if 0
 if (input_code_pressed(machine, KEYCODE_Q) && (*color & 0x20)) *color = rand();
 if (input_code_pressed(machine, KEYCODE_W) && (*color & 0x40)) *color = rand();
@@ -197,7 +197,7 @@ if (input_code_pressed(machine, KEYCODE_E) && (*color & 0x80)) *color = rand();
 
 void prmrsocr_sprite_callback( running_machine *machine, int *code, int *color, int *priority_mask )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	int pri = 0x20 | ((*color & 0x60) >> 2);
 	if (pri <= state->layerpri[2])
 		*priority_mask = 0;
@@ -223,7 +223,7 @@ void prmrsocr_sprite_callback( running_machine *machine, int *code, int *color,
 
 VIDEO_START( cuebrick )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	state->layer_colorbase[0] = 0;
 	state->layer_colorbase[1] = 32;
 	state->layer_colorbase[2] = 40;
@@ -232,7 +232,7 @@ VIDEO_START( cuebrick )
 
 VIDEO_START( mia )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	state->layer_colorbase[0] = 0;
 	state->layer_colorbase[1] = 32;
 	state->layer_colorbase[2] = 40;
@@ -244,7 +244,7 @@ VIDEO_START( mia )
 
 VIDEO_START( tmnt )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	state->layer_colorbase[0] = 0;
 	state->layer_colorbase[1] = 32;
 	state->layer_colorbase[2] = 40;
@@ -258,7 +258,7 @@ VIDEO_START( tmnt )
 
 VIDEO_START( lgtnfght )	/* also tmnt2, ssriders */
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	k05324x_set_z_rejection(state->k053245, 0);
 
@@ -272,7 +272,7 @@ VIDEO_START( lgtnfght )	/* also tmnt2, ssriders */
 
 VIDEO_START( glfgreat )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	state->roz_tilemap = tilemap_create(machine, glfgreat_get_roz_tile_info, tilemap_scan_rows, 16, 16, 512, 512);
 	tilemap_set_transparent_pen(state->roz_tilemap,0);
@@ -287,7 +287,7 @@ VIDEO_START( glfgreat )
 
 VIDEO_START( prmrsocr )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	state->roz_tilemap = tilemap_create(machine, prmrsocr_get_roz_tile_info, tilemap_scan_rows, 16, 16, 512, 256);
 	tilemap_set_transparent_pen(state->roz_tilemap,0);
@@ -300,7 +300,7 @@ VIDEO_START( prmrsocr )
 
 VIDEO_START( blswhstl )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 
 	state->blswhstl_rombank = -1;
 	state_save_register_global(machine, state->blswhstl_rombank);
@@ -326,7 +326,7 @@ WRITE16_HANDLER( tmnt_paletteram_word_w )
 
 WRITE16_HANDLER( tmnt_0a0000_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -352,7 +352,7 @@ WRITE16_HANDLER( tmnt_0a0000_w )
 
 WRITE16_HANDLER( punkshot_0a0020_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -372,7 +372,7 @@ WRITE16_HANDLER( punkshot_0a0020_w )
 
 WRITE16_HANDLER( lgtnfght_0a0018_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -393,7 +393,7 @@ WRITE16_HANDLER( lgtnfght_0a0018_w )
 
 WRITE16_HANDLER( blswhstl_700300_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -418,22 +418,22 @@ WRITE16_HANDLER( blswhstl_700300_w )
 
 READ16_HANDLER( glfgreat_rom_r )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (state->glfgreat_roz_rom_mode)
-		return memory_region(space->machine, "gfx3")[state->glfgreat_roz_char_bank * 0x80000 + offset];
+		return space->machine->region("gfx3")->base()[state->glfgreat_roz_char_bank * 0x80000 + offset];
 	else if (offset < 0x40000)
 	{
-		UINT8 *usr = memory_region(space->machine, "user1");
+		UINT8 *usr = space->machine->region("user1")->base();
 		return usr[offset + 0x80000 + state->glfgreat_roz_rom_bank * 0x40000] + 256 * usr[offset + state->glfgreat_roz_rom_bank * 0x40000];
 	}
 	else
-		return memory_region(space->machine, "user1")[((offset & 0x3ffff) >> 2) + 0x100000 + state->glfgreat_roz_rom_bank * 0x10000];
+		return space->machine->region("user1")->base()[((offset & 0x3ffff) >> 2) + 0x100000 + state->glfgreat_roz_rom_bank * 0x10000];
 }
 
 WRITE16_HANDLER( glfgreat_122000_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -466,7 +466,7 @@ WRITE16_HANDLER( glfgreat_122000_w )
 
 WRITE16_HANDLER( ssriders_eeprom_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -487,7 +487,7 @@ WRITE16_HANDLER( ssriders_eeprom_w )
 
 WRITE16_HANDLER( ssriders_1c0300_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -505,7 +505,7 @@ WRITE16_HANDLER( ssriders_1c0300_w )
 
 WRITE16_HANDLER( prmrsocr_122000_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -529,20 +529,20 @@ WRITE16_HANDLER( prmrsocr_122000_w )
 
 READ16_HANDLER( prmrsocr_rom_r )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if(state->glfgreat_roz_char_bank)
-		return memory_region(space->machine, "gfx3")[offset];
+		return space->machine->region("gfx3")->base()[offset];
 	else
 	{
-		UINT8 *usr = memory_region(space->machine, "user1");
+		UINT8 *usr = space->machine->region("user1")->base();
 		return 256 * usr[offset] + usr[offset + 0x020000];
 	}
 }
 
 WRITE16_HANDLER( tmnt_priority_w )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -578,7 +578,7 @@ WRITE16_HANDLER( tmnt_priority_w )
 
 VIDEO_UPDATE( mia )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 
 	k052109_tilemap_update(state->k052109);
 
@@ -593,7 +593,7 @@ VIDEO_UPDATE( mia )
 
 VIDEO_UPDATE( tmnt )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 
 	k052109_tilemap_update(state->k052109);
 
@@ -609,7 +609,7 @@ VIDEO_UPDATE( tmnt )
 
 VIDEO_UPDATE( punkshot )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 
 	state->sprite_colorbase = k053251_get_palette_index(state->k053251, K053251_CI1);
 	state->layer_colorbase[0] = k053251_get_palette_index(state->k053251, K053251_CI2);
@@ -639,7 +639,7 @@ VIDEO_UPDATE( punkshot )
 
 VIDEO_UPDATE( lgtnfght )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 	int bg_colorbase;
 
 	bg_colorbase = k053251_get_palette_index(state->k053251, K053251_CI0);
@@ -672,7 +672,7 @@ VIDEO_UPDATE( lgtnfght )
 
 READ16_HANDLER( glfgreat_ball_r )
 {
-	tmnt_state *state = (tmnt_state *)space->machine->driver_data;
+	tmnt_state *state = space->machine->driver_data<tmnt_state>();
 
 #ifdef MAME_DEBUG
 popmessage("%04x", state->glfgreat_pixel);
@@ -686,7 +686,7 @@ popmessage("%04x", state->glfgreat_pixel);
 
 VIDEO_UPDATE( glfgreat )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 	int bg_colorbase;
 
 	bg_colorbase = k053251_get_palette_index(state->k053251, K053251_CI0);
@@ -740,7 +740,7 @@ VIDEO_UPDATE( glfgreat )
 
 VIDEO_UPDATE( tmnt2 )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 	double brt;
 	int i, newdim, newen, cb, ce;
 
@@ -793,7 +793,7 @@ VIDEO_UPDATE( tmnt2 )
 
 VIDEO_UPDATE( thndrx2 )
 {
-	tmnt_state *state = (tmnt_state *)screen->machine->driver_data;
+	tmnt_state *state = screen->machine->driver_data<tmnt_state>();
 	int bg_colorbase;
 
 	bg_colorbase = k053251_get_palette_index(state->k053251, K053251_CI0);
@@ -833,6 +833,6 @@ VIDEO_UPDATE( thndrx2 )
 
 VIDEO_EOF( blswhstl )
 {
-	tmnt_state *state = (tmnt_state *)machine->driver_data;
+	tmnt_state *state = machine->driver_data<tmnt_state>();
 	k053245_clear_buffer(state->k053245);
 }
