@@ -1,5 +1,6 @@
 #include "emu.h"
 #include "video/taitoic.h"
+#include "includes/undrfire.h"
 
 UINT16 undrfire_rotate_ctrl[8];
 
@@ -77,7 +78,7 @@ Heavy use is made of sprite zooming.
 static void draw_sprites(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,const int *primasks,int x_offs,int y_offs)
 {
 	UINT32 *spriteram32 = machine->generic.spriteram.u32;
-	UINT16 *spritemap = (UINT16 *)memory_region(machine, "user1");
+	UINT16 *spritemap = (UINT16 *)machine->region("user1")->base();
 	int offs, data, tilenum, color, flipx, flipy;
 	int x, y, priority, dblsize, curx, cury;
 	int sprites_flipscreen = 0;
@@ -220,8 +221,8 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 static void draw_sprites_cbombers(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,const int *primasks,int x_offs,int y_offs)
 {
 	UINT32 *spriteram32 = machine->generic.spriteram.u32;
-	UINT16 *spritemap = (UINT16 *)memory_region(machine, "user1");
-	UINT8 *spritemapHibit = (UINT8 *)memory_region(machine, "user2");
+	UINT16 *spritemap = (UINT16 *)machine->region("user1")->base();
+	UINT8 *spritemapHibit = (UINT8 *)machine->region("user2")->base();
 
 	int offs, data, tilenum, color, flipx, flipy;
 	int x, y, priority, dblsize, curx, cury;
@@ -357,8 +358,8 @@ static void draw_sprites_cbombers(running_machine *machine, bitmap_t *bitmap,con
 
 VIDEO_UPDATE( undrfire )
 {
-	running_device *tc0100scn = screen->machine->device("tc0100scn");
-	running_device *tc0480scp = screen->machine->device("tc0480scp");
+	device_t *tc0100scn = screen->machine->device("tc0100scn");
+	device_t *tc0480scp = screen->machine->device("tc0480scp");
 	UINT8 layer[5];
 	UINT8 pivlayer[3];
 	UINT16 priority;
@@ -503,8 +504,8 @@ VIDEO_UPDATE( undrfire )
 
 VIDEO_UPDATE( cbombers )
 {
-	running_device *tc0100scn = screen->machine->device("tc0100scn");
-	running_device *tc0480scp = screen->machine->device("tc0480scp");
+	device_t *tc0100scn = screen->machine->device("tc0100scn");
+	device_t *tc0480scp = screen->machine->device("tc0480scp");
 	UINT8 layer[5];
 	UINT8 pivlayer[3];
 	UINT16 priority;
