@@ -9,6 +9,7 @@
 
 #include "emu.h"
 #include "video/konicdev.h"
+#include "includes/wecleman.h"
 
 #define BMP_PAD		8
 #define BLEND_STEPS	16
@@ -36,9 +37,6 @@ struct sprite
 	int shadow_mode, flags;
 };
 
-/* Variables defined in driver: */
-extern int wecleman_selected_ip, wecleman_irqctrl;
-
 /* Variables that driver has acces to: */
 UINT16 *wecleman_videostatus;
 UINT16 *wecleman_pageram, *wecleman_txtram, *wecleman_roadram;
@@ -97,8 +95,8 @@ static pen_t black_pen;
 static void get_sprite_info(running_machine *machine)
 {
 	const pen_t *base_pal = machine->pens;
-	UINT8 *base_gfx = memory_region(machine, "gfx1");
-	int gfx_max     = memory_region_length(machine, "gfx1");
+	UINT8 *base_gfx = machine->region("gfx1")->base();
+	int gfx_max     = machine->region("gfx1")->bytes();
 
 	UINT16 *source = machine->generic.spriteram.u16;
 
@@ -1125,8 +1123,8 @@ VIDEO_UPDATE ( wecleman )
 
 VIDEO_UPDATE( hotchase )
 {
-	running_device *k051316_1 = screen->machine->device("k051316_1");
-	running_device *k051316_2 = screen->machine->device("k051316_2");
+	device_t *k051316_1 = screen->machine->device("k051316_1");
+	device_t *k051316_2 = screen->machine->device("k051316_2");
 	int video_on;
 
 	video_on = wecleman_irqctrl & 0x40;
