@@ -36,6 +36,7 @@
 
 // MAMEOS headers
 #include "debugosx.h"
+#include "osdsdl.h"
 
 
 
@@ -63,19 +64,27 @@ static void console_create_window(running_machine *machine);
 
 
 //============================================================
-//  osd_wait_for_debugger
+//  sdl_osd_interface::init_debugger
 //============================================================
 
-void osd_wait_for_debugger(running_device *device, int firststop)
+void sdl_osd_interface::init_debugger()
+{
+}
+
+//============================================================
+//  sdl_osd_interface::wait_for_debugger
+//============================================================
+
+void sdl_osd_interface::wait_for_debugger(device_t &device, bool firststop)
 {
 	// create a console window
 	if (main_console == nil)
-		console_create_window(device->machine);
+		console_create_window(&machine());
 
 	// make sure the debug windows are visible
 	waiting_for_debugger = YES;
 	if (firststop) {
-		NSDictionary *info = [NSDictionary dictionaryWithObjectsAndKeys:[NSValue valueWithPointer:device],
+		NSDictionary *info = [NSDictionary dictionaryWithObjectsAndKeys:[NSValue valueWithPointer:&device],
 																		@"MAMEDebugDevice",
 																		nil];
 		[[NSNotificationCenter defaultCenter] postNotificationName:MAMEShowDebuggerNotification
@@ -340,7 +349,7 @@ void console_create_window(running_machine *machine)
 		return nil;
 	type = t;
 	machine = m;
-	view = machine->m_debug_view->alloc_view((debug_view_type)type, debugwin_view_update, self);
+	view = machine->debug_view().alloc_view((debug_view_type)type, debugwin_view_update, self);
 	if (view == nil) {
 		[self release];
 		return nil;
@@ -726,7 +735,7 @@ void console_create_window(running_machine *machine)
 
 - (NSSize)maximumFrameSize {
 	debug_view_xy				max;
-	running_device				*curcpu = debug_cpu_get_visible_cpu(machine);
+	device_t				*curcpu = debug_cpu_get_visible_cpu(machine);
 	const debug_view_source		*source = view->source_list().match_device(curcpu);
 
 	max.x = max.y = 0;
@@ -773,7 +782,7 @@ void console_create_window(running_machine *machine)
 }
 
 
-- (void)selectSubviewForCPU:(running_device *)device {
+- (void)selectSubviewForCPU:(device_t *)device {
 	const debug_view_source		*selected = view->source();
 	const debug_view_source		*source = view->source_list().match_device(device);
 	if ( selected != source ) {
@@ -878,7 +887,7 @@ void console_create_window(running_machine *machine)
 
 @implementation MAMEDisassemblyView
 
-- (device_debug::breakpoint *)findBreakpointAtAddress:(offs_t)address inAddressSpace:(const address_space *)space {
+- (device_debug::breakpoint *)findBreakpointAtAddress:(offs_t)address inAddressSpace:(address_space *)space {
 	device_debug			*cpuinfo = space->cpu->debug();
 	device_debug::breakpoint	*bp;
 	for (bp = cpuinfo->breakpoint_first(); (bp != NULL) && (address != bp->address()); bp = bp->next()) {}
@@ -1011,7 +1020,7 @@ void console_create_window(running_machine *machine)
 
 - (NSSize)maximumFrameSize {
 	debug_view_xy				max;
-	running_device				*curcpu = debug_cpu_get_visible_cpu(machine);
+	device_t				*curcpu = debug_cpu_get_visible_cpu(machine);
 	const debug_view_source		*source = view->source_list().match_device(curcpu);
 
 	max.x = max.y = 0;
@@ -1058,7 +1067,7 @@ void console_create_window(running_machine *machine)
 }
 
 
-- (void)selectSubviewForCPU:(running_device *)device {
+- (void)selectSubviewForCPU:(device_t *)device {
 	const debug_view_source     *selected = view->source();
 	const debug_view_source     *source = view->source_list().match_device(device);
 	if ( selected != source ) {
@@ -1081,7 +1090,7 @@ void console_create_window(running_machine *machine)
 
 - (IBAction)debugToggleBreakpoint:(id)sender {
 	if (view->cursor_visible()) {
-		const address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
+		address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
 		if (!useConsole || (debug_cpu_get_visible_cpu(machine) == space->cpu)) {
 			offs_t				address = downcast<debug_view_disasm *>(view)->selected_address();
 			device_debug::breakpoint *bp = [self findBreakpointAtAddress:address inAddressSpace:space];
@@ -1107,7 +1116,7 @@ void console_create_window(running_machine *machine)
 
 - (IBAction)debugToggleBreakpointEnable:(id)sender {
 	if (view->cursor_visible()) {
-		const address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
+		address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
 		if (!useConsole || (debug_cpu_get_visible_cpu(machine) == space->cpu)) {
 			offs_t				address = downcast<debug_view_disasm *>(view)->selected_address();
 			device_debug::breakpoint *bp = [self findBreakpointAtAddress:address inAddressSpace:space];
@@ -1131,11 +1140,11 @@ void console_create_window(running_machine *machine)
 
 - (IBAction)debugRunToCursor:(id)sender {
 	if (view->cursor_visible()) {
-		const address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
+		address_space *space = downcast<const debug_view_disasm_source *>(view->source())->space();
 		if (debug_cpu_get_visible_cpu(machine) == space->cpu) {
 			offs_t address = downcast<debug_view_disasm *>(view)->selected_address();
 			if (useConsole) {
-				NSString *command = [NSString stringWithFormat:@"go %lX", (unsigned long)address];
+				NSString *command = [NSString stringWithFormat:@"go 0x%lX", (unsigned long)address];
 				debug_console_execute_command(machine, [command UTF8String], 1);
 			} else {
 				debug_cpu_get_visible_cpu(machine)->debug()->go(address);
@@ -1249,7 +1258,7 @@ void console_create_window(running_machine *machine)
 
 - (NSSize)maximumFrameSize {
 	debug_view_xy				max;
-	running_device				*curcpu = debug_cpu_get_visible_cpu(machine);
+	device_t				*curcpu = debug_cpu_get_visible_cpu(machine);
 	const debug_view_source		*source = view->source_list().match_device(curcpu);
 
 
@@ -1283,7 +1292,7 @@ void console_create_window(running_machine *machine)
 }
 
 
-- (void)selectSubviewForCPU:(running_device *)device {
+- (void)selectSubviewForCPU:(device_t *)device {
 	//dv = get_view(dmain, DVT_STATE);
 	view->set_source(*view->source_list().match_device(device));
 }
@@ -1533,7 +1542,7 @@ void console_create_window(running_machine *machine)
 
 
 - (void)showDebugger:(NSNotification *)notification {
-	running_device *device = (running_device *) [[[notification userInfo] objectForKey:@"MAMEDebugDevice"] pointerValue];
+	device_t *device = (device_t *) [[[notification userInfo] objectForKey:@"MAMEDebugDevice"] pointerValue];
 	if (device->machine == machine) {
 		if (![window isVisible] && ![window isMiniaturized])
 			[window orderFront:self];
@@ -1733,7 +1742,7 @@ void console_create_window(running_machine *machine)
 }
 
 
-- (void)setCPU:(running_device *)device {
+- (void)setCPU:(device_t *)device {
 	[regView selectSubviewForCPU:device];
 	[dasmView selectSubviewForCPU:device];
 	[window setTitle:[NSString stringWithFormat:@"Debug: %s - %s '%s'",
@@ -1780,7 +1789,7 @@ void console_create_window(running_machine *machine)
 
 
 - (void)showDebugger:(NSNotification *)notification {
-	running_device *device = (running_device * )[[[notification userInfo] objectForKey:@"MAMEDebugDevice"] pointerValue];
+	device_t *device = (device_t * )[[[notification userInfo] objectForKey:@"MAMEDebugDevice"] pointerValue];
 	if (device->machine == machine) {
 		[self setCPU:device];
 		[window makeKeyAndOrderFront:self];
