@@ -13,6 +13,16 @@
 #include <SDL/SDL.h>
 #include <SDL/SDL_version.h>
 
+#ifdef SDLMAME_UNIX
+#ifndef SDLMAME_MACOSX
+#include <SDL/SDL_ttf.h>
+#include <fontconfig/fontconfig.h>
+#endif
+#ifdef SDLMAME_MACOSX
+#include <Carbon/Carbon.h>
+#endif
+#endif
+
 // standard includes
 #ifdef MESS
 #include <unistd.h>
@@ -94,7 +104,6 @@ static const options_entry mame_sdl_options[] =
 	{ SDLOPTION_MAXIMIZE ";max",              "1",        OPTION_BOOLEAN,    "default to maximized windows; otherwise, windows will be minimized" },
 	{ SDLOPTION_KEEPASPECT ";ka",             "1",        OPTION_BOOLEAN,    "constrain to the proper aspect ratio" },
 	{ SDLOPTION_UNEVENSTRETCH ";ues",         "1",        OPTION_BOOLEAN,    "allow non-integer stretch factors" },
-	{ SDLOPTION_EFFECT,                  SDLOPTVAL_NONE,  0,                 "name of a PNG file to use for visual effects, or 'none'" },
 	{ SDLOPTION_CENTERH,                      "1",        OPTION_BOOLEAN,    "center horizontally within the view area" },
 	{ SDLOPTION_CENTERV,                      "1",        OPTION_BOOLEAN,    "center vertically within the view area" },
 	#if (SDL_VERSION_ATLEAST(1,2,10))
@@ -281,6 +290,16 @@ int main(int argc, char *argv[])
 	setvbuf(stdout, (char *) NULL, _IONBF, 0);
 	setvbuf(stderr, (char *) NULL, _IONBF, 0);
 
+	#ifdef SDLMAME_UNIX
+	#ifndef SDLMAME_MACOSX
+	if (TTF_Init() == -1)
+	{
+		printf("SDL_ttf failed: %s\n", TTF_GetError());
+	}
+	FcInit();
+	#endif
+	#endif
+
 	#ifdef SDLMAME_OS2
 	MorphToPM();
 	#endif
@@ -304,7 +323,10 @@ int main(int argc, char *argv[])
 	}
 #endif
 
-	res = cli_execute(argc, argv, mame_sdl_options);
+	{
+		sdl_osd_interface osd;
+		res = cli_execute(argc, argv, osd, mame_sdl_options);
+	}
 
 #ifdef MALLOC_DEBUG
 	{
@@ -316,6 +338,13 @@ int main(int argc, char *argv[])
 	// already called...
 	//SDL_Quit();
 
+	#ifdef SDLMAME_UNIX
+	#ifndef SDLMAME_MACOSX
+	TTF_Quit();
+	FcFini();
+	#endif
+	#endif
+
 	exit(res);
 
 	return res;
@@ -334,11 +363,29 @@ static void output_oslog(running_machine &machine, const char *buffer)
 
 
 
+//============================================================
+//  constructor
+//============================================================
+
+sdl_osd_interface::sdl_osd_interface()
+{
+}
+
+
+//============================================================
+//  destructor
+//============================================================
+
+sdl_osd_interface::~sdl_osd_interface()
+{
+}
+
+
 //============================================================
 //  osd_exit
 //============================================================
 
-static void osd_exit(running_machine &machine)
+void sdl_osd_interface::osd_exit(running_machine &machine)
 {
 
 	if (!SDLMAME_INIT_IN_WORKER_THREAD)
@@ -463,22 +510,25 @@ static void osd_sdl_info(void)
 
 
 //============================================================
-//  osd_init
+//  init
 //============================================================
 
-void osd_init(running_machine *machine)
+void sdl_osd_interface::init(running_machine &machine)
 {
+	// call our parent
+	osd_interface::init(machine);
+
 	const char *stemp;
 
 	// Some driver options - must be before audio init!
-	stemp = options_get_string(machine->options(), SDLOPTION_AUDIODRIVER);
+	stemp = options_get_string(machine.options(), SDLOPTION_AUDIODRIVER);
 	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
 	{
 		mame_printf_verbose("Setting SDL audiodriver '%s' ...\n", stemp);
 		osd_setenv(SDLENV_AUDIODRIVER, stemp, 1);
 	}
 
-	stemp = options_get_string(machine->options(), SDLOPTION_VIDEODRIVER);
+	stemp = options_get_string(machine.options(), SDLOPTION_VIDEODRIVER);
 	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
 	{
 		mame_printf_verbose("Setting SDL videodriver '%s' ...\n", stemp);
@@ -487,7 +537,7 @@ void osd_init(running_machine *machine)
 
 	if (SDL_VERSION_ATLEAST(1,3,0))
 	{
-		stemp = options_get_string(machine->options(), SDLOPTION_RENDERDRIVER);
+		stemp = options_get_string(machine.options(), SDLOPTION_RENDERDRIVER);
 		if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
 		{
 			mame_printf_verbose("Setting SDL renderdriver '%s' ...\n", stemp);
@@ -500,7 +550,7 @@ void osd_init(running_machine *machine)
      */
 	/* FIXME: move lib loading code from drawogl.c here */
 
-	stemp = options_get_string(machine->options(), SDLOPTION_GL_LIB);
+	stemp = options_get_string(machine.options(), SDLOPTION_GL_LIB);
 	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
 	{
 		osd_setenv("SDL_VIDEO_GL_DRIVER", stemp, 1);
@@ -508,7 +558,7 @@ void osd_init(running_machine *machine)
 	}
 
 	/* get number of processors */
-	stemp = options_get_string(machine->options(), SDLOPTION_NUMPROCESSORS);
+	stemp = options_get_string(machine.options(), SDLOPTION_NUMPROCESSORS);
 
 	sdl_num_processors = 0;
 
@@ -537,35 +587,35 @@ void osd_init(running_machine *machine)
 		osd_sdl_info();
 	}
 	// must be before sdlvideo_init!
-	machine->add_notifier(MACHINE_NOTIFY_EXIT, osd_exit);
+	machine.add_notifier(MACHINE_NOTIFY_EXIT, osd_exit);
 
 	defines_verbose();
 
 	if (!SDLMAME_HAS_DEBUGGER)
-		if (machine->debug_flags & DEBUG_FLAG_OSD_ENABLED)
+		if (machine.debug_flags & DEBUG_FLAG_OSD_ENABLED)
 		{
 			mame_printf_error("sdlmame: -debug not supported on X11-less builds\n\n");
-			osd_exit(*machine);
+			osd_exit(machine);
 			exit(-1);
 		}
 
-	if (sdlvideo_init(machine))
+	if (sdlvideo_init(&machine))
 	{
-		osd_exit(*machine);
+		osd_exit(machine);
 		mame_printf_error("sdlvideo_init: Initialization failed!\n\n\n");
 		fflush(stderr);
 		fflush(stdout);
 		exit(-1);
 	}
 
-	sdlinput_init(machine);
+	sdlinput_init(&machine);
 
-	sdlaudio_init(machine);
+	sdlaudio_init(&machine);
 
-	sdloutput_init(machine);
+	sdloutput_init(&machine);
 
-	if (options_get_bool(machine->options(), SDLOPTION_OSLOG))
-		machine->add_logerror_callback(output_oslog);
+	if (options_get_bool(machine.options(), SDLOPTION_OSLOG))
+		machine.add_logerror_callback(output_oslog);
 
 #if (SDL_VERSION_ATLEAST(1,3,0))
 	SDL_EventState(SDL_TEXTINPUT, SDL_TRUE);
@@ -573,3 +623,438 @@ void osd_init(running_machine *machine)
 	SDL_EnableUNICODE(SDL_TRUE);
 #endif
 }
+
+#ifdef SDLMAME_UNIX
+#define POINT_SIZE 144.0
+
+#ifdef SDLMAME_MACOSX
+
+#define EXTRA_HEIGHT 1.0
+#define EXTRA_WIDTH 1.15
+
+//-------------------------------------------------
+//  font_open - attempt to "open" a handle to the
+//  font with the given name
+//-------------------------------------------------
+
+osd_font sdl_osd_interface::font_open(const char *_name, int &height)
+{
+	CFStringRef font_name = NULL;
+	CTFontRef ct_font = NULL;
+	CTFontDescriptorRef font_descriptor;
+	CGAffineTransform affine_transform = CGAffineTransformIdentity;
+
+	astring name(_name);
+
+	if (name == "default")
+	{
+		name = "LucidaGrande";
+	}
+
+	font_name = CFStringCreateWithCString( NULL, _name, kCFStringEncodingUTF8 );
+
+	if( font_name != NULL )
+	{
+      font_descriptor = CTFontDescriptorCreateWithNameAndSize( font_name, POINT_SIZE );
+
+      if( font_descriptor != NULL )
+      {
+         ct_font = CTFontCreateWithFontDescriptor( font_descriptor, POINT_SIZE, &affine_transform );
+
+         CFRelease( font_descriptor );
+      }
+   }
+
+   CFRelease( font_name );
+
+   if (!ct_font)
+	{
+		printf("WARNING: Couldn't find/open font %s, using MAME default\n", name.cstr());
+		return NULL;
+	}
+
+   CFStringRef real_name = CTFontCopyPostScriptName( ct_font );
+   char real_name_c_string[255];
+   CFStringGetCString ( real_name, real_name_c_string, 255, kCFStringEncodingUTF8 );
+   mame_printf_verbose("Matching font: %s\n", real_name_c_string);
+   CFRelease( real_name );
+
+   CGFloat line_height = 0.0;
+   line_height += CTFontGetAscent(ct_font);
+   line_height += CTFontGetDescent(ct_font);
+   line_height += CTFontGetLeading(ct_font);
+   height = ceilf(line_height * EXTRA_HEIGHT);
+
+   return (osd_font)ct_font;
+}
+
+//-------------------------------------------------
+//  font_close - release resources associated with
+//  a given OSD font
+//-------------------------------------------------
+
+void sdl_osd_interface::font_close(osd_font font)
+{
+   CTFontRef ct_font = (CTFontRef)font;
+
+   if( ct_font != NULL )
+   {
+      CFRelease( ct_font );
+   }
+}
+
+//-------------------------------------------------
+//  font_get_bitmap - allocate and populate a
+//  BITMAP_FORMAT_ARGB32 bitmap containing the
+//  pixel values MAKE_ARGB(0xff,0xff,0xff,0xff)
+//  or MAKE_ARGB(0x00,0xff,0xff,0xff) for each
+//  pixel of a black & white font
+//-------------------------------------------------
+
+bitmap_t *sdl_osd_interface::font_get_bitmap(osd_font font, unicode_char chnum, INT32 &width, INT32 &xoffs, INT32 &yoffs)
+{
+   UniChar uni_char;
+   CGGlyph glyph;
+   bitmap_t *bitmap = (bitmap_t *)NULL;
+   CTFontRef ct_font = (CTFontRef)font;
+   const CFIndex count = 1;
+   CGRect bounding_rect, success_rect;
+   CGContextRef context_ref;
+
+   if( chnum == ' ' )
+   {
+      uni_char = 'n';
+      CTFontGetGlyphsForCharacters( ct_font, &uni_char, &glyph, count );
+      success_rect = CTFontGetBoundingRectsForGlyphs( ct_font, kCTFontDefaultOrientation, &glyph, &bounding_rect, count );
+      uni_char = chnum;
+      CTFontGetGlyphsForCharacters( ct_font, &uni_char, &glyph, count );
+   }
+   else
+   {
+      uni_char = chnum;
+      CTFontGetGlyphsForCharacters( ct_font, &uni_char, &glyph, count );
+      success_rect = CTFontGetBoundingRectsForGlyphs( ct_font, kCTFontDefaultOrientation, &glyph, &bounding_rect, count );
+   }
+
+   if( CGRectEqualToRect( success_rect, CGRectNull ) == false )
+   {
+      size_t bitmap_width;
+      size_t bitmap_height;
+
+      bitmap_width = ceilf(bounding_rect.size.width * EXTRA_WIDTH);
+      bitmap_width = bitmap_width == 0 ? 1 : bitmap_width;
+
+      bitmap_height = ceilf( (CTFontGetAscent(ct_font) + CTFontGetDescent(ct_font) + CTFontGetLeading(ct_font)) * EXTRA_HEIGHT);
+
+      xoffs = yoffs = 0;
+      width = bitmap_width;
+
+      size_t bits_per_component;
+      CGColorSpaceRef color_space;
+      CGBitmapInfo bitmap_info = kCGBitmapByteOrder32Host | kCGImageAlphaPremultipliedFirst;
+
+      color_space = CGColorSpaceCreateDeviceRGB();
+      bits_per_component = 8;
+
+      bitmap = auto_alloc(&machine(), bitmap_t(bitmap_width, bitmap_height, BITMAP_FORMAT_ARGB32));
+
+      context_ref = CGBitmapContextCreate( bitmap->base, bitmap_width, bitmap_height, bits_per_component, bitmap->rowpixels*4, color_space, bitmap_info );
+
+      if( context_ref != NULL )
+      {
+         CGFontRef font_ref;
+         font_ref = CTFontCopyGraphicsFont( ct_font, NULL );
+         CGContextSetTextPosition(context_ref, -bounding_rect.origin.x*EXTRA_WIDTH, CTFontGetDescent(ct_font)+CTFontGetLeading(ct_font) );
+         CGContextSetRGBFillColor(context_ref, 1.0, 1.0, 1.0, 1.0);
+         CGContextSetFont( context_ref, font_ref );
+         CGContextSetFontSize( context_ref, POINT_SIZE );
+         CGContextShowGlyphs( context_ref, &glyph, count );
+         CGFontRelease( font_ref );
+         CGContextRelease( context_ref );
+      }
+
+      CGColorSpaceRelease( color_space );
+   }
+
+   return bitmap;
+}
+#else // UNIX but not OSX
+
+static TTF_Font *search_font_config(astring name, bool bold, bool italic, bool underline, bool &bakedstyles)
+{
+	TTF_Font *font = (TTF_Font *)NULL;
+	FcConfig *config;
+	FcPattern *pat;
+	FcObjectSet *os;
+	FcFontSet *fontset;
+	FcValue val;
+
+	config = FcConfigGetCurrent();
+	pat = FcPatternCreate();
+	os = FcObjectSetCreate();
+	FcPatternAddString(pat, FC_FAMILY, (const FcChar8 *)name.cstr());
+
+	// try and get a font with the requested styles baked-in
+	if (bold)
+	{
+		if (italic)
+		{
+			FcPatternAddString(pat, FC_STYLE, (const FcChar8 *)"Bold Italic");
+		}
+		else
+		{
+			FcPatternAddString(pat, FC_STYLE, (const FcChar8 *)"Bold");
+		}
+	}
+	else if (italic)
+	{
+		FcPatternAddString(pat, FC_STYLE, (const FcChar8 *)"Italic");
+	}
+	else
+	{
+		FcPatternAddString(pat, FC_STYLE, (const FcChar8 *)"Regular");
+	}
+
+	FcPatternAddString(pat, FC_FONTFORMAT, (const FcChar8 *)"TrueType");
+
+	FcObjectSetAdd(os, FC_FILE);
+	fontset = FcFontList(config, pat, os);
+
+	for (int i = 0; i < fontset->nfont; i++)
+	{
+		if (FcPatternGet(fontset->fonts[i], FC_FILE, 0, &val) != FcResultMatch)
+		{
+			continue;
+		}
+
+		if (val.type != FcTypeString)
+		{
+			continue;
+		}
+
+		mame_printf_verbose("Matching font: %s\n", val.u.s);
+		font = TTF_OpenFont((const char*)val.u.s, POINT_SIZE);
+
+		if (font)
+		{
+			bakedstyles = true;
+			break;
+		}
+	}
+
+	// didn't get a font above?  try again with no baked-in styles
+	if (!font)
+	{
+		FcPatternDestroy(pat);
+		FcFontSetDestroy(fontset);
+
+		pat = FcPatternCreate();
+		FcPatternAddString(pat, FC_FAMILY, (const FcChar8 *)name.cstr());
+		FcPatternAddString(pat, FC_STYLE, (const FcChar8 *)"Regular");
+		FcPatternAddString(pat, FC_FONTFORMAT, (const FcChar8 *)"TrueType");
+		fontset = FcFontList(config, pat, os);
+
+		for (int i = 0; i < fontset->nfont; i++)
+		{
+			if (FcPatternGet(fontset->fonts[i], FC_FILE, 0, &val) != FcResultMatch)
+			{
+				continue;
+			}
+
+			if (val.type != FcTypeString)
+			{
+				continue;
+			}
+
+			mame_printf_verbose("Matching unstyled font: %s\n", val.u.s);
+			font = TTF_OpenFont((const char*)val.u.s, POINT_SIZE);
+
+			if (font)
+			{
+				break;
+			}
+		}
+	}
+
+	FcPatternDestroy(pat);
+	FcObjectSetDestroy(os);
+	FcFontSetDestroy(fontset);
+	return font;
+}
+
+//-------------------------------------------------
+//  font_open - attempt to "open" a handle to the
+//  font with the given name
+//-------------------------------------------------
+
+osd_font sdl_osd_interface::font_open(const char *_name, int &height)
+{
+	TTF_Font *font = (TTF_Font *)NULL;
+	bool bakedstyles = false;
+	int style = 0;
+
+	// accept qualifiers from the name
+	astring name(_name);
+
+	if (name == "default")
+	{
+		name = "Liberation Sans";
+	}
+
+	bool bold = (name.replace(0, "[B]", "") + name.replace(0, "[b]", "") > 0);
+	bool italic = (name.replace(0, "[I]", "") + name.replace(0, "[i]", "") > 0);
+	bool underline = (name.replace(0, "[U]", "") + name.replace(0, "[u]", "") > 0);
+	bool strike = (name.replace(0, "[S]", "") + name.replace(0, "[s]", "") > 0);
+
+	// first up, try it as a filename
+	font = TTF_OpenFont(name.cstr(), POINT_SIZE);
+
+	// if no success, try the font path
+
+	if (!font)
+	{
+		mame_file *t;
+
+		mame_printf_verbose("Searching font %s in -%s\n", name.cstr(), SEARCHPATH_FONT);
+		if (mame_fopen(SEARCHPATH_FONT, name.cstr(), OPEN_FLAG_READ, &t) == FILERR_NONE)
+		{
+			astring full_name = mame_file_full_name(t);
+			mame_fclose(t);
+			font = TTF_OpenFont(full_name.cstr(), POINT_SIZE);
+			if (font)
+				mame_printf_verbose("Found font %s\n", full_name.cstr());
+		}
+	}
+
+	// if that didn't work, crank up the FontConfig database
+	if (!font)
+	{
+		font = search_font_config(name, bold, italic, underline, bakedstyles);
+	}
+
+	if (!font)
+	{
+		printf("WARNING: Couldn't find/open TrueType font %s, using MAME default\n", name.cstr());
+		return NULL;
+	}
+
+	// apply styles
+	if (!bakedstyles)
+	{
+		style |= bold ? TTF_STYLE_BOLD : 0;
+		style |= italic ? TTF_STYLE_ITALIC : 0;
+	}
+	style |= underline ? TTF_STYLE_UNDERLINE : 0;
+	// SDL_ttf 2.0.9 and earlier does not define TTF_STYLE_STRIKETHROUGH
+#if SDL_VERSIONNUM(TTF_MAJOR_VERSION, TTF_MINOR_VERSION, TTF_PATCHLEVEL) > SDL_VERSIONNUM(2,0,9)
+	style |= strike ? TTF_STYLE_STRIKETHROUGH : 0;
+#else
+	if (strike)
+		mame_printf_warning("Ignoring strikethrough for SDL_TTF with version less 2.0.10\n");
+#endif // PATCHLEVEL
+	TTF_SetFontStyle(font, style);
+
+	height = TTF_FontLineSkip(font);
+
+	return (osd_font)font;
+}
+
+//-------------------------------------------------
+//  font_close - release resources associated with
+//  a given OSD font
+//-------------------------------------------------
+
+void sdl_osd_interface::font_close(osd_font font)
+{
+	TTF_Font *ttffont;
+
+	ttffont = (TTF_Font *)font;
+
+	TTF_CloseFont(ttffont);
+}
+
+//-------------------------------------------------
+//  font_get_bitmap - allocate and populate a
+//  BITMAP_FORMAT_ARGB32 bitmap containing the
+//  pixel values MAKE_ARGB(0xff,0xff,0xff,0xff)
+//  or MAKE_ARGB(0x00,0xff,0xff,0xff) for each
+//  pixel of a black & white font
+//-------------------------------------------------
+
+bitmap_t *sdl_osd_interface::font_get_bitmap(osd_font font, unicode_char chnum, INT32 &width, INT32 &xoffs, INT32 &yoffs)
+{
+	TTF_Font *ttffont;
+	bitmap_t *bitmap = (bitmap_t *)NULL;
+	SDL_Surface *drawsurf;
+	SDL_Color fcol = { 0xff, 0xff, 0xff };
+	UINT16 ustr[16];
+
+	ttffont = (TTF_Font *)font;
+
+	memset(ustr,0,sizeof(ustr));
+	ustr[0] = (UINT16)chnum;
+	drawsurf = TTF_RenderUNICODE_Solid(ttffont, ustr, fcol);
+
+	// was nothing returned?
+	if (drawsurf)
+	{
+		// allocate a MAME destination bitmap
+		bitmap = auto_alloc(&machine(), bitmap_t(drawsurf->w, drawsurf->h, BITMAP_FORMAT_ARGB32));
+
+		// copy the rendered character image into it
+		for (int y = 0; y < bitmap->height; y++)
+		{
+			UINT32 *dstrow = BITMAP_ADDR32(bitmap, y, 0);
+			UINT8 *srcrow = (UINT8 *)drawsurf->pixels;
+
+			srcrow += (y * drawsurf->pitch);
+
+			for (int x = 0; x < drawsurf->w; x++)
+			{
+				dstrow[x] = srcrow[x] ? MAKE_ARGB(0xff,0xff,0xff,0xff) : MAKE_ARGB(0x00,0xff,0xff,0xff);
+			}
+		}
+
+		// what are these?
+		xoffs = yoffs = 0;
+		width = drawsurf->w;
+
+		SDL_FreeSurface(drawsurf);
+	}
+
+	return bitmap;
+}
+#endif	// not OSX
+#else	// not UNIX
+//-------------------------------------------------
+//  font_open - attempt to "open" a handle to the
+//  font with the given name
+//-------------------------------------------------
+
+osd_font sdl_osd_interface::font_open(const char *_name, int &height)
+{
+	return (osd_font)NULL;
+}
+
+//-------------------------------------------------
+//  font_close - release resources associated with
+//  a given OSD font
+//-------------------------------------------------
+
+void sdl_osd_interface::font_close(osd_font font)
+{
+}
+
+//-------------------------------------------------
+//  font_get_bitmap - allocate and populate a
+//  BITMAP_FORMAT_ARGB32 bitmap containing the
+//  pixel values MAKE_ARGB(0xff,0xff,0xff,0xff)
+//  or MAKE_ARGB(0x00,0xff,0xff,0xff) for each
+//  pixel of a black & white font
+//-------------------------------------------------
+
+bitmap_t *sdl_osd_interface::font_get_bitmap(osd_font font, unicode_char chnum, INT32 &width, INT32 &xoffs, INT32 &yoffs)
+{
+	return (bitmap_t *)NULL;
+}
+#endif
