@@ -51,6 +51,7 @@
 // MAME headers
 #include "emu.h"
 #include "uiinput.h"
+#include "debugger.h"
 #include "debug/debugvw.h"
 #include "debug/dvdisasm.h"
 #include "debug/dvmemory.h"
@@ -58,7 +59,6 @@
 #include "debug/debugvw.h"
 #include "debug/debugcon.h"
 #include "debug/debugcpu.h"
-#include "debugger.h"
 
 // MAMEOS headers
 #include "debugwin.h"
@@ -95,7 +95,7 @@
 #define EDIT_BOX_STYLE_EX		0
 
 // combo box styles
-#define COMBO_BOX_STYLE			WS_CHILD | WS_VISIBLE | CBS_DROPDOWNLIST
+#define COMBO_BOX_STYLE			WS_CHILD | WS_VISIBLE | CBS_DROPDOWNLIST | WS_VSCROLL
 #define COMBO_BOX_STYLE_EX		0
 
 // horizontal scroll bar styles
@@ -250,7 +250,7 @@ static void disasm_update_caption(running_machine *machine, HWND wnd);
 static void console_create_window(running_machine *machine);
 static void console_recompute_children(debugwin_info *info);
 static void console_process_string(debugwin_info *info, const char *string);
-static void console_set_cpu(running_device *device);
+static void console_set_cpu(device_t *device);
 
 static HMENU create_standard_menubar(void);
 static int global_handle_command(debugwin_info *info, WPARAM wparam, LPARAM lparam);
@@ -262,20 +262,20 @@ static void smart_show_all(BOOL show);
 
 
 //============================================================
-//  osd_wait_for_debugger
+//  wait_for_debugger
 //============================================================
 
-void osd_wait_for_debugger(running_device *device, int firststop)
+void windows_osd_interface::wait_for_debugger(device_t &device, bool firststop)
 {
 	MSG message;
 
 	// create a console window
 	if (main_console == NULL)
-		console_create_window(device->machine);
+		console_create_window(&machine());
 
 	// update the views in the console to reflect the current CPU
 	if (main_console != NULL)
-		console_set_cpu(device);
+		console_set_cpu(&device);
 
 	// when we are first stopped, adjust focus to us
 	if (firststop && main_console != NULL)
@@ -290,7 +290,7 @@ void osd_wait_for_debugger(running_device *device, int firststop)
 	smart_show_all(TRUE);
 
 	// run input polling to ensure that our status is in sync
-	wininput_poll(device->machine);
+	wininput_poll(&machine());
 
 	// get and process messages
 	GetMessage(&message, NULL, 0, 0);
@@ -308,7 +308,7 @@ void osd_wait_for_debugger(running_device *device, int firststop)
 
 		// process everything else
 		default:
-			winwindow_dispatch_message(device->machine, &message);
+			winwindow_dispatch_message(&machine(), &message);
 			break;
 	}
 
@@ -598,7 +598,7 @@ static void debugwin_window_free(debugwin_info *info)
 	for (viewnum = 0; viewnum < ARRAY_LENGTH(info->view); viewnum++)
 		if (info->view[viewnum].view != NULL)
 		{
-			info->machine->m_debug_view->free_view(*info->view[viewnum].view);
+			info->machine->debug_view().free_view(*info->view[viewnum].view);
 			info->view[viewnum].view = NULL;
 		}
 
@@ -842,7 +842,7 @@ static int debugwin_view_create(debugwin_info *info, int which, debug_view_type
 		goto cleanup;
 
 	// create the debug view
-	view->view = info->machine->m_debug_view->alloc_view(type, debugwin_view_update, view);
+	view->view = info->machine->debug_view().alloc_view(type, debugwin_view_update, view);
 	if (view->view == NULL)
 		goto cleanup;
 
@@ -850,7 +850,7 @@ static int debugwin_view_create(debugwin_info *info, int which, debug_view_type
 
 cleanup:
 	if (view->view)
-		info->machine->m_debug_view->free_view(*view->view);
+		info->machine->debug_view().free_view(*view->view);
 	if (view->hscroll)
 		DestroyWindow(view->hscroll);
 	if (view->vscroll)
@@ -1459,7 +1459,7 @@ static LRESULT CALLBACK debugwin_view_proc(HWND wnd, UINT message, WPARAM wparam
 			debug_view_xy topleft = info->view->visible_position();
 			topleft.x = debugwin_view_process_scroll(info, LOWORD(wparam), (HWND)lparam);
 			info->view->set_visible_position(topleft);
-			info->owner->machine->m_debug_view->flush_osd_updates();
+			info->owner->machine->debug_view().flush_osd_updates();
 			break;
 		}
 
@@ -1469,7 +1469,7 @@ static LRESULT CALLBACK debugwin_view_proc(HWND wnd, UINT message, WPARAM wparam
 			debug_view_xy topleft = info->view->visible_position();
 			topleft.y = debugwin_view_process_scroll(info, LOWORD(wparam), (HWND)lparam);
 			info->view->set_visible_position(topleft);
-			info->owner->machine->m_debug_view->flush_osd_updates();
+			info->owner->machine->debug_view().flush_osd_updates();
 			break;
 		}
 
@@ -1723,7 +1723,7 @@ static void log_create_window(running_machine *machine)
 
 static void memory_create_window(running_machine *machine)
 {
-	running_device *curcpu = debug_cpu_get_visible_cpu(machine);
+	device_t *curcpu = debug_cpu_get_visible_cpu(machine);
 	debugwin_info *info;
 	HMENU optionsmenu;
 
@@ -1775,14 +1775,19 @@ static void memory_create_window(running_machine *machine)
 	SendMessage(info->otherwnd[0], WM_SETFONT, (WPARAM)debug_font, (LPARAM)FALSE);
 
 	// populate the combobox
+	int maxlength = 0;
 	for (const debug_view_source *source = info->view[0].view->source_list().head(); source != NULL; source = source->next())
 	{
+		int length = strlen(source->name());
+		if (length > maxlength)
+			maxlength = length;
 		TCHAR *t_name = tstring_from_utf8(source->name());
 		SendMessage(info->otherwnd[0], CB_ADDSTRING, 0, (LPARAM)t_name);
 		osd_free(t_name);
 	}
 	const debug_view_source *source = info->view[0].view->source_list().match_device(curcpu);
 	SendMessage(info->otherwnd[0], CB_SETCURSEL, info->view[0].view->source_list().index(*source), 0);
+	SendMessage(info->otherwnd[0], CB_SETDROPPEDWIDTH, (maxlength + 2) * debug_font_width + vscroll_width, 0);
 	info->view[0].view->set_source(*source);
 
 	// set the child functions
@@ -2035,7 +2040,7 @@ static void memory_update_caption(running_machine *machine, HWND wnd)
 
 static void disasm_create_window(running_machine *machine)
 {
-	running_device *curcpu = debug_cpu_get_visible_cpu(machine);
+	device_t *curcpu = debug_cpu_get_visible_cpu(machine);
 	debugwin_info *info;
 	HMENU optionsmenu;
 
@@ -2081,14 +2086,19 @@ static void disasm_create_window(running_machine *machine)
 	SendMessage(info->otherwnd[0], WM_SETFONT, (WPARAM)debug_font, (LPARAM)FALSE);
 
 	// populate the combobox
+	int maxlength = 0;
 	for (const debug_view_source *source = info->view[0].view->source_list().head(); source != NULL; source = source->next())
 	{
+		int length = strlen(source->name());
+		if (length > maxlength)
+			maxlength = length;
 		TCHAR *t_name = tstring_from_utf8(source->name());
 		SendMessage(info->otherwnd[0], CB_ADDSTRING, 0, (LPARAM)t_name);
 		osd_free(t_name);
 	}
 	const debug_view_source *source = info->view[0].view->source_list().match_device(curcpu);
 	SendMessage(info->otherwnd[0], CB_SETCURSEL, info->view[0].view->source_list().index(*source), 0);
+	SendMessage(info->otherwnd[0], CB_SETDROPPEDWIDTH, (maxlength + 2) * debug_font_width + vscroll_width, 0);
 	info->view[0].view->set_source(*source);
 
 	// set the child functions
@@ -2242,7 +2252,7 @@ static int disasm_handle_command(debugwin_info *info, WPARAM wparam, LPARAM lpar
 					if (dasmview->cursor_visible() && debug_cpu_get_visible_cpu(info->machine) == dasmview->source()->device())
 					{
 						offs_t address = dasmview->selected_address();
-						sprintf(command, "go %X", address);
+						sprintf(command, "go 0x%X", address);
 						debug_console_execute_command(info->machine, command, 1);
 					}
 					return 1;
@@ -2465,11 +2475,11 @@ void console_create_window(running_machine *machine)
 
 cleanup:
 	if (info->view[2].view)
-		machine->m_debug_view->free_view(*info->view[2].view);
+		machine->debug_view().free_view(*info->view[2].view);
 	if (info->view[1].view)
-		machine->m_debug_view->free_view(*info->view[1].view);
+		machine->debug_view().free_view(*info->view[1].view);
 	if (info->view[0].view)
-		machine->m_debug_view->free_view(*info->view[0].view);
+		machine->debug_view().free_view(*info->view[0].view);
 }
 
 
@@ -2549,7 +2559,7 @@ static void console_process_string(debugwin_info *info, const char *string)
 //  console_set_cpu
 //============================================================
 
-static void console_set_cpu(running_device *device)
+static void console_set_cpu(device_t *device)
 {
 	// first set all the views to the new cpu number
 	main_console->view[0].view->set_source(*main_console->view[0].view->source_list().match_device(device));
